Index: debian-faq/Makefile
===================================================================
--- debian-faq/Makefile	(Revision 11722)
+++ debian-faq/Makefile	(Arbeitskopie)
@@ -14,7 +14,7 @@
 
 sources := $(manual).sgml faqstatic.ent faqdynamic.ent $(wildcard *.sgml)
 
-polangs = de fr it ja ru
+polangs = de fr it ja nl ru
 langs ?=  pt_BR pl es uk zh_CN $(polangs)
 pofiles := $(foreach lang, $(polangs), po4a/po/$(lang).po)
 
Index: debian-faq/debian/README.devel
===================================================================
--- debian-faq/debian/README.devel	(Revision 11722)
+++ debian-faq/debian/README.devel	(Arbeitskopie)
@@ -48,6 +48,8 @@
     last change of doc-debian-fr: FrÃ©dÃ©ric Bothamy <frederic.bothamy@free.fr>,
     Nov 2006. this does NOT include the Debian GNU/Linux FAQ (see #311825))
 
+** nl    (new translation, 2017-10-12,
+         by Frans Spiesschaert <Frans.Spiesschaert@yucom.be>).
 
 these are maintained in packages by others:
 ------------------------------------------
Index: debian-faq/debian/changelog
===================================================================
--- debian-faq/debian/changelog	(Revision 11722)
+++ debian-faq/debian/changelog	(Arbeitskopie)
@@ -1,6 +1,8 @@
 debian-faq (8.2.FIXME) UNRELEASED; urgency=medium
 
   * UNRELEASED
+  * 2017-11-12: Add Dutch translation by Frans Spiesschaert
+
   [ Joost van Baal-IliÄ ]
   * debian/changelog: update old changelog entries 5.0.2+nmu1 and 8.1
     (Closes: #762167, #806994)
Index: debian-faq/debian/control
===================================================================
--- debian-faq/debian/control	(Revision 11722)
+++ debian-faq/debian/control	(Arbeitskopie)
@@ -98,6 +98,25 @@
  the package debian-faq.)
 
 
+Package: debian-faq-nl
+Priority: optional
+Architecture: all
+Suggests: www-browser, postscript-viewer
+Depends: ${misc:Depends}
+Description: Debian Frequently Asked Questions, in Dutch
+ In this package you will find the Debian GNU/Linux FAQ, which gives
+ frequently asked questions (with their answers!) about the Debian distribution
+ (Debian GNU/Linux and others) and about the Debian project.
+ Some answers assume some knowledge of Unix-like operating systems.
+ However, as little prior knowledge as possible is assumed: answers to general
+ beginners questions will be kept simple.
+ .
+ The document is supplied in HTML, PDF, PostScript and plain text.
+ .
+ This is the translation in Dutch of the original English FAQ (available in
+ the package debian-faq.)
+
+
 Package: debian-faq-ru
 Priority: optional
 Architecture: all
Index: debian-faq/debian/debian-faq-nl.dirs
===================================================================
--- debian-faq/debian/debian-faq-nl.dirs	(nicht existent)
+++ debian-faq/debian/debian-faq-nl.dirs	(Arbeitskopie)
@@ -0,0 +1 @@
+usr/share/doc/debian/FAQ/nl
Index: debian-faq/debian/debian-faq-nl.doc-base
===================================================================
--- debian-faq/debian/debian-faq-nl.doc-base	(nicht existent)
+++ debian-faq/debian/debian-faq-nl.doc-base	(Arbeitskopie)
@@ -0,0 +1,20 @@
+Document: debian-faq-nl
+Title: Debian FAQ, in Dutch
+Author: Ray Dassen, Javier Fernandez-Sanguino, Susan G. Kleinmann,
+ Josip Rodin, Sven Rudolph, Chuck Stickelman, Santiago Vila e.a.
+Abstract: This document answers questions frequently asked about Debian
+ GNU/Linux.
+Section: Debian
+
+Format: HTML
+Index: /usr/share/doc/debian/FAQ/nl/index.nl.html
+Files: /usr/share/doc/debian/FAQ/nl/*.html
+
+Format: text
+Files: /usr/share/doc/debian/FAQ/debian-faq.nl.txt.gz
+
+Format: PostScript
+Files: /usr/share/doc/debian/FAQ/debian-faq.nl.ps.gz
+
+Format: PDF
+Files: /usr/share/doc/debian/FAQ/debian-faq.nl.pdf.gz
Index: debian-faq/debian/debian-faq-nl.install
===================================================================
--- debian-faq/debian/debian-faq-nl.install	(nicht existent)
+++ debian-faq/debian/debian-faq-nl.install	(Arbeitskopie)
@@ -0,0 +1,2 @@
+usr/share/doc/debian/FAQ/nl
+usr/share/doc/debian/FAQ/debian-faq.nl.*
Index: debian-faq/debian/rules
===================================================================
--- debian-faq/debian/rules	(Revision 11722)
+++ debian-faq/debian/rules	(Arbeitskopie)
@@ -6,7 +6,7 @@
 basedir = $(CURDIR)/debian/debian-faq
 installdir = $(basedir)/usr/share/doc/debian
 
-langs = de fr it ru zh_CN
+langs = de fr it nl ru zh_CN
 
 build: build-arch build-indep
 build-arch: stamp-build
Index: debian-faq/nl/Makefile
===================================================================
--- debian-faq/nl/Makefile	(nicht existent)
+++ debian-faq/nl/Makefile	(Arbeitskopie)
@@ -0,0 +1,63 @@
+#
+# Makefile for the Debian FAQ
+#
+# Should work both for a manual in the Debian Documentation Project
+# manuals.sgml tree, and for doc-debian package build.
+
+manual := debian-faq
+
+currentlang := $(notdir $(CURDIR))
+currentlangcn := $(subst _,-,$(shell echo $(currentlang) | tr A-Z a-z))
+
+# this can and will be overriden by a higher level makefile
+PUBLISHDIR := /org/www.debian.org/www/doc/manuals
+
+sources := $(manual).sgml faqstatic.ent ../faqdynamic.ent $(wildcard *.sgml)
+
+export LANG=C
+# stupid debiandoc stuff uses strings in another language otherwise
+
+all: html text ps pdf
+
+publish: all
+	test -d $(PUBLISHDIR)/$(manual) || install -d -m 755 $(PUBLISHDIR)/$(manual)
+	rm -f $(PUBLISHDIR)/$(manual)/*.$(currentlangcn).html
+	install -p -m 644 $(manual).$(currentlang).html/*.html $(PUBLISHDIR)/$(manual)
+	install -p -m 644 $(manual)*.txt $(manual)*.ps $(manual)*.pdf $(PUBLISHDIR)/$(manual)
+
+faqstatic.ent:
+	ln -sf ../$@ .
+
+../faqdynamic.ent:
+	cd .. && $(MAKE) faqdynamic.ent
+
+validate:
+	nsgmls -ges -wall $(manual).sgml
+
+html: $(manual).$(currentlang).html/index.$(currentlangcn).html
+$(manual).$(currentlang).html/index.$(currentlangcn).html: $(sources)
+	rm -rf $(manual).html $(manual).$(currentlang).html
+	debiandoc2html -C -l $(currentlang).UTF-8 $<
+	mv $(manual).html $(manual).$(currentlang).html
+
+text: $(manual).$(currentlang).txt
+$(manual).$(currentlang).txt: $(sources)
+	debiandoc2text -l $(currentlang).UTF-8 $<
+	mv $(manual).txt $(manual).$(currentlang).txt
+
+$(manual).$(currentlang).info: $(sources)
+	debiandoc2info -l $(currentlang).UTF-8 $<
+# TODO: rename to .$(currentlang).info?
+
+$(manual).$(currentlang).ps $(manual).$(currentlang).dvi $(manual).$(currentlang).pdf: \
+  $(manual).$(currentlang).%: $(sources)
+	debiandoc2latex$* -l $(currentlang).UTF-8 $<
+	mv $(manual).$* $(manual).$(currentlang).$*
+
+ps dvi pdf info: %: $(manual).$(currentlang).%
+
+clean distclean:
+	$(MAKE) -f ../Makefile currentlang=$(currentlang) cleanup
+	rm -f $(manual)*.sgml
+
+.PHONY: all publish clean distclean validate
Index: debian-faq/nl/README.translators
===================================================================
--- debian-faq/nl/README.translators	(nicht existent)
+++ debian-faq/nl/README.translators	(Arbeitskopie)
@@ -0,0 +1 @@
+Dutch translation managed by po4a under po4a/po/nl.po
Index: debian-faq/po4a/po/nl.po
===================================================================
--- debian-faq/po4a/po/nl.po	(nicht existent)
+++ debian-faq/po4a/po/nl.po	(Arbeitskopie)
@@ -0,0 +1,9839 @@
+# Dutch translation of the Debian FAQ. 
+# Copyright (C) YEAR Free Software Foundation, Inc.
+# This file is distributed under the same license as the debian-faq package.
+# Frans Spiesschaert <Frans.Spiesschaert@yucom.be>, 2017.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: debian-faq_8.1_\n"
+"POT-Creation-Date: 2017-10-21 13:12+0200\n"
+"PO-Revision-Date: 2017-11-13 14:37+0100\n"
+"Last-Translator: Frans Spiesschaert <Frans.Spiesschaert@yucom.be>\n"
+"Language-Team: Debian Dutch l10n Team <debian-l10n-dutch@lists.debian.org>\n"
+"Language: nl\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Generator: Gtranslator 2.91.7\n"
+
+#. type: definition of entity &debian;
+#, no-wrap
+msgid "Debian GNU/Linux"
+msgstr "Debian GNU/Linux"
+
+#. type: definition of entity &release;
+#, no-wrap
+msgid "8"
+msgstr "8"
+
+#. type: definition of entity &releasename;
+#, no-wrap
+msgid "jessie"
+msgstr "jessie"
+
+#. type: definition of entity &oldreleasename;
+#, no-wrap
+msgid "wheezy"
+msgstr "wheezy"
+
+#. type: definition of entity &testingreleasename;
+#, no-wrap
+msgid "stretch"
+msgstr "stretch"
+
+#. type: definition of entity &developers;
+#, no-wrap
+msgid "1033"
+msgstr "1033"
+
+#. type: definition of entity &all-pkgs;
+#, no-wrap
+msgid "42551"
+msgstr "42551"
+
+#. type: definition of entity &main-pkgs;
+#, no-wrap
+msgid "42304"
+msgstr "42304"
+
+#. type: definition of entity &contrib-nonfree-pkgs;
+#, no-wrap
+msgid "696"
+msgstr "696"
+
+#. type: definition of entity &archs;
+#, no-wrap
+msgid "10"
+msgstr "10"
+
+#. type: definition of entity &debian-donation;
+#, no-wrap
+msgid "http://www.debian.org/donations"
+msgstr "http://www.debian.org/donations"
+
+#. type: definition of entity &debian-help;
+#, no-wrap
+msgid "http://www.debian.org/intro/help"
+msgstr "http://www.debian.org/intro/help"
+
+#. type: definition of entity &docdate;
+#, no-wrap
+msgid "4 December 2016"
+msgstr "4 december 2016"
+
+#. type: definition of entity &docversion;
+#, no-wrap
+msgid "8.1"
+msgstr "8.1"
+
+#. type: <title></title>
+#: debian-faq.sgml:11
+msgid "The &debian; FAQ"
+msgstr "De &debian; FAQ"
+
+#. type: <author></author>
+#: debian-faq.sgml:12
+msgid ""
+"<name>Authors are listed at <qref id=\"authors\">Debian FAQ Authors</qref></"
+"name>"
+msgstr ""
+"<name>De auteurs worden vermeld in <qref id=\"authors\">Auteurs van de "
+"Debian FAQ</qref></name>"
+
+#. type: <version></version>
+#: debian-faq.sgml:13
+msgid "version &docversion;, &docdate;"
+msgstr "versie &docversion;, &docdate;"
+
+#. type: <abstract></abstract>
+#: debian-faq.sgml:14
+msgid "This document answers questions frequently asked about &debian;."
+msgstr "Dit document geeft antwoorden op veel gestelde vragen over &debian;."
+
+#. type: <copyrightsummary></copyrightsummary>
+#: debian-faq.sgml:19
+msgid ""
+"Copyright &copy; 1996-2016 by Software in the Public Interest, portions "
+"copyright &copy; 2004, 2005, 2006 Kamaraju Kusumanchi"
+msgstr ""
+"Copyright &copy; 1996-2016, Software in the Public Interest. Gedeelten: "
+"copyright &copy; 2004, 2005, 2006, Kamaraju Kusumanchi"
+
+#. type: <p></p>
+#: debian-faq.sgml:25
+msgid ""
+"Permission is granted to make and distribute verbatim copies of this "
+"document provided the copyright notice and this permission notice are "
+"preserved on all copies."
+msgstr ""
+"Er wordt toestemming verleend om van dit document letterlijke kopieÃ«n te "
+"maken en deze te verspreiden op voorwaarde dat de copyright-vermelding en de "
+"vermelding van deze toestemming op elke kopie behouden wordt."
+
+#. type: <p></p>
+#: debian-faq.sgml:30
+msgid ""
+"Permission is granted to copy and distribute modified versions of this "
+"document under the conditions for verbatim copying, provided that the entire "
+"resulting derived work is distributed under the terms of a permission notice "
+"identical to this one."
+msgstr ""
+"Er wordt toestemming verleend om gewijzigde versies van dit document te "
+"kopiÃ«ren en te verspreiden onder dezelfde voorwaarden als die voor "
+"letterlijke kopieÃ«n, op voorwaarde dat het volledige afgeleide werk dat "
+"daardoor ontstaat, verspreid wordt onder de termen van een kennisgeving "
+"waarin een identieke toestemming als deze verleend wordt."
+
+#. type: <p></p>
+#: debian-faq.sgml:35
+msgid ""
+"Permission is granted to copy and distribute translations of this document "
+"into another language, under the above conditions for modified versions, "
+"except that this permission notice may be included in translations approved "
+"by the Free Software Foundation instead of in the original English."
+msgstr ""
+"Er wordt toestemming verleend om vertalingen van dit document in een andere "
+"taal te kopiÃ«ren en te verspreiden onder de hierboven vermelde voorwaarden "
+"voor gewijzigde versies, behalve dat de kennisgeving van deze toestemming in "
+"een door de Free Software Foundation goedgekeurde vertaling mag gebeuren in "
+"plaats van in de originele Engelse versie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:42 basic_defs.sgml:5
+msgid "Definitions and overview"
+msgstr "Definities en overzicht"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:42 basic_defs.sgml:7
+msgid "What is this FAQ?"
+msgstr "Wat is deze FAQ?"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:15
+msgid ""
+"This document gives frequently asked questions (with their answers!) about "
+"the Debian distribution (&debian; and others) and about the Debian project. "
+"If applicable, pointers to other documentation will be given: we won't quote "
+"large parts of external documentation in this document. You'll find out that "
+"some answers assume some knowledge of Unix-like operating systems. We'll try "
+"to assume as little prior knowledge as possible: answers to general "
+"beginners questions will be kept simple."
+msgstr ""
+"Dit document bevat vaak gestelde vragen (en de antwoorden erop!) over de "
+"Debian-distributie (&debian; en andere) en over het Debian project. Waar dit "
+"van toepassing is wordt verwezen naar andere documentatie: in dit document "
+"zullen we geen uitgebreide citaten uit externe documenten opnemen. U zult "
+"merken dat sommige antwoorden enige kennis van Unix-achtige "
+"besturingssystemen veronderstellen. We zullen trachten uit te gaan van zo "
+"weinig mogelijk voorkennis: antwoorden op algemene beginnersvragen zullen "
+"eenvoudig gehouden worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:19
+msgid ""
+"If you can't find what you're looking for in this FAQ, be sure to check out "
+"<ref id=\"debiandocs\">. If even that doesn't help, refer to <ref id="
+"\"feedback\">."
+msgstr ""
+"Indien u in deze FAQ niet kunt vinden waar u naar op zoek bent, raadpleeg "
+"dan <ref id=\"debiandocs\">. Indien zelfs dat geen oplossing biedt, wendt u "
+"dan tot <ref id=\"feedback\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:42 basic_defs.sgml:21
+msgid "What is &debian;?"
+msgstr "Wat is &debian;?"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:24
+msgid ""
+"&debian; is a particular <em>distribution</em> of the Linux operating "
+"system, and numerous packages that run on it."
+msgstr ""
+"&debian; is een specifieke <em>distributie</em> van het Linux "
+"besturingssysteem met talloze pakketten die erop werken."
+
+#. type: <p><list>
+#: debian-faq.sgml:42 basic_defs.sgml:25
+msgid "&debian; is:"
+msgstr "&debian; is:"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:32
+msgid ""
+"<strong>full featured</strong>: Debian includes more than &all-pkgs; "
+"software packages at present. Users can select which packages to install; "
+"Debian provides a tool for this purpose. You can find a list and "
+"descriptions of the packages currently available in Debian at any of the "
+"Debian <url id=\"http://www.debian.org/distrib/ftplist\" name=\"mirror sites"
+"\">."
+msgstr ""
+"<strong>volledig functioneel</strong>: Debian bevat momenteel meer dan &all-"
+"pkgs; softwarepakketten. Gebruikers kunnen kiezen welke pakketten "
+"geÃ¯nstalleerd worden. Debian stelt hiervoor een hulpmiddel ter beschikking. "
+"U vindt een lijst en een beschrijving van de momenteel in Debian beschikbare "
+"pakketten op alle Debian <url id=\"http://www.debian.org/distrib/ftplist\" "
+"name=\"mirror sites\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:38
+msgid ""
+"<strong>free to use and redistribute</strong>: There is no consortium "
+"membership or payment required to participate in its distribution and "
+"development. All packages that are formally part of &debian; are free to "
+"redistribute, usually under terms specified by the GNU General Public "
+"License."
+msgstr ""
+"<strong>vrij te gebruiken en te verspreiden</strong>: Geen lidmaatschap van "
+"een consortium of betaling zijn vereist om te participeren in de "
+"ontwikkeling en verspreiding ervan. Alle pakketten die officieel deel "
+"uitmaken van &debian; kunnen vrij verspreid worden, meestal onder de "
+"voorwaarden van de GNU General Public License (GNU algemene publieke "
+"licentie)."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:42
+msgid ""
+"The Debian FTP archives also carry approximately &contrib-nonfree-pkgs; "
+"software packages (in the <tt>non-free</tt> and <tt>contrib</tt> sections), "
+"which are distributable under specific terms included with each package."
+msgstr ""
+"De Debian FTP-archieven bevatten ook ongeveer &contrib-nonfree-pkgs; "
+"softwarepakketten (in de secties <tt>non-free</tt> en <tt>contrib</tt>) die "
+"verspreid kunnen worden onder specifieke voorwaarden die bij elk pakket "
+"ingesloten zijn."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:45
+msgid ""
+"<strong>dynamic</strong>: With about &developers; volunteers constantly "
+"contributing new and improved code, Debian is evolving rapidly. The FTP "
+"archives are updated twice every day."
+msgstr ""
+"<strong>dynamisch</strong>: Met zijn ongeveer &developers; vrijwilligers die "
+"voortdurend nieuwe en verbeterde code aandragen, evolueert Debian snel. De "
+"FTP-archieven worden dagelijks tweemaal bijgewerkt."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:60
+msgid ""
+"Most Linux users run a specific <em>distribution</em> of Linux, like "
+"&debian;. However, in principle, users could obtain the Linux kernel via the "
+"Internet or from elsewhere, and compile it themselves. They could then "
+"obtain source code for many applications in the same way, compile the "
+"programs, then install them into their systems. For complicated programs, "
+"this process can be not only time-consuming but error-prone. To avoid it, "
+"users often choose to obtain the operating system and the application "
+"packages from one of the Linux distributors. What distinguishes the various "
+"Linux distributors are the software, protocols, and practices they use for "
+"packaging, installing, and tracking applications packages on users' systems, "
+"combined with installation and maintenance tools, documentation, and other "
+"services."
+msgstr ""
+"De meeste Linux-gebruikers maken gebruik van een specifieke <em>distributie</"
+"em> van Linux, zoals &debian;. In principe zouden gebruikers via het "
+"internet of op een andere manier de Linux kernel kunnen ophalen en die zelf "
+"compileren. Op dezelfde manier zouden ze voor veel toepassingen broncode "
+"kunnen bekomen en zelf de programma's compileren en ze nadien op hun systeem "
+"installeren. Voor ingewikkelde programma's kan dit niet enkel een tijdrovend "
+"maar ook foutgevoelig proces zijn. Om dit te vermijden kiezen gebruikers er "
+"vaak voor om het besturingssysteem en de pakketten met toepassingssoftware "
+"van een van de Linux-distributeurs te gebruiken. Wat de verschillende Linux-"
+"distributeurs van elkaar onderscheidt is de software, de protocollen en "
+"werkwijzen die ze gebruiken voor het verpakken, installeren en opvolgen van "
+"toepassingspakketten op de systemen van de gebruiker, samen met hulpmiddelen "
+"voor installatie en onderhoud, documentatie en andere diensten."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:66
+msgid ""
+"&debian; is the result of a volunteer effort to create a free, high-quality "
+"Unix-compatible operating system, complete with a suite of applications. The "
+"idea of a free Unix-like system originates from the GNU project, and many of "
+"the applications that make &debian; so useful were developed by the GNU "
+"project."
+msgstr ""
+"&debian; is het resultaat van het streven van vrijwilligers om een vrij Unix-"
+"achtig besturingssysteem van hoge kwaliteit te maken, samen met een geheel "
+"van toepassingen. Het idee van een vrij Unix-achtig  besturingssysteem is "
+"afkomstig van het GNU-project en veel van de toepassingen die &debian; zo "
+"bruikbaar maken werden door het GNU project ontwikkeld."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:74
+msgid ""
+"For Debian, free has the GNUish meaning (see the <url id=\"http://www.debian."
+"org/social_contract#guidelines\" name=\"Debian Free Software Guidelines\">). "
+"When we speak of free software, we are referring to freedom, not price. Free "
+"software means that you have the freedom to distribute copies of free "
+"software, that you receive source code or can get it if you want it, that "
+"you can change the software or use pieces of it in new free programs; and "
+"that you know you can do these things."
+msgstr ""
+"Voor Debian heeft vrij de GNU-achtige betekenis (zie de <url id=\"http://www."
+"debian.org/social_contract#guidelines\" name=\"Debian Free Software "
+"Guidelines\">). Als we over vrije software spreken, hebben we het over "
+"vrijheid, niet kosteloosheid. Vrije software wil zeggen dat u vrij bent "
+"kopieÃ«n van vrije software te verspreiden, dat u broncode ontvangt of ze kan "
+"bekomen als u dat wenst, dat u de software kunt wijzigen of stukken ervan in "
+"nieuwe vrije programma's kunt gebruiken en dat u weet dat u deze dingen kunt "
+"doen."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:78
+msgid ""
+"The Debian Project was created by Ian Murdock in 1993, initially under the "
+"sponsorship of the Free Software Foundation's GNU project. Today, Debian's "
+"developers think of it as a direct descendent of the GNU project."
+msgstr ""
+"Het Debian-project werd in 1993 door Ian Murdock opgestart, in het begin "
+"gesponsord door het GNU project van de Free Software Foundation. Vandaag "
+"beschouwen de ontwikkelaars van Debian het als een rechtstreekse "
+"afstammeling van het GNU-project."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:85
+msgid ""
+"Although &debian; itself is free software, it is a base upon which value-"
+"added Linux distributions can be built. By providing a reliable, full-"
+"featured base system, Debian provides Linux users with increased "
+"compatibility, and allows Linux distribution creators to eliminate "
+"duplication of effort and focus on the things that make their distribution "
+"special. See <ref id=\"childistro\"> for more information."
+msgstr ""
+"Hoewel &debian; zelf vrije software is, is het een basis waarop Linux-"
+"distributies met toegevoegde waarde gebouwd kunnen worden. Door een "
+"betrouwbaar volwaardig basissysteem ter beschikking te stellen, verschaft "
+"Debian Linuxgebruikers een verhoogde compatibiliteit en laat het makers van "
+"een Linux-distributie toe om dubbel werk te vermijden en zich te focussen op "
+"die dingen die hun distributie bijzonder maken. Zie <ref id=\"childistro\"> "
+"voor bijkomende informatie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:42 basic_defs.sgml:87
+msgid "OK, now I know what Debian is... what is Linux?!"
+msgstr "OK, nu ik weet wat Debian is... wat is Linux?!"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:92
+msgid ""
+"In short, Linux is the kernel of a Unix-like operating system. It was "
+"originally designed for 386 (and better) PCs; today Linux also runs on a "
+"dozen of other systems. Linux is written by Linus Torvalds and many computer "
+"scientists around the world."
+msgstr ""
+"Om kort te gaan, Linux is de kernel van een Unix-achtig besturingssysteem. "
+"Oorspronkelijk werd hij ontworpen voor 386 (en snellere) PC's. Tegenwoordig "
+"functioneert Linux ook op een dozijn andere systemen. Linux werd geschreven "
+"door Linus Torvalds en veel computerwetenschappers van over de hele wereld."
+
+#. type: <p><list>
+#: debian-faq.sgml:42 basic_defs.sgml:93
+msgid "Besides its kernel, a \"Linux\" system usually has:"
+msgstr "Behalve de kernel bevat een \"Linux\"-systeem gewoonlijk:"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:95
+msgid ""
+"a file system that follows the Linux Filesystem Hierarchy Standard <url id="
+"\"http://www.pathname.com/fhs/\">."
+msgstr ""
+"een bestandssysteem dat beantwoord aan de Linux Filesystem Hierarchy "
+"Standard (de standaardisatie van de directory-structuur) <url id=\"http://"
+"www.pathname.com/fhs/\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:98
+msgid ""
+"a wide range of Unix utilities, many of which have been developed by the GNU "
+"project and the Free Software Foundation."
+msgstr ""
+"een hele waaier Unix hulpprogramma's. Vele ervan werden ontwikkeld door het "
+"GNU project en de Free Software Foundation."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:104
+msgid ""
+"The combination of the Linux kernel, the file system, the GNU and FSF "
+"utilities, and the other utilities are designed to achieve compliance with "
+"the POSIX (IEEE 1003.1) standard; see <ref id=\"otherunices\">."
+msgstr ""
+"Het geheel van de Linux kernel, het bestandssysteem, de GNU en FSF "
+"hulpprogramma's en de overige hulpprogramma's werd ontworpen om in "
+"overeenstemming te zijn met de POSIX (IEEE 1003.1) standaard; zie <ref id="
+"\"otherunices\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:107
+msgid ""
+"For more information about Linux, see <url id=\"http://www.linux.org/info/\" "
+"name=\"What is Linux\"> by <url id=\"http://www.linux.org/\" name=\"Linux "
+"Online\">."
+msgstr ""
+"Zie voor bijkomende informatie over Linux <url id=\"http://www.linux.org/"
+"info/\" name=\"What is Linux\"> van <url id=\"http://www.linux.org/\" name="
+"\"Linux Online\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:42 basic_defs.sgml:109
+msgid "Does Debian just do GNU/Linux?"
+msgstr "Maakt Debian alleen maar GNU/Linux?"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:114
+msgid ""
+"Currently, Debian is only available for Linux, but with Debian GNU/Hurd and "
+"Debian on BSD kernels, we have started to offer non-Linux-based OSes as a "
+"development, server and desktop platform, too. However, these non-linux "
+"ports are not officially released yet."
+msgstr ""
+"Momenteel is Debian enkel beschikbaar voor Linux. Maar met Debian GNU/Hurd "
+"en Debian op BSD kernels, zijn we ook begonnen met het aanbieden van niet op "
+"Linux gebaseerde besturingssystemen als ontwikkelaars-, server- en "
+"desktopplatform. Deze zogenaamde niet-linux \"ports\" zijn echter nog niet "
+"officieel uitgebracht."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:116
+msgid "The oldest porting effort is Debian GNU/Hurd."
+msgstr ""
+"Het oudste streven om Debian geschikt te maken voor andere architecturen "
+"(waar het Engelse begrip \"port\" naar verwijst) is Debian GNU/Hurd."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:119
+msgid ""
+"The Hurd is a set of servers running on top of the GNU Mach microkernel. "
+"Together they build the base for the GNU operating system."
+msgstr ""
+"De Hurd is een geheel van servers die bovenop de GNU Mach microkernel "
+"functioneren. Samen vormen ze de basis voor het GNU besturingssysteem."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:123
+msgid ""
+"Please see <url id=\"http://www.gnu.org/software/hurd/\"> for more "
+"information about the GNU/Hurd in general, and <url id=\"http://www.debian."
+"org/ports/hurd/\"> for more information about Debian GNU/Hurd."
+msgstr ""
+"Raadpleeg <url id=\"http://www.gnu.org/software/hurd/\"> voor bijkomende "
+"informatie over de GNU/Hurd in het algemeen en <url id=\"http://www.debian."
+"org/ports/hurd/\"> voor meer informatie overDebian GNU/Hurd."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:126
+msgid ""
+"A second effort is the port to a BSD kernel. People are working with the "
+"FreeBSD kernel."
+msgstr ""
+"Een andere poging is de aanpassing aan een BSD kernel. De betrokkenen werken "
+"met de FreeBSD kernel."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:129
+msgid ""
+"See <url id=\"http://www.debian.org/ports/#nonlinux\"> for more information "
+"about these non-linux ports."
+msgstr ""
+"Raadpleeg <url id=\"http://www.debian.org/ports/#nonlinux\"> voor bijkomende "
+"informatie over deze niet-linux \"ports\"."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:42 basic_defs.sgml:133
+msgid ""
+"What is the difference between &debian; and other Linux distributions? Why "
+"should I choose Debian over some other distribution?"
+msgstr ""
+"Wat is het verschil tussen &debian; en andere Linux distributies? Waarom zou "
+"ik Debian moeten verkiezen boven een bepaalde andere distributie?"
+
+#. type: <p><taglist>
+#: debian-faq.sgml:42 basic_defs.sgml:135
+msgid "These key features distinguish Debian from other Linux distributions:"
+msgstr "Deze kernaspecten onderscheiden Debian van andere Linux distributies:"
+
+#. type: <tag></tag>
+#: debian-faq.sgml:42 basic_defs.sgml:137
+msgid "Freedom:"
+msgstr "Vrijheid:"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:146
+msgid ""
+"As stated in the <url id=\"http://www.debian.org/social_contract\" name="
+"\"Debian Social Contract\">, Debian will remain 100% free. Debian is very "
+"strict about shipping truly free software. The guidelines used to determine "
+"if a work is \"free\" are provided in <url id=\"http://www.debian.org/"
+"social_contract#guidelines\" name=\"The Debian Free Software Guidelines "
+"(DFSG)\">."
+msgstr ""
+"Zoals bepaald in het <url id=\"http://www.debian.org/social_contract\" name="
+"\"Debian Social Contract\">, zal Debian 100% vrij blijven. Debian is zeer "
+"strikt inzake het aanleveren van echt vrije software. De richtlijnen om uit "
+"te maken of een werk \"vrij\" is, staan vermeld in <url id=\"http://www."
+"debian.org/social_contract#guidelines\" name=\"The Debian Free Software "
+"Guidelines (DFSG)\">."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:42 basic_defs.sgml:146
+msgid "The Debian package maintenance system:"
+msgstr "Het systeem van Debian voor pakketonderhoud:"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:156
+msgid ""
+"The entire system, or any individual component of it, can be upgraded in "
+"place without reformatting, without losing custom configuration files, and "
+"(in most cases) without rebooting the system. Most Linux distributions "
+"available today have some kind of package maintenance system; the Debian "
+"package maintenance system is unique and particularly robust (see <ref id="
+"\"pkg_basics\">)."
+msgstr ""
+"Het volledige systeem en elke individuele component ervan kunnen bijgewerkt "
+"worden terwijl het functioneert, zonder herformattering en zonder verlies "
+"van lokaal aangepaste configuratiebestanden en (in de meeste gevallen) "
+"zonder dat het systeem herstart wordt. De meeste Linux distributies die "
+"tegenwoordig beschikbaar zijn hebben een vorm van pakketonderhoud. Het "
+"systeem van pakketonderhoud van Debian is uniek en bijzonder robuust (zie "
+"<ref id=\"pkg_basics\">)."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:42 basic_defs.sgml:156
+msgid "Open development:"
+msgstr "Open ontwikkeling:"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:162
+msgid ""
+"Whereas many other Linux distributions are developed by individuals, small, "
+"closed groups, or commercial vendors, Debian is a major Linux distribution "
+"that is being developed by an association of individuals who have made "
+"common cause to create a free operating system, in the same spirit as Linux "
+"and other free software."
+msgstr ""
+"Terwijl veel andere Linux distributies ontwikkeld worden door individuen, "
+"kleine gesloten groepen of commerciÃ«le bedrijven, is Debian een belangrijke "
+"Linux distributie die ontwikkeld wordt door een vereniging van individuen "
+"die zich gezamenlijk tot doel hebben gesteld om een vrij besturingssysteem "
+"te maken in dezelfde geest als Linux en andere vrije software."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:171
+msgid ""
+"More than &developers; volunteer package maintainers are working on over "
+"&all-pkgs; packages and improving &debian;. The Debian developers contribute "
+"to the project not by writing new applications (in most cases), but by "
+"packaging existing software according to the standards of the project, by "
+"communicating bug reports to upstream developers, and by providing user "
+"support. See also additional information on how to become a contributor in "
+"<ref id=\"contrib\">."
+msgstr ""
+"Meer dan &developers; vrijwillige pakketonderhouders werken aan meer dan "
+"&all-pkgs; pakketten en aan het beter maken van &debian;. De ontwikkelaars "
+"van Debian dragen bij tot het project (in de meeste gevallen) niet door het "
+"schrijven van nieuwe toepassingen, maar door het verpakken van bestaande "
+"software volgens de standaarden van het project, door probleemrapporten over "
+"te maken aan de ontwikkelaars van die software en door het geven ven "
+"gebruikersondersteuning. Raadpleeg ook de bijkomende informatie over hoe u "
+"zelf kunt beginnen bijdragen in <ref id=\"contrib\">."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:42 basic_defs.sgml:171
+msgid "The Universal Operating System:"
+msgstr "Het universele besturingssysteem:"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:180
+msgid ""
+"Debian comes with <url id=\"http://packages.debian.org/stable/\" name=\"more "
+"than &all-pkgs; packages\"> and runs on <url id=\"http://www.debian.org/"
+"ports/\" name=\"&archs; architectures\">. This is far more than is available "
+"for any other GNU/Linux distribution. See <ref id=\"apps\"> for an overview "
+"of the provided software and see <ref id=\"arches\"> for a description of "
+"the supported hardware platforms."
+msgstr ""
+"Debian bevat <url id=\"http://packages.debian.org/stable/\" name=\"meer dan "
+"&all-pkgs; pakketten\"> en functioneert op <url id=\"http://www.debian.org/"
+"ports/\" name=\"&archs; architecturen\">. Dit is veel meer dan wat om het "
+"even welke andere GNU/Linux te bieden heeft. Zie <ref id=\"apps\"> voor een "
+"overzicht van de beschikbare software en <ref id=\"arches\"> voor een "
+"beschrijving van de ondersteunde hardware-platformen."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:42 basic_defs.sgml:180
+msgid "The Bug Tracking System:"
+msgstr "Het bugopvolgingssysteem:"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:196
+msgid ""
+"The geographical dispersion of the Debian developers required sophisticated "
+"tools and quick communication of bugs and bug-fixes to accelerate the "
+"development of the system. Users are encouraged to send bugs in a formal "
+"style, which are quickly accessible by WWW archives or via e-mail. See "
+"additional information in this FAQ on the management of the bug log in <ref "
+"id=\"buglogs\">."
+msgstr ""
+"De geografische spreiding van de ontwikkelaars van Debian vereiste "
+"gesofisticeerde instrumenten en snelle communicatie over bugs en "
+"bugreparaties om de ontwikkeling van het systeem te versnellen. Gebruikers "
+"worden aangemoedigd om bugs te signaleren in een formele stijl waardoor ze "
+"snel toegankelijk worden via WWW-archieven en via e-mail. U vindt in deze "
+"FAQ bijkomende informatie over het beheer van de buglog in <ref id=\"buglogs"
+"\">."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:42 basic_defs.sgml:196
+msgid "The Debian Policy:"
+msgstr "De Debian-beleidslijn:"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:200
+msgid ""
+"Debian has an extensive specification of our standards of quality, the "
+"Debian Policy. This document defines the qualities and standards to which we "
+"hold Debian packages."
+msgstr ""
+"Debian heeft zijn kwaliteitsstandaarden uitgebreid gespecificeerd in 'the "
+"Debian Policy' (de Debian-beleidslijn). Dit document definieert de "
+"kwaliteiten en de standaarden waaraan Debian pakketten moeten beantwoorden."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:205
+msgid ""
+"For additional information about this, please see our web page about <url id="
+"\"http://www.debian.org/intro/why_debian\" name=\"reasons to choose Debian"
+"\">."
+msgstr ""
+"Voor bijkomende informatie hierover kunt u onze webpagina over <url id="
+"\"http://www.debian.org/intro/why_debian\" name=\"reasons to choose Debian"
+"\"> raadplegen."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:42 basic_defs.sgml:208
+msgid ""
+"How does the Debian project fit in or compare with the Free Software "
+"Foundation's GNU project?"
+msgstr ""
+"Hoe past het Debian-project zich in het GNU project van de Free Software "
+"Foundation in of hoe staat het ertegenover?"
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:214
+msgid ""
+"The Debian system builds on the ideals of free software first championed by "
+"the <url id=\"http://www.gnu.org/\" name=\"Free Software Foundation\"> and "
+"in particular by <url id=\"http://www.stallman.org/\" name=\"Richard Stallman"
+"\">. FSF's powerful system development tools, utilities, and applications "
+"are also a key part of the Debian system."
+msgstr ""
+"Het Debian-systeem steunt op de idealen van vrije software waarvan de <url "
+"id=\"http://www.gnu.org/\" name=\"Free Software Foundation\"> en in het "
+"bijzonder <url id=\"http://www.stallman.org/\" name=\"Richard Stallman\"> de "
+"eerste voorvechters waren. Ook het krachtige systeemontwikkelingsgereedschap "
+"van de FSF en hun hulpprogramma's en toepassingen maken wezenlijk deel uit "
+"van het Debian-systeem."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:219
+msgid ""
+"The Debian Project is a separate entity from the FSF, however we communicate "
+"regularly and cooperate on various projects. The FSF explicitly requested "
+"that we call our system \"&debian;\", and we are happy to comply with that "
+"request."
+msgstr ""
+"Het Debian-project en de FSF zijn twee aparte entiteiten, maar we "
+"communiceren geregeld en werken op verschillende projecten samen. De FSF "
+"heeft expliciet gevraagd dat we ons systeem \"&debian;\" zouden heten en we "
+"voldoen graag aan dit verzoek."
+
+#. type: <p></p>
+#: debian-faq.sgml:42 basic_defs.sgml:224
+msgid ""
+"The FSF's long-standing objective is to develop a new operating system "
+"called GNU, based on <url id=\"http://www.gnu.org/software/hurd/\" name="
+"\"Hurd\">. Debian is working with FSF on this system, called <url id="
+"\"http://www.debian.org/ports/hurd/\" name=\"Debian GNU/Hurd\">."
+msgstr ""
+"De langetermijndoelstelling van de FSF is een nieuw besturingssysteem, GNU "
+"genaamd, te ontwikkelen, gebaseerd op <url id=\"http://www.gnu.org/software/"
+"hurd/\" name=\"Hurd\">. Debian werkt met de FSF samen aan dit systeem onder "
+"de naam <url id=\"http://www.debian.org/ports/hurd/\" name=\"Debian GNU/Hurd"
+"\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:42 basic_defs.sgml:227
+msgid "How does one pronounce Debian and what does this word mean?"
+msgstr "Hoe spreekt men het woord Debian uit en wat betekent het?"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:3
+msgid ""
+"The project name is pronounced Deb'-ee-en, with a short e in Deb, and "
+"emphasis on the first syllable. This word is a contraction of the names of "
+"Debra and Ian Murdock, who founded the project. (Dictionaries seem to offer "
+"some ambiguity in the pronunciation of Ian (!), but Ian prefers ee'-en.)"
+msgstr ""
+"De naam van het project wordt Deb'-ie-en, met een korte e in Deb en een "
+"doffe e in en, en met de klemtoon op de eerste lettergreep. Het woord is een "
+"samentrekking van de namen van Debra en Ian Murdock, de stichters van het "
+"project. (Woordenboeken zijn wat dubbelzinnig over de uitspraak van Ian (!), "
+"maar Ian verkiest ie'-en.)"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:43 getting.sgml:5
+msgid "Getting and installing &debian;"
+msgstr "&debian; verkrijgen en installeren"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:10
+msgid ""
+"The official document giving installation instructions is the <url id="
+"\"http://www.debian.org/releases/stable/installmanual\" name=\"Debian GNU/"
+"Linux Installation Guide\">. We'll give some additional notes about getting "
+"and installing &debian; here."
+msgstr ""
+"Het officiÃ«le document voor installatie-instructies is de <url id=\"http://"
+"www.debian.org/releases/stable/installmanual\" name=\"Debian GNU/Linux "
+"Installation Guide\">. Hier zullen we wat bijkomende informatie geven over "
+"het verkrijgen en installeren van &debian;."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:43 getting.sgml:12
+msgid "What is the latest version of Debian?"
+msgstr "Wat is de recentste versie van Debian?"
+
+#. type: <p><taglist>
+#: debian-faq.sgml:43 getting.sgml:13
+msgid "Currently there are three versions of &debian;:"
+msgstr "Momenteel bestaan er drie versies van &debian;:"
+
+#. type: <tag></tag>
+#: debian-faq.sgml:43 getting.sgml:14
+msgid ""
+"<em>release &release;, a.k.a. the `stable' distribution or &releasename;</em>"
+msgstr ""
+"<em>release &release;, ook wel de `stable' of `stabiele' distributie of "
+"&releasename;</em>"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:16
+msgid ""
+"This is stable and well tested software, it changes if major security or "
+"usability fixes are incorporated."
+msgstr ""
+"Dit is stabiele en grondig geteste software. Ze wordt aangepast bij het "
+"inpassen van reparaties van belangrijke beveiligings- of "
+"functioneringsproblemen."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:43 getting.sgml:17
+msgid ""
+"<em>the `testing' distribution, currently called &testingreleasename;</em>"
+msgstr ""
+"<em> de distributie 'testing', de testdistributie, die momenteel "
+"&testingreleasename; heet.</em>"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:21
+msgid ""
+"This is where packages that will be released as the next `stable' are "
+"placed; they've had some testing in unstable but they may not be completely "
+"fit for release yet. This distribution is updated more often than `stable', "
+"but not more often than `unstable'."
+msgstr ""
+"Hierin worden de pakketten geplaatst die als de volgende `stable' release "
+"uitgebracht zullen worden. Ze werden wat uitgetest in de distributie "
+"`unstable', de onstabiele distributie, maar zijn misschien nog niet volledig "
+"geschikt om uitgebracht te worden. Deze distributie wordt veel vaker "
+"bijgewerkt dan `stable', maar niet vaker dan `unstable'."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:43 getting.sgml:22
+msgid "<em>the `unstable' distribution</em>"
+msgstr "<em> de distributie 'unstable', de onstabiele distributie</em>"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:28
+msgid ""
+"This is the version currently under development; it is updated continuously. "
+"You can retrieve packages from the `unstable' archive on any Debian FTP site "
+"and use them to upgrade your system at any time, but you may not expect the "
+"system to be as usable or as stable as before - that's why it's called "
+"`<strong>unstable</strong>'!"
+msgstr ""
+"Dit is de versie die momenteel ontwikkeld wordt. Ze wordt voortdurend "
+"bijgewerkt. Van elke Debian FTP-site kunt u pakketten ophalen uit het "
+"archief `unstable' en ze gebruiken om op gelijk welk moment uw systeem op te "
+"waarderen, maar u mag niet verwachten dat het systeem even bruikbaar of even "
+"stabiel zal zijn als voordien - daarom wordt het ook '<strong>unstable</"
+"strong>' genoemd!"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:32
+msgid "Please see <ref id=\"dists\"> for more information."
+msgstr "Raadpleeg <ref id=\"dists\"> voor bijkomende informatie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:43 getting.sgml:34
+msgid "Are there package upgrades in `stable'?"
+msgstr "Vinden er opwaarderingen van pakketten plaats in 'stable'?"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:39
+msgid ""
+"No new functionality is added to the stable release. Once a Debian version "
+"is released and tagged `stable' it will only get security updates. That is, "
+"only packages for which a security vulnerability has been found after the "
+"release will be upgraded. All the security updates are served through <url "
+"id=\"ftp://security.debian.org\" name=\"security.debian.org\">."
+msgstr ""
+"Aan de stabiele release wordt geen nieuwe functionaliteit toegevoegd. Eens "
+"een versie van Debian uitgebracht is en het label 'stable' heeft, zal ze "
+"enkel nog beveiligingsupdates krijgen. Dat wil zeggen dat enkel pakketten "
+"waarbij na de release een beveiligingsprobleem werd vastgesteld, "
+"opgewaardeerd zullen worden. Alle beveiligingsupdates worden aangeboden via "
+"<url id=\"ftp://security.debian.org\" name=\"security.debian.org\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:47
+msgid ""
+"Security updates serve one purpose: to supply a fix for a security "
+"vulnerability. They are not a method for sneaking additional changes into "
+"the stable release without going through normal point release procedure. "
+"Consequently, fixes for packages with security issues will not upgrade the "
+"software. The Debian Security Team will backport the necessary fixes to the "
+"version of the software distributed in `stable' instead."
+msgstr ""
+"Beveiligingsupdates hebben Ã©Ã©n doel: een reparatie verstrekken voor een "
+"beveiligingsprobleem. Het is geen manier om heimelijk bijkomende wijzigingen "
+"in de stabiele release binnen te loodsen zonder de normale procedure voor "
+"een tussenrelease (point release) te volgen. Het repareren van een pakket "
+"met een beveiligingsprobleem waardeert de software dus niet op. Het "
+"beveiligingsteam van Debian voert daarentegen wel de noodzakelijke "
+"reparaties uit op de versie van de software die in 'stable' verdeeld wordt."
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:54
+msgid ""
+"For more information related to security support please read the <url id="
+"\"http://www.debian.org/security/faq\" name=\"Security FAQ\"> or the <url id="
+"\"http://www.debian.org/doc/manuals/securing-debian-howto/\" name=\"Debian "
+"Security Manual\">."
+msgstr ""
+"Voor bijkomende informatie over ondersteuning op het valk van beveiliging "
+"kunt u de <url id=\"http://www.debian.org/security/faq\" name=\"Security FAQ"
+"\"> lezen of de <url id=\"http://www.debian.org/doc/manuals/securing-debian-"
+"howto/\" name=\"Debian Security Manual\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:43 getting.sgml:56
+msgid "Where/how can I get the Debian installation images?"
+msgstr "Waar/hoe kan ik Debian installatie-images verkrijgen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:60
+msgid ""
+"You can get the installation images by downloading the appropriate files "
+"from the <url id=\"https://www.debian.org/distrib/\" name=\"Debian website"
+"\">."
+msgstr ""
+"U kunt de installatie-images verkrijgen door de passende bestanden te "
+"downloaden van de <url id=\"https://www.debian.org/distrib/\" name=\"Debian "
+"website\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:63
+msgid ""
+"Please refer to <url id=\"http://www.debian.org/CD\" name=\"Debian GNU/Linux "
+"on CDs\"> for more information about CD (and DVD) images."
+msgstr ""
+"Raadpleeg <url id=\"http://www.debian.org/CD\" name=\"Debian GNU/Linux on CDs"
+"\"> voor bijkomende informatie over CD-(en DVD-)images."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:43 getting.sgml:65
+msgid "How do I install Debian from CD-ROMs?"
+msgstr "Hoe installeer ik Debian vanaf CD's?"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:71
+msgid ""
+"Installing Debian from CD is straightforward: configure your system for "
+"booting off a CD, insert your CD, and reboot. Your system will now be "
+"running the Debian Installer. See the <url id=\"http://www.debian.org/"
+"releases/stable/installmanual\" name=\"Debian GNU/Linux Installation Guide"
+"\"> for more information."
+msgstr ""
+"Debian vanaf een CD installeren is heel eenvoudig: stel uw systeem in om op "
+"te starten van CD, plaats uw CD in het station en start de computer opnieuw "
+"op. Uw systeem zal dan het Debian installatiesysteem opstarten. Zie de <url "
+"id=\"http://www.debian.org/releases/stable/installmanual\" name=\"Debian GNU/"
+"Linux Installation Guide\"> voor bijkomende informatie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:43 getting.sgml:75
+msgid ""
+"Why does the official stable released CD-ROM contain symlinks for `frozen' "
+"and `unstable'? I thought this CD contains just `stable'!"
+msgstr ""
+"Waarom bevat de officiÃ«le CD van de stabiele release symbolische koppelingen "
+"naar 'frozen' en 'unstable'? Ik dacht dat op die CD enkel `stable' stond!"
+
+#. type: <p><example>
+#: debian-faq.sgml:43 getting.sgml:77
+msgid "Official Debian CD images indeed contain symlinks like:"
+msgstr ""
+"OfficiÃ«le Debian CD-images bevatten inderdaad symbolische koppelingen zoals:"
+
+#. type: <example></example>
+#: debian-faq.sgml:43 getting.sgml:82
+#, no-wrap
+msgid ""
+" /dists/frozen -> &releasename;/\n"
+" /dists/stable -> &releasename;/\n"
+" /dists/testing -> &releasename;/\n"
+" /dists/unstable -> &releasename;/"
+msgstr ""
+" /dists/frozen -> &releasename;/\n"
+" /dists/stable -> &releasename;/\n"
+" /dists/testing -> &releasename;/\n"
+" /dists/unstable -> &releasename;/"
+
+#. type: <p><example>
+#: debian-faq.sgml:43 getting.sgml:86
+msgid "so that they work when your sources.list has an entry like"
+msgstr ""
+"waardoor zij werken als uw bestand 'sources.list' een regel bevat zoals"
+
+#. type: <example></example>
+#: debian-faq.sgml:43 getting.sgml:88
+#, no-wrap
+msgid " deb cdrom:[&lt;name as on cd label&gt;]/ unstable main [...]"
+msgstr " deb cdrom:[&lt;naam zoals op het cd-label&gt;]/ unstable main [...]"
+
+#. type: </example></p>
+#: debian-faq.sgml:43 getting.sgml:91
+msgid "."
+msgstr "."
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:96
+msgid ""
+"The fact these symlinks are present does <em>not</em> mean the image is "
+"`unstable' or `testing' or anything. Read the CD label in <file>/.disk/info</"
+"file> to find out which Debian version it contains. This information is also "
+"present in <file>/README.txt</file> on the CD."
+msgstr ""
+"Het feit dat deze symbolische koppelingen daar aanwezig zijn, betekent "
+"<em>niet</em> dat het image 'unstable' of 'testing' is of iets dergelijks. "
+"Kijk naar het CD-label in <file>/.disk/info</file> om te weten welke versie "
+"van Debian hij bevat. Deze informatie is ook te vinden in <file>/README.txt</"
+"file> op de CD."
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:99
+msgid ""
+"Read <url id=\"http://www.debian.org/releases/\"> to find out what the "
+"current `stable' and `testing' releases are."
+msgstr ""
+"Kijk op <url id=\"http://www.debian.org/releases/\"> om te weten welke "
+"uitgaven momenteel de 'stable' en de 'testing' release zijn."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:43 getting.sgml:102
+msgid "Can I get and install Debian directly from a remote Internet site?"
+msgstr ""
+"Kan ik Debian rechtstreeks verkrijgen en installeren vanaf een internetsite?"
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:105
+msgid ""
+"Yes. You can boot the Debian installation system from a set of files you can "
+"download from our FTP site and its mirrors."
+msgstr ""
+"Ja. U kunt het installatiesysteem van Debian opstarten met een aantal "
+"bestanden die u van onze FTP-site en zijn spiegelservers kunt downloaden."
+
+#. type: <p></p>
+#: debian-faq.sgml:43 getting.sgml:109
+msgid ""
+"You can download a small CD image file, create a bootable CD from it, "
+"install the basic system from it and the rest over the network. For more "
+"information please see <url id=\"http://www.debian.org/CD/netinst/\">."
+msgstr ""
+"U kunt een klein CD-imagebestand downloaden, er een opstartbare CD mee "
+"aanmaken, er het basissysteem mee installeren en de rest over het netwerk "
+"installeren. Raadpleeg voor bijkomende informatie <url id=\"http://www."
+"debian.org/CD/netinst/\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:43 getting.sgml:112
+msgid "Are there any alternative strategies for booting the system installer?"
+msgstr "Zijn er nog andere methodes om het installatiesysteem op te starten?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:3
+msgid ""
+"Yes. Apart from CD or DVD, you can install Debian GNU/Linux by booting from "
+"USB memory stick, directly from hard disk, or using TFTP net booting. For "
+"installing on multiple computers it's possible to do fully automatic "
+"installations. NB: not all methods are supported by all computer "
+"architectures. Once the installer has booted, the rest of the system can be "
+"downloaded over the network, or installed from local media. See the <url id="
+"\"http://www.debian.org/releases/stable/installmanual\" name=\"Debian GNU/"
+"Linux Installation Guide\"> for more information."
+msgstr ""
+"Ja. Behalve vanaf een CD of DVD, kunt u Debian ook installeren door op te "
+"starten van een USB-stick, rechtstreeks van een harde schijf of door via "
+"TFTP over het netwerk op te starten. Voor een installatie op verschillende "
+"computers kunt u het installatieproces volledig automatiseren. NB: niet alle "
+"methodes worden voor alle architecturen ondersteund. Eens het "
+"installatiesysteem opgestart is, kan de rest van het systeem over het "
+"netwerk gedownload worden, of vanaf lokale media geÃ¯nstalleerd worden. Zie "
+"de <url id=\"http://www.debian.org/releases/stable/installmanual\" name="
+"\"Debian GNU/Linux Installation Guide\"> voor bijkomende informatie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:5
+msgid "Choosing a Debian distribution"
+msgstr "Een Debian-distributie kiezen"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:12
+msgid ""
+"There are many different Debian distributions. Choosing the proper Debian "
+"distribution is an important decision. This section covers some information "
+"useful for users that want to make the choice best suited for their system "
+"and also answers possible questions that might be arising during the "
+"process. It does not deal with \"why you should choose Debian\" but rather "
+"\"which distribution of Debian\"."
+msgstr ""
+"Er bestaan veel verschillende Debian-distributies. De geschikte Debian-"
+"distributie kiezen is een belangrijke beslissing. Dit onderdeel bevat wat "
+"nuttige informatie voor gebruikers die de voor hun systeem best geschikte "
+"keuze willen maken en het geeft ook antwoorden op mogelijke vragen die "
+"tijdens dit proces kunnen opduiken. Het handelt niet over de vraag \"waarom "
+"kiezen voor Debian\" maar eerder over \"welke distributie van Debian kiezen"
+"\"."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:14
+msgid ""
+"For more information on the available distributions read <ref id=\"dists\">."
+msgstr ""
+"Lees voor bijkomende informatie over de beschikbare distributies <ref id="
+"\"dists\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:17
+msgid "Which Debian distribution (stable/testing/unstable) is better for me?"
+msgstr "Welke Debian-distributie (stable/testing/unstable) is best voor mij?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:20
+msgid ""
+"The answer is a bit complicated. It really depends on what you intend to do. "
+"One solution would be to ask a friend who runs Debian. But that does not "
+"mean that you cannot make an independent decision. In fact, you should be "
+"able to decide once you complete reading this chapter."
+msgstr ""
+"Het antwoord is een beetje ingewikkeld. Het hangt echt af van wat u wilt "
+"doen. Een mogelijkheid is raad te vragen aan een vriend die Debian gebruikt. "
+"Maar dit wil niet zeggen dat u niet autonoom zou kunnen beslissen. In feite "
+"zou u in staat moeten zijn een beslissing te nemen na het lezen van dit "
+"hoofdstuk."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:25
+msgid ""
+"If security or stability are at all important for you: install stable. "
+"period. This is the most preferred way."
+msgstr ""
+"Indien veiligheid en stabiliteit voor u zeer belangrijk zijn, installeer dan "
+"stable. Punt. Dit is het meest verkieslijk."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:30
+msgid ""
+"If you are a new user installing to a desktop machine, start with stable. "
+"Some of the software is quite old, but it's the least buggy environment to "
+"work in. You can easily switch to the more modern unstable (or testing) once "
+"you are a little more confident."
+msgstr ""
+"Indien u een nieuwe gebruiker bent en een installatie op een desktopcomputer "
+"uitvoert, begin dan met stable. Sommige software is wat ouder, maar het is "
+"de minst foutgevoelige omgeving om in te werken. U kunt gemakkelijk "
+"overschakelen naar het modernere unstable (of testing) eens u er wat meer "
+"vertrouwd mee bent."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:35
+msgid ""
+"If you are a desktop user with a lot of experience in the operating system "
+"and do not mind facing the odd bug now and then, or even full system "
+"breakage, use unstable. It has all the latest and greatest software, and "
+"bugs are usually fixed swiftly."
+msgstr ""
+"Indien u een desktopgebruiker bent met veel ervaring met het "
+"besturingssysteem er er niet om geeft af en toe geconfronteerd te worden met "
+"een vreemde bug of zelfs met een volledig onklaar geraakt systeem, gebruik "
+"dan unstable. Dat bevat al de recentste en geweldigste software en bugs "
+"worden meestal snel gerepareerd."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:39
+msgid ""
+"If you are running a server, especially one that has strong stability "
+"requirements or is exposed to the Internet, install stable. This is by far "
+"the strongest and safest choice."
+msgstr ""
+"Indien u een server beheert, in het bijzonder wanneer er hoge eisen inzake "
+"stabiliteit aan gesteld worden of wanneer hij met het internet verbonden is, "
+"installeer dan stable. Dit is veruit de beste en veiligste keuze."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:45
+msgid ""
+"The following questions (hopefully) provide more detail on these choices. "
+"After reading this whole FAQ, if you still could not make a decision, stick "
+"with the stable distribution."
+msgstr ""
+"Via de volgende vragen gaan we (hopelijk) dieper in op deze keuzes. Indien u "
+"na het lezen van de volledige FAQ nog steeds geen beslissing kunt nemen, "
+"houd u dan bij stable als distributie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:50
+msgid ""
+"You asked me to install stable, but in stable so and so hardware is not "
+"detected/working. What should I do?"
+msgstr ""
+"U vroeg me om stable te installeren, maar in stable wordt die en die "
+"hardware niet herkend of werkt ze niet. Wat moet ik doen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:54
+msgid ""
+"Try to search the web using a search engine and see if someone else is able "
+"to get it working in stable. Most of the hardware should work fine with "
+"stable. But if you have some state-of-the-art, cutting edge hardware, it "
+"might not work with stable. If this is the case, you might want to install/"
+"upgrade to either testing or unstable."
+msgstr ""
+"Probeer met een zoekmachine op het web te zoeken om te zien of iemand anders "
+"erin geslaagd is die hardware in stable te laten functioneren. Maar indien u "
+"bepaalde hypermoderne hardware heeft, het nieuwste van het nieuwste, dan is "
+"het mogelijk dat die niet werkt met stable. Indien dit het geval is, wit u "
+"misschien testing of unstable installeren of ernaar opwaarderen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:59
+msgid ""
+"For laptops, <url id=\"http://www.linux-on-laptops.com/\"> is a very good "
+"website to see if someone else is able to get it to work under Linux. The "
+"website is not specific to Debian, but is nevertheless a tremendous "
+"resource. I am not aware of any such website for desktops."
+msgstr ""
+"Voor laptops is <url id=\"http://www.linux-on-laptops.com/\"> een heel goede "
+"website om te weten of iemand anders de hardware onder Linux aan de praat "
+"kreeg. De website richt zich niet specifiek op Debian, maar is desondanks "
+"een geweldige bron van informatie. Voor desktops is me geen dergelijke "
+"website bekend."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:69
+msgid ""
+"Another option would be to ask in the debian-user mailing list by sending an "
+"email to debian-user@lists.debian.org. Messages can be posted to the list "
+"even without subscribing. The archives can be read through <url id=\"http://"
+"lists.debian.org/debian-user/\">. Information regarding subscribing to the "
+"list can be found at the location of archives. You are strongly encouraged "
+"to post your questions on the mailing-list rather than on <url id=\"http://"
+"www.debian.org/support\" name=\"irc\">. The mailing-list messages are "
+"archived, so the solution to your problem can help others with the same "
+"issue."
+msgstr ""
+"Een andere mogelijkheid is om de vraag te stellen op een debian-user "
+"mailinglijst door een e-mail te sturen naar debian-user@lists.debian.org "
+"(Engelstalig) of naar debian-user-dutch@lists.debian.org (Nederlandstalig). "
+"Zelfs zonder dat u op de lijst geabonneerd bent, kunt u een e-mail sturen. "
+"Via  <url id=\"http://lists.debian.org/debian-user/\"> kunt u de archieven "
+"van de mailinglijst inkijken. Informatie over het intekenen op de lijst "
+"vindt u op de plaats waar u de archieven vindt. Het wordt sterk aangeraden "
+"om uw vragen op de mailinglijst te stellen, eerder dan op <url id=\"http://"
+"www.debian.org/support\" name=\"irc\">. De berichten van de mailinglijst "
+"worden gearchiveerd, zodat een oplossing voor uw probleem ook anderen kan "
+"helpen die met hetzelfde geconfronteerd worden."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:73
+msgid ""
+"Will there be different versions of packages in different distributions?"
+msgstr "Hebben pakketten in verschillende distributies een andere versie?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:74
+msgid ""
+"Yes. Unstable has the most recent (latest) versions. But the packages in "
+"unstable are not well tested and might have bugs."
+msgstr ""
+"Ja. Unstable bevat de meest recente (nieuwste) versies. Maar de pakketten in "
+"unstable zijn niet grondig getest en kunnen bugs bevatten."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:77
+msgid ""
+"On the other hand, stable contains old versions of packages. But this "
+"package is well tested and is less likely to have any bugs."
+msgstr ""
+"Anderzijds bevat stable oude versies van pakketten. Maar deze pakketten zijn "
+"grondig getest en er is minder kans dat ze bugs bevatten."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:79
+msgid "The packages in testing fall between these two extremes."
+msgstr "De pakketten in testing vallen tussen deze beide uitersten in."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:83
+msgid ""
+"The stable distributions really contains outdated packages. Just look at "
+"Kde, Gnome, Xorg or even the kernel. They are very old. Why is it so?"
+msgstr ""
+"De stabiele distributies bevatten echt verouderde pakketten. Kijk gewoon "
+"naar Kde, Gnome, Xorg en zelfs de kernel. Die zijn erg oud. Waarom is dat zo?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:90
+msgid ""
+"Well, you might be correct. The age of the packages at stable depends on "
+"when the last release was made. Since there is typically over 1 year between "
+"releases you might find that stable contains old versions of packages. "
+"However, they have been tested in and out. One can confidently say that the "
+"packages do not have any known severe bugs, security holes etc., in them. "
+"The packages in stable integrate seamlessly with other stable packages. "
+"These characteristics are very important for production servers which have "
+"to work 24 hours a day, 7 days a week."
+msgstr ""
+"Welnu, u zou wel eens gelijk kunnen hebben. De leeftijd van de pakketten in "
+"stable is afhankelijk van het tijdstip waarop de laatste release gebeurde. "
+"Aangezien er tussen releases gewoonlijk meer dan 1 jaar verloopt, is het "
+"mogelijk dat u moet vaststellen dat stable oude versies van pakketten bevat. "
+"Zij werden evenwel door en door getest. Men kan met stelligheid beweren dat "
+"die pakketten geen gekende ernstige bugs, gaten in de beveiliging, enz. "
+"hebben. De pakketten in stable integreren naadloos met de andere stabiele "
+"pakketten. Deze eigenschappen zijn erg belangrijk voor productieservers die "
+"24 uur per dag en 7 dagen per week moeten functioneren."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:96
+msgid ""
+"On the other hand, packages in testing or unstable can have hidden bugs, "
+"security holes etc. Moreover, some packages in testing and unstable might "
+"not be working as intended. Usually people working on a single desktop "
+"prefer having the latest and most modern set of packages. Unstable is the "
+"solution for this group of people."
+msgstr ""
+"Pakketten in testing en unstable van hun kant kunnen verborgen bugs, gaten "
+"in de beveiliging, enz. hebben. Bovendien kunnen sommige pakketten in "
+"testing en unstable mogelijk niet naar behoren werken. Gewoonlijk verkiezen "
+"mensen die op een eenvoudige desktop werken om de recentste en meest moderne "
+"reeks pakketten te hebben. Unstable biedt voor deze groep mensen een "
+"oplossing."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:100
+msgid ""
+"As you can see, stability and novelty are two opposing ends of the spectrum. "
+"If stability is required: install stable distribution. If you want to work "
+"with the latest packages, then install unstable."
+msgstr ""
+"Zoals u merkt, zijn stabiliteit en nieuwigheid de twee uitersten van een "
+"spectrum. Indien stabiliteit een vereiste is, installeer dan de stabiele "
+"distributie. Indien u met de recentste pakketten wilt werken, installeer dan "
+"unstable."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:105
+msgid "If I were to decide to change to another distribution, can I do that?"
+msgstr ""
+"Mocht ik besluiten om naar een andere distributie over te gaan, kan ik dat "
+"dan doen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:107
+msgid ""
+"Yes, but it is a one way process. You can go from stable --&gt; testing --"
+"&gt; unstable. But the reverse direction is not \"possible\". So better be "
+"sure if you are planning to install/upgrade to unstable."
+msgstr ""
+"Jazeker, maar dit werkt maar in Ã©Ã©n richting. U kunt van stable --&gt; "
+"testing --&gt; unstable overgaan. Maar de omgekeerde richting is \"onmogelijk"
+"\". U kunt dus maar best zeker van uw stuk zijn als u van plan bent unstable "
+"te installeren of ernaar op te waarderen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:115
+msgid ""
+"Actually, if you are an expert and if you are willing to spend some time and "
+"if you are real careful and if you know what you are doing, then it might be "
+"possible to go from unstable to testing and then to stable. The installer "
+"scripts are not designed to do that. So in the process, your configuration "
+"files might be lost and..."
+msgstr ""
+"Eigenlijk, als u een expert bent en als u bereid bent om wat tijd te "
+"investeren en als u echt voorzichtig te werk gaat en als u weet wat u doet, "
+"dan zou het mogelijk kunnen zijn dat u van unstable overgaat naar testing en "
+"daarna naar stable. De installatiescripts zijn niet ontworpen om dat te "
+"doen. Dus kunnen in de loop van dit proces uw configuratiebestanden mogelijk "
+"verloren gaan en..."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:117
+msgid "Could you tell me whether to install stable, testing or unstable?"
+msgstr "Kunt u me zeggen of ik stable, testing of unstable moet installeren?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:120
+msgid ""
+"No. This is a rather subjective issue. There is no perfect answer as it "
+"depends on your software needs, your willingness to deal with possible "
+"breakage, and your experience in system administration. Here are some tips:"
+msgstr ""
+"Nee. Dit is eerder een subjectieve keuze. Een perfect antwoord is niet "
+"mogelijk, omdat het afhankelijk is van uw softwarebehoeften, uw bereidheid "
+"om af te rekenen met mogelijke defecten en uw ervaring op het gebied van "
+"systeembeheer. Hierna volgen enkele tips:"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:127
+msgid ""
+"Stable is rock solid. It does not break and has full security support. But "
+"it not might have support for the latest hardware."
+msgstr ""
+"Stable is zeer stabiel. Er treden geen defecten op en het wordt volledig "
+"ondersteund op het gebied van beveiliging. Maar mogelijk ondersteunt het "
+"niet de recentste hardware."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:130
+msgid ""
+"Testing has more up-to-date software than Stable, and it breaks less often "
+"than Unstable. But when it breaks, it might take a long time for things to "
+"get rectified. Sometimes this could be days and it could be months at times. "
+"It also does not have permanent security support."
+msgstr ""
+"Testing heeft meer recente software dan Stable en er doen zich minder "
+"defecten voor dan in Unstable. Maar als er een defect optreedt, kan het lang "
+"duren voor de zaak rechtgezet wordt. Soms kan het gaan om dagen, maar dit "
+"kunnen soms ook maanden zijn. Er is ook geen permanente "
+"beveiligingsondersteuning voor voorzien."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:136
+msgid ""
+"Unstable has the latest software and changes a lot. Consequently, it can "
+"break at any point. However, fixes get rectified in many occasions in a "
+"couple of days and it always has the latest releases of software packaged "
+"for Debian."
+msgstr ""
+"Unstable heeft de recentste software en ondergaat veel wijzigingen. Een "
+"gevolg is dat het op elk moment defect kan geraken. In veel gevallen zetten "
+"reparaties de zaak terug recht binnen enkele dagen en de distributie bevat "
+"steeds de recentste releases van de voor Debian verpakte software."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:145
+msgid ""
+"When deciding between testing and unstable bear in mind that there might be "
+"times when tracking testing would be beneficial as opposed to unstable. One "
+"of this document's authors experienced such situation due to the gcc "
+"transition from gcc3 to gcc4. He was trying to install the <package>labplot</"
+"package> package on a machine tracking unstable and it could not be "
+"installed in unstable as some of its dependencies have undergone gcc4 "
+"transition and some have not. But the package in testing was installable on "
+"a testing machine as the gcc4 transitioned packages had not \"trickled down"
+"\" to testing."
+msgstr ""
+"Wanneer u wilt kiezen tussen testing en unstable, dan moet u in gedachten "
+"houden dat er momenten kunnen zijn dat het voordeliger is om testing in "
+"plaats van unstable op te volgen. Een van de auteurs van dit document heeft "
+"een dergelijke situatie meegemaakt ten gevolge van de transitie van gcc van "
+"gcc3 naar gcc4. Hij probeerde het pakket <package>labplot</package> te "
+"installeren op een machine die unstable gebruikte, maar dat lukte niet omdat "
+"sommige van de pakketten die dit pakket vereiste, de transitie naar gcc4 "
+"reeds doorgemaakt hadden en andere nog niet. Maar op een machine die testing "
+"gebruikte, kon het pakket wel geÃ¯nstalleerd worden, omdat de pakketten die "
+"de overgang naar gcc4 gemaakt hadden, nog niet \"doorgesijpeld\" waren naar "
+"testing."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:151
+msgid "You are talking about testing being broken. What do you mean by that?"
+msgstr "U hebt het over testing dat defect kan zijn. Wat bedoelt u daarmee?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:154
+msgid ""
+"Sometimes, a package might not be installable through package management "
+"tools. Sometimes, a package might not be available at all, maybe it was "
+"(temporarily) removed due to bugs or unmet dependencies. Sometimes, a "
+"package installs but does not behave in the proper way."
+msgstr ""
+"Soms kan het zijn dat een pakket niet geÃ¯nstalleerd kan worden via de "
+"hulpmiddelen voor pakketbeheer. Soms kan een pakket helemaal niet "
+"beschikbaar zijn, misschien omdat het (tijdelijk) verwijderd werd omwille "
+"van bugs of niet-voldane vereisten. Soms lukt het om een pakket te "
+"installeren, maar functioneert het niet naar behoren."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:157
+msgid ""
+"When these things happen, the distribution is said to be broken (at least "
+"for this package)."
+msgstr ""
+"Als zich dergelijke zaken voordoen, wordt gezegd dat de distributie defect "
+"is (althans voor dit pakket)."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:162
+msgid ""
+"Why is it that testing could be broken for months? Won't the fixes "
+"introduced in unstable flow directly down into testing?"
+msgstr ""
+"Wat is de reden waarom testing gedurende maanden defect kan zijn? Schuiven "
+"de reparaties die in unstable geÃ¯ntroduceerd worden, niet onmiddellijk door "
+"naar testing?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:166
+msgid ""
+"The bug fixes and improvements introduced in the unstable distribution "
+"trickle down to testing after a certain number of days. Let's say this "
+"threshold is 5 days. The packages in unstable go into testing only when "
+"there are no RC-bugs reported against them. If there is a RC-bug filed "
+"against a package in unstable, it will not go into testing after the 5 days."
+msgstr ""
+"De reparaties van bugs en de verbeteringen die in unstable ingebracht "
+"worden, sijpelen door naar testing na een bepaald aantal dagen. Laten we "
+"stellend at de drempelwaarde 5 dagen is. De pakketten in unstable komen "
+"testing enkel binnen wanneer er tegen hen geen RC-bugs (bugs die het "
+"ongeschikt maken om uitgebracht te worden) gerapporteerd werden. Als er "
+"tegen een pakket een RC-bug ingediend werd, zal dat pakket testing niet "
+"binnenkomen nadat de 5 dagen verstreken zijn."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:172
+msgid ""
+"The idea is that, if the package has any problems, it would be discovered by "
+"people using unstable and will be fixed before it enters testing. This keeps "
+"testing in a usable state for most of the time. Overall a brilliant concept, "
+"if you ask me. But things aren't always that simple. Consider the following "
+"situation:"
+msgstr ""
+"De achterliggende gedachte is dat indien een pakket eventuele problemen "
+"vertoont, die ontdekt zullen worden door mensen die unstable gebruiken en "
+"gerepareerd zullen worden vooraleer het testing binnenkomt. Dit houdt "
+"testing voor het merendeel van de tijd in een bruikbare toestand. Een "
+"volslagen briljant concept, als u het mij vraagt. Maar de zaken zijn niet "
+"steeds zo eenvoudig. Neem bijvoorbeeld de volgende situatie:"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:176
+msgid "Imagine you are interested in package XYZ."
+msgstr "Stel u voor dat u geÃ¯nteresseerd bent in pakket XYZ."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:178
+msgid ""
+"Let's assume that on June 10, the version in testing is XYZ-3.6 and in "
+"unstable it is XYZ-3.7."
+msgstr ""
+"Laten we aannamen dat de versie in testing op 10 juni versie XYZ-3.6 is en "
+"in unstable XYZ-3.7."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:180
+msgid "After 5 days, XYZ-3.7 from unstable migrates into testing."
+msgstr "Na 5 dagen komt XYZ-3.7 vanuit unstable testing binnen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:182
+msgid ""
+"So on June 15, both testing and unstable have XYZ-3.7 in their repositories."
+msgstr ""
+"En dus bevindt versie XYZ-3.7 zich op 15 juni zowel in het archief van "
+"testing als in dat van unstable."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:184
+msgid ""
+"Let's say, the user of testing distribution sees that a new XYZ package is "
+"available and updates his XYZ-3.6 to XYZ-3.7."
+msgstr ""
+"Nemen we nu aan dat de gebruiker van de distributie testing merkt dat er een "
+"nieuw pakket XYZ beschikbaar is en zijn XYZ-3.6 naar XYZ-3.7 opwaardeert."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:187
+msgid ""
+"Now on June 25, someone using testing or unstable discovers an RC bug in "
+"XYZ-3.7 and files it in the BTS."
+msgstr ""
+"Op 25 juni merkt nu een gebruiker van testing of unstable een RC-bug in "
+"XYZ-3.7 en rapporteert dit in het BTS (het bugopvolgingssysteem)."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:192
+msgid ""
+"The maintainer of XYZ fixes this bug and uploads it to unstable say on June "
+"30. Here it is assumed that it takes 5 days for the maintainer to fix the "
+"bug and upload the new version. The number 5 should not be taken literally. "
+"It could be less or more, depending upon the severity of the RC-bug at hand."
+msgstr ""
+"De pakketonderhouder van XYZ repareert de bug en plaatst het in unstable op "
+"laten we zeggen 30 juni. Hier veronderstellen we dat het de "
+"pakketonderhouder 5 dagen tijd gekost heeft om de bug te repareren en de "
+"nieuwe versie te uploaden. Het getal 5 moet hier niet letterlijk genomen "
+"worden. Dit had minder of meer kunnen zijn, afhankelijk van de ernst van de "
+"betrokken bug."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:194
+msgid ""
+"This new version in unstable, XYZ-3.8 is scheduled to enter testing on July "
+"5th."
+msgstr ""
+"Deze nieuwe versie in unstable, XYZ-3.8, staat gepland om op 5 juli testing "
+"binnen te komen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:196
+msgid "But on July 3rd some other person discovers another RC-bug in XYZ-3.8."
+msgstr "Maar op 3 juli ontdekt iemand anders nog een andere RC-bug in XYZ-3.8."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:198
+msgid ""
+"Let's say the maintainer of XYZ fixes this new RC-bug and uploads new "
+"version of XYZ after 5 days."
+msgstr ""
+"Nemen we aan dat de onderhouder van XYZ deze nieuwe RC-bug repareert en een "
+"nieuwe versie van XYZ uploadt na 5 dagen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:200
+msgid "So on July 8th, testing has XYZ-3.7 while unstable has XYZ-3.9."
+msgstr "Op 8 juli heeft testing dus versie XYZ-3.7 en unstable versie XYZ-3.9."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:202
+msgid ""
+"This new version XYZ-3.9 is now rescheduled to enter testing on July 13th."
+msgstr ""
+"Dze nieuwe versie XYZ-3.9 staat nu gepland om op 13 juli testing binnen te "
+"komen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:208
+msgid ""
+"Now since you are running testing, and since XYZ-3.7 is buggy, you could "
+"probably use XYZ only after July 13th. That is you essentially ended up with "
+"a broken XYZ for about one month."
+msgstr ""
+"Welnu, vermits u testing gebruikt en vermits XYZ-3.7 fouten vertoont, zult u "
+"XYZ wellicht pas na 13 juli kunnen gebruiken. Dit betekent dat u "
+"uiteindelijk ongeveer gedurende een maand met een defect XYZ gezeten heeft."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:215
+msgid ""
+"The situation can get much more complicated, if say, XYZ depends on 4 other "
+"packages. This could in turn lead to an unusable testing distribution for "
+"months. While the scenario above is immaginary, similar things can occur in "
+"real life, though they are rare."
+msgstr ""
+"De situatie kan nog veel ingewikkelder worden als XYZ laten e zeggen 4 "
+"andere pakketten vereist. Dit kan op zijn beurt leiden tot het gedurende "
+"maanden onbruikbaar worden van de distributie testing. Hoewel het hierboven "
+"geschetste scenario theoretisch is, kunnen zich dergelijke situaties ook in "
+"het echt voordoen, al is dat uitzonderlijk."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:218
+msgid ""
+"From an administrator's point of view, which distribution requires more "
+"attention?"
+msgstr ""
+"Welke distributie vereist vanuit het oogpunt van een beheerder meer aandacht?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:226
+msgid ""
+"One of the main reasons why many people choose Debian over other Linux "
+"distributions is that it requires very little administration. People want a "
+"system that just works. In general one can say that stable requires very "
+"little maintenance, while testing and unstable require constant maintenance "
+"from the administrator. If you are running stable, all you need to worry "
+"about is keeping track of security updates. If you are running either "
+"testing or unstable it is a good idea to be aware of the new bugs discovered "
+"in the installed packages, new bugfixes/features introduced etc."
+msgstr ""
+"Een van de belangrijkste redenen waarom veel mensen Debian kiezen boven "
+"andere Linux distributies is dat het heel weinig onderhoud vraagt. Mensen "
+"willen een systeem dat gewoon werkt. Over het algemeen kan men stellen dat "
+"stable heel weinig onderhoud vraagt, terwijl testing en unstable een "
+"voortdurend onderhoud van de systeembeheerder vragen. Indien u met stable "
+"werkt, is het enige waar u aandacht voor moet hebben, het opvolgen van "
+"beveiligingsupdates. Indien u testing of unstable gebruikt, doet u er goed "
+"aan op de hoogte te blijven van pas ontdekte bugs in de pakketten die u "
+"gebruikt, van bugreparaties, van toegevoegde nieuwe functionaliteit, enz."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:238
+msgid "What happens when a new release is made?"
+msgstr "Wat gebeurt er als er een nieuwe release gemaakt wordt?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:241
+msgid ""
+"This question will not help you in choosing a Debian distribution. But "
+"sooner or later you will face this question."
+msgstr ""
+"Deze vraag zal u niet helpen bij het kiezen van een Debian-distributie. Maar "
+"vroeg of laat zult u hiermee geconfronteerd worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:244
+msgid ""
+"The stable distribution is currently &releasename;; The next stable "
+"distribution will be called &testingreleasename;. Let's consider the "
+"particular case of what happens when &testingreleasename; is released as the "
+"new stable version."
+msgstr ""
+"De distributie stable is momenteel &releasename;. De volgende stabiele "
+"distributie zal &testingreleasename; genoemd worden. Laten we nu eens "
+"concreet bekijken wat er gebeurt als &testingreleasename; uitgebracht wordt "
+"als de nieuwe stabiele versie."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:248
+msgid ""
+"oldstable = &oldreleasename;; stable = &releasename;; testing = "
+"&testingreleasename;; unstable = sid"
+msgstr ""
+"oldstable = &oldreleasename;; stable = &releasename;; testing = "
+"&testingreleasename;; unstable = sid"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:250
+msgid ""
+"Unstable is always referred to as sid irrespective of whether a release is "
+"made or not."
+msgstr ""
+"Naar unstable wordt steeds verwezen met de naam sid, ongeacht of er een "
+"nieuwe release uitgebracht werd of niet."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:253
+msgid ""
+"Packages constantly migrate from sid to testing (i.e. &testingreleasename;). "
+"But packages in stable (i.e. &releasename;) remain the same except for "
+"security updates."
+msgstr ""
+"Palletten schuiven constant door van sid naar testing (m.a.w. "
+"&testingreleasename;). Maar pakketten in stable (m.a.w. &releasename;) "
+"blijven ongewijzigd, behalve voor beveiligingsupdates."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:256
+msgid ""
+"After some time testing becomes frozen. But it will still be called testing. "
+"At this point no new packages from unstable can migrate to testing unless "
+"they include release-critical (RC) bug fixes."
+msgstr ""
+"Na een bepaalde tijd wordt testing bevroren. Maar het zal nog altijd testing "
+"heten. Op dit punt kunnen geen nieuwe pakketten meer doorschuiven van "
+"unstable naar testing, tenzij ze reparaties bevatten voor RC-bugs (release-"
+"critical bugs, d.w.z. bugs die het pakket ongeschikt maken voor release)."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:260
+msgid ""
+"When testing is frozen, all the new bugfixes introduced have to be manually "
+"checked by the members of the release team. This is done to ensure that "
+"there won't be any unknown severe problems in the frozen testing."
+msgstr ""
+"Wanneer testing bevroren is, moeten alle nieuwe bugreparaties die toegevoegd "
+"worden, handmatig gecontroleerd worden door de leden van het release-team. "
+"Dit gebeurt om te garanderen dat de bevroren testing geen niet-gekende "
+"ernstige problemen zou hebben."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:263
+msgid ""
+"RC bugs in 'frozen testing' are reduced to either zero or, if greater than "
+"zero, the bugs are either marked as ignored for the release or are deferred "
+"for a point release."
+msgstr ""
+"In het 'bevroren testing' wordt het aantal RC-bugs ofwel teruggebracht op "
+"nul, of als dat getal groter dan nul blijft, worden de bugs ofwel gemarkeerd "
+"als 'buiten beschouwing te laten voor de release' of wordt de reparatie "
+"ervan uitgesteld tot een tussenrelease.(point release)."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:266
+msgid ""
+"The 'frozen testing' with no rc-bugs will be released as the new stable "
+"version. In our example, this new stable release will be called "
+"&testingreleasename;."
+msgstr ""
+"De 'bevroren testing' wordt dan zonder RC-bugs uitgebracht als de nieuwe "
+"stabiele versie. In ons voorbeeld zal die nieuwe stabniele release "
+"&testingreleasename; genoemd worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:268
+msgid ""
+"At this stage oldstable = &releasename;, stable = &testingreleasename;. The "
+"contents of stable and 'frozen testing' are same at this point."
+msgstr ""
+"In deze fase is oldstable = &releasename;, stable = &testingreleasename;. De "
+"inhoud van stable en 'bevroren testing' is op dat ogenblik hetzelfde."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:269
+msgid "A new testing is based on the old testing."
+msgstr "Een nieuwe testing wordt op de oude testing gebaseerd."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:272
+msgid ""
+"Packages start coming down from sid to testing and the Debian community will "
+"be working towards making the next stable release."
+msgstr ""
+"Pakketten beginnen vanuit sid testing binnen te komen en de Debian-"
+"gemeenschap begint te werken aan het realiseren van de volgende stabiele "
+"release."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:277
+msgid ""
+"I have a working Desktop/cluster with Debian installed. How do I know which "
+"distribution I am running?"
+msgstr ""
+"Ik heb een werkende desktopcomputer/cluster met daarop Debian. Hoe weet ik "
+"welke distributie ik gebruik?"
+
+#. type: <p><example>
+#: debian-faq.sgml:44 choosing.sgml:280
+msgid ""
+"In most situations it is very easy to figure this out. Take a look at the "
+"<file>/etc/apt/sources.list</file> file. There will be an entry similar to "
+"this:"
+msgstr ""
+"In de meeste gevalle valt dit gemakkelijk uit te zoeken. Ga eens kijken in "
+"het bestand <file>/etc/apt/sources.list</file>. Daarin zal een regel te "
+"vinden zijn zoals deze:"
+
+#. type: <example></example>
+#: debian-faq.sgml:44 choosing.sgml:282
+#, no-wrap
+msgid "deb http://ftp.us.debian.org/debian/ unstable main contrib"
+msgstr "deb http://ftp.us.debian.org/debian/ unstable main contrib"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:285
+msgid ""
+"The third field ('unstable' in the above example) indicates the Debian "
+"distribution the system is currently tracking."
+msgstr ""
+"Het derde veld ('unstable' in het bovenstaande voorbeeld) geeft aan welke "
+"Debian-distributie het systeem momenteel opvolgt."
+
+#. type: <p><example>
+#: debian-faq.sgml:44 choosing.sgml:291
+msgid ""
+"You can also use <prgn>lsb_release</prgn> (available in the <package>lsb-"
+"release</package> package). If you run this program in an unstable system "
+"you will get:"
+msgstr ""
+"U kunt ook het commando <prgn>lsb_release</prgn> (te vinden in het pakket "
+"<package>lsb-release</package>) gebruiken. Indien u dat programma uitvoert "
+"op een systeem met unstable, zult u het volgende krijgen:"
+
+#. type: <example></example>
+#: debian-faq.sgml:44 choosing.sgml:298
+#, no-wrap
+msgid ""
+"$ lsb_release  -a\n"
+"LSB Version:    core-2.0-noarch:core-3.0-noarch:core-3.1-noarch:core-2.0-ia32:core-3.0-ia32:core-3.1-ia32\n"
+"Distributor ID: Debian\n"
+"Description:    Debian GNU/Linux unstable (sid)\n"
+"Release:    unstable\n"
+"Codename:   sid"
+msgstr ""
+"$ lsb_release  -a\n"
+"LSB Version:    core-2.0-noarch:core-3.0-noarch:core-3.1-noarch:core-2.0-ia32:core-3.0-ia32:core-3.1-ia32\n"
+"Distributor ID: Debian\n"
+"Description:    Debian GNU/Linux unstable (sid)\n"
+"Release:    unstable\n"
+"Codename:   sid"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:307
+msgid ""
+"However, this is not always that easy. Some systems might have <file>sources."
+"list</file> files with multiple entries corresponding to different "
+"distributions. This could happen if the administrator is tracking different "
+"packages from different Debian distributions. This is frequently referred to "
+"as apt-pinning. These systems might run a mixture of distributions."
+msgstr ""
+"Het is echter niet altijd zo gemakkelijk. Sommige systemen hebben mogelijk "
+"een bestand <file>sources.list</file> met verschillende regels die "
+"overeenkomen met verschillende distributies. Dit is mogelijk als de "
+"systeembeheerder verschillende pakketten uit verschillende Debian-"
+"distributies opvolgt. Hiernaar wordt vaak verwezen met de term apt-pinning "
+"(apt-verankering). Op deze systemen kan een mix van distributies "
+"functioneren."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:310
+msgid ""
+"I am currently tracking stable. Can I change to testing or unstable? If so, "
+"how?"
+msgstr ""
+"Ik volg momenteel stable op. Kan ik overschakelen op testing of instable? "
+"Hoe gaat dat dan?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:317
+msgid ""
+"If you are currently running stable, then in the <file>/etc/apt/sources."
+"list</file> file the third field will be either '&releasename;' or 'stable'. "
+"You need to change this to the distribution you want to run. If you want to "
+"run testing, then change the third field of <file>/etc/apt/sources.list</"
+"file> to 'testing'. If you want to run unstable, then change the third field "
+"to 'unstable'."
+msgstr ""
+"Indien u momenteel stable gebruikt, zal het derde veld in het bestand <file>/"
+"etc/apt/sources.list</file> ofwel '&releasename;' of 'stable' zijn. U moet "
+"dit veranderen naar de distributie die u wilt gebruiken. Indien u testing "
+"wilt gebruiken, verander dan het derde veld van <file>/etc/apt/sources.list</"
+"file> in 'testing'. Indien u unstable wilt gebruiken, verander dan het derde "
+"veld in 'unstable'."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:319
+msgid ""
+"Currently testing is called &testingreleasename;. So, if you change the "
+"third field of <file>/etc/apt/sources.list</file> to '&testingreleasename;', "
+"then also you will be running testing. But even when &testingreleasename; "
+"becomes stable, you will still be tracking &testingreleasename;."
+msgstr ""
+"Momenteel heet testing &testingreleasename;. Indien u dus het derde veld van "
+"<file>/etc/apt/sources.list</file> verandert in '&testingreleasename;', zult "
+"u ook testing gebruiken. Maar ook wanneer &testingreleasename; de stabiele "
+"distributie wordt, zult ge nog altijd &testingreleasename; opvolgen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:324
+msgid ""
+"Unstable is always called Sid. So if you change the third field of <file>/"
+"etc/apt/sources.list</file> to 'sid', then you will be tracking unstable."
+msgstr ""
+"Unstable blijft steeds Sid heten. Indien u dus het derde veld van <file>/etc/"
+"apt/sources.list</file> verandert in 'sid', zult u unstable opvolgen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:329
+msgid ""
+"Currently Debian offers security updates for testing but not for unstable, "
+"as fixes in unstable are directly made to the main archive. So if you are "
+"running unstable make sure that you remove the lines relating to security "
+"updates in <file>/etc/apt/sources.list</file>."
+msgstr ""
+"Momenteel biedt Debian-beveiligingsupdates voor testing, maar niet voor "
+"unstable, vermits reparaties in unstable rechtstreeks in het hoofdarchief "
+"gemaakt worden. Indien u dus unstable gebruikt, moet u ervoor zorgen dat u "
+"de regels in verband met beveiligingsupdates verwijdert uit <file>/etc/apt/"
+"sources.list</file>."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:333
+msgid ""
+"If there is a release notes document available for the distribution you are "
+"upgrading to (even though it has not yet been released) it would be wise to "
+"review it, as it might provide information on how you should upgrade to it."
+msgstr ""
+"Als er een document met 'release notes' (notities bij de release) bestaat "
+"voor de distributie waarnaartoe u opwaardeert (zelfs al is ze nog niet "
+"uitgebracht), zou u er goed aan doen het na te kijken, vermits het mogelijk "
+"informatie bevat over hoe u ernaartoe moet opwaarderen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:339
+msgid ""
+"Nevertheless, once you make the above changes, you can run <file>aptitude "
+"update</file> and then install the packages that you want. Notice that "
+"installing a package from a different distribution might automatically "
+"upgrade half of your system. If you install individual packages you will end "
+"up with a system running mixed distributions."
+msgstr ""
+"Maar u kunt, eens u de bovenvermelde wijzigingen heeft aangebracht, "
+"<file>aptitude update</file> uitvoeren en dan de pakketten installeren die u "
+"wenst. Merk op dat het installeren van een pakket van een andere distributie "
+"tot gevolg zou kunnen hebben dat de helft van uw systeem opgewaardeerd "
+"wordt. Indien u afzonderlijke pakketten installeert, zult u een systeem "
+"bekomen dat werkt met gemengde distributies."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:344
+msgid ""
+"It might be best in some situations to just fully upgrade to the new "
+"distribution running <prgn>apt full-upgrade</prgn>, <prgn>aptitude safe-"
+"upgrade</prgn> or <prgn>aptitude full-upgrade</prgn>. Read apt's and "
+"aptitude's manual pages for more information."
+msgstr ""
+"In sommige gevallen kan het beter zijn om gewoon volledig up te waarderen "
+"naar de nieuwe distributie met de opdracht <prgn>apt full-upgrade</prgn>, "
+"<prgn>aptitude safe-upgrade</prgn> of <prgn>aptitude full-upgrade</prgn>. "
+"Raadpleeg de man-pagina's van apt en aptitude voor bijkomende informatie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:348
+msgid ""
+"I am currently tracking testing (&testingreleasename;). What will happen "
+"when a release is made? Will I still be tracking testing or will my machine "
+"be running the new stable distribution?"
+msgstr ""
+"Momenteel volg ik testing op (&testingreleasename;). Wat zal er gebeuren als "
+"een nieuwe release uitgebracht wordt? Zal ik nog steeds testing opvolgen of "
+"zal mijn computer dan de nieuwe stabiele distributie gebruiken?"
+
+#. type: <p><example>
+#: debian-faq.sgml:44 choosing.sgml:352
+msgid ""
+"It depends on the entries in the <file>/etc/apt/sources.list</file> file. If "
+"you are currently tracking testing, these entries are similar to either:"
+msgstr ""
+"Dit is afhankelijk van de regels in het bestand <file>/etc/apt/sources.list</"
+"file>. Indien u momenteel testing opvolgt, dan zien die regels er ofwel als "
+"volgt uit:"
+
+#. type: <example></example>
+#: debian-faq.sgml:44 choosing.sgml:354
+#, no-wrap
+msgid "deb http://ftp.us.debian.org/debian/ testing main"
+msgstr "deb http://ftp.us.debian.org/debian/ testing main"
+
+#. type: </example><example>
+#: debian-faq.sgml:44 choosing.sgml:358
+msgid "or"
+msgstr "of als volgt:"
+
+#. type: <example></example>
+#: debian-faq.sgml:44 choosing.sgml:360
+#, no-wrap
+msgid "deb http://ftp.us.debian.org/debian/ &testingreleasename; main"
+msgstr "deb http://ftp.us.debian.org/debian/ &testingreleasename; main"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:365
+msgid ""
+"If the third field in <file>/etc/apt/sources.list</file> is 'testing' then "
+"you will be tracking testing even after a release is made. So after "
+"&testingreleasename; is released, you will be running a new Debian "
+"distribution which will have a different codename. Changes might not be "
+"apparent at first but will be evident as soon as new packages from unstable "
+"go over to the testing distribution."
+msgstr ""
+"Indien het derde veld in <file>/etc/apt/sources.list</file> 'testing' is, "
+"dan zult u ook na het uitbrengen van een release testing blijven opvolgen. "
+"Dus nadat &testingreleasename; uitgebracht werd, zult u een nieuwe "
+"distributie van Debian met een andere codenaam gebruiken. Aanvankelijk "
+"zullen geen verschillen merkbaar zijn, maar die zullen duidelijk worden van "
+"zodra nieuwe pakketten vanuit unstable naar de nieuwe testing-distributie "
+"overkomen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:369
+msgid ""
+"But if the third field contains '&testingreleasename;' then you will be "
+"tracking stable (since &testingreleasename; will then be the new stable "
+"distribution)."
+msgstr ""
+"Maar als het derde veld '&testingreleasename;' bevat, dan zult u 'stable' "
+"opvolgen (aangezien '&testingreleasename;' dan de nieuwe stabiele "
+"distributie zal zijn)."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:373
+msgid "I am still confused. What did you say I should install?"
+msgstr ""
+"Ik ben nog steeds wat in de war. Wat had u weer gezegd dat ik moest "
+"installeren?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:373
+msgid "If unsure, the best bet would be the stable distribution."
+msgstr "Bij twijfel is de beste keuze de stabiele distributie te installeren."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:377
+msgid "But what about Knoppix, Linux Mint Debian Edition, Ubuntu, and others?"
+msgstr "Maar wat dan met Knoppix, Linux Mint Debian Edition, Ubuntu en andere?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:379
+msgid ""
+"They are not Debian; they are <em>Debian based</em>. Though there are many "
+"similarities and commonalities between them, there are also crucial "
+"differences."
+msgstr ""
+"Die zijn niet van Debian. Ze zijn <em>op Debian gebaseerd</em>. Hoewel er "
+"veel onderlinge gelijkenissen zijn en ze veel gemeen hebben, zijn er ook "
+"cruciale verschillen."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:387
+msgid ""
+"All these distributions have their own merits and are suited to some "
+"specific set of users. For more information, read <url id=\"http://www."
+"debian.org/misc/children-distros\" name=\"Software distributions based on "
+"Debian\"> available at the Debian website."
+msgstr ""
+"Al deze distributies hebben hun eigen verdiensten en zijn geschikt voor een "
+"specifieke groep gebruikers. Lees voor bijkomende informatie <url id="
+"\"http://www.debian.org/misc/children-distros\" name=\"Software "
+"distributions based on Debian\"> op de website van Debian."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:389
+msgid ""
+"I know that Knoppix/Linux Mint Debian Edition/Ubuntu/... is Debian-based. So "
+"after installing it on the hard disk, can I use 'apt' package tools on it?"
+msgstr ""
+"Ik weet dat Knoppix/Linux Mint Debian Edition/Ubuntu/... op Sebian gebaseerd "
+"zijn. Kan ik bijgevolg de pakketbeheerhulpmiddelen van 'apt' gebruiken nadat "
+"ik ze op de harde schijf geÃ¯nstalleerd heb?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:393
+msgid ""
+"These distributions are Debian based. But they are not Debian. You will be "
+"still able to use apt package tools by pointing the <file>/etc/apt/sources."
+"list</file> file to these distributions' repositories. But then you are not "
+"running Debian, you are running a different distribution. They are not the "
+"same."
+msgstr ""
+"Deze distributies zijn gebaseerd op Debian, maar ze zijn Debian niet. U kunt "
+"wel de pakketbeheerhulpmiddelen van apt gebruiken als u het bestand <file>/"
+"etc/apt/sources.list</file> laat verwijzen naar de pakketbronnen van die "
+"distributies. Maar dan gebruikt u niet Debian, maar een andere distributie. "
+"Ze zijn niet gelijk."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:402
+msgid ""
+"In most situations if you stick with one distribution you should use that "
+"and not mix packages from other distributions. Many common breakages arise "
+"due to people running a distribution and trying to install Debian packages "
+"from other distributions. The fact that they use the same formatting and "
+"name (.deb), does not make them immediately compatible."
+msgstr ""
+"Als u het bij een distributie houdt, zou u in de meeste gevallen deze moeten "
+"gebruiken en ze niet mengen met pakketten uit andere distributies. Veel van "
+"de vaak voorkomende defecten ontstaan door het feit dat mensen die een "
+"bepaalde distributie gebruiken, Debian-pakketten uit andere distributies "
+"trachten te installeren. Het feit dat ze dezelfde indeling en naam (.deb) "
+"hebben, maakt ze nog niet onmiddellijk compatibel."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:408
+msgid ""
+"For example, Knoppix is a Linux distribution designed to be booted as a live "
+"CD whereas Debian is designed to be installed on the hard-disk. Knoppix is "
+"great if you want to know whether a particular piece of hardware works, or "
+"if you want to experience how a GNU/Linux system 'feels' etc., Knoppix is "
+"good for demonstration purposes while Debian is designed to run 24/7. "
+"Moreover the number of packages available, the number of architectures "
+"supported by Debian are far more than that of Knoppix."
+msgstr ""
+"Bijvoorbeeld, Knoppix is een Linux-distributie die ontworpen is om op te "
+"starten als een live-CD, terwijl Debian ontworpen is om op de harde schijf "
+"geÃ¯nstalleerd te worden. Knoppix is zeer geschikt om te weten of een bepaald "
+"stuk hardware werkt, of als u wilt ondervinden hoe een GNU/Linux-systeem "
+"'aanvoelt', enz. Knoppix is goed voor demonstratiedoeleinden, terwijl Debian "
+"ontworpen is om 24/7 te werken. Bovendien is het aantal beschikbare "
+"pakketten en het aantal ondersteunde architecturen veel groter bij Debian "
+"dan bij Knoppix."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:414
+msgid ""
+"If you want Debian, it is best to install Debian from the get-go. Although "
+"it is possible to install Debian through other distributions, such as "
+"Knoppix, the procedure calls for expertise. If you are reading this FAQ, I "
+"would assume that you are new to both Debian and Knoppix. In that case, save "
+"yourself a lot of trouble later and install Debian right at the beginning."
+msgstr ""
+"Indien u Debian wenst, is het best om onmiddellijk Debian te installeren. "
+"Hoewel het mogelijk is om Debian te installeren via andere distributies, "
+"zoals Knoppix, vereist deze werkwijze een zekere expertise. Vermits u deze "
+"FAQ leest, neem ik aan dat zowel Debian als Knoppix nieuw zijn voor u. "
+"Bespaar u in dat geval later een heleboel problemen en installeer Debian "
+"onmiddellijk van bij het begin."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:419
+msgid ""
+"I installed Knoppix/Linux Mint Debian Edition/Ubuntu/... on my hard disk. "
+"Now I have a problem. What should I do?"
+msgstr ""
+"Ik installeerde Knoppix/Linux Mint Debian Edition/Ubuntu/... op mijn harde "
+"schijf en heb nu een probleem. Wat moet ik doen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:424
+msgid ""
+"You are advised not to use the Debian forums (either mailing lists or IRC) "
+"for help as people there may base their suggestions on the assumption that "
+"you are running a Debian system. These \"fixes\" might not be suited to what "
+"you are running, and might even make your problem worse."
+msgstr ""
+"We raden u aan om de Debian-forums (mailinglijsten of IRC) niet te gebruiken "
+"om hulp te vragen, vermits de mensen daar hun suggesties zullen baseren op "
+"de veronderstelling dat u een Debian-systeem gebruikt. Het is mogelijk dat "
+"deze \"reparaties\" niet aangepast zijn aan het systeem dat u gebruikt en uw "
+"probleem misschien zelfs nog groter zouden maken."
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:429
+msgid ""
+"Use the forums of the specific distribution you are using first. If you do "
+"not get help or the help you get does not fix your problem you might want to "
+"try asking in Debian forums, but keep the advice of the previous paragraph "
+"in mind."
+msgstr ""
+"Gebruik eerst de forums die specifiek bedoeld zijn voor de distributie die u "
+"gebruikt. Indien u er geen hulp krijgt, of indien de gekregen hulp geen "
+"oplossing biedt voor uw probleem, kunt u proberen om uw vraag te stellen op "
+"forums van Debian, maar houd de aanbeveling uit de vorige paragraaf in "
+"gedachten."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:44 choosing.sgml:431
+msgid ""
+"I'm using Knoppix/LMDE/Ubuntu/... and now I want to use Debian. How do I "
+"migrate?"
+msgstr ""
+"Ik ben een gebruiker van Knoppix/LMDE/Ubuntu/... en nu wil ik Debian gaan "
+"gebruiken. Hoe kan ik overschakelen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:44 choosing.sgml:437
+msgid ""
+"Consider the change from a Debian-based distribution to Debian just like a "
+"change from one operating system to another one. You should make a backup of "
+"all your data and reinstall the operating system from scratch. You should "
+"not attempt to \"upgrade\" to Debian using the package management tools as "
+"you might end up with an unusable system."
+msgstr ""
+"Beschouw de overstap van een op Debian gebaseerde distributie naar Debian "
+"juist gelijk een overstap van het ene besturingssysteem naar het andere. U "
+"moet een reservekopie maken van al uw gegevens en het besturingssysteem "
+"helemaal opnieuw herinstalleren. U moet niet proberen om naar Debian \"op te "
+"waarderen\" met behulp van de instrumenten voor pakketbeheer, aangezien u "
+"uiteindelijk misschien een onbruikbaar systeem bekomt."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:3
+msgid ""
+"If all your user data (i.e. your <file>/home</file>) is under a separate "
+"partition migrating to Debian is actually quite simple, you just have to "
+"tell the installation system to mount (but not reformat) that partition when "
+"reinstalling. Making backups of your data, as well as your previous system's "
+"configuration (i.e. <file>/etc/</file> and, maybe, <file>/var/</file>) is "
+"still encouraged."
+msgstr ""
+"Indien al uw gebruikersgegevens (d.w.z. uw <file>/home</file>) zich o een "
+"aparte partitie bevinden, is overstappen naar Debian eigenlijk heel "
+"eenvoudig. U moet bij het herinstalleren het installatiesysteem enkel "
+"opdragen om die partitie aan te koppelen (maar niet te formatteren). "
+"ReservekopieÃ«n maken van uw gegevens evenals van de configuratie van uw "
+"vroegere systeem (d.w.z. <file>/etc/</file> en misschien <file>/var/</file>) "
+"blijft aanbevolen."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:45 compat.sgml:7
+msgid "Compatibility issues"
+msgstr "Compatibiliteitskwesties"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:45 compat.sgml:9
+msgid "On what hardware architectures/systems does &debian; run?"
+msgstr "Op welke hardwarearchitecturen/systemen kan &debian; werken?"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:14
+msgid ""
+"&debian; includes complete source-code for all of the included programs, so "
+"it should work on all systems which are supported by the Linux kernel; see "
+"the <url id=\"http://en.tldp.org/FAQ/Linux-FAQ/intro.html#DOES-LINUX-RUN-ON-"
+"MY-COMPUTER\" name=\"Linux FAQ\"> for details."
+msgstr ""
+"&debian; bevat ook de volledige broncode voor alle programma's die het "
+"bevat, waardoor het kan werken op alle systemen die door de Linux-kernel "
+"ondersteund worden. Raadpleeg de <url id=\"http://en.tldp.org/FAQ/Linux-FAQ/"
+"intro.html#DOES-LINUX-RUN-ON-MY-COMPUTER\" name=\"Linux FAQ\"> voor meer "
+"details."
+
+#. type: <p><list>
+#: debian-faq.sgml:45 compat.sgml:17
+msgid ""
+"The current &debian; release, &release;, contains a complete, binary "
+"distribution for the following architectures:"
+msgstr ""
+"De huidige &debian; release, &release;, bevat een complete binaire "
+"distributie voor de volgende architecturen:"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:22
+msgid ""
+"<em>amd64</em>: this covers systems based on AMD 64bit CPUs with AMD64 "
+"extension and all Intel CPUs with EM64T extension, and a common 64bit "
+"userspace."
+msgstr ""
+"<em>amd64</em>: dit zijn systemen die gebaseerd zijn op 64-bits CPU's van "
+"AMD met de AMD64-uitbreiding en alle CPU's van Intel met de EM64T-"
+"uitbreiding, en een gemeenschappelijke 64-bits gebruikersruimte."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:24
+msgid "<em>arm64</em>: supports the latest 64-bit ARM-powered devices."
+msgstr ""
+"<em>arm64</em>: ondersteunt de recentste door ARM aangestuurde 64-bits "
+"apparaten."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:26
+msgid "<em>armel</em>: little-endian ARM machines."
+msgstr "<em>armel</em>: little-endian ARM machines."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:28
+msgid ""
+"<em>armhf</em>: an alternative to armel for ARMv7 machines with hard-float."
+msgstr ""
+"<em>armhf</em>: een alternatief voor armel voor ARMv7 machines met hard-"
+"float."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:33
+msgid ""
+"<em>i386</em>: this covers systems based on Intel and compatible processors, "
+"including Intel's 386, 486, Pentium, Pentium Pro, Pentium II (both Klamath "
+"and Celeron), and Pentium III, and most compatible processors by AMD, Cyrix "
+"and others."
+msgstr ""
+"<em>i386</em>: dit gaat om systemen die gebaseerd zijn op Intel en "
+"compatibele processoren, waaronder de 386, 486, Pentium, Pentium Pro, "
+"Pentium II (zowel Klamath als Celeron) en Pentium III van Intel en de meeste "
+"compatibele processoren van AMD, Cyrix en anderen."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:35
+msgid "<em>ia64</em>: Intel IA-64 (\"Itanium\") computers."
+msgstr "<em>ia64</em>: Intel IA-64 (\"Itanium\") computers."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:38
+msgid ""
+"<em>mips</em>: SGI's big-endian MIPS systems, Indy and Indigo2; <em>mipsel</"
+"em>: little-endian MIPS machines, Digital DECstations."
+msgstr ""
+"<em>mips</em>: SGI's big-endian MIPS-systemen, Indy en Indigo2; <em>mipsel</"
+"em>: little-endian MIPS-machines, Digital DECstations."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:42
+msgid ""
+"<em>powerpc</em>: this covers some IBM/Motorola PowerPC machines, including "
+"the Apple Macintosh PowerMac models, and the CHRP and PReP open architecture "
+"machines."
+msgstr ""
+"<em>powerpc</em>: daaronder vallen sommige IBM/Motorola PowerPC-machines, "
+"waaronder de Apple Macintosh PowerMac modellen en de CHRP en PReP open-"
+"architectuur-machines."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:45
+msgid ""
+"<em>ppc64el</em>: 64-bit little-endian PowerPC port, supports several recent "
+"PowerPC/POWER processors."
+msgstr ""
+"<em>ppc64el</em>: een versie voor de 64-bits little-endian PowerPC met "
+"ondersteuning voor verschillende recente PowerPC/POWER processors."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:47
+msgid "<em>s390x</em>: 64-bit port for IBM System z machines, replaced s390."
+msgstr ""
+"<em>s390x</em>: een 64-bits versie voor IBM System z machines, ter "
+"vervanging van s390."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:58
+msgid ""
+"The development of binary distributions of Debian for <em>hurd-i386</em> "
+"(for GNU Hurd kernel on i386 32-bit PCs), <em>mipsel64</em> (for 64 bit MIPS "
+"in little-endian mode), <em>powerpcspe</em> (port for the \"Signal "
+"Processing Engine\" hardware), <em>sparc64</em> (for 64 bit SPARC "
+"processors), <em>sh</em> (for Hitachi SuperH processors), and <em>x32</em> "
+"(for amd64/x86_64 CPUs using 32-bit pointers) is currently underway."
+msgstr ""
+"Momenteel wordt gewerkt aan de ontwikkeling van binaire distributies van "
+"Debian voor <em>hurd-i386</em> (voor de GNU Hurd kernel op i386 32-bits "
+"PC's), <em>mipsel64</em> (voor 64-bits MIPS in little-endian modus), "
+"<em>powerpcspe</em> (een versie voor de \"Signal Processing Engine\" "
+"hardware), <em>sparc64</em> (voor 64-bits SPARC processors), <em>sh</em> "
+"(voor Hitachi SuperH processors) en <em>x32</em> (voor amd64/x86_64 CPU's "
+"die werken met 32-bits pointers)."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:65
+msgid ""
+"Support for the <em>m68k</em> architecture was dropped in the Etch (Debian "
+"4.0) release, because it did not meet the criteria set by the Debian Release "
+"Managers. This architecture covers Amigas and ATARIs having a Motorola 680x0 "
+"processor for x>=2; with MMU. However, the port is still active and "
+"available for installation even if not a part of this official stable "
+"release and might be reactivated for future releases."
+msgstr ""
+"Ondersteuning voor de <em>m68k</em>-architectuur werd gestopt met de release "
+"van Etch (Debian 4.0), omdat ze niet beantwoorde aan de criteria die door de "
+"Release Managers van Debian vooropgesteld werden. Deze architectuur omvat "
+"Amiga's en ATARI's met een Motorola 680x0 processor voor x>=2; met MMU. Maar "
+"deze versie is nog steeds actief en kan nog geÃ¯nstalleerd worden, ook al "
+"maakt ze geen deel uit van deze officiÃ«le stabiele release en kan mogelijk "
+"voor toekomstige releases opnieuw geactiveerd worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:72
+msgid ""
+"Support for the <em>hppa</em> (Hewlett-Packard's PA-RISC machines) and "
+"<em>alpha</em> (Compaq/Digital's Alpha systems) were dropped in the Squeeze "
+"(Debian 6.0) release for similar reasons. The <em>arm</em> was dropped too "
+"in this release, as it was superseded by the <em>armel</em> architecture."
+msgstr ""
+"Voor gelijkaardige redenen werd ondersteuning voor de <em>hppa</em> (Hewlett-"
+"Packard's PA-RISC machines) en <em>alpha</em> (Compaq/Digital's Alpha "
+"systemen) gestopt in de release van Squeeze (Debian 6.0). Ook in deze "
+"release werd <em>arm</em> en vervangen door de <em>armel</em> architectuur."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:77
+msgid ""
+"Support for the 32-bit <em>s390</em> port (s390) was discontinued and "
+"replaced with s390x in Jessie (Debian 8). In addition, the ports to IA-64 "
+"and Sparc had to be removed from this release due to insufficient developer "
+"support."
+msgstr ""
+"Ondersteuning voor de 32-bits <em>s390</em>-uitgave (s390) werd gestopt en "
+"vervangen door s390x in Jessie (Debian 8). Daarenboven moesten de versies "
+"voor IA-64 en Sparc weggelaten worden in deze release omdat te weinig "
+"ontwikkelaars beschikbaar waren om ze te ondersteunen."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:80 compat.sgml:120
+msgid ""
+"For more information on the available ports see the <url id=\"http://www."
+"debian.org/ports/\" name=\"ports pages at the website\">."
+msgstr ""
+"Voor bijkomende informatie over de beschikbare architectuurgerelateerde "
+"versies (ports) kunt u de <url id=\"http://www.debian.org/ports/\" name="
+"\"architectuur-pagina's op de website\"> raadplegen."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:85
+msgid ""
+"For further information on booting, partitioning your drive, enabling PCMCIA "
+"(PC Card) devices and similar issues please follow the instructions given in "
+"the Installation Manual, which is available from our WWW site at <url id="
+"\"http://www.debian.org/releases/stable/installmanual\">."
+msgstr ""
+"Voor bijkomende informatie over het opstarten, de schijfindeling, het "
+"gebruiken van PCMCIA-(PC-kaart)apparaten en dergelijke zaken, volgt u best "
+"de instructies uit de Installatiehandleiding, die u op onze WWW-site vindt "
+"op <url id=\"http://www.debian.org/releases/stable/installmanual\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:45 compat.sgml:87
+msgid "What kernels does &debian; run?"
+msgstr "Welke kernels gebruikt &debian;?"
+
+#. type: <p><list>
+#: debian-faq.sgml:45 compat.sgml:90
+msgid ""
+"Beside Linux, Debian provides a complete, binary distribution for the "
+"following operating system kernels:"
+msgstr ""
+"Behalve voor Linux biedt Debian ook een volledige binaire distributie voor "
+"de volgende kernels van besturingssystemen:"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:96
+msgid ""
+"FreeBSD: provided through the <em>kfreebsd-amd64</em> and <em>kfreebsd-i386</"
+"em> ports, for 64-bit PCs and 32-bit PCs respectively. These ports were "
+"first released in Debian 6.0 Squeeze as a <em>technology preview</em>. "
+"However they were not part of the Debian 8 Jessie release."
+msgstr ""
+"FreeBSD: via de versies <em>kfreebsd-amd64</em> en <em>kfreebsd-i386</em>, "
+"respectievelijk voor 64-bits PC's en 32-bits PC's. Deze versies (ports) "
+"werden voor het eerst uitgebracht in Debian 6.0 Squeeze als een "
+"<em>technologische voorbeelduitgave</em>. Zij maakten evenwel geen deel uit "
+"van de release van Debian 8 Jessie."
+
+#. type: <p><list>
+#: debian-faq.sgml:45 compat.sgml:101
+msgid "In addition to these, work is in progress on the following adaptations:"
+msgstr "Daarnaast wordt ook nog gewerkt aan de volgende aanpassingen:"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:105
+msgid "<em>avr32</em>, port to Atmel's 32-bit RISC architecture,"
+msgstr ""
+"<em>avr32</em>, het geschikt maken (port) voor Atmel's 32-bits RISC "
+"architectuur,"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:108
+msgid ""
+"<em>hurd-i386</em>, a port for 32-bit PC. This port will use GNU Hurd, the "
+"new operating system being put together by the GNU group,"
+msgstr ""
+"<em>hurd-i386</em>, een versie voor 32-bits PC. Deze versie zal GNU Hurd "
+"gebruiken, het nieuwe besturingssysteem dat samengesteld wordt door de GNU "
+"groep."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:110
+msgid "<em>sh</em>, port to Hitachi SuperH processors."
+msgstr ""
+"<em>sh</em>, het geschikt maken (port) voor de Hitachi SuperH processors."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:116
+msgid ""
+"There were attempts to port the distribution to the NetBSD kernel, providing "
+"<em>netbsd-i386</em> (for 32-bit PCs) and <em>netbsd-alpha</em> (for Alpha "
+"machines) but these ports were never released and are currently abandoned."
+msgstr ""
+"Er waren ook pogingen om de distributie geschikt te maken voor de NetBSD "
+"kernel met <em>netbsd-i386</em> (voor 32-bits PC's) en <em>netbsd-alpha</em> "
+"(voor Alpha machines), maar deze versies werden nooit uitgebracht en zijn "
+"momenteel gestopt."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:45 compat.sgml:123
+msgid "How compatible is Debian with other distributions of Linux?"
+msgstr "Hoe compatibel is Debian met andere Linux-distributies?"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:128
+msgid ""
+"Debian developers communicate with other Linux distribution creators in an "
+"effort to maintain binary compatibility across Linux distributions. Most "
+"commercial Linux products run as well under Debian as they do on the system "
+"upon which they were built."
+msgstr ""
+"Ontwikkelaars van Debian communiceren met de ontwikkelaars van andere Linux-"
+"distributies om onderlinge binaire compatibiliteit te behouden tussen Linux-"
+"distributies. De meeste commerciÃ«le Linux-producten functioneren evengoed "
+"onder Debian als op het systeem waarop zij gebouwd werden."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:133
+msgid ""
+"&debian; adheres to the <url id=\"http://www.pathname.com/fhs/\" name="
+"\"Linux Filesystem Hierarchy Standard\">. However, there is room for "
+"interpretation in some of the rules within this standard, so there may be "
+"slight differences between a Debian system and other Linux systems."
+msgstr ""
+"&debian; houdt zich aan de <url id=\"http://www.pathname.com/fhs/\" name="
+"\"Linux Filesystem Hierarchy Standard\">. Voor sommige van de regels in deze "
+"standaard is er echter ruimte voor interpretatie, waardoor er kleine "
+"verschillen kunnen zijn tussen een Debian-systeem en andere Linux-systemen."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:144
+msgid ""
+"&debian; supports software developed for the <url id=\"http://www.linuxbase."
+"org/\" name=\"Linux Standard Base\">. The LSB is a specification for "
+"allowing the same binary package to be used on multiple distributions. The "
+"Debian Etch release is certified for LSB Release 3.1, see the <url id="
+"\"https://www.linux-foundation.org/lsb-cert/productdir.php\" name=\"Linux "
+"Foundation Certification webpage\">. Discussion and coordination of efforts "
+"towards ensuring Debian meets the requirements of the Linux Standard Base is "
+"taking place on the <url id=\"http://lists.debian.org/debian-lsb/\" name="
+"\"debian-lsb mailing list\">."
+msgstr ""
+"&debian; ondersteunt software die ontwikkeld wordt voor de <url id=\"http://"
+"www.linuxbase.org/\" name=\"Linux Standard Base\">. De LSB is een "
+"specificatie die moet toelaten dat hetzelfde binaire bestand kan gebruikt "
+"worden op verschillende distributies. De uitgave van Debian Etch heeft een "
+"gelijkvormigheidsattest voor LSB Release 3.1; zie de  <url id=\"https://www."
+"linux-foundation.org/lsb-cert/productdir.php\" name=\"Linux Foundation "
+"Certification webpage\">. Overleg over en coÃ¶rdinatie van de inspanningen "
+"van Debian om te beantwoorden aan de vereisten van de Linux Standard Base "
+"vindt plaats op de <url id=\"http://lists.debian.org/debian-lsb/\" name="
+"\"debian-lsb mailing-lijst\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:45 compat.sgml:147
+msgid "How source code compatible is Debian with other Unix systems?"
+msgstr "Hoe compatibel is de broncode van Debian met andere Unix-systemen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:156
+msgid ""
+"For most applications Linux source code is compatible with other Unix "
+"systems. It supports almost everything that is available in System V Unix "
+"systems and the free and commercial BSD-derived systems. However in the Unix "
+"business such claim has nearly no value because there is no way to prove it. "
+"In the software development area complete compatibility is required instead "
+"of compatibility in \"about most\" cases. So years ago the need for "
+"standards arose, and nowadays POSIX.1 (IEEE Standard 1003.1-1990) is one of "
+"the major standards for source code compatibility in Unix-like operating "
+"systems."
+msgstr ""
+"Bij de meeste Linux-toepassingen is de broncode compatibel met andere Unix-"
+"systemen. Bijna alles wat beschikbaar is in System V Unix-systemen en in de "
+"vrije en commerciÃ«le van BSD afgeleide systemen, wordt ondersteund. In het "
+"Unix-bedrijf heeft een dergelijke bewering nauwelijks waarde, omdat er geen "
+"manier bestaat om ze te bewijzen. Op het gebied van softwareontwikkeling is "
+"volledige compatibiliteit vereist in plaats van een compatibiliteit in "
+"\"bijna alle\" gevallen. Daarom ontstond jaren geleden de behoefte aan "
+"standaarden en tegenwoordig is POSIX.1 (IEEE Standard 1003.1-1990) een van "
+"de belangrijkste standaarden voor broncodecompatibliteit in Unix-achtige "
+"besturingssystemen."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:171
+msgid ""
+"Linux is intended to adhere to POSIX.1, but the POSIX standards cost real "
+"money and the POSIX.1 (and FIPS 151-2) certification is quite expensive; "
+"this made it more difficult for the Linux developers to work on complete "
+"POSIX conformance. The certification costs make it unlikely that Debian will "
+"get an official conformance certification even if it completely passed the "
+"validation suite. (The validation suite is now freely available, so it is "
+"expected that more people will work on POSIX.1 issues.)"
+msgstr ""
+"Het is de bedoeling dat Linux beantwoordt aan POSIX.1, maar de POSIX-"
+"standaarden kosten geld en de certificatie voor POSIX.1 (en FIPS 151-2) is "
+"behoorlijk duur. Dit bemoeilijkte de taak van Linux-ontwikkelaars om te "
+"werken aan volledige POSIX-conformiteit. De kosten verbonden aan de "
+"certificatie maken het niet waarschijnlijk dat Debian een officieel "
+"conformiteitscertificaat zal krijgen, zelfs als het volledig slaagde in de "
+"valideringssuite. (De valideringssuite is nu vrij beschikbaar, waardoor kan "
+"verwacht worden dat meer mensen zullen werken op POSIX.1-materies.)"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:183
+msgid ""
+"Unifix GmbH (Braunschweig, Germany) developed a Linux system that has been "
+"certified to conform to FIPS 151-2 (a superset of POSIX.1). This technology "
+"was available in Unifix' own distribution called Unifix Linux 2.0 and in "
+"Lasermoon's Linux-FT."
+msgstr ""
+"Unifix GmbH (Braunschweig, Duitsland) ontwikkelde een Linux-systeem dat "
+"gecertificeerd werd als conform aan FIPS 151-2 (een uitbreiding van "
+"POSIX.1). Deze technologie was beschikbaar in de eigen distributie van "
+"Unifix onder de naam Unifix Linux 2.0, en in Linux-FT van Lasermoon."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:45 compat.sgml:187
+msgid ""
+"Can I use Debian packages (\".deb\" files) on my Red Hat/Slackware/... Linux "
+"system? Can I use Red Hat packages (\".rpm\" files) on my &debian; system?"
+msgstr ""
+"Kan ik Debian-pakketten (\".deb\"-bestanden) gebruiken op mijn Red Hat/"
+"Slackware/... Linux-systeem? Kan ik Red Hat-pakketten (\".rpm\"-bestanden) "
+"gebruiken op mijn &debian;-systeem?"
+
+#. type: <p><taglist>
+#: debian-faq.sgml:45 compat.sgml:190
+msgid ""
+"Different Linux distributions use different package formats and different "
+"package management programs."
+msgstr ""
+"Verschillende Linux-distributies gebruiken verschillende indelingen voor hun "
+"pakketten en verschikkende programma's voor pakketbeheer."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:45 compat.sgml:191
+msgid "<strong>You probably can:</strong>"
+msgstr "<strong>Wat u wellicht kunt doen:</strong>"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:203
+msgid ""
+"A program to unpack a Debian package onto a Linux host that is been built "
+"from a `foreign' distribution is available, and will generally work, in the "
+"sense that files will be unpacked. The converse is probably also true, that "
+"is, a program to unpack a Red Hat or Slackware package on a host that is "
+"based on &debian; will probably succeed in unpacking the package and placing "
+"most files in their intended directories. This is largely a consequence of "
+"the existence (and broad adherence to) the Linux Filesystem Hierarchy "
+"Standard. The <url id=\"http://packages.debian.org/alien\" name=\"Alien\"> "
+"package is used to convert between different package formats."
+msgstr ""
+"Er bestaat een programma om een Debian-pakket uit te pakken naar een Linux-"
+"computer waarop een \"vreemde\" distributie geÃ¯nstalleerd is. Dat zal "
+"meestal werken in die zin dat de bestanden uitgepakt zullen worden. Het "
+"omgekeerde is wellicht ook waar, hetgeen wil zeggen dat een programma om een "
+"pakket van Red Hat of Slackware uit te pakken op een computer die op "
+"&debian; gebaseerd is er wellicht in zal slagen het pakket uit te pakken en "
+"de meeste bestanden te plaatsen in de mappen waar ze thuis horen. Dit is in "
+"belangrijke mate een gevolg van het feit dat de Linux Filesystem Hierarchy "
+"Standard bestaat (en een brede navolging kent). Het pakket <url id=\"http://"
+"packages.debian.org/alien\" name=\"Alien\"> wordt gebruikt voor het "
+"converteren van verschillende pakketindelingen."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:45 compat.sgml:203
+msgid "<strong>You probably do not want to:</strong>"
+msgstr "<strong>Wat u wellicht niet wilt doen:</strong>"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:214
+msgid ""
+"Most package managers write administrative files when they are used to "
+"unpack an archive. These administrative files are generally not "
+"standardized. Therefore, the effect of unpacking a Debian package on a "
+"`foreign' host will have unpredictable (certainly not useful) effects on the "
+"package manager on that system. Likewise, utilities from other distributions "
+"might succeed in unpacking their archives on Debian systems, but will "
+"probably cause the Debian package management system to fail when the time "
+"comes to upgrade or remove some packages, or even simply to report exactly "
+"what packages are present on a system."
+msgstr ""
+"De meeste pakketbeheerders schrijven beheerbestanden als daarvan gebruik "
+"gemaakt wordt voor het uitpakken van een archief. Meestal zijn dit soort "
+"beheerbestanden niet gestandaardiseerd. Om die reden is het onvoorspelbaar "
+"welke effecten het uitpakken van een Debian-pakket op een \"vreemde\" "
+"computer zal hebben op het pakketbeheerssysteem van dat systeem (en zijn ze "
+"zeker niet bruikbaar). Evenzeer kunnen hulpprogramma's van andere "
+"distributies erin slagen om hun archieven uit te pakken op een Debian-"
+"systeem, maar wellicht zal het pakketbeheersysteem van Debian falen op het "
+"moment dat bepaalde pakketten moeten opgewaardeerd of verwijderd worden of "
+"misschien zelfs gewoon niet instaat zijn om te rapporteren welke pakketten "
+"exact aanwezig zijn op het systeem."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:45 compat.sgml:214
+msgid "<strong>A better way:</strong>"
+msgstr "<strong>Een betere werkwijze:</strong>"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:220
+msgid ""
+"The Linux File System Standard (and therefore &debian;) requires that "
+"subdirectories under <tt>/usr/local/</tt> be entirely under the user's "
+"discretion. Therefore, users can unpack `foreign' packages into this "
+"directory, and then manage their configuration, upgrade and removal "
+"individually."
+msgstr ""
+"De Linux File System Standard (en dus &debian;) schrijft voor dat de mappen "
+"onder <tt>/usr/local/</tt> volledig onder de discretionaire bevoegdheid van "
+"de gebruiker vallen. Daarom kunnen gebruikers \"vreemde\" pakketten "
+"uitpakken naar deze map en hun configuratie, opwaardering en verwijdering "
+"individueel beheren."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:45 compat.sgml:228
+msgid "How should I install a non-Debian program?"
+msgstr "Hoe moet ik een niet-Debian programma installeren?"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:236
+msgid ""
+"Files under the directory <tt>/usr/local/</tt> are not under the control of "
+"the Debian package management system. Therefore, it is good practice to "
+"place the source code for your program in /usr/local/src/. For example, you "
+"might extract the files for a package named \"foo.tar\" into the directory "
+"<tt>/usr/local/src/foo</tt>. After you compile them, place the binaries in "
+"<tt>/usr/local/bin/</tt>, the libraries in <tt>/usr/local/lib/</tt>, and the "
+"configuration files in <tt>/usr/local/etc/</tt>."
+msgstr ""
+"Bestanden onder de map <tt>/usr/local/</tt> vallen niet onder de controle "
+"van het pakketbeheersysteem van Debian. Het is daarom een goede gewoonte om "
+"de broncode van uw programma te plaatsen in /usr/local/src/. U zou "
+"bijvoorbeeld de bestanden voor een pakket \"foo.tar\" kunnen uitpakken in de "
+"map <tt>/usr/local/src/foo</tt>. Plaats, nadat u ze gecompileerd heeft, de "
+"binaire bestanden in <tt>/usr/local/bin/</tt>, de bibliotheken in <tt>/usr/"
+"local/lib/</tt> en de configuratiebestanden in <tt>/usr/local/etc/</tt>."
+
+#. type: <p><example>
+#: debian-faq.sgml:45 compat.sgml:240
+msgid ""
+"If your programs and/or files really must be placed in some other directory, "
+"you could still store them in <tt>/usr/local/</tt>, and build the "
+"appropriate symbolic links from the required location to its location in "
+"<tt>/usr/local/</tt>, e.g., you could make the link"
+msgstr ""
+"Indien uw programma's en/of bestanden echt in een andere map geplaatst "
+"moeten worden, zou u ze nog steeds kunnen plaatsen in <tt>/usr/local/</tt> "
+"en de passende symbolische koppelingen aanmaken van de vereiste locatie naar "
+"hun locatie in <tt>/usr/local/</tt>. U zou bijvoorbeeld de volgende "
+"koppeling kunnen maken"
+
+#. type: <example></example>
+#: debian-faq.sgml:45 compat.sgml:236
+#, no-wrap
+msgid "ln -s /usr/local/bin/foo /usr/bin/foo"
+msgstr "ln -s /usr/local/bin/foo /usr/bin/foo"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:247
+msgid ""
+"In any case, if you obtain a package whose copyright allows redistribution, "
+"you should consider making a Debian package of it, and uploading it for the "
+"Debian system. Guidelines for becoming a package developer are included in "
+"the Debian Policy manual (see <ref id=\"debiandocs\">)."
+msgstr ""
+"Als u beschikt over een pakket met een copyright dat de verspreiding ervan "
+"toelaat, zou u in elk geval kunnen overwegen om er een pakket voor Debian "
+"van te maken en dit naar het Debian-systeem te uploaden. Richtlijnen over "
+"hoe u een pakketontwikkelaar kunt worden, zijn te vinden in het "
+"Beleidshandboek van Debian (Debian Policy manual - zie <ref id=\"debiandocs"
+"\">)."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:45 compat.sgml:249
+msgid "Why can't I compile programs that require libtermcap?"
+msgstr "Waarom kan ik geen programma's compileren die libtermcap vereisen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:253
+msgid ""
+"Debian uses the <tt>terminfo</tt> database and the <tt>ncurses</tt> library "
+"of terminal interface routes, rather than the <tt>termcap</tt> database and "
+"the <tt>termcap</tt> library."
+msgstr ""
+"Debian gebruikt de database <tt>terminfo</tt> en de bibliotheek <tt>ncurses</"
+"tt> van terminal interface routes in plaats van de database en de "
+"bibliotheek van <tt>termcap</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:259
+msgid ""
+"The low-level <tt>terminfo</tt> library has been split out from the general "
+"<tt>ncurses</tt> library, making a new package called <tt>libtinfo5</tt>. "
+"<tt>libncurses</tt> is linked to <tt>libtinfo</tt>, so users who are "
+"compiling programs that require some knowledge of the terminal interface "
+"should replace references to <tt>libtermcap</tt> with references to "
+"<tt>libncurses</tt>."
+msgstr ""
+"De bibliotheek van lagere orde <tt>terminfo</tt> werd afgesplitst uit de "
+"algemene bibliotheek <tt>ncurses</tt> met een nieuw pakket met de naam "
+"<tt>libtinfo5</tt> tot gevolg. <tt>libncurses</tt> is gekoppeld aan "
+"<tt>libtinfo</tt>, waardoor gebruikers die een programma compileren dat "
+"enige kennis vereist van de terminal interface, verwijzingen naar "
+"<tt>libtermcap</tt> moeten vervangen met verwijzingen naar <tt>libncurses</"
+"tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:45 compat.sgml:265
+msgid ""
+"To support binaries that have already been linked with the <tt>termcap</tt> "
+"library, and for which you do not have the source, you will have to find the "
+"library source and compile it yourself. Debian used to provide a package "
+"called termcap-compat which contained both <tt>libtermcap.so.2</tt> and <tt>/"
+"etc/termcap</tt>, but this was removed from the distribution in 2005."
+msgstr ""
+"Om binaire bestanden te ondersteunen die reeds gelinkt zijn met de "
+"<tt>termcap</tt>-bibliotheek en waarvan u niet over de broncode beschikt, "
+"zult u zelf de broncode van de bibliotheek moeten zoeken en ze zelf moeten "
+"compileren. Vroeger stelde Debian een pakket met de naam termcap-compat ter "
+"beschikking dat zowel <tt>libtermcap.so.2</tt> als <tt>/etc/termcap</tt> "
+"bevatte, maar dit werd in 2005 uit de distributie verwijderd."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:45 compat.sgml:267
+msgid "Why can't I install AccelX?"
+msgstr "Waarom kan ik AccelX niet installeren?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:3
+msgid ""
+"AccelX uses the <tt>termcap</tt> library for installation. See <ref id="
+"\"termcap\"> above."
+msgstr ""
+"AccelX maakt voor de installatie gebruik van de <tt>termcap</tt>-"
+"bibliotheek. Zie <ref id=\"termcap\"> hierboven."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:5
+msgid "Software available in the Debian system"
+msgstr "In het Debian-systeem aanwezige software"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:8
+msgid ""
+"What types of applications and development software are available for "
+"&debian;?"
+msgstr ""
+"Welke types toepassingssoftware en ontwikkelingssoftware zijn beschikbaar in "
+"&debian;?"
+
+#. type: <p><list>
+#: debian-faq.sgml:46 software.sgml:9
+msgid "Like most Linux distributions, &debian; provides:"
+msgstr "Zoals de meeste Linux-distributies levert &debian;:"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:12
+msgid ""
+"the major GNU applications for software development, file manipulation, and "
+"text processing, including gcc, g++, make, texinfo, Emacs, the Bash shell "
+"and numerous upgraded Unix utilities,"
+msgstr ""
+"de belangrijkste GNU-toepassingen voor softwareontwikkeling, "
+"bestandsmanipulatie en tekstbehandeling, waaronder gcc, g++, make, texinfo, "
+"Emacs, de Bash shell en talloze opgewaardeerde Unix-hulpprogramma's,"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:14
+msgid ""
+"Perl, Python, Tcl/Tk and various related programs, modules and libraries for "
+"each of them,"
+msgstr ""
+"Perl, Python, Tcl/Tk en talrijke verwante programma's, modules en "
+"bibliotheken voor elk van hen,"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:15
+msgid "TeX (LaTeX) and Lyx, dvips, Ghostscript,"
+msgstr "TeX (LaTeX) en Lyx, dvips, Ghostscript,"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:18
+msgid ""
+"the Xorg windowing system, which provides a networked graphical user "
+"interface for Linux, and countless X applications including the GNOME, KDE "
+"and Xfce desktop environments,"
+msgstr ""
+"het windowssysteem van Xorg dat voorziet in een genetwerkte grafische "
+"gebruikersinterface voor Linux en talloze grafische applicaties, waaronder "
+"de desktopomgevingen GNOME, KDE en Xfce,"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:22
+msgid ""
+"a full suite of networking applications, including servers for Internet "
+"protocols such as HTTP (WWW), FTP, NNTP (news), SMTP and POP (mail) and DNS "
+"(name servers); relational databases like PostgreSQL, MySQL; also provided "
+"are web browsers including the various Mozilla products,"
+msgstr ""
+"een volledige suite netwerktoepassingen, waaronder servers voor "
+"internetprotocollen zoals HTTP (WWW), FTP, NNTP (nieuws), SMTP en POP (mail) "
+"en DNS (naamservers); relationele databases zoals PostgreSQL, MySQL; ook "
+"webbrowsers werden voorzien, waaronder de verschillende producten van "
+"Mozilla,"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:26
+msgid ""
+"a complete set of office applications, including the LibreOffice "
+"productivity suite, Gnumeric and other spreadsheets, WYSIWYG editors, "
+"calendars."
+msgstr ""
+"een volledige set kantoortoepassingen, waaronder de productieve suite van "
+"LibreOffice, Gnumeric en andere rekenbladen, WYSIWYG-editors en "
+"kalendertoepassingen."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:35
+msgid ""
+"More than &main-pkgs; packages, ranging from news servers and readers to "
+"sound support, FAX programs, database and spreadsheet programs, image "
+"processing programs, communications, net, and mail utilities, Web servers, "
+"and even ham-radio programs are included in the distribution. Other &contrib-"
+"nonfree-pkgs; software suites are available as Debian packages, but are not "
+"formally part of Debian due to license restrictions."
+msgstr ""
+"De distributie bevat meer dan &main-pkgs; pakketten, gaande van "
+"nieuwsservers en -lezers tot ondersteuning voor geluid, FAX-programma's, "
+"databanken en rekenbladen, programma's voor beeldbewerking, "
+"communicatieprogramma's, toepassingen voor het net en e-mailtoepassingen, "
+"webservers en zelfs programma's voor amateurradio. Nog &contrib-nonfree-"
+"pkgs; andere softwaresuites worden als Debian-pakketten ter beschikking "
+"gesteld, maar maken omwille van licentierestricties formeel geen deel uit "
+"van Debian."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:37
+msgid "Who wrote all that software?"
+msgstr "Wie schreef al deze software?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:41
+msgid ""
+"For each package the <em>authors</em> of the program(s) are credited in the "
+"file <tt>/usr/share/doc/PACKAGE/copyright</tt>, where PACKAGE is to be "
+"substituted with the package's name."
+msgstr ""
+"Bij elk pakket worden de <em>auteurs</em> van het programma vermeld in het "
+"bestand <tt>/usr/share/doc/PAKKET/copyright</tt>, waarbij PAKKET vervangen "
+"moet worden door de naam van het pakket."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:47
+msgid ""
+"<em>Maintainers</em> who package this software for the &debian; system are "
+"listed in the Debian control file (see <ref id=\"controlfile\">) that comes "
+"with each package. The Debian changelog, in <tt>/usr/share/doc/PACKAGE/"
+"changelog.Debian.gz</tt>, mentions the people who've worked on the Debian "
+"packaging too."
+msgstr ""
+"De <em>onderhouders</em> die deze software voor het &debian;-systeem "
+"verpakken, worden vermeld in het control-bestand van Debian (zie <ref id="
+"\"controlfile\">) dat bij elk pakket zit. Ook het changelog-bestand van "
+"Debian in <tt>/usr/share/doc/PAKKET/changelog.Debian.gz</tt> vermeldt de "
+"mensen die werkten aan de verpakking voor Debian."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:50
+msgid ""
+"How can I get a current list of programs that have been packaged for Debian?"
+msgstr ""
+"Hoe verkrijg ik een actuele lijst van programma's die verpakt werden voor "
+"Debian?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:55
+msgid ""
+"A complete list is available from any of the <url id=\"http://www.debian.org/"
+"distrib/ftplist\" name=\"Debian mirrors\">, in the file <tt>indices/"
+"Maintainers</tt>. That file includes the package names and the names and e-"
+"mails of their respective maintainers."
+msgstr ""
+"Een volledige lijst is te vinden op elk van de <url id=\"http://www.debian."
+"org/distrib/ftplist\" name=\"Debian mirrors\"> in het bestand <tt>indices/"
+"Maintainers</tt>. Dat bestand bevat de namen van de pakketten en de namen en "
+"de e-mailadressen van hun respectieve onderhouders."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:59
+msgid ""
+"The <url id=\"http://packages.debian.org/\" name=\"WWW interface to the "
+"Debian packages\"> conveniently summarizes the packages in each of about "
+"thirty \"sections\" of the Debian archive."
+msgstr ""
+"De <url id=\"http://packages.debian.org/\" name=\"WWW-interface naar de "
+"Debian-pakketten\"> vat de pakketten handig samen in de ongeveer dertig "
+"\"secties\" van het Debian-archief."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:61
+msgid "How can I install a developer's environment to build packages?"
+msgstr ""
+"Hoe kan ik een ontwikkelingsomgeving installeren voor het bouwen van "
+"pakketten?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:68
+msgid ""
+"If you want to build packages in your Debian system you will need to have a "
+"basic development environment, including a C/C++ compiler and some other "
+"essential packages. In order to install this environment you just need to "
+"install the <package>build-essential</package> package. This is a meta-"
+"package or place-holder package which depends on the standard development "
+"tools one needs to build a Debian package."
+msgstr ""
+"Indien u op uw Debian-systeem pakketten wilt bouwen, heeft u een basale "
+"ontwikkelingsomgeving nodig, met daarin een C/C++-compiler en enkele andere "
+"essentiÃ«le pakketten. Om deze omgeving te installeren dient u enkel het "
+"pakket <package>build-essential</package> te installeren. Dit is een meta-"
+"pakket of een dummypakket dat de standaard ontwikkelingsgereedschappen die "
+"men nodig heeft om een Debian-pakket te bouwen, als vereiste heeft."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:73
+msgid ""
+"Some software can, however, need additional software to be rebuilt, "
+"including library headers or additional tools such as <prgn>autoconf</prgn> "
+"or <prgn>gettext</prgn>. Debian provides many of the tools needed to build "
+"other software as Debian packages."
+msgstr ""
+"Voor het opnieuw bouwen van sommige software kan nog bijkomende software "
+"nodig zijn, waaronder bibliotheek-headers of extra gereedschappen, zoals "
+"<prgn>autoconf</prgn> of <prgn>gettext</prgn>. Veel van de gereedschappen "
+"die nodig zijn om andere software te bouwen, worden door Debian als Debian-"
+"pakketten ter beschikking gesteld."
+
+#. type: <p><example>
+#: debian-faq.sgml:46 software.sgml:81
+msgid ""
+"Finding which software is precisely required can be tricky, however, unless "
+"you are planning on rebuilding Debian packages. This last task is rather "
+"easy to do, as official packages have to include a list of the additional "
+"software (besides the packages in <package>build-essential</package>) needed "
+"to build the package, this is known as <tt>Build-Dependencies</tt>. To "
+"install all the packages needed to build a given source package and then "
+"build said source package you can just run:"
+msgstr ""
+"Uitzoeken welke software exact nodig is, kan evenwel moeilijk zijn, tenzij u "
+"van plan bent Debian-pakketten opnieuw te bouwen. Dit laatste is een eerder "
+"gemakkelijke taak, vermits officiÃ«le pakketten een lijst moeten bevatten van "
+"de extra software (behalve de pakketten in <package>build-essential</"
+"package>) die nodig is om het pakket te bouwen en welke bekend staat als de "
+"<tt>Build-Dependencies</tt>. Om alle pakketten te installeren die nodig zijn "
+"om een bepaald bronpakket te bouwen en vervolgens dat pakket te bouwen, "
+"voert u gewoon de volgende opdrachten uit:"
+
+#. type: <example></example>
+#: debian-faq.sgml:46 software.sgml:84
+#, no-wrap
+msgid ""
+"# apt-get build-dep <var>foo</var>\n"
+"# apt-get source --build <var>foo</var>"
+msgstr ""
+"# apt-get build-dep <var>foo</var>\n"
+"# apt-get source --build <var>foo</var>"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:90
+msgid ""
+"Notice that if you want to build the Linux kernels distributed by Debian you "
+"will want to install also the <package>kernel-package</package> package. For "
+"more information see <ref id=\"customkernel\">."
+msgstr ""
+"Merk op dat wanneer u de Linux-kernels die door Debian verdeeld worden, wilt "
+"bouwen, u ook het pakket <package>kernel-package</package> moet installeren. "
+"Raadpleeg voor bijkomende informatie <ref id=\"customkernel\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:92
+msgid "What is missing from &debian;?"
+msgstr "Wat ontbreekt in &debian;?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:95
+msgid ""
+"There is a list of packages which still need to be packaged for Debian, the "
+"<url id=\"http://www.debian.org/devel/wnpp/\" name=\"Work-Needing and "
+"Prospective Packages list\">."
+msgstr ""
+"Er bestaat een lijst van pakketten die nog voor Debian verpakt moeten "
+"worden, de  <url id=\"http://www.debian.org/devel/wnpp/\" name=\"Work-"
+"Needing and Prospective Packages list\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:97
+msgid "For more details about adding missing things, see <ref id=\"contrib\">."
+msgstr ""
+"Raadpleeg <ref id=\"contrib\"> voor bijkomende informatie over het toevoegen "
+"van ontbrekende zaken."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:101
+msgid ""
+"Why do I get \"ld: cannot find -lfoo\" messages when compiling programs? Why "
+"aren't there any libfoo.so files in Debian library packages?"
+msgstr ""
+"Waarom krijg ik bij het compileren van programma's meldingen zoals \"ld: "
+"cannot find -lfoo\"? Waarom bevatten bibliotheekpakketten in Debian geen "
+"libfoo.so-bestanden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:106
+msgid ""
+"Debian Policy requires that such symbolic links (to libfoo.so.x.y.z or "
+"similar) are placed in separate, development packages. Those packages are "
+"usually named libfoo-dev or libfooX-dev (presuming the library package is "
+"named libfooX, and X is a whole number)."
+msgstr ""
+"De beleidsrichtlijn van Debian vereist dat dergelijke symbolische "
+"koppelingen (naar libfoo.so.x.y.z of iets dergelijks) in aparte "
+"ontwikkelingspakketten geplaatst worden. Deze pakketten heten gewoonlijk "
+"libfoo-dev of libfooX-dev (in de veronderstelling dat het bibliotheekpakket "
+"libfooX heet en X een geheel getal is)."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:108
+msgid "(How) Does Debian support Java?"
+msgstr "(Hoe) ondersteunt Debian Java?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:112
+msgid ""
+"Several <em>free</em> implementations of Java technology are available as "
+"Debian packages, providing both Java Development Kits as well as Runtime "
+"Environments. You can write, debug and run Java programs using Debian."
+msgstr ""
+"Verschillende <em>vrije</em> implementaties van Java-technologie zijn als "
+"Debian-pakketten beschikbaar, met daarbij zowel Java Development Kits als "
+"Runtime Environments. Met Debian kunt u Java-programma's schrijven, debuggen "
+"en uitvoeren."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:117
+msgid ""
+"Running a Java applet requires a web browser with the capability to "
+"recognize and execute it. Several web browsers available in Debian, such as "
+"Mozilla or Konqueror, support Java plug-ins that enable running Java applets "
+"within them."
+msgstr ""
+"Het uitvoeren van een Java-applet vereist een webbrowser die in staat is het "
+"te herkennen en uit te voeren. Verschillende web-browsers in Debian, zoals "
+"Mozilla en Konqueror, ondersteunen Java plug-ins die het uitvoeren van Java-"
+"applets mogelijk maken."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:121
+msgid ""
+"Please refer to the <url id=\"http://www.debian.org/doc/manuals/debian-java-"
+"faq/\" name=\"Debian Java FAQ\"> for more information."
+msgstr ""
+"Raadpleeg de <url id=\"http://www.debian.org/doc/manuals/debian-java-faq/\" "
+"name=\"Debian Java FAQ\"> voor bijkomende informatie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:124
+msgid ""
+"How can I check that I am using a Debian system, and what version it is?"
+msgstr ""
+"Hoe kan ik nagaan dat ik een Debian-systeem gebruik en welke versie het is?"
+
+#. type: <p><example>
+#: debian-faq.sgml:46 software.sgml:126
+msgid ""
+"In order to make sure that your system has been installed from the real "
+"Debian base disks, use the"
+msgstr ""
+"Om er zeker van te zijn dat uw systeem geÃ¯nstalleerd werd met behulp van de "
+"echte basisschijven van Debian, gebruikt u het commando"
+
+#. type: <example></example>
+#: debian-faq.sgml:46 software.sgml:124
+#, no-wrap
+msgid "lsb_release -a"
+msgstr "lsb_release -a"
+
+#. type: </example><example>
+#: debian-faq.sgml:46 software.sgml:131
+msgid ""
+"command. It will display the name of the distribution (in Distributor ID "
+"field) and the version of the system (in Release and Codename fields). The "
+"following is an example run in a Debian system:"
+msgstr ""
+"Dat zal de naam van de distributie weergeven (in het veld Distributor ID) en "
+"de versie van het systeem (in de velden Release en Codename). In het "
+"hiernavolgende voorbeeld wordt het commando op een Debian-systeem uitgevoerd:"
+
+#. type: <example></example>
+#: debian-faq.sgml:46 software.sgml:138
+#, no-wrap
+msgid ""
+"$ lsb_release -a\n"
+"No LSB modules are available.\n"
+"Distributor ID: Debian\n"
+"Description:    Debian GNU/Linux 7.4 (wheezy)\n"
+"Release:    7.4\n"
+"Codename:   wheezy"
+msgstr ""
+"$ lsb_release -a\n"
+"No LSB modules are available.\n"
+"Distributor ID: Debian\n"
+"Description:    Debian GNU/Linux 7.4 (wheezy)\n"
+"Release:    7.4\n"
+"Codename:   wheezy"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:145
+msgid ""
+"You can also check for the existence of <tt>/etc/debian_version</tt> file, "
+"which contains a single one-line entry giving the version number of the "
+"release, as defined by the package <tt>base-files</tt>."
+msgstr ""
+"U kunt ook nagaan of het bestand <tt>/etc/debian_version</tt> bestaat. Het "
+"bevat Ã©Ã©n enkele regel met het versienummer van de release, zoals "
+"gedefinieerd door het pakket <tt>base-files</tt>."
+
+#. type: <p><example>
+#: debian-faq.sgml:46 software.sgml:150
+msgid ""
+"Users should be aware, however, that the Debian system consists of many "
+"parts, each of which can be updated (almost) independently. Each Debian "
+"\"release\" contains well defined and unchanging contents. Updates are "
+"separately available. For a one-line description of the installation status "
+"of package <tt>foo</tt>, use the command <tt>dpkg --list foo</tt>. For a "
+"more verbose description, use:"
+msgstr ""
+"Gebruikers moeten echter weten dat het Debian-systeem uit verschillende "
+"onderdelen bestaat en dat elk ervan (bijna) onafhankelijk opgewaardeerd kan "
+"worden. Elke \"release\" van Debian heeft een duidelijk omschreven en "
+"onveranderlijke inhoud. Updates zijn afzonderlijk beschikbaar. Een "
+"beschrijving op Ã©Ã©n enkele regel van de installatietoestand van een pakket "
+"<tt>foo</tt>, krijgt u met het commando <tt>dpkg --list foo</tt>. Gebruik "
+"voor een meer uitgebreide beschrijving:"
+
+#. type: <example></example>
+#: debian-faq.sgml:46 software.sgml:145
+#, no-wrap
+msgid "dpkg --status foo"
+msgstr "dpkg --status foo"
+
+#. type: </example><example>
+#: debian-faq.sgml:46 software.sgml:152
+msgid "To view versions of all installed packages, run:"
+msgstr ""
+"Om de versienummers van alle geÃ¯nstalleerde pakketten te zien, geeft u het "
+"commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:46 software.sgml:145
+#, no-wrap
+msgid "dpkg -l"
+msgstr "dpkg -l"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:160
+msgid ""
+"Note that the existence of the program <tt>dpkg</tt> shows that you should "
+"be able to install Debian packages on your system. However, since the "
+"program has been ported to many other operating systems and architectures, "
+"this is no longer a reliable method of determining if a system is &debian;."
+msgstr ""
+"Merk op at het bestaan van het programma <tt>dpkg</tt> aantoont dat u in "
+"staat zou moeten zijn om op uw systeem Debian-pakketten te installeren. "
+"Aangezien het programma echter geschikt gemaakt werd voor veel andere "
+"besturingssystemen en architecturen, is dit niet langer een betrouwbare "
+"methode om uit te maken of een systeem &debian; is."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:162
+msgid "How does Debian support non-English languages?"
+msgstr "Hoe ondersteunt Debian andere talen dan het Engels?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:165
+msgid ""
+"&debian; is distributed with keymaps for nearly two dozen keyboards, and "
+"with utilities (in the <tt>kbd</tt> package) to install, view, and modify "
+"the tables."
+msgstr ""
+"&debian; wordt verdeeld met toetsenbordindelingen voor bijna twee dozijn "
+"toetsenborden en met hulpprogramma's (in het pakket <tt>kbd</tt>) om de "
+"tabellen te installeren, te bekijken en te wijzigen."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:166
+msgid "The installation prompts the user to specify the keyboard he will use."
+msgstr ""
+"Het installatieprogramma vraagt de gebruiker om op te geven welk toetsenbord "
+"hij gebruikt."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:169
+msgid ""
+"Nearly all of the software in Debian supports UTF-8 as character set. Legacy "
+"character sets, such as ISO-8859-1 or ISO-8859-2, should be considered "
+"obsolete."
+msgstr ""
+"Bijna alle software in Debian ondersteunt de tekenset UTF-8. Vroegere "
+"tekensets, zoals ISO-8859-1 en ISO-8859-2, moeten als verouderd beschouwd "
+"worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:176
+msgid ""
+"Currently, support for German-, Spanish-, French-, Hungarian-, Italian-, "
+"Japanese-, Korean-, Dutch-, Polish-, Portuguese-, Russian-, Turkish-, and "
+"Chinese-language manual pages is provided through the <tt>manpages-LANG</tt> "
+"packages (where LANG is the two-letter ISO country code). To access an NLS "
+"manual page, the user must set the shell LC_MESSAGES variable to the "
+"appropriate string."
+msgstr ""
+"Momenteel wordt ondersteuning geboden voor man-pagina's in het Duits, "
+"Spaans, Frans, Hongaars, Italiaans, Japans. Koreaans, Nederlands, Pools, "
+"Portugees, Russisch, Turks en Chinees via de pakketten <tt>manpages-TAAl</"
+"tt> (waarbij TAAL de uit twee letters bestaande ISO-landcode is). Om een man-"
+"pagina in zijn moedertaal te raadplegen, moet de gebruiker de shell-"
+"variabele LC_MESSAGES op de gepaste manier instellen."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:180
+msgid ""
+"For example, in the case of the Italian-language manual pages, LC_MESSAGES "
+"needs to be set to 'italian'. The <prgn>man</prgn> program will then search "
+"for Italian manual pages under <tt>/usr/share/man/it/</tt>."
+msgstr ""
+"Bijvoorbeeld, voor man-pagina's in de Nederlandse taal, moet LC_MESSAGES "
+"ingesteld worden op 'Nederlands'. Het programma <prgn>man</prgn> zal dan "
+"zoeken naar Nederlandse man-pagina's onder <tt>/usr/share/man/nl/</tt>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:184
+msgid "Where is ezmlm/djbdns/qmail?"
+msgstr "Waar vindt men ezmlm/djbdns/qmail?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:191
+msgid ""
+"Dan J. Bernstein used to distribute <url id=\"http://cr.yp.to/software.html"
+"\" name=\"all software he has written\"> with a restrictive license which "
+"does not allow modified binaries to be distributed. In november 2007 "
+"however, Bernstein said \"[...] i have decided to put all of my future and "
+"[...] past software into the public domain\". See <url id=\"http://cr.yp.to/"
+"distributors.html\" name=\"FAQ from distributors\"> for his distribution "
+"terms."
+msgstr ""
+"Dan J. Bernstein verspreidde <url id=\"http://cr.yp.to/software.html\" name="
+"\"alle software die hij schreef\"> met een restrictieve licentie die het "
+"verspreiden van gewijzigde binaire bestanden verbood. In november 2007 "
+"echter verklaarde Bernstein \"[...] ik heb beslist om al mijn toekomstige en "
+"[...] mijn vroegere software in het publieke domein te plaatsen\". Zie <url "
+"id=\"http://cr.yp.to/distributors.html\" name=\"FAQ vanwege distributeurs\"> "
+"voor zijn distributiebepalingen."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:200
+msgid ""
+"As of this writing (2016-03), <package>ezmlm-idx</package> is available in "
+"experimental only (<package>mlmmj</package> is similar, and shipped with "
+"Debian jessie); <package>djbdns</package> is available in sid (unstable) "
+"only, see <url id=\"https://bugs.debian.org/516394\" name=\"Bug #516394\"> "
+"and <url id=\"https://bugs.debian.org/796118\" name=\"Bug #796118\"> for "
+"details and see <package>dbndns</package> for a similar alternative; the "
+"<tt>publicfile</tt> software is still not free software, a "
+"<package>publicfile-installer</package> package is available from Debian's "
+"contrib section."
+msgstr ""
+"Sinds deze schriftelijke verklaring (03-2016) is <package>ezmlm-idx</"
+"package> enkel in 'experimental', de experimentele distributie, te vinden "
+"(<package>mlmmj</package> is vergelijkbaar en wordt verdeeld met Debian "
+"Jessie). <package>djbdns</package> is enkel te vinden in sid (unstable - de "
+"onstabiele distributie); zie <url id=\"https://bugs.debian.org/516394\" name="
+"\"Bug #516394\"> en <url id=\"https://bugs.debian.org/796118\" name=\"Bug "
+"#796118\"> voor meer gegevens en zie <package>dbndns</package> voor een "
+"vergelijkbaar alternatief. De software <tt>publicfile</tt> is nog steeds "
+"geen vrije software; het pakket <package>publicfile-installer</package> is "
+"te vinden en de sectie 'contrib' van Debian."
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:205
+msgid ""
+"Other software of Dan J. Bernstein (<package>qmail</package>, "
+"<package>daemontools</package>, <package>ucspi-tcp</package>) is shipped "
+"with Debian."
+msgstr ""
+"Andere software van Dan J. Bernstein (<package>qmail</package>, "
+"<package>daemontools</package>, <package>ucspi-tcp</package>) wordt door "
+"Debian verdeeld."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:207
+msgid "Where is a player for Flash (SWF)?"
+msgstr "Waar vindt men een speler voor Flash (SWF)?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:210
+msgid ""
+"Debian ships both <package>gnash</package> and <package>swfdec</package>: "
+"two free SWF movie players."
+msgstr ""
+"Debian verdeelt zowel <package>gnash</package> als <package>swfdec</"
+"package>: twee vrije SWF filmspelers."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:212
+msgid "Where is Google Earth?"
+msgstr "Waar is Google Earth te vinden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:217
+msgid ""
+"Google Earth is available for GNU/Linux from Google's web site, but not only "
+"it is not Free Software, but is completely undistributable by a third party. "
+"However, <package>googleearth-package</package> (in the contrib-section) "
+"might be helpful in using this software."
+msgstr ""
+"Google Earth voor GNU/Linux is te vinden op de website van Google, maar het "
+"is niet enkel niet-vrije software, maar mag ook helemaal niet door derden "
+"verdeeld worden. Het pakket <package>googleearth-package</package> (in de "
+"sectie contrib) kan eventueel behulpzaam zijn bij het gebruik van die "
+"software."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:219
+msgid "Where is VoIP software?"
+msgstr "Waar vindt men VoIP-software?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:223
+msgid ""
+"Two main open protocols are used for Voice Over IP: SIP and H.323. Both are "
+"implemented by a wide variety of software in Debian main. <package>ekiga</"
+"package> is one of the popular clients."
+msgstr ""
+"Voor Voice Over IP worden twee dominante open protocollen gebruikt: SIP en "
+"H.323. Beide worden door een hele resem software in 'Debian main', het "
+"hoofdarchief van Debian, geÃ¯mplementeerd. <package>ekiga</package> is een "
+"van de populaire clients."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:46 software.sgml:226
+msgid ""
+"I have a wireless network card which doesn't work with Linux. What should I "
+"do?"
+msgstr ""
+"Ik heb een kaart voor draadloos netwerk die in Linux niet werkt. Wat moet ik "
+"doen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:46 software.sgml:228
+msgid "Buy one which does :)"
+msgstr "Koop er een die wel werkt :)"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:3
+msgid ""
+"Alternatively, use <package>ndiswrapper</package> to use a driver for "
+"Windows (if you have one) on your Linux system. See the <url id=\"http://"
+"wiki.debian.org/NdisWrapper\" name=\"Debian Wiki ndiswrapper page\"> for "
+"more information."
+msgstr ""
+"In het andere geval kunt u <package>ndiswrapper</package> gebruiken om een "
+"stuurprogramma voor Windows (als u er een heeft) te gebruiken o uw Linux-"
+"systeem. Zie de <url id=\"http://wiki.debian.org/NdisWrapper\" name=\"Debian "
+"Wiki-pagina over ndiswrapper\"> voor meer informatie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:5
+msgid "The Debian FTP archives"
+msgstr "De FTP-archieven van Debian"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:7
+msgid "How many Debian distributions are there?"
+msgstr "Hoeveel distributies van Debian zijn er?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:13
+msgid ""
+"There are three major distributions: the \"stable\" distribution, the "
+"\"testing\" distribution, and the \"unstable\" distribution. The \"testing\" "
+"distribution is sometimes `frozen' (see <ref id=\"frozen\">). Next to these, "
+"there is the \"oldstable\" distribution (that's just the one from before "
+"\"stable\"), and the \"experimental\" distribution."
+msgstr ""
+"Er bestaan drie hoofd-distributies: de stabiele distributie \"stable\", de "
+"test-distributie \"testing\" en de onstabiele distributie \"unstable\". Soms "
+"wordt de distributie \"testing\" 'bevroren' (zie <ref id=\"frozen\">). "
+"Daarnaast zijn er ook de oude stabiele distributie \"oldstable\" en de "
+"experimentele distributie \"experimental\"."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:19
+msgid ""
+"Experimental is used for packages which are still being developed, and with "
+"a high risk of breaking your system. It's used by developers who'd like to "
+"study and test bleeding edge software. Users shouldn't be using packages "
+"from there, because they can be dangerous and harmful even for the most "
+"experienced people."
+msgstr ""
+"\"Experimental\" wordt gebruikt voor pakketten die nog in ontwikkeling zijn "
+"en die een hoog risico in zich dragen om uw systeem onbruikbaar te maken. De "
+"distributie wordt gebruikt door ontwikkelaars die de allernieuwste software "
+"willen bestuderen en testen. Gebruikers moeten er geen pakketten van "
+"gebruiken, omdat ze zelfs voor de meest ervaren mensen gevaarlijk en "
+"schadelijk kunnen zijn."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:21
+msgid "See <ref id=\"choosing\"> for help when choosing a Debian distribution."
+msgstr ""
+"Zie <ref id=\"choosing\"> voor hulp bij het kiezen van een Debian-"
+"distributie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:23
+msgid "What are all those names like etch, lenny, etc.?"
+msgstr "Wat beteken het soort namen zoals etch, lenny, enz.?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:30
+msgid ""
+"They are just \"codenames\". When a Debian distribution is in the "
+"development stage, it has no version number but a codename. The purpose of "
+"these codenames is to make easier the mirroring of the Debian distributions "
+"(if a real directory like <tt>unstable</tt> suddenly changed its name to "
+"<tt>stable</tt>, a lot of stuff would have to be needlessly downloaded "
+"again)."
+msgstr ""
+"Het zijn gewoon \"codenamen\". Wanneer een distributie van Debian zich in de "
+"ontwikkelingsfase bevindt, heeft ze geen versienummer, maar een codenaam. "
+"Het doel van die codenamen is het vergemakkelijken van het onderhoud van een "
+"spiegelserver voor de distributies van Debian (indien een echte map zoals "
+"<tt>unstable</tt> plots de naam <tt>stable</tt> zou krijgen zou dit het "
+"nodeloos opnieuw downloaden van een heleboel zaken tot gevolg hebben)."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:36
+msgid ""
+"Currently, <tt>stable</tt> is a symbolic link to <tt>&releasename;</tt> (i."
+"e. &debian; &release;) and <tt>testing</tt> is a symbolic link to "
+"<tt>&testingreleasename;</tt>. This means that <tt>&releasename;</tt> is the "
+"current stable distribution and <tt>&testingreleasename;</tt> is the current "
+"testing distribution."
+msgstr ""
+"Momenteel is <tt>stable</tt> een symbolische koppeling met <tt>&releasename;"
+"</tt> (d.w.z. &debian; &release;) en <tt>testing</tt> een symbolische "
+"koppeling met <tt>&testingreleasename;</tt>. Dit betekent dat "
+"<tt>&releasename;</tt> de huidige stabiele distributie is en "
+"<tt>&testingreleasename;</tt> de huidige test-distributie."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:39
+msgid ""
+"<tt>unstable</tt> is a permanent symbolic link to <tt>sid</tt>, as <tt>sid</"
+"tt> is always the unstable distribution (see <ref id=\"sid\">)."
+msgstr ""
+"<tt>unstable</tt> is een permanente symbolische koppeling met <tt>sid</tt>, "
+"vermist <tt>sid</tt> steeds de onstabiele distributie blijft (zie <ref id="
+"\"sid\">)."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:41
+msgid "Which other codenames have been used in the past?"
+msgstr "Welke ander codenamen werden in het verleden gebruikt?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:53
+msgid ""
+"Aside <tt>&releasename;</tt> and <tt>&testingreleasename;</tt>, other "
+"codenames that have been already used are: <tt>buzz</tt> for release 1.1, "
+"<tt>rex</tt> for release 1.2, <tt>bo</tt> for releases 1.3.x, <tt>hamm</tt> "
+"for release 2.0, <tt>slink</tt> for release 2.1, <tt>potato</tt> for release "
+"2.2, <tt>woody</tt> for release 3.0, <tt>sarge</tt> for release 3.1, "
+"<tt>etch</tt> for release 4.0, <tt>lenny</tt> for release 5.0, <tt>squeeze</"
+"tt> for release 6.0, <tt>wheezy</tt> for release 7, <tt>jessie</tt> for "
+"release 8, <tt>stretch</tt> for release 9."
+msgstr ""
+"Naast <tt>&releasename;</tt> en <tt>&testingreleasename;</tt> zijn andere "
+"codenamen die reeds gebruikt werden: <tt>buzz</tt> voor release 1.1, "
+"<tt>rex</tt> voor release 1.2, <tt>bo</tt> voor de releases 1.3.x, <tt>hamm</"
+"tt> voor release 2.0, <tt>slink</tt> voor release 2.1, <tt>potato</tt> voor "
+"release 2.2, <tt>woody</tt> voor release 3.0, <tt>sarge</tt> voor release "
+"3.1, <tt>etch</tt> voor release 4.0, <tt>lenny</tt> voor release 5.0, "
+"<tt>squeeze</tt> voor release 6.0, <tt>wheezy</tt> voor release 7, "
+"<tt>jessie</tt> voor release 8, <tt>stretch</tt> voor release 9."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:55
+msgid "Where do these codenames come from?"
+msgstr "Waar komen deze codenamen vandaan?"
+
+#. type: <p><list>
+#: debian-faq.sgml:47 ftparchives.sgml:56
+msgid ""
+"So far they have been characters taken from the \"Toy Story\" movies by "
+"Pixar."
+msgstr ""
+"Tot nu toe zijn het figuurtjes geweest uit de \"Toy Story\"-filmen van Pixar."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:57
+msgid "<em>buzz</em> (Buzz Lightyear) was the spaceman,"
+msgstr "<em>buzz</em> (Buzz Lightyear) is de ruimtevaarder,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:58
+msgid "<em>rex</em> was the tyrannosaurus,"
+msgstr "<em>rex</em> is de tyrannosaurus,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:59
+msgid "<em>bo</em> (Bo Peep) was the girl who took care of the sheep,"
+msgstr "<em>bo</em> (Bo Peep) is het meisje dat zorgt voor het schaap,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:60
+msgid "<em>hamm</em> was the piggy bank,"
+msgstr "<em>hamm</em> is het spaarvarken,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:61
+msgid "<em>slink</em> (Slinky Dog) was the toy dog,"
+msgstr "<em>slink</em> (Slinky Dog) is de speelgoedhond,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:62
+msgid "<em>potato</em> was, of course, Mr. Potato,"
+msgstr "<em>potato</em> is natuurlijk Mr. Potato,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:63
+msgid "<em>woody</em> was the cowboy,"
+msgstr "<em>woody</em> is de cowboy,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:64
+msgid "<em>sarge</em> was the sergeant of the Green Plastic Army Men,"
+msgstr "<em>sarge</em> is de sergeant van de Groene Plastic Soldaatjes,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:65
+msgid "<em>etch</em> was the toy whiteboard (Etch-a-Sketch),"
+msgstr "<em>etch</em> is het tekenspeelgoed (Etch-a-Sketch),"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:66
+msgid "<em>lenny</em> was the toy binoculars,"
+msgstr "<em>lenny</em> is de speelgoedverrekijker,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:67
+msgid "<em>squeeze</em> was the name of the three-eyed aliens,"
+msgstr "<em>squeeze</em> is de naam van de aliens met de drie ogen,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:69
+msgid "<em>wheezy</em> was the rubber toy penguin with a red bow tie,"
+msgstr ""
+"<em>wheezy</em> is de rubberen speelgoedpinguÃ¯n met een rood vlinderdasje,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:70
+msgid "<em>jessie</em> was the yodeling cowgirl,"
+msgstr "<em>jessie</em> is de jodelende cowgirl,"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:71
+msgid ""
+"<em>stretch</em> was the rubber toy octopus with suckers on her eight long "
+"arms."
+msgstr ""
+"<em>stretch</em> is de rubberen speelgoedoctopus met zuignappen o zijn acht "
+"lange armen."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:72
+msgid "<em>buster</em> was Andy's pet dog."
+msgstr "<em>buster</em> is de lievelingshond van Andy."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:76
+msgid "<em>bullseye</em> was Woody's wooden toyhorse."
+msgstr "<em>bullseye</em> is het houten speelgoedpaard van Woody."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:78
+msgid "<em>sid</em> was the evil neighbor kid next door who broke all toys."
+msgstr ""
+"<em>sid</em> is het boosaaardige buurjongetje van naast de deur die al het "
+"speelgoed vernielt."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:84
+msgid ""
+"The <url id=\"https://lists.debian.org/debian-devel/1996/06/msg00515.html\" "
+"name=\"decision\"> of using Toy Story names was <url id=\"https://lists."
+"debian.org/debian-user/1997/04/msg00011.html\" name=\"made\"> by Bruce "
+"Perens who was, at the time, the Debian Project Leader and was working also "
+"at Pixar, the company that produced the movies."
+msgstr ""
+"De <url id=\"https://lists.debian.org/debian-devel/1996/06/msg00515.html\" "
+"name=\"keuze\"> om namen uit Toy Story te gebruiken werd <url id=\"https://"
+"lists.debian.org/debian-user/1997/04/msg00011.html\" name=\"gemaakt\"> door "
+"Bruce Perens die toen de Projectleider van Debian was en die ook bij Pixar "
+"werkte, het bedrijf dat de films produceerde."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:175
+msgid "What about \"sid\"?"
+msgstr "Hoe zit het met \"sid\"?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:181
+msgid ""
+"<em>sid</em> or <em>unstable</em> is the place where most of the packages "
+"are initially uploaded. It will never be released directly, because packages "
+"which are to be released will first have to be included in <em>testing</em>, "
+"in order to be released in <em>stable</em> later on. sid contains packages "
+"for both released and unreleased architectures."
+msgstr ""
+"<em>sid</em> of <em>unstable</em> is de plaats waar de meeste pakketten "
+"initieel geÃ¼pload worden. Deze distributie zal nooit rechtstreeks "
+"uitgebracht worden, aangezien pakketten die uitgebracht zullen worden eerst "
+"opgenomen moeten worden in <em>testing</em> om dan later in <em>stable</em> "
+"uitgebracht te worden. sid bevat pakketten voor zowel uitgebrachte als niet-"
+"uitgebrachte architecturen."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:184
+msgid ""
+"The name \"sid\" also comes from the \"Toy Story\" animated motion picture: "
+"Sid was the boy next door who destroyed toys :-)"
+msgstr ""
+"Ook de naam \"sid\" is afkomstig uit de tekenfilm \"Toy Story\": Sid is de "
+"buurjongen die speelgoed vernielt :-)"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:206
+msgid ""
+"<footnote><p>When the present-day sid did not exist, the FTP site "
+"organization had one major flaw: there was an assumption that when an "
+"architecture is created in the current unstable, it will be released when "
+"that distribution becomes the new stable. For many architectures that isn't "
+"the case, with the result that those directories had to be moved at release "
+"time. This was impractical because the move would chew up lots of bandwidth. "
+"</p><p>The archive administrators worked around this problem for several "
+"years by placing binaries for unreleased architectures in a special "
+"directory called \"sid\". For those architectures not yet released, the "
+"first time they were released there was a link from the current stable to "
+"sid, and from then on they were created inside the unstable tree as normal. "
+"This layout was somewhat confusing to users. </p><p>With the advent of "
+"package pools (see <ref id=\"pools\">), binary packages began to be stored "
+"in a canonical location in the pool, regardless of the distribution, so "
+"releasing a distribution no longer causes large bandwidth consumption on the "
+"mirrors (there is, however, a lot of gradual bandwidth consumption "
+"throughout the development process).</p></footnote>"
+msgstr ""
+"<footnote><p>Toen het huidige sid niet bestond, vertoonde de organisatie van "
+"de FTP-site een belangrijk mankement: de aanname was dat als een nieuwe "
+"architectuur gecreÃ«erd werd in de huidige onstabiele distributie, deze "
+"uitgebracht zou worden wanneer deze distributie de nieuwe stabiele "
+"distributie werd. Voor veel architecturen was dat niet het geval, met als "
+"gevolg dat deze mappen verplaatst moesten worden op het moment van de "
+"release. Dit was niet praktisch, aangezien het verplaatsen veel bandbreedte "
+"vrat. </p><p>Vele jaren omzeilden de archiefbeheerders dit probleem door de "
+"binaire bestanden voor niet-uitgebrachte architecturen in een bijzondere map "
+"te plaatsen met als naam \"sid\". Voor die nog niet uitgebrachte "
+"architecturen werd er een koppeling van het actuele \"stable\" naar \"sid\" "
+"gemaakt wanneer zij voor het eerst uitgebracht werden, en vanaf dan werden "
+"ze, zoals de normale gang van zaken is, binnenin de boomstructuur van "
+"\"unstable\" aangemaakt. Voor gebruikers was deze indeling nogal verwarrend. "
+"</p><p> Met de introductie van pools van pakketten (zie <ref id=\"pools\">) "
+"begon men binaire pakketten op te slaan op een geÃ«igende plaats in de pool, "
+"ongeacht de distributie waartoe ze behoorden. Daardoor had het uitbrengen "
+"van een release bij de spiegelservers niet langer een grote consumptie van "
+"bandbreedte tot gevolg (doorheen het ontwikkelingsproces vindt er echter "
+"heel wat graduele bandbreedteconsumptie plaats).</p></footnote>"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:208
+msgid "What does the stable directory contain?"
+msgstr "Wat bevat de map 'stable'?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:212
+msgid ""
+"stable/main/: This directory contains the packages which formally constitute "
+"the most recent release of the &debian; system."
+msgstr ""
+"stable/main/: deze map bevat de pakketten die formeel de meest recente "
+"release van het &debian;-systeem vormen."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:216
+msgid ""
+"These packages all comply with the <url id=\"http://www.debian.org/"
+"social_contract#guidelines\" name=\"Debian Free Software Guidelines\">, and "
+"are all freely usable and distributable."
+msgstr ""
+"Al deze pakketten beantwoorden aan de <url id=\"http://www.debian.org/"
+"social_contract#guidelines\" name=\"Debian Free Software Guidelines\"> en "
+"kunnen alle vrij gebruikt en verspreid worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:220
+msgid ""
+"stable/non-free/: This directory contains packages distribution of which is "
+"restricted in a way that requires that distributors take careful account of "
+"the specified copyright requirements."
+msgstr ""
+"stable/non-free/: deze map bevat pakketten waarvan de distributie aan "
+"restricties onderhevig is, zodat distributeurs de vermelde copyright-"
+"vereisten zorgvuldig in acht moeten nemen."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:226
+msgid ""
+"For example, some packages have licenses which prohibit commercial "
+"distribution. Others can be redistributed but are in fact shareware and not "
+"free software. The licenses of each of these packages must be studied, and "
+"possibly negotiated, before the packages are included in any redistribution "
+"(e.g., in a CD-ROM)."
+msgstr ""
+"Bijvoorbeeld hebben sommige pakketten een licentie die commerciÃ«le "
+"distributie verbiedt. Andere mogen verspreid worden, maar zijn in feite "
+"shareware en geen vrije software. De licentie van elk van deze pakketten "
+"moet bestudeerd worden en eventueel heronderhandeld alvorens deze pakketten "
+"opgenomen worden op een distributiemedium (bijvoorbeeld een CD)."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:231
+msgid ""
+"stable/contrib/: This directory contains packages which are DFSG-free and "
+"<em>freely distributable</em> themselves, but somehow depend on a package "
+"that is <em>not</em> freely distributable and thus available only in the non-"
+"free section."
+msgstr ""
+"stable/contrib/: deze map bevat pakketten die zelf vrij zijn volgens de DFSG "
+"en <em>vrij verspreid mogen worden</em>, maar die op een of andere manier "
+"een pakket vereisen dat <em>niet</em> vrij verspreid mag worden en dus enkel "
+"in de sectie non-free te vinden is."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:235
+msgid "What does the testing distribution contain?"
+msgstr "Wat bevat de distributie 'testing'?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:238
+msgid ""
+"Packages are installed into the `testing' directory after they have "
+"undergone some degree of testing in <qref id=\"unstable\">unstable</qref>."
+msgstr ""
+"Pakketten worden in de map 'testing' geÃ¯nstalleerd nadat ze in zekere mate "
+"getest werden in <qref id=\"unstable\">unstable</qref>."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:244
+msgid ""
+"They must be in sync on all architectures where they have been built and "
+"mustn't have dependencies that make them uninstallable; they also need to "
+"have fewer release-critical bugs than the versions currently in unstable. "
+"This way, we hope that `testing' is always close to being a release "
+"candidate."
+msgstr ""
+"Op alle architecturen waarop ze gebouwd werden, moeten ze onderling "
+"synchroon zijn en ze mogen geen vereisten hebben die tot gevolg hebben dat "
+"ze niet geÃ¯nstalleerd kunnen worden. Ze moeten ook minder bugs hebben die in "
+"functie van de release cruciaal zijn, dan de versie die momenteel in "
+"'unstable' zit. We hopen dat op die manier 'testing' steeds dicht de "
+"toestand van release-kandidaat benadert."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:248
+msgid ""
+"More information about the status of \"testing\" in general and the "
+"individual packages is available at <url id=\"http://www.debian.org/devel/"
+"testing\">."
+msgstr ""
+"Meer informatie over de status van \"testing\" in het algemeen en over de "
+"individuele pakketten is te vinden op <url id=\"http://www.debian.org/devel/"
+"testing\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:250
+msgid "What about \"testing\"? How is it `frozen'?"
+msgstr "Hoe zit het met \"testing\"? Hoe wordt het 'bevroren'?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:254
+msgid ""
+"When the \"testing\" distribution is mature enough, the release manager "
+"starts `freezing' it. The normal propagation delays are increased to ensure "
+"that as few new bugs as possible from \"unstable\" enter \"testing\"."
+msgstr ""
+"Als de \"testing\"-distributie voldoende matuur is, begint de releasemanager "
+"het te 'bevriezen'. De normale doorschuifvertraging wordt verhoogd om te "
+"verzekeren dat zo weinig mogelijk nieuwe bugs vanuit \"unstable\" in "
+"\"testing\" binnenkomen."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:260
+msgid ""
+"After a while, the \"testing\" distribution becomes truly `frozen'. This "
+"means that all new packages that are to propagate to the \"testing\" are "
+"held back, unless they include release-critical bug fixes. The \"testing\" "
+"distribution can also remain in such a deep freeze during the so-called "
+"`test cycles', when the release is imminent."
+msgstr ""
+"Na een tijd wordt de \"testing\"-distributie echt 'bevroren'. Dit betekent "
+"dat alle nieuwe pakketten die naar \"testing\" zouden moeten doorschuiven, "
+"tegengehouden worden, tenzij zij reparaties bevatten van bugs die cruciaal "
+"zijn voor de release. De \"testing\"-distributie kan ook in een dergelijke "
+"diepe bevriezing blijven tijdens de zogenaamde 'test-cycli' wanneer de "
+"release ophanden is."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:266
+msgid ""
+"When a \"testing\" release becomes `frozen', \"unstable\" tends to partially "
+"freeze as well. This is because developers are reluctant to upload radically "
+"new software to unstable, in case the frozen software in testing needs minor "
+"updates and to fix release critical bugs which keep testing from becoming "
+"\"stable\"."
+msgstr ""
+"Wanneer een testing\"-release 'bevroren' wordt, heeft ook \"unstable\" ten "
+"dele de neiging te bevriezen. Dit is omdat ontwikkelaars weigerachtig staan "
+"tegen het uploaden van radicaal nieuwe software in unstable, voor het geval "
+"de bevroren software in testing kleine updates nodig mocht hebben voor het "
+"repareren van voor de release cruciale bugs die verhinderen dat testing "
+"\"stable\" kan worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:271
+msgid ""
+"We keep a record of bugs in the \"testing\" distribution that can hold off a "
+"package from being released, or bugs that can hold back the whole release. "
+"For details, please see <url id=\"http://www.debian.org/releases/testing/\" "
+"name=\"current testing release information\">."
+msgstr ""
+"We houden een register bij van bugs in de \"testing\"-distributie die de "
+"release van een pakket kunnen tegenhouden en van bugs de de hele release "
+"kunnen tegenhouden. Raadpleeg voor meer informatie de <url id=\"http://www."
+"debian.org/releases/testing/\" name=\"release-informatie over de huidige "
+"testing-release\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:275
+msgid ""
+"Once that bug count lowers to maximum acceptable values, the frozen \"testing"
+"\" distribution is declared \"stable\" and released with a version number."
+msgstr ""
+"Eens het aantal bugs lager ligt dan het maximaal aanvaardbare, wordt de "
+"bevroren \"testing\"-distributie stabiel verklaard en uitgegeven met een "
+"versienummer."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:284
+msgid ""
+"The most important bug count is the \"Release Critical\" bug count, which "
+"can be followed in the <url id=\"http://bugs.debian.org/release-critical/\" "
+"name=\"Release-critical bug status page\">. A common release goal is <url id="
+"\"http://wiki.debian.org/ReleaseGoals/NoRCBugs\" name=\"NoRCBugs\"> which "
+"means that the distribution should not have any bugs of severity critical, "
+"grave or serious. The full list of issues considered critical can be found "
+"in the <url id=\"http://release.debian.org/testing/rc_policy.txt\" name=\"RC "
+"policy document\">."
+msgstr ""
+"Het belangrijkste aantal bugs is dat van deze welke \"cruciaal zijn voor de "
+"release\" (de zogenaamde release critical bugs). Dit aantal kan gevolgd "
+"worden op de <url id=\"http://bugs.debian.org/release-critical/\" name="
+"\"Statuspagina over release-critical bugs\">. Een algemeen erkende "
+"releasedoelstelling is <url id=\"http://wiki.debian.org/ReleaseGoals/NoRCBugs"
+"\" name=\"NoRCBugs - geen release critical bugs\">, wat betekent dat de "
+"release geen bugs zou mogen bevatten die een graad van ernstigheid hebben "
+"van cruciaal, zorgwekkend of ernstig. De volledige lijst van zaken die als "
+"cruciaal beschouwd worden, is te vinden in het <url id=\"http://release."
+"debian.org/testing/rc_policy.txt\" name=\"beleidsdocument inzake RC\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:288
+msgid ""
+"With each new release, the previous \"stable\" distribution becomes obsolete "
+"and moves to the archive. For more information please see <url id=\"http://"
+"www.debian.org/distrib/archive\" name=\"Debian archive\">."
+msgstr ""
+"Bij elke nieuwe release wordt de vorige \"stable\" release als verouderd "
+"bestempeld en verhuist deze naar het archief. Raadpleeg voor bijkomende "
+"informatie <url id=\"http://www.debian.org/distrib/archive\" name=\"Het "
+"Debian-archief\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:290
+msgid "What does the unstable distribution contain?"
+msgstr "Wat zit er in de distributie unstable?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:296
+msgid ""
+"The `unstable' directory contains a snapshot of the current development "
+"system. Users are welcome to use and test these packages, but are warned "
+"about their state of readiness. The advantage of using the unstable "
+"distribution is that you are always up-to-date with the latest in GNU/Linux "
+"software industry, but if it breaks: you get to keep both parts :-)"
+msgstr ""
+"De map 'unstable' bevat een momentopname van het huidige systeem in "
+"ontwikkeling. Gebruikers worden uitgenodigd om deze pakketten te gebruiken "
+"en uit te testen, maar worden gewaarschuwd wat hun staat van onafheid "
+"betreft. Het voordeel van het gebruik van de onstabiele distributie is dat u "
+"altijd up-to-date bent wat de meest recente software voor GNU/Linux betreft, "
+"maar als er iets fout gaat, dan zit u met de brokken :-)"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:299
+msgid ""
+"There are also main, contrib and non-free subdirectories in `unstable', "
+"separated on the same criteria as in `stable'."
+msgstr ""
+"Ook in 'unstable' bestaan de onderliggende mappen main, contrib en non-free, "
+"waarvoor dezelfde criteria gehanteerd worden als in 'stable'."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:301
+msgid "What are all those directories at the Debian FTP archives?"
+msgstr "Wat betekenen al die mappen in de FTP-archieven van Debian?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:304
+msgid ""
+"The software that has been packaged for &debian; is available in one of "
+"several directory trees on each Debian mirror site."
+msgstr ""
+"De software die voor &debian; verpakt werd, is te vinden op elke Debian-"
+"spiegelserver in een van de verschillende mappenbomen."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:308
+msgid ""
+"The <tt>dists</tt> directory is short for \"distributions\", and it is the "
+"canonical way to access the currently available Debian releases (and pre-"
+"releases)."
+msgstr ""
+"De map <tt>dists</tt> is een afkorting van \"distributies\" en het is de "
+"geÃ«igende manier om toegang te krijgen tot de huidige beschikbare releases "
+"(en pre-releases) van Debian."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:311
+msgid ""
+"The <tt>pool</tt> directory contains the actual packages, see <ref id=\"pools"
+"\">."
+msgstr ""
+"De map <tt>pool</tt> bevat de eigenlijke pakketten. Zie <ref id=\"pools\">."
+
+#. type: <p><taglist>
+#: debian-faq.sgml:47 ftparchives.sgml:312
+msgid "There are the following supplementary directories:"
+msgstr "Er zijn ook nog de volgende bijkomende mappen:"
+
+#. type: <tag></tag>
+#: debian-faq.sgml:47 ftparchives.sgml:313
+msgid "<em>/tools/</em>:"
+msgstr "<em>/tools/</em>:"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:315
+msgid ""
+"DOS utilities for creating boot disks, partitioning your disk drive, "
+"compressing/decompressing files, and booting Linux."
+msgstr ""
+"DOS-hulprogramma's voor het aanmaken van opstartdisks, voor schijfindeling, "
+"voor het comprimeren/decomprimeren van bestanden en om Linux op te starten."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:47 ftparchives.sgml:316
+msgid "<em>/doc/</em>:"
+msgstr "<em>/doc/</em>:"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:318
+msgid ""
+"The basic Debian documentation, such as this FAQ, the bug reporting system "
+"instructions, etc."
+msgstr ""
+"De basale documentatie van Debian, zoals deze FAQ, de instructies voor het "
+"brugrapporteringssysteem, enz."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:47 ftparchives.sgml:319
+msgid "<em>/indices/</em>:"
+msgstr "<em>/indices/</em>:"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:321
+msgid ""
+"various indices of the site (the Maintainers file and the override files)."
+msgstr ""
+"verschillende indexbestanden van de site (het bestand Maintainers en de "
+"override-bestanden)."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:47 ftparchives.sgml:322
+msgid "<em>/project/</em>:"
+msgstr "<em>/project/</em>:"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:324
+msgid "mostly developer-only materials and some miscellaneous files."
+msgstr ""
+"voor het merendeel materiaal dat enkel voor ontwikkelaars bestemd is en "
+"enkele varia-bestanden."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:329
+msgid "What are all those directories inside <tt>dists/stable/main</tt>?"
+msgstr "Wat betekenen al deze mappen binnenin <tt>dists/stable/main</tt>?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:334
+msgid ""
+"Within each of the major directory trees<footnote><p><tt>dists/stable/main</"
+"tt>, <tt>dists/stable/contrib</tt>, <tt>dists/stable/non-free</tt>, and "
+"<tt>dists/unstable/main/</tt>, etc.</p></footnote>, there are three sets of "
+"subdirectories containing index files."
+msgstr ""
+"Binnenin elk van de hoofdmappenbomen<footnote><p><tt>dists/stable/main</tt>, "
+"<tt>dists/stable/contrib</tt>, <tt>dists/stable/non-free</tt> en <tt>dists/"
+"unstable/main/</tt>, enz.</p></footnote>, zijn er drie groepen onderliggende "
+"mappen met indexbestanden."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:340
+msgid ""
+"There's one set of <tt>binary-<var>something</var></tt> subdirectories which "
+"contain index files for binary packages of each available computer "
+"architecture, for example <tt>binary-i386</tt> for packages which execute on "
+"Intel x86 PC machines or <tt>binary-sparc</tt> for packages which execute on "
+"Sun SPARCStations."
+msgstr ""
+"Er is een groep van onderliggende mappen <tt>binary-<var>iets</var></tt> die "
+"indexbestanden bevatten over binaire pakketten voor elke beschikbare "
+"computerarchitectuur. Bijvoorbeeld<tt>binary-i386</tt> voor pakketten die "
+"werken op PC's van het type Intel x86 of <tt>binary-sparc</tt> voor "
+"pakketten die werken op Sun SPARCStations."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:344
+msgid ""
+"The complete list of available architectures for each release is available "
+"at <url id=\"http://www.debian.org/releases/\" name=\"the release's web page"
+"\">. For the current release, please see <ref id=\"arches\">."
+msgstr ""
+"De volledige lijst van beschikbare architecturen voor elke release is te "
+"vinden op <url id=\"http://www.debian.org/releases/\" name=\"de webpagina "
+"van de release\">. Zie voor de huidige release <ref id=\"arches\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:349
+msgid ""
+"The index files in binary-* are called Packages(.gz, .bz2) and they include "
+"a summary of each binary package that is included in that distribution. The "
+"actual binary packages reside in the top level <qref id=\"pools\"><tt>pool</"
+"tt> directory</qref>."
+msgstr ""
+"De indexbestanden in binary-* heten Packages(.gz, .bz2) en ze bevatten een "
+"samenvatting van elk binair pakket dat tot die distributie behoort. De echte "
+"binaire pakketten bevinden zich in de <qref id=\"pools\">basismap <tt>pool</"
+"tt></qref>."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:353
+msgid ""
+"Furthermore, there's a subdirectory called source/ which contains index "
+"files for source packages included in the distribution. The index file is "
+"called Sources(.gz, .bz2)."
+msgstr ""
+"Voorts is er nog een onderliggende map source/ die indexbestanden bevat voor "
+"de bronpakketten die in de distributie zitten. Het indexbestand heet "
+"Sources(.gz, .bz2)."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:357
+msgid ""
+"Last but not least, there's a set of subdirectories meant for the "
+"installation system index files, they are at <tt>debian-installer/binary-"
+"<var>architecture</var></tt>."
+msgstr ""
+"Tenslotte is er nog een groep onderliggende mappen die bedoeld zijn voor de "
+"indexbestanden van het installatiesysteem. Zij zitten in <tt>debian-"
+"installer/binary-<var>architectuur</var></tt>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:359
+msgid "Where is the source code?"
+msgstr "Waar zit de broncode?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:364
+msgid ""
+"Source code is included for everything in the Debian system. Moreover, the "
+"license terms of most programs in the system <em>require</em> that source "
+"code be distributed along with the programs, or that an offer to provide the "
+"source code accompany the programs."
+msgstr ""
+"Van alles wat in het Debian-systeem aanwezig is, wordt de broncode "
+"opgenomen. Daarenboven <em>vereisen</em> de licentiebepalingen van de meeste "
+"programma's in het systeem dat de broncode samen met het programma "
+"meegeleverd wordt of dat bij het programma een aanbod voor het bezorgen van "
+"de broncode gevoegd wordt."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:371
+msgid ""
+"The source code is distributed in the <tt>pool</tt> directory (see <ref id="
+"\"pools\">) together with all the architecture-specific binary directories. "
+"To retrieve the source code without having to be familiar with the structure "
+"of the FTP archive, try a command like <tt>apt-get source mypackagename</tt>."
+msgstr ""
+"De broncode wordt verdeeld in de map <tt>pool</tt> (zie <ref id=\"pools\">) "
+"samen met al de mappen met architectuur-specifieke binaire pakketten. Om de "
+"broncode op te halen zonder dat u vertrouwd moet zijn met de structuur van "
+"het FTP-archief, kunt u een commando zoals <tt>apt-get source pakketnaam</"
+"tt> gebruiken."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:379
+msgid ""
+"Due to restrictions in their licenses, source code may or may not be "
+"available for packages in the \"contrib\" and \"non-free\" areas, which are "
+"not formally part of the Debian system. In some cases only sourceless "
+"\"binary blobs\" can be distributed (see for instance <tt>firmware-misc-"
+"nonfree</tt>); in other cases the license prohibits the distribution of "
+"prebuilt binaries, but does allow packages of source code which users can "
+"compile locally (see <tt>broadcom-sta-dkms</tt>)."
+msgstr ""
+"Wegens restricties in hun licentiebepalingen kan het zijn dat de broncode "
+"van pakketten die zich in de gebieden \"contrib\" en \"non-free\" bevinden "
+"en niet formeel deel uitmaken van het Debian-systeem, al dan niet "
+"beschikbaar is. In sommige gevallen mogen enkel zogenaamde \"binary blobs\" "
+"zonder broncode verdeeld worden (zie bijvoorbeeld <tt>firmware-misc-nonfree</"
+"tt>). In andere gevallen verbiedt de licentie het verdelen van vooraf "
+"gebouwde binaire bestanden, maar laat toe dat pakketten met broncode "
+"verdeeld worden die gebruikers lokaal kunnen compileren (zie <tt>broadcom-"
+"sta-dkms</tt>)."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:381
+msgid "What's in the <tt>pool</tt> directory?"
+msgstr "Wat is de map <tt>pool</tt>?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:388
+msgid ""
+"Packages are kept in a large `pool', structured according to the name of the "
+"source package. To make this manageable, the pool is subdivided by section "
+"(`main', `contrib' and `non-free') and by the first letter of the source "
+"package name. These directories contain several files: the binary packages "
+"for each architecture, and the source packages from which the binary "
+"packages were generated."
+msgstr ""
+"Pakketten worden in een grote 'pool' bijgehouden die gestructureerd is op "
+"basis van de naam van het bronpakket. Om dit beheersbaar te maken wordt de "
+"pool onderverdeeld volgens sectie ('main', 'contrib' en 'non-free') en "
+"volgens de eerste letter van de naam van het bronpakket. Deze mappen "
+"bevatten verschillende bestanden: de binaire pakketten voor elk van de "
+"architecturen en de bronpakketten waaruit de binaire pakketten gegenereerd "
+"werden."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:393
+msgid ""
+"You can find out where each package is placed by executing a command like "
+"<tt>apt-cache showsrc mypackagename</tt> and looking at the `Directory:' "
+"line. For example, the <tt>apache</tt> packages are stored in <tt>pool/main/"
+"a/apache/</tt>."
+msgstr ""
+"U kunt de plaats van elk pakket te weten komen door een commando te "
+"gebruiken zoals <tt>apt-cache showsrc pakketnaam</tt> en dan te kijken naar "
+"de regel 'Directory:'. De <tt>apache</tt>-pakketten liggen opgeslagen in "
+"<tt>pool/main/a/apache/</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:403
+msgid ""
+"Additionally, since there are so many <tt>lib*</tt> packages, these are "
+"treated specially: for instance, libpaper packages are stored in <tt>pool/"
+"main/libp/libpaper/</tt>."
+msgstr ""
+"Daarbij komt nog dat <tt>lib*</tt>-pakketten op eeen bijzondere manier "
+"behandeld worden, omdat ze zo talrijk zijn. De libpaper-pakketten worden "
+"bijvoorbeeld opgeslagen in <tt>pool/main/libp/libpaper/</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:413
+msgid ""
+"<footnote><p>Historically, packages were kept in the subdirectory of "
+"<tt>dists</tt> corresponding to which distribution contained them. This "
+"turned out to cause various problems, such as large bandwidth consumption on "
+"mirrors when major changes were made. This was fixed with the introduction "
+"of the package pool. </p><p>The <tt>dists</tt> directories are still used "
+"for the index files used by programs like <tt>apt</tt>.</p></footnote>"
+msgstr ""
+"<footnote><p>Vroeger werden pakketten bewaard in een onderliggende map van "
+"<tt>dists</tt> die overeenkwam met de distributie waarin ze thuis hoorden. "
+"Het bleek dat dit tot verschillende problemen leidde, zoals een groot "
+"gebruik van bandbreedte door spiegelservers wanneer er belangrijke "
+"wijzigingen aangebracht werden. Dit werd opgelost door het introduceren van "
+"de pakketpool. </p><p>De <tt>dists</tt>-mappen worden nog steeds gebruikt "
+"voor de indexbestanden die door programma's zoals <tt>apt</tt> gebruikt "
+"worden.</p></footnote>"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:415
+msgid "What is \"incoming\"?"
+msgstr "Wat is \"incoming\"?"
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:419
+msgid ""
+"After a developer uploads a package, it stays for a short while in the "
+"\"incoming\" directory before it is checked that it's genuine and allowed "
+"into the archive."
+msgstr ""
+"Nadat een ontwikkelaar een pakket geÃ¼pload heeft, blijft het voor een korte "
+"periode zitten in de map \"incoming\" waar nagegaan wordt of het authentiek "
+"is, voordat het toegelaten wordt in het archief."
+
+#. type: <p></p>
+#: debian-faq.sgml:47 ftparchives.sgml:425
+msgid ""
+"Usually nobody should install things from this place. However, in some rare "
+"cases of emergency, the incoming directory is available at <url id=\"http://"
+"incoming.debian.org/\">. You can manually fetch packages, check the GPG "
+"signature and MD5sums in the .changes and .dsc files, and then install them."
+msgstr ""
+"Normaal zou niemand zaken uit die map moeten installeren. Voor die enkele "
+"zeldzame gevallen van hoogdringendheid evenwel, staat de map van "
+"binnenkomende pakketten (incoming) ter beschikking op <url id=\"http://"
+"incoming.debian.org/\">. U kunt handmatig pakketten ophalen, de GPG-"
+"ondertekening en de MD5sums controleren in de bestanden .changes en .dsc en "
+"ze dan installeren."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:47 ftparchives.sgml:427
+msgid "How do I set up my own apt-able repository?"
+msgstr "Hoe zet ik mijn eigen pakketbron op die met apt gebruikt kan worden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:3
+msgid ""
+"If you have built some private Debian packages which you'd like to install "
+"using the standard Debian package management tools, you can set up your own "
+"apt-able package archive. This is also useful if you'd like to share your "
+"Debian packages while these are not distributed by the Debian project. "
+"Instructions on how to do this are given on the <url id=\"https://wiki."
+"debian.org/HowToSetupADebianRepository\" name=\"Debian Wiki\">."
+msgstr ""
+"Indien u zelf een aantal Debian-pakketten gebouwd heeft die u wenst te "
+"installeren met behulp van de standaardgereedschappen voor pakketbeheer van "
+"Debian, dan kunt u uw eigen pakketarchief dat met apt gebruikt kan worden, "
+"opzetten. Dit is ook handig als u uw Debian-pakketten wenst te delen terwijl "
+"ze niet door het Debian-project verdeeld worden. Instructie over hoe u dit "
+"moet doen worden gegeven op de <url id=\"https://wiki.debian.org/"
+"HowToSetupADebianRepository\" name=\"Debian Wiki\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:5
+msgid "Basics of the Debian package management system"
+msgstr "Grondbeginselen van het pakketbeheersysteem van Debian"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:9
+msgid ""
+"This chapter touches on some lower level internals of Debian package "
+"management. If you're interested mainly in <em>usage</em> of the relevant "
+"tools, skip to chapters <ref id=\"pkgtools\"> and/or <ref id=\"uptodate\">."
+msgstr ""
+"In dit hoofdstuk worden een aantal basiszaken uit de interne keuken van het "
+"pakketbeheersysteem van Debian behandeld. Indien u hoofdzakelijk "
+"geÃ¯nteresseerd bent in het <em>gebruik</em> van de  desbetreffende "
+"gereedschappen, ga dan verder naar de hoofdstukken <ref id=\"pkgtools\"> en/"
+"of <ref id=\"uptodate\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:11
+msgid "What is a Debian package?"
+msgstr "Wat is een Debian-pakket?"
+
+#. type: <p><list>
+#: debian-faq.sgml:48 pkg_basics.sgml:14
+msgid ""
+"Packages generally contain all of the files necessary to implement a set of "
+"related commands or features. There are two types of Debian packages:"
+msgstr ""
+"Pakketten bevatten over het algemeen alle noodzakelijke bestanden om een "
+"aantal gerelateerde commando's of functies te implementeren. Eer bestaan "
+"twee types van Debian-pakketten:"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:22
+msgid ""
+"<em>Binary packages</em>, which contain executables, configuration files, "
+"man/info pages, copyright information, and other documentation. These "
+"packages are distributed in a Debian-specific archive format (see <ref id="
+"\"deb-format\">); they are usually characterized by having a '.deb' file "
+"extension. Binary packages can be unpacked using the Debian utility "
+"<tt>dpkg</tt> (possibly via a frontend like <prgn>aptitude</prgn>); details "
+"are given in its manual page."
+msgstr ""
+"<em>Binaire pakketten</em> die uitvoerbare bestanden bevatten, "
+"configuratiebestanden, man/info-pagina's, copyright-informatie en andere "
+"documentatie. Deze pakketten worden verdeeld in een Debian-specifieke "
+"archiefindeling (zie <ref id=\"deb-format\">). Zij worden gewoonlijk "
+"gekenmerkt door het feit dat ze '.deb' als bestandsextensie hebben. Binaire "
+"pakketten kunnen uitgepakt worden met het hulpprogramma <tt>dpkg</tt> van "
+"Debian (eventueel via een frontend zoals <prgn>aptitude</prgn>). Meer "
+"informatie is beschikbaar in zijn man-pagina."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:31
+msgid ""
+"<em>Source packages</em>, which consist of a <tt>.dsc</tt> file describing "
+"the source package (including the names of the following files), a <tt>.orig."
+"tar.gz</tt> file that contains the original unmodified source in gzip-"
+"compressed tar format and usually a <tt>.diff.gz</tt> file that contains the "
+"Debian-specific changes to the original source. The utility <tt>dpkg-source</"
+"tt> packs and unpacks Debian source archives; details are provided in its "
+"manual page. (The program <prgn>apt-get</prgn> can be used as a frontend for "
+"<tt>dpkg-source</tt>.)"
+msgstr ""
+"<em>Bron-pakketten</em>, die bestaan uit een <tt>.dsc</tt>-bestand dat het "
+"bronpakket beschrijft (inclusief de namen van de volgende bestanden), een "
+"<tt>.orig.tar.gz</tt>-bestand dat de originele ongewijzigde broncode bevat "
+"in een met gzip gecomprimeerd tar-archief en meestal een <tt>.diff.gz</tt>-"
+"bestand dat de Debian-specifieke wijzigingen aan de originele broncode "
+"bevat. Het hulpprogramma <tt>dpkg-source</tt> kan broncodearchieven van "
+"Debian verpakken en uitpakken. Informatie is te vinden in zijn man-pagina. "
+"(Het programma <prgn>apt-get</prgn> kan als frontend gebruikt worden voor "
+"<tt>dpkg-source</tt>.)"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:45
+msgid ""
+"Installation of software by the package system uses \"dependencies\" which "
+"are carefully designed by the package maintainers. These dependencies are "
+"documented in the <tt>control</tt> file associated with each package. For "
+"example, the package containing the GNU C compiler (<package>gcc</package>) "
+"\"depends\" on the package <package>binutils</package> which includes the "
+"linker and assembler. If a user attempts to install <package>gcc</package> "
+"without having first installed <package>binutils</package>, the package "
+"management system (dpkg) will send an error message that it also needs "
+"<package>binutils</package>, and stop installing <package>gcc</package>. "
+"(However, this facility can be overridden by the insistent user, see <manref "
+"name=\"dpkg\" section=\"8\">.) See more in <ref id=\"depends\"> below."
+msgstr ""
+"Het pakketsysteem maakt bij de installatie van software gebruik van "
+"\"dependencies\" (vereisten, soms ook afhankelijkheden genoemd) die door de "
+"pakketonderhouders zorgvuldig ontworpen werden. Deze vereisten worden "
+"beschreven in het bestand <tt>control</tt> dat in elk pakket aanwezig is. "
+"Bijvoorbeeld, het pakket dat de GNU C compiler (<package>gcc</package>) "
+"bevat, \"vereist\" het pakket <package>binutils</package> waarin zich de "
+"linker en de assembler bevinden. Indien een gebruiker het pakket "
+"<package>gcc</package> tracht te installeren zonder dat vooraf "
+"<package>binutils</package> geÃ¯nstalleerd werd, zal het pakketbeheersysteem "
+"(dpkg) de foutmelding geven dat het ook <package>binutils</package> nodig "
+"heeft en stoppen met de installatie van <package>gcc</package>. (De "
+"veeleisende gebruiker kan deze voorziening echter omzeilen; (zie <manref "
+"name=\"dpkg\" section=\"8\">.) Meer hierover in <ref id=\"depends\"> "
+"hieronder."
+
+#. type: <p><list>
+#: debian-faq.sgml:48 pkg_basics.sgml:46
+msgid "Debian's packaging tools can be used to:"
+msgstr "Het pakketbeheergereedschap van Debian kan gebruikt worden om:"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:47
+msgid "manipulate and manage packages or parts of packages,"
+msgstr "pakketten of delen ervan te hanteren en te beheren,"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:48
+msgid "administer local overrides of files in a package,"
+msgstr "lokale vervangingen van bestanden uit een pakket te beheren,"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:49
+msgid "aid developers in the construction of package archives, and"
+msgstr "ontwikkelaars te helpen bij de constructie van pakketarchieven, en"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:52
+msgid ""
+"aid users in the installation of packages which reside on a remote FTP site."
+msgstr ""
+"gebruikers te helpen bij het installeren van pakketten die op een externe "
+"FTP-site staan."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:56
+msgid "What is the format of a Debian binary package?"
+msgstr "Wat is de indeling van een binair pakket van Debian?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:61
+msgid ""
+"A Debian \"package\", or a Debian archive file, contains the executable "
+"files, libraries, and documentation associated with a particular suite of "
+"program or set of related programs. Normally, a Debian archive file has a "
+"filename that ends in <tt>.deb</tt>."
+msgstr ""
+"Een \"pakket\" van Debian, of een archiefbestand van Debian, bevat de "
+"uitvoerbare bestanden, bibliotheken en documentatie die verband houdt met "
+"een specifieke programma-suite of groep van verwante programma's. Gewoonlijk "
+"heeft een Debian-archief een bestandsnaam die eindigt op <tt>.deb</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:67
+msgid ""
+"The internals of this Debian binary packages format are described in the "
+"<manref name=\"deb\" section=\"5\"> manual page. This internal format is "
+"subject to change (between major releases of &debian;), therefore please "
+"always use <manref name=\"dpkg-deb\" section=\"1\"> if you need to do "
+"lowlevel manipulations on <tt>.deb</tt> files."
+msgstr ""
+"De interne indeling van deze binaire pakketten van Debian wordt beschreven "
+"in de man-pagina <manref name=\"deb\" section=\"5\">. Deze interne indeling "
+"kan veranderen (naar aanleiding van een hoofdrelease van &debian;). Gebruik "
+"daarom altijd <manref name=\"dpkg-deb\" section=\"1\"> als u "
+"grondbewerkingen moet uitvoeren op <tt>.deb</tt>-bestanden."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:69
+msgid "Why are Debian package file names so long?"
+msgstr "Waarom hebben Debian-pakketten dergelijke lange namen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:72
+msgid ""
+"The Debian binary package file names conform to the following convention: "
+"&lt;foo&gt;_&lt;VersionNumber&gt;-&lt;DebianRevisionNumber&gt;_&lt;"
+"DebianArchitecture&gt;.deb"
+msgstr ""
+"De bestandsnaam van een Debian-pakket beantwoordt aan de volgende conventie: "
+"&lt;foo&gt;_&lt;VersieNummer&gt;-&lt;DebianRevisieNummer&gt;_&lt;"
+"DebianArchitectuur&gt;.deb"
+
+#. type: <p><list>
+#: debian-faq.sgml:48 pkg_basics.sgml:75
+msgid ""
+"Note that <tt>foo</tt> is supposed to be the package name. Checking the "
+"package name associated with a particular Debian archive file (.deb file) "
+"can be done in one of these ways:"
+msgstr ""
+"Merk op dat <tt>foo</tt> hier staat voor de pakketnaam. Nagaan wat de "
+"pakketnaam is van een specifiek archiefbestand van Debian (een .deb-"
+"bestand), kan op een van de volgende manieren gebeuren:"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:78
+msgid ""
+"inspect the \"Packages\" file in the directory where it was stored at a "
+"Debian FTP archive site. This file contains a stanza describing each "
+"package; the first field in each stanza is the formal package name."
+msgstr ""
+"onderzoek het bestand \"Packages\" in de map waar het zich op een Debian FTP-"
+"archiefsite bevindt. Dit bestand bevat voor elk pakket een paragraaf met de "
+"beschrijving ervan. Het eerste veld van die paragraaf bevat de formele "
+"pakketnaam."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:83
+msgid ""
+"use the command <tt>dpkg --info foo_VVV-RRR_AAA.deb</tt> (where VVV, RRR and "
+"AAA are the version, revision and architecture of the package in question, "
+"respectively). This displays, among other things, the package name "
+"corresponding to the archive file being unpacked."
+msgstr ""
+"gebruik het commando <tt>dpkg --info foo_VVV-RRR_AAA.deb</tt> (waarbij VVV, "
+"RRR en AAA respectievelijk het versienummer, het revisienummer en de "
+"architectuur van het pakket in kwestie zijn). Dit commando toont onder meer "
+"de pakketnaam die overeenkomt met het archiefbestand dat uitgepakt wordt."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:89
+msgid ""
+"The <tt>VVV</tt> component is the version number specified by the upstream "
+"developer. There are no standards in place here, so the version number may "
+"have formats as different as \"19990513\" and \"1.3.8pre1\"."
+msgstr ""
+"De component <tt>VVV</tt> is het versienummer dat door de "
+"programmaontwikkelaar (de zogenaamde upstream developer) aan het programma "
+"gegeven werd. Hier gelden geen standaarden, waardoor dit versienummer heel "
+"uiteenlopende vormen kan hebben, zoals \"19990513\" of \"1.3.8pre1\"."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:97
+msgid ""
+"The <tt>RRR</tt> component is the Debian revision number, and is specified "
+"by the Debian developer (or an individual user if he chooses to build the "
+"package himself). This number corresponds to the revision level of the "
+"Debian package, thus, a new revision level usually signifies changes in the "
+"Debian Makefile (<tt>debian/rules</tt>), the Debian control file (<tt>debian/"
+"control</tt>), the installation or removal scripts (<tt>debian/p*</tt>), or "
+"in the configuration files used with the package."
+msgstr ""
+"De component <tt>RRR</tt> is het revisienummer van Debian en wordt gegeven "
+"door de ontwikkelaar van Debian (of een individuele gebruiker die kiest om "
+"het pakket zelf te bouwen). Dit nummer komt overeen met het revisieniveau "
+"van het Debian-pakket. En dus betekent een nieuw revisienummer meestal dat "
+"de Debian Makefile (<tt>debian/rules</tt>), het Debian control-bestand "
+"(<tt>debian/control</tt>), de scripts voor installatie en verwijdering "
+"(<tt>debian/p*</tt>) of de configuratiebestanden van het pakket gewijzigd "
+"werden."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:104
+msgid ""
+"The <tt>AAA</tt> component identifies the processor for which the package "
+"was built. This is commonly <tt>amd64</tt>, which refers to AMD64, Intel 64 "
+"or VIA Nano chips. For other possibilities review Debian's FTP directory "
+"structure at <ref id=\"dirtree\">. For details, see the description of "
+"\"Debian architecture\" in the manual page <manref name=\"dpkg-architecture"
+"\" section=\"1\">."
+msgstr ""
+"De component <tt>AAA</tt> identificeert de processor waarvoor het pakket "
+"gebouwd werd. Dit is vaak <tt>amd64</tt>, wat verwijst naar de chips van het "
+"type AMD64, Intel 64 of VIA Nano. Kijk de mappenstructuur van de FTP-site "
+"van Debian op <ref id=\"dirtree\"> erop na voor andere mogelijkheden. Zie "
+"voor meer info de beschrijving van \"Debian architectuur\" in de man-pagina "
+"<manref name=\"dpkg-architecture\" section=\"1\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:106
+msgid "What is a Debian control file?"
+msgstr "Wat is een Debian control-bestand?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:109
+msgid ""
+"Specifics regarding the contents of a Debian control file are provided in "
+"the Debian Policy Manual, section 5, see <ref id=\"debiandocs\">."
+msgstr ""
+"Specificaties over de inhoud van een control-bestand van Debian worden "
+"gegeven in het Beleidshandboek van Debian, hoofdstuk 5. Zie <ref id="
+"\"debiandocs\">."
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:110
+msgid ""
+"Briefly, a sample control file is shown below for the Debian package hello:"
+msgstr ""
+"Een beknopt voorbeeld van een control-bestand voor het Debian-pakket ziet u "
+"hieronder:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:131
+#, no-wrap
+msgid ""
+"Package: hello\n"
+"Version: 2.9-2+deb8u1\n"
+"Architecture: amd64\n"
+"Maintainer: Santiago Vila &lt;sanvila@debian.org&gt;\n"
+"Installed-Size: 145\n"
+"Depends: libc6 (>= 2.14)\n"
+"Conflicts: hello-traditional\n"
+"Breaks: hello-debhelper (<< 2.9)\n"
+"Replaces: hello-debhelper (<< 2.9), hello-traditional\n"
+"Section: devel\n"
+"Priority: optional\n"
+"Homepage: http://www.gnu.org/software/hello/\n"
+"Description: example package based on GNU hello\n"
+" The GNU hello program produces a familiar, friendly greeting.  It\n"
+" allows non-programmers to use a classic computer science tool which\n"
+" would otherwise be unavailable to them.\n"
+" .\n"
+" Seriously, though: this is an example of how to do a Debian package.\n"
+" It is the Debian version of the GNU Project's `hello world' program\n"
+" (which is itself an example for the GNU Project)."
+msgstr ""
+"Pakket: hello\n"
+"Versie: 2.9-2+deb8u1\n"
+"Architectuur: amd64\n"
+"Onderhouder: Santiago Vila &lt;sanvila@debian.org&gt;\n"
+"Grootte-na-Installatie: 145\n"
+"Vereist: libc6 (>= 2.14)\n"
+"Tegenstrijdig met: hello-traditional\n"
+"Maakt defect: hello-debhelper (<< 2.9)\n"
+"Vervangt: hello-debhelper (<< 2.9), hello-traditional\n"
+"Sectie: devel\n"
+"Prioriteit: optional\n"
+"Homepage: http://www.gnu.org/software/hello/\n"
+"Beschrijving: voorbeeldpakket gebaseerd op GNU hello\n"
+" Het GNU-programma hello produceert een bekende, vriendelijke\n"
+" begroeting. Het laat niet-programmeurs toe een klassiek\n"
+" gereedschap uit de computerwetenschappen te gebruiken\n"
+" waartoe ze anders geen toegang zouden hebben.\n"
+" .\n"
+" Ernstig nu: dit is een voorbeeld van hoe u een Debian-pakket maakt.\n"
+" Het is de Debian-versie van het programma `hello world'\n"
+" van het GNU Project. (dat zelf voor het GNU Project als\n"
+" voorbeeld dient)."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:138
+msgid ""
+"The Package field gives the package name. This is the name by which the "
+"package can be manipulated by the package tools, and usually similar to but "
+"not necessarily the same as the first component string in the Debian archive "
+"file name."
+msgstr ""
+"Het veld Package vermeldt de naam van het pakket. Dat is de naam waarmee het "
+"pakket door de pakketgereedschappen gemanipuleerd kan worden. En meestal, "
+"maar niet noodzakelijk, is die hetzelfde als de eerste component van de naam "
+"van het Debian-archiefbestand."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:142
+msgid ""
+"The Version field gives both the upstream developer's version number and (in "
+"the last component) the revision level of the Debian package of this program "
+"as explained in <ref id=\"pkgname\">."
+msgstr ""
+"Het veld Version vermeldt zowel het versienummer dat de toeleverende "
+"programmaontwikkelaar eraan geeft als (in de laatste component) het "
+"revisieniveau van het Debian-pakket van dit programma, zoals toegelicht werd "
+"in <ref id=\"pkgname\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:145
+msgid ""
+"The Architecture field specifies the chip for which this particular binary "
+"was compiled."
+msgstr ""
+"Het veld Architecture vermeldt de chip waarvoor dit specifieke binaire "
+"pakket gecompileerd werd."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:148
+msgid ""
+"The Depends field gives a list of packages that have to be installed in "
+"order to install this package successfully."
+msgstr ""
+"Het veld Depends vermeldt een lijst van pakketten die geÃ¯nstalleerd moeten "
+"zijn opdat dit pakket met succes geÃ¯nstalleerd zou kunnen worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:153
+msgid ""
+"The Installed-Size indicates how much disk space the installed package will "
+"consume. This is intended to be used by installation front-ends in order to "
+"show whether there is enough disk space available to install the program."
+msgstr ""
+"Het veld Installed-Size geeft aan hoeveel schijfruimte het geÃ¯nstalleerde "
+"pakket zal gebruiken. Het is de bedoeling dat de installatie-frontends "
+"daarvan gebruik maken om te tonen of er voldoende schijfruimte beschikbaar "
+"is voor de installatie van het programma."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:156
+msgid ""
+"The Section line gives the \"section\" where this Debian package is stored "
+"at the Debian FTP sites."
+msgstr ""
+"De regel Section geeft de \"sectie\" aan waar dit Debian-pakket opgeslagen "
+"is op de Debian FTP-sites."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:161
+msgid ""
+"The Priority indicates how important is this package for installation, so "
+"that semi-intelligent software like apt or aptitude can sort the package "
+"into a category of e.g. packages optionally installed. See <ref id=\"priority"
+"\">."
+msgstr ""
+"Het veld Priority geeft aan hoe belangrijk het is dat dit pakket "
+"geÃ¯nstalleerd is, waardoor semi-intelligente software zoals apt en aptitude "
+"het pakket kunnen indelen in een categorie, zoals bijvoorbeeld optioneel "
+"geÃ¯nstalleerde pakketten. Zie <ref id=\"priority\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:164
+msgid ""
+"The Maintainer field gives the e-mail address of the person who is currently "
+"responsible for maintaining this package."
+msgstr ""
+"Het veld Maintainer vermeldt het e-mailadres van de persoon die momenteel "
+"verantwoordelijk is voor het onderhoud van dit pakket."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:166
+msgid "The Description field gives a brief summary of the package's features."
+msgstr ""
+"Het veld Description bevat een korte beschrijving van de functionaliteit van "
+"het pakket."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:170
+msgid ""
+"For more information about all possible fields a package can have, please "
+"see the Debian Policy Manual, section 5, \"Control files and their fields\", "
+"see <ref id=\"debiandocs\">."
+msgstr ""
+"Voor meer informatie over alle mogelijke velden welke een pakket kan hebben "
+"kunt u hoofdstuk 5 van het Debian beleidshandboek, \"Controle-bestanden en "
+"hun velden\", raadplegen. Zie <ref id=\"debiandocs\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:172
+msgid "What is a Debian conffile?"
+msgstr "Wat is een Debian conffile?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:178
+msgid ""
+"Conffiles is a list of configuration files (usually placed in <tt>/etc</tt>) "
+"that the package management system will not overwrite when the package is "
+"upgraded. This ensures that local values for the contents of these files "
+"will be preserved, and is a critical feature enabling the in-place upgrade "
+"of packages on a running system."
+msgstr ""
+"Conffiles is een lijst van configuratiebestanden (die meestal in <tt>/etc</"
+"tt> geplaatst worden) welke het pakketbeheersysteem niet zal overschrijven "
+"als het pakket opgewaardeerd wordt. Dit garandeert dat de lokale waarden van "
+"de inhoud van die bestanden behouden blijven, hetgeen een cruciale "
+"functionaliteit is voor het mogelijk maken van de opwaardering van pakketten "
+"op een werkend systeem."
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:178
+msgid "To determine exactly which files are preserved during an upgrade, run:"
+msgstr ""
+"Om exact te weten welke bestanden behouden blijven tijdens een opwaardering, "
+"geeft u het commando"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:178
+#, no-wrap
+msgid "dpkg --status package"
+msgstr "dpkg --status pakket"
+
+#. type: </example></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:182
+msgid "And look under \"Conffiles:\"."
+msgstr "en kijkt u bij \"Conffiles:\"."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:185
+msgid "What is a Debian preinst, postinst, prerm, and postrm script?"
+msgstr "Wat is een Debian preinst, postinst, prerm, en postrm script?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:189
+msgid ""
+"These files are executable scripts which are automatically run before or "
+"after a package is installed or removed. Along with a file named "
+"<tt>control</tt>, all of these files are part of the \"control\" section of "
+"a Debian archive file."
+msgstr ""
+"Deze bestanden zijn uitvoerbare scripts die automatisch uitgevoerd worden "
+"vooraleer of nadat een pakket geÃ¯nstalleerd of verwijderd wordt. Samen met "
+"het bestand met de naam <tt>control</tt>, maken al deze bestanden deel uit "
+"van de \"controle\"-sectie van een Debian archiefbestand."
+
+#. type: <p><taglist>
+#: debian-faq.sgml:48 pkg_basics.sgml:190
+msgid "The individual files are:"
+msgstr "De verschillende bestanden zijn:"
+
+#. type: <tag></tag>
+#: debian-faq.sgml:48 pkg_basics.sgml:191
+msgid "preinst"
+msgstr "preinst"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:197
+msgid ""
+"This script is executed before the package it belongs to is unpacked from "
+"its Debian archive (\".deb\") file. Many 'preinst' scripts stop services for "
+"packages which are being upgraded until their installation or upgrade is "
+"completed (following the successful execution of the 'postinst' script)."
+msgstr ""
+"Dit script wordt uitgevoerd vooraleer het pakket waartoe het behoort, "
+"uitgepakt wordt uit zijn Debian-archiefbestand (\".deb\"). Vele 'preinst'-"
+"scripts stoppen diensten voor pakketten die opgewaardeerd worden totdat hun "
+"opwaardering of installatie voltooid is (na de succesvolle uitvoering van "
+"het 'postinst'-script)."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:48 pkg_basics.sgml:197
+msgid "postinst"
+msgstr "postinst"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:206
+msgid ""
+"This script typically completes any required configuration of the package "
+"<tt>foo</tt> once <tt>foo</tt> has been unpacked from its Debian archive (\"."
+"deb\") file. Often, 'postinst' scripts ask users for input, and/or warn them "
+"that if they accept default values, they should remember to go back and re-"
+"configure that package as needed. Many 'postinst' scripts then execute any "
+"commands necessary to start or restart a service once a new package has been "
+"installed or upgraded."
+msgstr ""
+"Dit script werkt meestal een eventuele vereiste configuratie van het pakket "
+"<tt>foo</tt> af nadat <tt>foo</tt> uitgepakt werd uit zijn Debian-"
+"archiefbestand (\".deb\"). Vaak vragen 'postinst'-scripts de gebruiker om "
+"invoer en/of waarschuwen hem dat als hij de standaardwaarden aanvaardt, hij "
+"later op de configuratie moet terugkomen om die volgens behoefte te "
+"herconfigureren. Vele 'postinst'-scripts voeren dan eventueel commando's uit "
+"die nodig zijn om een dienst te starten of te herstarten eens een nieuw "
+"pakket opgewaardeerd of geÃ¯nstalleerd werd."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:48 pkg_basics.sgml:206
+msgid "prerm"
+msgstr "prerm"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:211
+msgid ""
+"This script typically stops any daemons which are associated with a package. "
+"It is executed before the removal of files associated with the package."
+msgstr ""
+"Dit script stopt meestal eventuele daemons die verband houden met dat "
+"pakket. Het wordt uitgevoerd vooraleer de bestanden die verband houden met "
+"het pakket, verwijderd worden."
+
+#. type: <tag></tag>
+#: debian-faq.sgml:48 pkg_basics.sgml:211
+msgid "postrm"
+msgstr "postrm"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:215
+msgid ""
+"This script typically modifies links or other files associated with <tt>foo</"
+"tt>, and/or removes files created by the package. (Also see <ref id=\"virtual"
+"\">.)"
+msgstr ""
+"Dit script wijzigt gewoonlijk koppelingen of andere bestanden die verband "
+"houden met <tt>foo</tt> en/of verwijdert bestanden die door het pakket "
+"gecreÃ«erd werden. (Zie ook <ref id=\"virtual\">.)"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:225
+msgid ""
+"Currently all of the control files can be found in the directory <tt>/var/"
+"lib/dpkg/info</tt>. The files relevant to package <tt>foo</tt> begin with "
+"the name \"foo\" and have file extensions of \"preinst\", \"postinst\", "
+"etc., as appropriate. The file <tt>foo.list</tt> in that directory lists all "
+"of the files that were installed with the package <tt>foo</tt>. (Note that "
+"the location of these files is a dpkg internal; you should not rely on it.)"
+msgstr ""
+"Momenteel zijn alle controle-bestanden te vinden in de map <tt>/var/lib/dpkg/"
+"info</tt>. De bestanden die verband houden met het pakket <tt>foo</tt> "
+"hebben een naam die begint met \"foo\" en hebben voor zover van toepassing "
+"de bestandsextensie \"preinst\", \"postinst\", enz. Het bestand <tt>foo."
+"list</tt> in die map vermeldt alle bestanden die door het pakket <tt>foo</"
+"tt> geÃ¯nstalleerd werden. (merk op dat de locatie van die bestanden behoort "
+"tot de interne keuken van dpkg; u moet daarop niet vertrouwen.)"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:228
+msgid ""
+"What is an <em>Essential</em>, <em>Required</em>, <em>Important</em>, "
+"<em>Standard</em>, <em>Optional</em>, or <em>Extra</em> package?"
+msgstr ""
+"Wat is een <em>Essential</em> (essentieel), <em>Required</em> (vereist), "
+"<em>Important</em> (belangrijk), <em>Standard</em> (standaard), "
+"<em>Optional</em> (optioneel) en <em>Extra</em> (extra) pakket?"
+
+#. type: <p><list>
+#: debian-faq.sgml:48 pkg_basics.sgml:231
+msgid ""
+"Each Debian package is assigned a <em>priority</em> by the distribution "
+"maintainers, as an aid to the package management system. The priorities are:"
+msgstr ""
+"Elk pakket krijgt door de onderhouders van de distributie een "
+"<em>prioriteit</em> toegekend als een hulpmiddel voor het "
+"pakketbeheersysteem. De prioriteiten zijn:"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:233
+msgid ""
+"<strong>Required</strong>: packages that are necessary for the proper "
+"functioning of the system."
+msgstr ""
+"<strong>Required</strong> (vereist): pakketten die noodzakelijk zijn voor de "
+"goede werking van het systeem."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:239
+msgid ""
+"This includes all tools that are necessary to repair system defects. You "
+"must not remove these packages or your system may become totally broken and "
+"you may probably not even be able to use dpkg to put things back. Systems "
+"with only the Required packages are probably unusable, but they do have "
+"enough functionality to allow the sysadmin to boot and install more software."
+msgstr ""
+"Dit omvat alle noodzakelijke gereedschappen voor het repareren van een "
+"defect systeem. U mag deze pakketten niet verwijderen want uw systeem zou "
+"volledig defect kunnen geraken en waarschijnlijk zou u niet eens dpkg kunnen "
+"gebruiken om de zaken terug te plaatsen. Systemen met enkel pakketten met "
+"prioriteit 'Required' zijn waarschijnlijk onbruikbaar, maar hebben voldoende "
+"functionaliteit om de systeembeheerder in staat te stellen het op te starten "
+"en bijkomende software te installeren."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:241
+msgid ""
+"<strong>Important</strong> packages should be found on any Unix-like system."
+msgstr ""
+"<strong>Important</strong> (belangrijke) pakketten zouden op elk Unix-achtig "
+"systeem aanwezig moeten zijn."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:245
+msgid ""
+"Other packages which the system will not run well or be usable without will "
+"be here. This does <em>NOT</em> include Emacs or X or TeX or any other large "
+"application. These packages only constitute the bare infrastructure."
+msgstr ""
+"Andere pakketten zonder dewelke het systeem niet goed zou functioneren of "
+"niet bruikbaar zou zijn, vallen hieronder. Daaronder valllen <em>NIET</em> "
+"Emacs of X of TeX of gelijk welke andere omvangrijke toepassing. Deze "
+"pakketten voorzien enkel in de basisinfrastructuur."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:249
+msgid ""
+"<strong>Standard</strong> packages are standard on any Linux system, "
+"including a reasonably small but not too limited character-mode system. "
+"Tools are included to be able to send e-mail (with mutt) and download files "
+"from FTP servers."
+msgstr ""
+"<strong>Standard</strong>-pakketten zijn standaard aanwezig op elk Linux-"
+"systeem en omvatten onder meer een klein maar niet al te beperkt "
+"tekenmodussysteem. Ook gereedschap dat het mogelijk maakt e-mails te "
+"verzenden (met mutt) en bestanden te downloaden van FTP-servers valt "
+"hieronder."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:255
+msgid ""
+"This is what will be installed by default if users do not select anything "
+"else. It does not include many large applications, but it does include the "
+"Python interpreter and some server software like OpenSSH (for remote "
+"administration) and Exim (for mail delivery, although it can be configured "
+"for local delivery only). It also includes some common generic documentation "
+"that most users will find helpful."
+msgstr ""
+"Dit is wat standaard geÃ¯nstalleerd wordt als de gebruiker niets anders "
+"selecteert. Veel uitgebreide toepassingen vallen hieronder niet, maar "
+"hieronder valt wel de interpreter van Python en bepaalde serversoftware, "
+"zoals OpenSSH (om beheer vanop afstand mogelijk te maken) en Exim (voor het "
+"afleveren van e-mail, hoewel het ingesteld kan worden om enkel lokaal e-mail "
+"af te leveren). Hieronder valt ook bepaalde algemene documentatie die voor "
+"de meeste gebruikers nuttig is."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:258
+msgid ""
+"<strong>Optional</strong> packages include all those that you might "
+"reasonably want to install if you do not know what they are, or that do not "
+"have specialized requirements."
+msgstr ""
+"<strong>Optional</strong> (optionele) pakketten zijn al die pakketten die u "
+"redelijkerwijs wel wilt installeren als u ze niet goed kent, of pakketten "
+"die geen bijzondere vereisten stellen."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:259
+msgid "This includes X, a full TeX distribution, and lots of applications."
+msgstr "Daaronder vallen X, een complete TeX-distributie en vele toepassingen."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:264
+msgid ""
+"<strong>Extra</strong>: packages that either conflict with others with "
+"higher priorities, are only likely to be useful if you already know what "
+"they are, or have specialized requirements that make them unsuitable for "
+"\"Optional\"."
+msgstr ""
+"<strong>Extra</strong>: pakketten die ofwel tegenstrijdig zijn met andere "
+"pakketten met een hogere prioriteit, meestal enkel nuttig zijn voor wie ze "
+"echt kent, of bijzondere vereisten stellen die ze ongeschikt maken voor de "
+"categorie \"Optional\" (optioneel)."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:271
+msgid ""
+"If you do a default Debian installation all the packages of priority "
+"<strong>Standard</strong> or higher will be installed in your system. If you "
+"select pre-defined tasks you will get lower priority packages too."
+msgstr ""
+"Indien u een standaardinstallatie van Debian uitvoert zullen alle pakketten "
+"met prioriteit <strong>Standard</strong> of hoger op uw systeem "
+"geÃ¯nstalleerd worden. Indien u voorgedefinieerde taken ('tasks') selecteert "
+"zullen er ook pakketten met een lagere prioriteit geÃ¯nstalleerd worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:275
+msgid ""
+"Additionally, some packages are marked as <strong>Essential</strong> since "
+"they are absolutely necessary for the proper functioning of the system. The "
+"package management tools will refuse to remove these."
+msgstr ""
+"Daarnaast worden sommige pakketten gemarkeerd als <strong>Essential</strong> "
+"(essentieel) omdat ze absoluut noodzakelijk zijn voor het goed functioneren "
+"van het systeem. De gereedschappen voor pakketbeheer zullen weigeren om deze "
+"te verwijderen."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:277
+msgid "What is a Virtual Package?"
+msgstr "Wat is een virtueel pakket?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:285
+msgid ""
+"A virtual package is a generic name that applies to any one of a group of "
+"packages, all of which provide similar basic functionality. For example, "
+"both the <tt>konqueror</tt> and <tt>firefox-esr</tt> programs are web "
+"browsers, and should therefore satisfy any dependency of a program that "
+"requires a web browser on a system, in order to work or to be useful. They "
+"are therefore both said to provide the \"virtual package\" called <tt>www-"
+"browser</tt>."
+msgstr ""
+"Een virtueel pakket is een algemene naam voor een groep pakketten die "
+"allemaal eenzelfde functionaliteit bieden. Bijvoorbeeld, de programma's "
+"<tt>konqueror</tt> en <tt>firefox-esr</tt> zijn allebei webbrowsers en "
+"kunnen daarom voldoen aan de vereiste van elk programma dat de aanwezigheid "
+"van een webbrowser op het systeem nodig heeft om te kunnen functioneren of "
+"van nut te kunnen zijn. Daarom wordt van beide pakketten gezegd dat ze "
+"voorzien in het \"virtueel pakket\" met de naam <tt>www-browser</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:292
+msgid ""
+"Similarly, <tt>exim4</tt> and <tt>sendmail</tt> both provide the "
+"functionality of a mail transport agent. They are therefore said to provide "
+"the virtual package \"mail-transport-agent\". If either one is installed, "
+"then any program depending on the installation of a <tt>mail-transport-"
+"agent</tt> will be satisfied by the presence of this virtual package."
+msgstr ""
+"Evenzo leveren zowel <tt>exim4</tt> als <tt>sendmail</tt> de functionaliteit "
+"van e-mailtransporteur. Daarom wordt van beide pakketten gezegd dat ze "
+"voorzien in het virtueel pakket \"mail-transport-agent\". Indien een van "
+"beide geÃ¯nstalleerd is, zal met de aanwezigheid van dit virtueel pakket "
+"voldaan zijn aan de vereiste van elk programma dat afhankelijk is van de "
+"installatie van een <tt>mail-transport-agent</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:298
+msgid ""
+"Debian provides a mechanism so that, if more than one package which provide "
+"the same virtual package is installed on a system, then system "
+"administrators can set one as the preferred package. The relevant command is "
+"<tt>update-alternatives</tt>, and is described further in <ref id=\"diverse"
+"\">."
+msgstr ""
+"Indien op een systeem meer dan een pakket geÃ¯nstalleerd is dat voorziet in "
+"hetzelfde virtueel pakket, beschikt Debian over een mechanisme waardoor "
+"systeembeheerders een ervan kunnen aanduiden als voorkeurspakket. Het "
+"betreffende commando is <tt>update-alternatives</tt> en wordt later "
+"behandeld onder <ref id=\"diverse\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:302
+msgid ""
+"What is meant by saying that a package <em>Depends</em>, <em>Recommends</"
+"em>, <em>Suggests</em>, <em>Conflicts</em>, <em>Replaces</em>, <em>Breaks</"
+"em> or <em>Provides</em> another package?"
+msgstr ""
+"Wat wordt bedoeld met het feit dat een pakket een ander pakket <em>Depends</"
+"em> (vereist), <em>Recommends</em> (aanbeveelt), <em>Suggests</em> "
+"(suggereert), <em>Conflicts</em> (ermee in strijd is), <em>Replaces</em> "
+"(vervangt), <em>Breaks</em> (maakt onklaar) of <em>Provides</em> (erin "
+"voorziet)?"
+
+#. type: <p><list>
+#: debian-faq.sgml:48 pkg_basics.sgml:306
+msgid ""
+"The Debian package system has a range of package \"dependencies\" which are "
+"designed to indicate (in a single flag) the level at which Program A can "
+"operate independently of the existence of Program B on a given system:"
+msgstr ""
+"Het pakketsysteem van Debian kent een scala van \"afhankelijkheden/vereisten"
+"\" (dependencies) dat ontworpen werd om aan te geven (met een enkele vlag) "
+"in welke mate een programma A op een bepaald systeem kan functioneren zonder "
+"de aanwezigheid van programma B:"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:311
+msgid ""
+"Package A <em>depends</em> on Package B if B absolutely must be installed in "
+"order to run A. In some cases, A depends not only on B, but on a version of "
+"B. In this case, the version dependency is usually a lower limit, in the "
+"sense that A depends on any version of B more recent than some specified "
+"version."
+msgstr ""
+"Pakket A <em>vereist</em> (depends in het jargon van Debian - in vertalingen "
+"wordt soms ook de term 'is afhankelijk van' gebruikt) pakket B als B "
+"absoluut geÃ¯nstalleerd moet zijn om B te kunnen uitvoeren. In sommige "
+"gevallen vereist A niet enkel B, maar een bepaalde versie van B. In "
+"dergelijk geval geeft het versienummer meestal een ondergrens aan, in die "
+"zin dat A ook om het even welke versie van B kan gebruiken die recenter is "
+"dan de opgegeven versie."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:314
+msgid ""
+"Package A <em>recommends</em> Package B, if the package maintainer judges "
+"that most users would not want A without also having the functionality "
+"provided by B."
+msgstr ""
+"Pakket A <em>beveelt</em> pakket B <em>aan</em> (recommends in het jargon "
+"van Debian) als de pakketbeheerder van oordeel is dat de meeste gebruikers A "
+"niet zouden willen hebben zonder ook te beschikken over de functionaliteit "
+"die door B geboden wordt."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:316
+msgid ""
+"Package A <em>suggests</em> Package B if B contains files that are related "
+"to (and usually enhance) the functionality of A."
+msgstr ""
+"Pakket A <em>suggereert</em> (suggests in het jargon van Debian) pakket B "
+"als pakket B bestanden bevat die verband houden met de functionaliteit van A "
+"(en deze meestal uitbreiden)."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:320
+msgid ""
+"Package A <em>conflicts</em> with Package B when A will not operate if B is "
+"installed on the system. Most often, conflicts are cases where A contains "
+"files which are an improvement over those in B. \"Conflicts\" are often "
+"combined with \"replaces\"."
+msgstr ""
+"Pakket A <em>is in tegenstrijd met</em> (conflicts in het jargon van Debian "
+"- in vertalingen wordt soms ook de term 'conflicteert met' gebruikt) pakket "
+"B als pakket A niet zal werken als pakket B op het systeem geÃ¯nstalleerd is. "
+"Meestal doet een conflict zich voor als A bestanden bevat die een verbeterde "
+"versie zijn van die van B. De kwalificatie \"Conflicts\" wordt vaak gebruikt "
+"in combinatie met \"replaces\"."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:322
+msgid ""
+"Package A <em>replaces</em> Package B when files installed by B are removed "
+"and (in some cases) over-written by files in A."
+msgstr ""
+"Pakket A <em>vervangt</em> (replaces in het jargon van Debian) pakket B als "
+"bestanden die door B geÃ¯nstalleerd worden, verwijderd en (in sommige "
+"gevallen) overschreven worden door bestanden uit A."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:326
+msgid ""
+"Package A <em>breaks</em> Package B when both packages cannot be "
+"simultaneously configured in a system. The package management system will "
+"refuse to install one if the other one is already installed and configured "
+"in the system."
+msgstr ""
+"Pakket A <em>maakt</em> pakket B <em>onklaar</em> (breaks in het jargon van "
+"Debian - in vertalingen wordt soms ook de term 'breekt' gebruikt) wanneer "
+"beide pakketten niet gelijktijdig geconfigureerd kunnen zijn op een systeem. "
+"Het pakketbeheersysteem zal weigeren om het ene pakket te installeren als "
+"het andere reeds geÃ¯nstalleerd en geconfigureerd is op het systeem."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:331
+msgid ""
+"Package A <em>provides</em> Package B when all of the files and "
+"functionality of B are incorporated into A. This mechanism provides a way "
+"for users with constrained disk space to get only that part of package A "
+"which they really need."
+msgstr ""
+"Pakket A <em>voorziet in</em> (provides in het jargon van Debian) pakket B "
+"als alle bestanden en alle functionaliteit van B opgenomen zijn in A. Dit "
+"mechanisme biedt gebruikers met beperkte opslagruimte de mogelijkheid om "
+"enkel dat deel van pakket A te nemen waaraan ze echt behoefte hebben."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:337
+msgid ""
+"More detailed information on the use of each of these terms can be found in "
+"the Debian Policy manual, section 7.2, \"Binary Dependencies\", see <ref id="
+"\"debiandocs\">."
+msgstr ""
+"Meer uitgebreide informatie over het gebruik van elk van deze termen i s te "
+"vinden in het Beleidshandboek van Debian, hoofdstuk 7.2, \"Binary "
+"Dependencies\" (Vereisten van binaire pakketten), zie <ref id=\"debiandocs"
+"\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:339
+msgid "What is meant by Pre-Depends?"
+msgstr "Wat wordt bedoeld met Pre-Depends (voorvereisten)?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:349
+msgid ""
+"\"Pre-Depends\" is a special dependency. In the case of most packages, "
+"<tt>dpkg</tt> will unpack the archive file of a package (i.e., its <tt>.deb</"
+"tt> file) independently of whether or not the files on which it depends "
+"exist on the system. Simplistically, unpacking means that <tt>dpkg</tt> will "
+"extract the files from the archive file that were meant to be installed on "
+"your file system, and put them in place. If those packages <em>depend</em> "
+"on the existence of some other packages on your system, <tt>dpkg</tt> will "
+"refuse to complete the installation (by executing its \"configure\" action) "
+"until the other packages are installed."
+msgstr ""
+"\"Pre-Depends\" (een voorvereiste) is een bijzondere vereiste. Bij de meeste "
+"pakketten is het zo dat <tt>dpkg</tt> het archiefbestand van een pakket (d.w."
+"z. zijn <tt>.deb</tt>-bestand) zal uitpakken ongeacht het feit of de "
+"bestanden die het vereist op het systeem aanwezig zijn of niet. Eenvoudig "
+"geformuleerd betekent uitpakken dat <tt>dpkg</tt> de bestanden die "
+"geÃ¯nstalleerd moeten worden, zal extraheren uit het archiefbestand en ze op "
+"hun plaats zal zetten. Indien dit pakket de aanwezigheid op het systeem van "
+"bepaalde andere pakketten <em>vereist</em>, zal <tt>dpkg</tt> weigeren de "
+"installatie af te ronden (door te weigeren de actie \"configureren\" uit te "
+"voeren) totdat de andere pakketten geÃ¯nstalleerd zijn."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:358
+msgid ""
+"However, for some packages, <tt>dpkg</tt> will refuse even to unpack them "
+"until certain dependencies are resolved. Such packages are said to \"Pre-"
+"depend\" on the presence of some other packages. The Debian project provided "
+"this mechanism to support the safe upgrading of systems from <tt>a.out</tt> "
+"format to <tt>ELF</tt> format, where the <em>order</em> in which packages "
+"were unpacked was critical. There are other large upgrade situations where "
+"this method is useful, e.g. the packages with the required priority and "
+"their LibC dependency."
+msgstr ""
+"Echter, bij sommige pakketten zal <tt>dpkg</tt> zelfs weigeren deze uit te "
+"pakken totdat voldaan werd aan sommige vereisten. Van dergelijke pakketten "
+"wordt gezegd dat ze de aanwezigheid van andere pakketten als \"voorvereiste"
+"\" (Pre-depends) hebben. Het Debian-project ontwikkelde dit mechanisme om de "
+"veilige opwaardering mogelijk te maken van systemen op basis van het <tt>a."
+"out</tt>-formaat naar het <tt>ELF</tt>-formaat, waarbij de <em>volgorde</em> "
+"waarin pakketten uitgepakt werden, cruciaal was. Er doen zich ook andere "
+"uitgebreide opwaarderingssituaties voor waarbij deze methode nuttig is, "
+"bijvoorbeeld bij de opwaardering van pakketten die als prioriteit "
+"'required' (vereist) hebben en hun LibC-vereiste."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:361
+msgid ""
+"As before, more detailed information about this can be found in the Policy "
+"manual."
+msgstr ""
+"Zoals hiervoor reeds het geval was, kan ook hierover meer informatie "
+"gevonden worden in het Beleidshandboek."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:364
+msgid ""
+"What is meant by <em>unknown</em>, <em>install</em>, <em>remove</em>, "
+"<em>purge</em> and <em>hold</em> in the package status?"
+msgstr ""
+"Wat wordt bedoeld met <em>unknown</em> (onbekend), <em>install</em> "
+"(installeren), <em>remove</em> (verwijderen), <em>purge</em> (wissen) en "
+"<em>hold</em> (handhaven) in de pakketstatus?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:368
+msgid ""
+"These \"want\" flags tell what the user wanted to do with a package (as "
+"indicated by the user's direct invocations of <tt>dpkg</tt>/<tt>apt</tt>/ "
+"<tt>aptitude</tt>)."
+msgstr ""
+"Deze \"gewenst\"-vlaggen geven aan wat de gebruiker met een pakket wilde "
+"doen (zoals aangegeven bij de rechtstreekse aanroeping door de gebruiker van "
+"<tt>dpkg</tt>/<tt>apt</tt>/ <tt>aptitude</tt>)."
+
+#. type: <p><list>
+#: debian-faq.sgml:48 pkg_basics.sgml:369
+msgid "Their meanings are:"
+msgstr "Hun betekenis is de volgende:"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:370
+msgid "unknown - the user has never indicated whether the package is wanted."
+msgstr ""
+"unknown - (onbekend) de gebruiker heeft nooit aangegeven dat hij het pakket "
+"wilde."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:371
+msgid "install - the user wants the package installed or upgraded."
+msgstr ""
+"install - (installeren) de gebruiker wil dat het pakket geÃ¯nstalleerd of "
+"opgewaardeerd wordt."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:373
+msgid ""
+"remove - the user wants the package removed, but does not want to remove any "
+"existing configuration file."
+msgstr ""
+"remove - (verwijderen) de gebruiker wil dat het pakket verwijderd wordt, "
+"maar wil eventuele bestaande configuratiebestanden niet verwijderen."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:375
+msgid ""
+"purge - the user wants the package to be removed completely, including its "
+"configuration files."
+msgstr ""
+"purge - (wissen) de gebruiker wil dat het pakket volledig verwijderd wordt, "
+"met inbegrip van zijn configuratiebestanden."
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:378
+msgid ""
+"hold - the user wants this package not to be processed, i.e. wants to keep "
+"the current version with the current status whatever that is."
+msgstr ""
+"hold - (handhaven) de gebruiker wil niet dat er iets gebeurt met dit pakket, "
+"d.w.z. dat hij de huidige versie in de huidige toestand wenst te behouden, "
+"wat die ook is."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:382
+msgid "How do I put a package on hold?"
+msgstr "Hoe plaats ik een pakket in de toestand 'te handhaven' (on hold)?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:384
+msgid ""
+"There are three ways of holding back packages, with dpkg, apt or aptitude."
+msgstr ""
+"Er zijn drie manieren om pakketten vast te houden/zetten, met dpkg, apt of "
+"aptitude."
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:384
+msgid "With dpkg, you have to export the list of package selections, with:"
+msgstr "Bij dpkg moet u de lijst met pakketselecties exporteren met:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:384
+#, no-wrap
+msgid "dpkg --get-selections \\* > selections.txt"
+msgstr "dpkg --get-selections \\* > selections.txt"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:387
+msgid ""
+"Then edit the resulting file <file>selections.txt</file>, change the line "
+"containing the package you wish to hold, e.g. <package>libc6</package>, from "
+"this:"
+msgstr ""
+"Dan moet u het gegenereerde bestand <file>selections.txt</file> bewerken en "
+"de regel met het pakket dat u wenst te handhaven, bijvoorbeeld "
+"<package>libc6</package>, veranderen van:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:384
+#, no-wrap
+msgid "libc6                                           install"
+msgstr "libc6                                           install"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:389
+msgid "to this:"
+msgstr "in:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:384
+#, no-wrap
+msgid "libc6                                           hold"
+msgstr "libc6                                           hold"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:391
+msgid "Save the file, and reload it into dpkg database with:"
+msgstr "Bewaar het bestand en laad het opnieuw in de databank van dpkg met:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:384
+#, no-wrap
+msgid "dpkg --set-selections < selections.txt"
+msgstr "dpkg --set-selections < selections.txt"
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:394
+msgid "With apt, you can set a package to hold using"
+msgstr "Bij apt kunt u een pakket als te handhaven instellen met"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:394
+#, no-wrap
+msgid "apt-mark hold package_name"
+msgstr "apt-mark hold pakket_naam"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:396 pkg_basics.sgml:401
+msgid "and remove the hold with"
+msgstr "en de 'te handhaven'-status verwijderen met"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:394
+#, no-wrap
+msgid "apt-mark unhold package_name"
+msgstr "apt-mark unhold pakket_naam"
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:399
+msgid "With aptitude, you can hold a package using"
+msgstr ""
+"Bij aptitude kunt u de 'te handhaven'-status van een pakket regelen met"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:399
+#, no-wrap
+msgid "aptitude hold package_name"
+msgstr "aptitude hold pakket_naam"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:399
+#, no-wrap
+msgid "aptitude unhold package_name"
+msgstr "aptitude unhold pakket_naam"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:406
+msgid "How do I install a source package?"
+msgstr "Hoe installeer ik een bronpakket?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:410
+msgid ""
+"Debian source packages can't actually be \"installed\", they are just "
+"unpacked in whatever directory you want to build the binary packages they "
+"produce."
+msgstr ""
+"Bronpakketten van Debian kunnen niet echt \"geÃ¯nstalleerd\" worden. Ze "
+"worden enkel uitgepakt in om het even welke map waarin u de binaire "
+"pakketten die deze produceren, wilt gaan bouwen."
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:415
+msgid ""
+"Source packages are distributed on most of the same mirrors where you can "
+"obtain the binary packages. If you set up your APT's <manref name=\"sources."
+"list\" section=\"5\"> to include the appropriate \"deb-src\" lines, you'll "
+"be able to easily download any source package by running"
+msgstr ""
+"Bronpakketten worden meestal verspreid door dezelfde spiegelservers waarop u "
+"de binaire pakketten vindt. Indien u uw APT's <manref name=\"sources.list\" "
+"section=\"5\"> zo instelt dat het bestand de passende \"deb-src\"-regels "
+"bevat, kunt u eenvoudig een bronpakket downloaden met de opdracht"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:410 pkg_basics.sgml:433
+#, no-wrap
+msgid "apt-get source foo"
+msgstr "apt-get source foo"
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:422
+msgid ""
+"To help you in actually building the source package, Debian source packages "
+"provide the so-called build-dependencies mechanism. This means that the "
+"source package maintainer keeps a list of other packages that are required "
+"to build their package. To see how this is useful, run"
+msgstr ""
+"Om u te helpen bij het effectief bouwen van het bronpakket, voorzien Debian-"
+"bronpakketten in het zogenaamde bouwvereistenmechanisme (build-dependencies "
+"mechanism). Dit betekent dat de onderhouder van het bronpakket een lijst "
+"bijhoudt van andere pakketten die vereist zijn voor het bouwen van hun "
+"pakket. Om het nut ervan te zien, gebruikt u het commando"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:418
+#, no-wrap
+msgid "apt-get build-dep foo"
+msgstr "apt-get build-dep foo"
+
+#. type: </example></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:427
+msgid "before building the source."
+msgstr "voor u het bronpakket bouwt."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:429
+msgid "How do I build binary packages from a source package?"
+msgstr "Hoe bouw ik binaire pakketten, vertrekkend van een bronpakket?"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:433
+msgid ""
+"The preferred way to do this is by using various wrapper tools. We'll show "
+"how it's done using the <tt>devscripts</tt> tools. Install this package if "
+"you haven't done so already."
+msgstr ""
+"De aangewezen manier om dit te doen is met behulp van verschillende "
+"verpakkingsgereedschappen. We tonen hoe dit gebeurt met de gereedschappen "
+"van <tt>devscripts</tt>. Installeer dit pakket als dat nog niet gebeurd is."
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:434
+msgid "Now, first get the source package:"
+msgstr "Haal eerst het bronpakket op:"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:438
+msgid "and change to the source tree:"
+msgstr "en ga naar de broncodeboom:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:433
+#, no-wrap
+msgid "cd foo-*"
+msgstr "cd foo-*"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:442
+msgid "Then install needed build-dependencies (if any):"
+msgstr "Installeer de bouwvereisten die (eventueel) nodig zijn:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:433
+#, no-wrap
+msgid "sudo apt-get build-dep foo"
+msgstr "sudo apt-get build-dep foo"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:447
+msgid ""
+"Then create a dedicated version of your own build (so that you won't get "
+"confused later when Debian itself releases a new version):"
+msgstr ""
+"CreÃ«er nadien een speciaal versienummer voor uw eigen bouw (zodat u later "
+"niet in verwarring raakt wanneer Debian zelf een nieuwe versie uitbrengt):"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:433
+#, no-wrap
+msgid "dch -l local 'Blah blah blah'"
+msgstr "dch -l local 'Bla bla bla'"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:451
+msgid "And finally build your package:"
+msgstr "En bouw tenslotte uw pakket:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:433
+#, no-wrap
+msgid "debuild -us -uc"
+msgstr "debuild -us -uc"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:456
+msgid ""
+"If everything worked out fine, you should now be able to install your "
+"package by running"
+msgstr ""
+"Indien alles correct verliep, zou u nu in staat moeten zijn uw pakket te "
+"installeren met het commando"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:433
+#, no-wrap
+msgid "sudo dpkg -i ../*.deb"
+msgstr "sudo dpkg -i ../*.deb"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:460
+msgid ""
+"If you prefer to do things manually, and don't want to use <tt>devscripts</"
+"tt>, follow this procedure:"
+msgstr ""
+"Indien u <tt>devscripts</tt> niet wilt gebruiken en verkiest om de zaken "
+"handmatig te doen, volg dan deze werkwijze:"
+
+#. type: <p></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:466
+msgid ""
+"You will need all of foo_*.dsc, foo_*.tar.gz and foo_*.diff.gz to compile "
+"the source (note: there is no .diff.gz for some packages that are native to "
+"Debian)."
+msgstr ""
+"U heeft alle bestanden nodig van het type foo_*.dsc, foo_*.tar.gz en foo_*."
+"diff.gz om het bronpakket te compileren (opmerking: voor sommige pakketten "
+"waarvan de originele broncode van Debian zelf afkomstig is, bestaat geen ."
+"diff.gz)"
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:468
+msgid ""
+"Once you have them (<ref id=\"sourcepkgs\">) and if you have the "
+"<package>dpkg-dev</package> package installed, the following command:"
+msgstr ""
+"Eens u deze verzameld heeft (<ref id=\"sourcepkgs\">) en als het pakket "
+"<package>dpkg-dev</package> op uw systeem geÃ¯nstalleerd is, dan zal het "
+"volgende commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:466
+#, no-wrap
+msgid "dpkg-source -x foo_version-revision.dsc"
+msgstr "dpkg-source -x foo_versie-revisie.dsc"
+
+#. type: </example></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:472
+msgid "will extract the package into a directory called <tt>foo-version</tt>."
+msgstr "het pakket uitpakken in een map met de naam <tt>foo-versie</tt>."
+
+#. type: <p><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:473
+msgid ""
+"If you just want to compile the package, you may cd into the <tt>foo-"
+"version</tt> directory and issue the command"
+msgstr ""
+"Indien u enkel het pakket wilt compileren, kunt met het commando cd naar de "
+"map <tt>foo-versie</tt> gaan en het volgende commando geven:"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:472
+#, no-wrap
+msgid "dpkg-buildpackage -rfakeroot -b"
+msgstr "dpkg-buildpackage -rfakeroot -b"
+
+#. type: </example><example>
+#: debian-faq.sgml:48 pkg_basics.sgml:476
+msgid ""
+"to build the package (note that this also requires the <package>fakeroot</"
+"package> package), and then"
+msgstr ""
+"om het pakket te bouwen (merk op dat daarvoor ook het pakket "
+"<package>fakeroot</package> nodig is) en daarna"
+
+#. type: <example></example>
+#: debian-faq.sgml:48 pkg_basics.sgml:472
+#, no-wrap
+msgid "dpkg -i ../foo_version-revision_arch.deb"
+msgstr "dpkg -i ../foo_versie-revisie_arch.deb"
+
+#. type: </example></p>
+#: debian-faq.sgml:48 pkg_basics.sgml:480
+msgid "to install the newly-built package(s)."
+msgstr "om de/het pas gebouwde pakket(ten) te installeren."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:48 pkg_basics.sgml:482
+msgid "How do I create Debian packages myself?"
+msgstr "Hoe kan ik zelf Debian-pakketten maken?"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:3
+msgid ""
+"For a more detailed description on this, read the New Maintainers' Guide, "
+"available in the <package>maint-guide</package> package or at <url id="
+"\"http://www.debian.org/doc/devel-manuals#maint-guide\">, or the Guide for "
+"Debian Maintainers, available in the <package>debmake-doc</package> package "
+"or at <url id=\"https://www.debian.org/doc/devel-manuals#debmake-doc\">."
+msgstr ""
+"Voor een meer gedetailleerde beschrijving hiervan moet u de Handleiding voor "
+"nieuwe onderhouders (New Maintainers' Guide) lezen, die u vindt in het "
+"pakket <package>maint-guide</package> of op <url id=\"http://www.debian.org/"
+"doc/devel-manuals#maint-guide\">, of de Gids voor onderhouders van Debian, "
+"die u vindt in het pakket <package>debmake-doc</package> of op <url id="
+"\"https://www.debian.org/doc/devel-manuals#debmake-doc\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:5
+msgid "The Debian package management tools"
+msgstr "De gereedschappen voor het pakketbeheer in Debian"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:8
+msgid "What programs does Debian provide for managing its packages?"
+msgstr ""
+"Welke programma's stelt Debian ter beschikking voor het beheren van zijn "
+"pakketten?"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:14
+msgid ""
+"There are multiple tools that are used to manage Debian packages, from "
+"graphic or text-based interfaces to the low level tools used to install "
+"packages. All the available tools rely on the lower level tools to properly "
+"work and are presented here in decreasing complexity level."
+msgstr ""
+"Er bestaan verschillende gereedschappen die gebruikt worden voor het beheer "
+"van Debian-pakketten, gaande van grafische of tekstgebaseerde interfaces tot "
+"eenvoudig basisgereedschap voor het installeren van pakketten. Alle "
+"beschikbaar gereedschappen steunen op de basisgereedschappen om correct te "
+"functioneren en worden hier voorgesteld volgens aflopend complexiteitsniveau."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:19
+msgid ""
+"It is important to understand that the higher level package management tools "
+"such as <prgn>aptitude</prgn> or <prgn>synaptic</prgn> rely on <prgn>apt</"
+"prgn> which, itself, relies on <prgn>dpkg</prgn> to manage the packages in "
+"the system."
+msgstr ""
+"Het is belangrijk te weten dat de hogere gereedschappen voor pakketbeheer, "
+"zoals <prgn>aptitude</prgn> en <prgn>synaptic</prgn>, voor het beheren van "
+"de pakketten op het systeem steunen op <prgn>apt</prgn> dat zelf steunt op "
+"<prgn>dpkg</prgn>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:30
+msgid ""
+"See <url id=\"http://www.debian.org/doc/manuals/debian-reference/ch02.en.html"
+"\" name=\"Chapter 2. Debian package management\"> of the <url id=\"http://"
+"www.debian.org/doc/manuals/debian-reference/\" name=\"Debian reference\"> "
+"for more information about the Debian package management utilities. This "
+"document is available in various languages and formats, see <url id=\"http://"
+"www.debian.org/doc/user-manuals#quick-reference\" name=\"the Debian "
+"Reference entry in the DDP Users' Manuals overview\">."
+msgstr ""
+"Zie <url id=\"http://www.debian.org/doc/manuals/debian-reference/ch02.en.html"
+"\" name=\"Hoofdstuk 2. Pakketbeheer in Debian\"> van het <url id=\"http://"
+"www.debian.org/doc/manuals/debian-reference/\" name=\"Referentiehandboek van "
+"Debian\"> voor meer informatie over de hulpprogramma's voor pakketbeheer van "
+"Debian. Dit document is beschikbaar in verschillende talen en formaten, "
+"zie<url id=\"http://www.debian.org/doc/user-manuals#quick-reference\" name="
+"\"het item over het Referentiehandboek van Debian in de overzichtspagina van "
+"gebruikershandleidingen van het Documentatieproject van Debian\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:32
+msgid "dpkg"
+msgstr "dpkg"
+
+#. type: <p><list>
+#: debian-faq.sgml:49 pkgtools.sgml:34
+msgid ""
+"This is the main package management program. <prgn>dpkg</prgn> can be "
+"invoked with many options. Some common uses are:"
+msgstr ""
+"Dit is het belangrijkste programma voor pakketbeheer. <prgn>dpkg</prgn> kan "
+"met verschillende opties uitgevoerd worden. Enkele vaak voorkomende "
+"toepassingen zijn:"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:35
+msgid "Find out all the options: <tt>dpkg --help</tt>."
+msgstr "Een overzicht vragen van alle opties: <tt>dpkg --help</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:37
+msgid ""
+"Print out the control file (and other information) for a specified package: "
+"<tt>dpkg --info foo_VVV-RRR.deb</tt>."
+msgstr ""
+"Het control-bestand (en andere informatie) afdrukken van een opgegeven "
+"pakket: <tt>dpkg --info foo_VVV-RRR.deb</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:39
+msgid ""
+"Install a package (including unpacking and configuring) onto the file system "
+"of the hard disk: <tt>dpkg --install foo_VVV-RRR.deb</tt>."
+msgstr ""
+"Een pakket installeren (met inbegrip van uitpakken en configureren) op het "
+"bestandssysteem van de harde schijf: <tt>dpkg --install foo_VVV-RRR.deb</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:46
+msgid ""
+"Unpack (but do not configure) a Debian archive into the file system of the "
+"hard disk: <tt>dpkg --unpack foo_VVV-RRR.deb</tt>. Note that this operation "
+"does <em>not</em> necessarily leave the package in a usable state; some "
+"files may need further customization to run properly. This command removes "
+"any already-installed version of the program and runs the preinst (see <ref "
+"id=\"maintscripts\">) script associated with the package."
+msgstr ""
+"Een Debian-archief uitpakken (maar niet configureren) op het bestandssysteem "
+"van de harde schijf: <tt>dpkg --unpack foo_VVV-RRR.deb</tt>. Merk op dat "
+"deze bewerking het pakket <em>niet</em> noodzakelijk in een bruikbare "
+"toestand achterlaat. Mogelijk moeten sommige bestanden verder aangepast "
+"worden om behoorlijk te functioneren. Dit commando verwijdert een eventueel "
+"reeds geÃ¯nstalleerde versie van het programma en voert het preinst-script "
+"(zie <ref id=\"maintscripts\">) uit dat bij het pakket hoort."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:53
+msgid ""
+"Configure a package that already has been unpacked: <tt>dpkg --configure "
+"foo</tt>. Among other things, this action runs the postinst (see <ref id="
+"\"maintscripts\">) script associated with the package. It also updates the "
+"files listed in the <tt>conffiles</tt> for this package. Notice that the "
+"'configure' operation takes as its argument a package name (e.g., foo), "
+"<em>not</em> the name of a Debian archive file (e.g., foo_VVV-RRR.deb)."
+msgstr ""
+"Een pakket dat reeds uitgepakt werd, configureren: <tt>dpkg --configure foo</"
+"tt>. Naast andere bewerkingen voert deze actie het postinst-script (zie <ref "
+"id=\"maintscripts\">) uit dat bij het pakket hoort. Ze werkt ook de "
+"bestanden bij die vermeld worden in het bestand <tt>conffiles</tt> dat bij "
+"het pakket hoort. Merk op dat de bewerking 'configure' als argument de naam "
+"van een pakket (bijv. foo) nodig heeft en <em>niet</em> de naam van een "
+"archiefbestand van Debian (bijv. foo_VVV-RRR.deb)."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:56
+msgid ""
+"Extract a single file named \"blurf\" (or a group of files named \"blurf*\") "
+"from a Debian archive: <tt>dpkg --fsys-tarfile foo_VVV-RRR.deb | tar -xf - "
+"'blurf*'</tt>."
+msgstr ""
+"Een enkel bestand met de naam \"blurf\" (of een groep bestanden met de naam "
+"\"blurf*\") extraheren uit een Debian-archief: <tt>dpkg --fsys-tarfile "
+"foo_VVV-RRR.deb | tar -xf - 'blurf*'</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:58
+msgid ""
+"Remove a package (but not its configuration files): <tt>dpkg --remove foo</"
+"tt>."
+msgstr ""
+"Een pakket verwijderen (maar niet zijn configuratiebestanden): <tt>dpkg --"
+"remove foo</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:60
+msgid ""
+"Remove a package (including its configuration files): <tt>dpkg --purge foo</"
+"tt>."
+msgstr ""
+"Een pakket verwijderen (met inbegrip van zijn configuratiebestanden): "
+"<tt>dpkg --purge foo</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:63
+msgid ""
+"List the installation status of packages containing the string (or regular "
+"expression) \"foo*\": <tt>dpkg --list 'foo*'</tt>."
+msgstr ""
+"De installatietoestand weergeven van pakketten die de tekenreeks (of de "
+"reguliere expressie) \"foo*\" bevatten: <tt>dpkg --list 'foo*'</tt>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:67
+msgid "APT"
+msgstr "APT"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:75
+msgid ""
+"APT is the <em>Advanced Package Tool</em>, an advanced interface to the "
+"Debian packaging system which provides the <prgn>apt-get</prgn> program. It "
+"provides commandline tools for searching and managing packages, and for "
+"querying information about them, as well as low-level access to all features "
+"of the libapt-pkg library. For more information, see the User's Guide in "
+"<tt>/usr/share/doc/apt-doc/guide.html/index.html</tt> (you will have to "
+"install the <package>apt-doc</package> package)."
+msgstr ""
+"APT is het <em>Advanced Package Tool</em> (geavanceerd pakketgereedschap), "
+"een geavanceerde interface met het pakketsysteem van Debian, die voorziet in "
+"het programma <prgn>apt-get</prgn>. Het biedt hulpmiddelen voor de "
+"commandoregel die dienen voor het opzoeken en beheren van pakketten en voor "
+"het opzoeken van informatie over hen, evenals basistoegang tot alle "
+"functionaliteit van de bibliotheek libapt-pkg. Raadpleeg voor bijkomende "
+"informatie de gebruikershandleiding in <tt>/usr/share/doc/apt-doc/guide.html/"
+"index.html</tt> (daarvoor moet u het pakket <package>apt-doc</package> "
+"installeren)."
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:84
+msgid ""
+"Starting with Debian Jessie, some frequently used <prgn>apt-get</prgn> and "
+"<prgn>apt-cache</prgn> commands have an equivalent via the new <prgn>apt</"
+"prgn> binary. This means some popular commands like <prgn>apt-get update</"
+"prgn>, <prgn>apt-get install</prgn>, <prgn>apt-get remove</prgn>, <prgn>apt-"
+"cache search</prgn>, or <prgn>apt-cache show</prgn> now can also be called "
+"simply via <prgn>apt</prgn>, say <prgn>apt update</prgn>, <prgn>apt install</"
+"prgn>, <prgn>apt remove</prgn>, <prgn>apt search</prgn>, or <prgn>apt show</"
+"prgn>. The following is an overview of the old and new commands:"
+msgstr ""
+"Sinds Debian Jessie kregen sommige vaak gebruikte <prgn>apt-get</prgn>- en "
+"<prgn>apt-cache</prgn>-commando's een equivalent via het nieuwe programma "
+"<prgn>apt</prgn>. Dit houdt in dat sommige populaire commando's zoals "
+"<prgn>apt-get update</prgn>, <prgn>apt-get install</prgn>, <prgn>apt-get "
+"remove</prgn>, <prgn>apt-cache search</prgn> en <prgn>apt-cache show</prgn> "
+"nu ook gewoon via apt gebruikt kunnen worden, zoals <prgn>apt update</prgn>, "
+"<prgn>apt install</prgn>, <prgn>apt remove</prgn>, <prgn>apt search</prgn>, "
+"en <prgn>apt show</prgn>. Hierna volgt een overzicht van de oude en de "
+"nieuwe commando's:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:95
+#, no-wrap
+msgid ""
+" apt-get update             ->  apt update\n"
+" apt-get upgrade            ->  apt upgrade\n"
+" apt-get dist-upgrade       ->  apt full-upgrade\n"
+" apt-get install package    ->  apt install package\n"
+" apt-get remove package     ->  apt remove package\n"
+" apt-get autoremove         ->  apt autoremove\n"
+" apt-cache search string    ->  apt search string\n"
+" apt-cache policy package   ->  apt list -a package\n"
+" apt-cache show package     ->  apt show package\n"
+" apt-cache showpkg package  ->  apt show -a package"
+msgstr ""
+" apt-get update             ->  apt update\n"
+" apt-get upgrade            ->  apt upgrade\n"
+" apt-get dist-upgrade       ->  apt full-upgrade\n"
+" apt-get install pakket     ->  apt install pakket\n"
+" apt-get remove pakket      ->  apt remove pakket\n"
+" apt-get autoremove         ->  apt autoremove\n"
+" apt-cache search tekst     ->  apt search tekst\n"
+" apt-cache policy pakket    ->  apt list -a pakket\n"
+" apt-cache show pakket      ->  apt show pakket\n"
+" apt-cache showpkg pakket   ->  apt show -a pakket"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:102
+msgid ""
+"The <prgn>apt</prgn> tool merges functionality of apt-get and apt-cache and "
+"by default has a fancier colored output format, making it more pleasant for "
+"humans. For usage in scripts or advanced use cases, apt-get is still "
+"preferable or needed."
+msgstr ""
+"Het hulpprogramma <prgn>apt</prgn> voegt functionaliteit van apt-get en apt-"
+"cache samen en heeft standaard een leukere en gekleurde uitvoer, wat het "
+"voor mensen aangenamer maakt. Voor het gebruik in scripts en voor meer "
+"gevorderde toepassingen is apt-get nog steeds te verkiezen of vereist."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:115
+msgid ""
+"<prgn>apt-get</prgn> provides a simple way to retrieve and install packages "
+"from multiple sources using the command line. Unlike <prgn>dpkg</prgn>, "
+"<prgn>apt-get</prgn> does not understand .deb files, it works with the "
+"packages proper name and can only install .deb archives from a source "
+"specified in <file>/etc/apt/sources.list</file>. <prgn>apt-get</prgn> will "
+"call <prgn>dpkg</prgn> directly after downloading the .deb "
+"archives<footnote><p>Notice that there are ports that make this tool "
+"available with other package management systems, like Red Hat package "
+"manager, also known as <prgn>rpm</prgn></p></footnote> from the configured "
+"sources."
+msgstr ""
+"<prgn>apt-get</prgn> biedt een eenvoudige manier om aan de commandoregel "
+"pakketten uit verschillende pakketbronnen op te halen en te installeren. "
+"Anders dan <prgn>dpkg</prgn> heeft <prgn>apt-get</prgn> geen kennis over ."
+"deb-bestanden. Het werkt met de echte namen van de pakketten en kan enkel ."
+"deb-archieven installeren uit een pakketbron die in <file>/etc/apt/sources."
+"list</file> vermeld staat. <prgn>apt-get</prgn> zal <prgn>dpkg</prgn> "
+"aanroepen onmiddellijk na het downloaden van de .deb-"
+"archieven<footnote><p>Merk op dat er bepaalde uitgaven (ports) zijn die dit "
+"gereedschap ook ter beschikking stellen bij andere pakketbeheersystemen, "
+"zoals het pakketbeheersysteem van Red Hat, ook gekend als <prgn>rpm</prgn></"
+"p></footnote> uit de geconfigureerde pakketbronnen."
+
+#. type: <p><list>
+#: debian-faq.sgml:49 pkgtools.sgml:117
+msgid "Some common ways to use <prgn>apt-get</prgn> are:"
+msgstr "Enkele veel voorkomende toepassingen van <prgn>apt-get</prgn> zijn:"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:118
+msgid "To update the list of packages known by your system, you can run:"
+msgstr ""
+"Om de lijst van de door uw systeem gekende pakketten bij te werken, gebruikt "
+"u het commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:118
+#, no-wrap
+msgid "apt update"
+msgstr "apt update"
+
+#. type: </example></p>
+#: debian-faq.sgml:49 pkgtools.sgml:121
+msgid "(you should execute this regularly to update your package lists)"
+msgstr "(u moet dit regelmatig gebruiken om uw pakketlijsten bij te werken)"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:122
+msgid "To install the <var>foo</var> package and all its dependencies, run:"
+msgstr ""
+"Om het pakket <var>foo</var> en al zijn vereisten te installeren, gebruikt u "
+"het commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:118
+#, no-wrap
+msgid "apt install foo"
+msgstr "apt install foo"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:125
+msgid "To remove the foo package from your system, run:"
+msgstr ""
+"Om het pakket foo van uw systeem te verwijderen, gebruikt u het commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:118
+#, no-wrap
+msgid "apt remove foo"
+msgstr "apt remove foo"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:129
+msgid ""
+"To remove the foo package and its configuration files from your system, run:"
+msgstr ""
+"Om het pakket foor en de configuratiebestanden ervan van uw systeem te "
+"verwijderen, gebruikt u het commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:118
+#, no-wrap
+msgid "apt purge foo"
+msgstr "apt purge foo"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:133
+msgid "To list all packages for which newer versions are available, run:"
+msgstr ""
+"Om alle pakketten te toen waarvoor een nieuwere versie beschikbaar is, "
+"gebruikt u het comando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:118
+#, no-wrap
+msgid "apt list --upgradable"
+msgstr "apt list --upgradable"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:137
+msgid ""
+"To upgrade all the packages on your system (without installing extra "
+"packages or removing packages), run:"
+msgstr ""
+"Om alle pakketten op uw systeem op te waarderen (zonder extra pakketten te "
+"installeren of pakketten te verwijderen), gebruikt u het commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:118
+#, no-wrap
+msgid "apt upgrade"
+msgstr "apt upgrade"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:141
+msgid ""
+"To upgrade all the packages on your system, and, if needed for a package "
+"upgrade, installing extra packages or removing packages, run:"
+msgstr ""
+"Om alle pakketten op uw systeem op te waarderen en, als dat nodig is voor "
+"het opwaarderen van een pakket, extra pakketten te installeren of pakketten "
+"te verwijderen, gebruikt u het commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:118
+#, no-wrap
+msgid "apt full-upgrade"
+msgstr "apt full-upgrade"
+
+#. type: </example></p>
+#: debian-faq.sgml:49 pkgtools.sgml:148
+msgid ""
+"(The command <tt>upgrade</tt> keeps a package at its installed obsolete "
+"version if upgrading would need an extra package to be installed, for a new "
+"dependency to be satisfied. The <tt>full-upgrade</tt> command is less "
+"conservative.)"
+msgstr ""
+"(Het commando <tt>upgrade</tt> behoudt een pakket op zijn geÃ¯nstalleerde "
+"verouderde versie als voor de opwaardering ervan de installatie van een "
+"bijkomend pakket nodig is om op die manier te voldoen aan een nieuwe "
+"vereiste. Het commando <tt>full-upgrade</tt> is minder conservatief.)"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:153
+msgid ""
+"Note that you must be logged in as root to perform any commands that modify "
+"packages."
+msgstr ""
+"Merk op dat u als root (systeembeheerder) aangemeld dient te zijn om elk "
+"commando uit te voeren dat pakketten wijzigt."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:157
+msgid ""
+"Note that <prgn>apt-get</prgn> now also installs recommended packages as "
+"default, and thanks to its robustness it's the preferred program for package "
+"management from console to perform system installation and major system "
+"upgrades."
+msgstr ""
+"Merk op dat <prgn>apt-get</prgn> nu ook standaard aanbevolen pakketten "
+"installeert. Omwille van zijn robuustheid is het ook het aanbevolen "
+"programma voor pakketbeheer aan de console bij het uitvoeren van de "
+"installatie van een systeem en van belangrijke opwaarderingen van het "
+"systeem."
+
+#. type: <p><list>
+#: debian-faq.sgml:49 pkgtools.sgml:163
+msgid ""
+"The apt tool suite also includes the <prgn>apt-cache</prgn> tool to query "
+"the package lists. You can use it to find packages providing specific "
+"functionality through simple text or regular expression queries and through "
+"queries of dependencies in the package management system. Some common ways "
+"to use <prgn>apt-cache</prgn> are:"
+msgstr ""
+"De gereedschapssuite apt bevat ook het hulpprogramma <prgn>apt-cache</prgn> "
+"voor het doorzoeken van de pakketlijsten. U kunt het gebruiken om pakketten "
+"te zoeken die een specifieke functionaliteit bieden via een eenvoudige "
+"zoekopdracht met tekst of een reguliere expressie en via het doorzoeken van "
+"vereisten in het pakketbeheersysteem. Enkele gebruikelijke toepassingen van "
+"<prgn>apt-cache</prgn> zijn:"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:164
+msgid "To find packages whose description contain <var>word</var>:"
+msgstr "Alle pakketten vinden waarvan de beschrijving <var>woord</var> bevat:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:164
+#, no-wrap
+msgid "apt search <var>word</var>"
+msgstr "apt search <var>woord</var>"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:167
+msgid "To print the detailed information of a package:"
+msgstr "Gedetailleerde informatie over een pakket weergeven:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:164
+#, no-wrap
+msgid "apt show <var>package</var>"
+msgstr "apt show <var>pakket</var>"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:170
+msgid "To print the packages a given package depends on:"
+msgstr "Weergeven welke pakketten een bepaald pakket vereist:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:164
+#, no-wrap
+msgid "apt-cache depends <var>package</var>"
+msgstr "apt-cache depends <var>pakket</var>"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:175
+msgid ""
+"To print detailed information on the versions available for a package and "
+"the packages that reverse-depends on it:"
+msgstr ""
+"Gedetailleerde informatie weergeven over de beschikbare versies van een "
+"pakket en over de pakketten die het als vereiste hebben (reverse-dependency)"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:164
+#, no-wrap
+msgid "apt-cache showpkg <var>package</var>"
+msgstr "apt-cache showpkg <var>pakket</var>"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:187
+msgid ""
+"For more information, install the <package>apt</package> package and read "
+"<manref name=\"apt\" section=\"8\">, <manref name=\"apt-get\" section="
+"\"8\">, <manref name=\"sources.list\" section=\"5\"> and install the "
+"<package>apt-doc</package> package and read <file>/usr/share/doc/apt-doc/"
+"guide.html/index.html</file>."
+msgstr ""
+"Installeer het pakket <package>apt</package> voor bijkomende informatie en "
+"lees <manref name=\"apt\" section=\"8\">, <manref name=\"apt-get\" section="
+"\"8\">, <manref name=\"sources.list\" section=\"5\"> en installeer ook het "
+"pakket <package>apt-doc</package> en lees <file>/usr/share/doc/apt-doc/guide."
+"html/index.html</file>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:189 debian-faq.sgml:50 uptodate.sgml:36
+msgid "aptitude"
+msgstr "aptitude"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:195
+msgid ""
+"<prgn>aptitude</prgn> is a package manager for &debian; systems that "
+"provides a frontend to the apt package management infrastructure. "
+"<prgn>aptitude</prgn> is a text-based interface using the curses library. "
+"Actions may be performed from a visual interface or from the command-line."
+msgstr ""
+"<prgn>aptitude</prgn> is een pakketbeheerprogramma voor &debian;-systemen "
+"dat een frontend biedt voor de pakketbeheerinfrastructuur van apt. "
+"<prgn>aptitude</prgn> is een op tekst gebaseerde interface die gebruik maakt "
+"van de curses-bibliotheek. Acties kunnen uitgevoerd worden in de visuele "
+"interface of aan de commandoregel."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:200
+msgid ""
+"<prgn>aptitude</prgn> can be used to perform management tasks in a fast and "
+"easy way. It allows the user to view the list of packages and to perform "
+"package management tasks such as installing, upgrading, and removing "
+"packages."
+msgstr ""
+"<prgn>aptitude</prgn> kan gebruikt worden om beheertaken op een snelle en "
+"gemakkelijke manier uit te voeren. Het laat de gebruiker toe de pakketlijst "
+"te bekijken en pakketbeheertaken, zoals het installeren, opwaarderen en "
+"verwijderen van pakketten, uit te voeren."
+
+#. type: <p><list>
+#: debian-faq.sgml:49 pkgtools.sgml:203
+msgid ""
+"<prgn>aptitude</prgn> provides the functionality of <prgn>apt-get</prgn>, as "
+"well as many additional features:"
+msgstr ""
+"<prgn>aptitude</prgn> biedt de functionaliteit van <prgn>apt-get</prgn> en "
+"heeft veel bijkomende functies:"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:205
+msgid "<prgn>aptitude</prgn> offers easy access to all versions of a package."
+msgstr ""
+"<prgn>aptitude</prgn> biedt een gemakkelijke toegang tot alle versies van "
+"een pakket."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:209
+msgid ""
+"<prgn>aptitude</prgn> makes it easy to keep track of obsolete software by "
+"listing it under \"Obsolete and Locally Created Packages\"."
+msgstr ""
+"<prgn>aptitude</prgn> maakt het gemakkelijk om bij te houden welke software "
+"verouderd is door deze te vermelden onder \"Verouderde en lokaal aangemaakte "
+"pakketten\"."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:214
+msgid ""
+"<prgn>aptitude</prgn> includes a fairly powerful system for searching "
+"particular packages and limiting the package display. Users familiar with "
+"<prgn>mutt</prgn> will pick up quickly, as <prgn>mutt</prgn> was the "
+"inspiration for the expression syntax."
+msgstr ""
+"<prgn>aptitude</prgn> bevat een behoorlijk krachtig systeem voor het zoeken "
+"van een specifiek pakket en voor het instellen van beperkingen voor de "
+"weergave van pakketten. Gebruikers die met <prgn>mutt</prgn> vertrouwd zijn, "
+"zullen dit snel oppikken, vermits <prgn>mutt</prgn> de inspiratiebron vormde "
+"voor de gebruikte expressie-syntaxis."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:217
+msgid ""
+"<prgn>aptitude</prgn> can be used to install the predefined tasks available. "
+"For more information see <ref id=\"tasksel\">."
+msgstr ""
+"<prgn>aptitude</prgn> kan gebruikt worden voor het installeren van de "
+"beschikbare voorgedefinieerde taken. Zie voor meer informatie <ref id="
+"\"tasksel\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:223
+msgid ""
+"<prgn>aptitude</prgn> in full screen mode has <prgn>su</prgn> functionality "
+"embedded and can be run by a normal user. It will call <prgn>su</prgn> (and "
+"ask for the root password, if any) when you really need administrative "
+"privileges."
+msgstr ""
+"In de modus 'volledig scherm' beschikt <prgn>aptitude</prgn> over ingebouwde "
+"<prgn>su</prgn>-functionaliteit en kan het uitgevoerd worden door een gewone "
+"gebruiker. Het zal <prgn>su</prgn> aanroepen (en desgevallend om het "
+"wachtwoord van root vragen) indien u echt systeembeheerrechten nodig heeft."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:231
+msgid ""
+"You can use <prgn>aptitude</prgn> through a visual interface (simply run "
+"<tt>aptitude</tt>) or directly from the command line. The command line "
+"syntax used is very similar to the one used in <prgn>apt-get</prgn>. For "
+"example, to install the <var>foo</var> package, you can run <tt>aptitude "
+"install <var>foo</var></tt>."
+msgstr ""
+"U kunt <prgn>aptitude</prgn> via een visuele interface gebruiken (geef "
+"gewoon de opdtacht <tt>aptitude</tt>) of rechtstreeks aan de commandoregel. "
+"De gebruikte syntaxis aan de commandoregel is erg gelijkaardig aan die voor "
+"<prgn>apt-get</prgn>. Bijvoorbeeld, om het pakket <var>foo</var> te "
+"installeren kunt u de opdracht <tt>aptitude install <var>foo</var></tt> "
+"gebruiken."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:234
+msgid ""
+"Note that <prgn>aptitude</prgn> is the preferred program for daily package "
+"management from the console."
+msgstr ""
+"Meer op dat <prgn>aptitude</prgn> het programma is dat u bij voorkeur "
+"gebruikt voor het dagelijkse pakketbeheer aan de console."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:238
+msgid ""
+"For more information, read the manual page <manref name=\"aptitude\" section="
+"\"8\"> and install the <package>aptitude-doc</package> package."
+msgstr ""
+"Voor bijkomende informatie kunt u de man-pagina <manref name=\"aptitude\" "
+"section=\"8\"> lezen en het pakket <package>aptitude-doc</package> "
+"installeren."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:240
+msgid "synaptic"
+msgstr "synaptic"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:253
+msgid ""
+"<prgn>synaptic</prgn> is a graphical package manager. It enables you to "
+"install, upgrade and remove software packages in a user friendly way. Along "
+"with most of the features offered by aptitude, it also has a feature for "
+"editing the list of used repositories, and supports browsing all available "
+"documentation related to a package. See the <url id=\"http://www.nongnu.org/"
+"synaptic/\" name=\"Synaptic Website\"> for more information."
+msgstr ""
+"<prgn>synaptic</prgn> is een grafische pakketbeheerder. Het laat u toe "
+"softwarepakketten te installeren, op te waarderen en te verwijderen op een "
+"gebruikersvriendelijke manier. Naast de meeste functies die ook door "
+"aptitude geboden worden, biedt het ook een functie voor het bewerken van de "
+"lijst van gebruikte pakketbronnen en ondersteunt het het doorbladeren van "
+"alle beschikbare informatie over een pakket. Zie de <url id=\"http://www."
+"nongnu.org/synaptic/\" name=\"Website van Synaptic\"> voor bijkomende "
+"informatie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:255
+msgid "tasksel"
+msgstr "tasksel"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:262
+msgid ""
+"When you want to perform a specific task it might be difficult to find the "
+"appropiate suite of packages that fill your need. The Debian developers have "
+"defined <tt>tasks</tt>, a task is a collection of several individual Debian "
+"packages all related to a specific activity. Tasks can be installed through "
+"the <prgn>tasksel</prgn> program or through <prgn>aptitude</prgn>."
+msgstr ""
+"Indien u een specifieke taak wenst uit te voeren, kan het moeilijk zijn om "
+"het passende geheel van pakketten te vinden dat aan uw behoeften "
+"beantwoordt. De ontwikkelaars van Debian hebben daarom <tt>tasks</tt> "
+"(taken) gedefinieerd. Een 'task' is een verzameling van verschillende "
+"individuele Debian-pakketten die alle verband houden met een specifieke "
+"activiteit. Het installeren van 'tasks' kan uitgevoerd worden met het "
+"programma <prgn>tasksel</prgn> of met <prgn>aptitude</prgn>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:272
+msgid ""
+"Typically, the Debian installer will automatically install the task "
+"associated with a standard system and a desktop environment. The specific "
+"desktop environment installed will depend on the CD/DVD media used, most "
+"commonly it will be the GNOME desktop (<tt>gnome-desktop</tt> task). Also, "
+"depending on your selections throughout the installation process, tasks "
+"might be automatically installed in your system. For example, if you "
+"selected a language other than English, the task associated with it will be "
+"installed automatically too and if the installer recognises you are "
+"installing on a laptop system the <tt>laptop</tt> task will also be "
+"installed."
+msgstr ""
+"Gewoonlijk zal het installatiesysteem van Debian automatisch de taak "
+"installeren voor een standaardsysteem en een desktopomgeving. Welke "
+"specifieke desktopomgeving geÃ¯nstalleerd wordt, hangt af van de gebruikte CD/"
+"DVD-media. Het meest gebruikelijk is de desktop van GNOME (taak <tt>gnome-"
+"desktop</tt>). Ook kunnen er op basis van uw keuzes tijdens het "
+"installatieproces nog andere taken automatisch geÃ¯nstalleerd worden op uw "
+"systeem. Bijvoorbeeld, indien u een andere taal dan het Engels selecteerde, "
+"zal ook de ermee verband houdende taak automatisch geÃ¯nstalleerd worden, en "
+"als het installatieproces kon vaststellen dat u de installatie uitvoert op "
+"een laptop, zal ook de taak <tt>laptop</tt> geÃ¯nstalleerd worden."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:274
+msgid "Other package management tools"
+msgstr "Andere gereedschappen voor pakketbeheer"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:276
+msgid "dpkg-deb"
+msgstr "dpkg-deb"
+
+#. type: <p><list>
+#: debian-faq.sgml:49 pkgtools.sgml:278
+msgid ""
+"This program manipulates Debian archive (<tt>.deb</tt>) files. Some common "
+"uses are:"
+msgstr ""
+"Dit programma voert bewerkingen uit op Debian-archiefbestanden (<tt>.deb</"
+"tt>). Enkele courante toepassingen zijn:"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:279
+msgid "Find out all the options: <tt>dpkg-deb --help</tt>."
+msgstr "Alle mogelijke opties opvragen: <tt>dpkg-deb --help</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:281
+msgid ""
+"Determine what files are contained in a Debian archive file: <tt>dpkg-deb --"
+"contents foo_VVV-RRR.deb</tt>)"
+msgstr ""
+"Vaststellen welke bestanden een Debian-archiefbestand bevat: <tt>dpkg-deb --"
+"contents foo_VVV-RRR.deb</tt>)"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:287
+msgid ""
+"Extract the files contained in a named Debian archive into a user specified "
+"directory: <tt>dpkg-deb --extract foo_VVV-RRR.deb tmp</tt> extracts each of "
+"the files in <tt>foo_VVV-RRR.deb</tt> into the directory <tt>tmp/</tt>. This "
+"is convenient for examining the contents of a package in a localized "
+"directory, without installing the package into the root file system."
+msgstr ""
+"De bestanden uit een opgegeven Debian-archief uitpakken naar een door de "
+"gebruiker opgegeven map: <tt>dpkg-deb --extract foo_VVV-RRR.deb tmp</tt>. "
+"Dit commando extraheert alle bestanden uit <tt>foo_VVV-RRR.deb</tt> en "
+"plaatst ze in de map <tt>tmp/</tt>. Dit is een handige manier om de inhoud "
+"van een pakket te onderzoeken in een welbepaalde map, zonder het pakket te "
+"installeren op het basisbestandssysteem."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:290
+msgid ""
+"Extract the control information files from a package: <tt>dpkg-deb --control "
+"foo_VVV-RRR.deb tmp</tt>."
+msgstr ""
+"De bestanden met controle-informatie extraheren uit een pakket: <tt>dpkg-deb "
+"--control foo_VVV-RRR.deb tmp</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:296
+msgid ""
+"Note that any packages that were merely unpacked using <tt>dpkg-deb --"
+"extract</tt> will be incorrectly installed, you should use <tt>dpkg --"
+"install</tt> instead."
+msgstr ""
+"Merk op dat pakketten die louter met <tt>dpkg-deb --extract</tt> uitgepakt "
+"werden, niet correct geÃ¯nstalleerd zullen zijn. U moet in de plaats daarvan "
+"<tt>dpkg --install</tt> gebruiken."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:299
+msgid ""
+"More information is given in the manual page <manref name=\"dpkg-deb\" "
+"section=\"1\">."
+msgstr ""
+"Meer informatie wordt verstrekt in de man-pagina <manref name=\"dpkg-deb\" "
+"section=\"1\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:304
+msgid ""
+"Debian claims to be able to update a running program; how is this "
+"accomplished?"
+msgstr ""
+"Debian beweert in staat te zijn een actief programma te kunnen opwaarderen. "
+"Hoe wordt dit gerealiseerd?"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:307
+msgid ""
+"The kernel (file system) in &debian; systems supports replacing files even "
+"while they're being used."
+msgstr ""
+"De kernel (het bestandssysteem) van &debian;-systemen ondersteunt het "
+"vervangen van bestanden, zelfs als ze in gebruik zijn."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:313
+msgid ""
+"We also provide a program called <prgn>start-stop-daemon</prgn> which is "
+"used to start daemons at boot time or to stop daemons when the runlevel is "
+"changed (e.g., from multi-user to single-user or to halt). The same program "
+"is used by installation scripts when a new package containing a daemon is "
+"installed, to stop running daemons, and restart them as necessary."
+msgstr ""
+"We voorzien ook in een programma dat <prgn>start-stop-daemon</prgn> heet en "
+"dat gebruikt wordt om 'daemons' op te starten bij het opstarten van de "
+"computer of ze te stoppen als het 'runlevel' verandert (als bijvoorbeeld "
+"overgeschakeld wordt van meerdere-gebruikersmodus naar Ã©Ã©n-gebruikersmodus "
+"of naar halt). Hetzelfde programma wordt gebruikt door installatiescripts "
+"wanneer een nieuw pakket met een daemon geÃ¯nstalleerd wordt en dit om "
+"actieve daemons te stoppen en ze nadien, indien nodig, te herstarten."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:316
+msgid "How can I tell what packages are already installed on a Debian system?"
+msgstr ""
+"Hoe kan ik weten welke pakketten reeds geÃ¯nstalleerd zijn op deen Debian-"
+"systeem?"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:317
+msgid ""
+"To learn the status of all the packages installed on a Debian system, "
+"execute the command"
+msgstr ""
+"Om de toestand te kennen van alle pakketten die op een Debian-systeem "
+"geÃ¯nstalleerd zijn, moet u het volgende commando uitvoeren:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:316
+#, no-wrap
+msgid "dpkg --list"
+msgstr "dpkg --list"
+
+#. type: </example></p>
+#: debian-faq.sgml:49 pkgtools.sgml:324
+msgid ""
+"This prints out a one-line summary for each package, giving a 2-letter "
+"status symbol (explained in the header), the package name, the version which "
+"is <em>installed</em>, and a brief description."
+msgstr ""
+"Dit produceert een samenvatting van Ã©Ã©n regel per pakket met een uit twee "
+"letters bestaand symbool dat de toestand weergeeft (toegelicht in de "
+"kopregel), de naam van het pakket, de <em>geÃ¯nstalleerde</em> versie en een "
+"korte beschrijving."
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:325
+msgid ""
+"To learn the status of packages whose names match any pattern beginning with "
+"\"foo\", run the command:"
+msgstr ""
+"Om de toestand te kennen van pakketten waarvan het begin van de naam bestaat "
+"uit \"foor\", gebruikt u het commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:324
+#, no-wrap
+msgid "dpkg --list 'foo*'"
+msgstr "dpkg --list 'foo*'"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:329
+msgid ""
+"To get a more verbose report for a particular package, execute the command:"
+msgstr ""
+"Om over een specifiek pakket een meer uitgebreid rapport op te vragen, geeft "
+"u de opdracht:"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:328
+#, no-wrap
+msgid "dpkg --status packagename"
+msgstr "dpkg --status pakketnaam"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:334
+msgid "How do I display the files of an installed package?"
+msgstr "Hoe geef ik de bestanden weer van een geÃ¯nstalleerd pakket?"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:335
+msgid ""
+"To list all the files provided by the installed package <tt>foo</tt> execute "
+"the command"
+msgstr ""
+"Om alle bestanden weer te geven waarin door het geÃ¯nstalleerde pakket "
+"<tt>foo</tt>, gebruikt u het commando"
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:334
+#, no-wrap
+msgid "dpkg --listfiles foo"
+msgstr "dpkg --listfiles foo"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:340
+msgid ""
+"Note that the files created by the installation scripts aren't displayed."
+msgstr ""
+"Merk op dat de bestanden die aangemaakt worden door de installatiescripts "
+"niet weergegeven worden."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:343
+msgid "How can I find out what package produced a particular file?"
+msgstr "Hoe kan ik te weten komen welk pakket een gegeven bestand produceerde?"
+
+#. type: <p><list>
+#: debian-faq.sgml:49 pkgtools.sgml:346
+msgid ""
+"To identify the package that produced the file named <tt>foo</tt> execute "
+"either:"
+msgstr ""
+"Om het pakket dat het bestand met de naam <tt>foo</tt> produceerde, te "
+"kennen, geeft u ofwel de volgende opdracht:"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:347
+msgid "<tt>dpkg --search foo</tt>"
+msgstr "<tt>dpkg --search foo</tt>"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:353
+msgid ""
+"This searches for <tt>foo</tt> in installed packages. (This is (currently) "
+"equivalent to searching all of the files having the file extension of <tt>."
+"list</tt> in the directory <tt>/var/lib/dpkg/info/</tt>, and adjusting the "
+"output to print the names of all the packages containing it, and diversions.)"
+msgstr ""
+"Dit zoekt <tt>foo</tt> op in geÃ¯nstalleerde pakketten. (Dit komt (momenteel) "
+"overeen met het doorzoeken van alle bestanden met de extensie <tt>.list</tt> "
+"in de map <tt>/var/lib/dpkg/info/</tt>, waarna de namen weergegeven worden "
+"van alle pakketten die het bestand en afgeleiden bevat.)"
+
+#. type: <p><example>
+#: debian-faq.sgml:49 pkgtools.sgml:354
+msgid "A faster alternative to this is the <prgn>dlocate</prgn> tool."
+msgstr ""
+"Een sneller alternatief hiervoor is het gereedschap <prgn>dlocate</prgn>."
+
+#. type: <example></example>
+#: debian-faq.sgml:49 pkgtools.sgml:347
+#, no-wrap
+msgid "dlocate -S foo"
+msgstr "dlocate -S foo"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:357
+msgid "<tt>zgrep foo Contents-ARCH.gz</tt>"
+msgstr "<tt>zgrep foo Contents-ARCH.gz</tt>"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:366
+msgid ""
+"This searches for files which contain the substring <tt>foo</tt> in their "
+"full path names. The files <tt>Contents-ARCH.gz</tt> (where ARCH represents "
+"the wanted architecture) reside in the major package directories (main, non-"
+"free, contrib) at a Debian FTP site (i.e. under <tt>/debian/dists/"
+"&releasename;</tt>). A <tt>Contents</tt> file refers only to the packages in "
+"the subdirectory tree where it resides. Therefore, a user might have to "
+"search more than one <tt>Contents</tt> files to find the package containing "
+"the file <tt>foo</tt>."
+msgstr ""
+"Dit zoekt naar bestanden die de tekenreeks <tt>foo</tt> hebben in de naam "
+"van hun volledig pad. De bestanden <tt>Contents-ARCH.gz</tt> (waarbij ARCH "
+"staat voor de gewenste architectuur) staan in de hoofdpakketmappen (main, "
+"non-free, contrib) op een Debian FTP-site (dit is onder <tt>/debian/dists/"
+"&releasename;</tt>). Een <tt>Contents</tt>-bestand bevat enkel verwijzingen "
+"naar de pakketten die zich bevinden in zijn onderliggende mappenboom. "
+"Daardoor kan het zijn dat een gebruiker meer dan een <tt>Contents</tt>-"
+"bestand moet doorzoeken om het pakket te vinden dat het bestand <tt>foo</tt> "
+"bevat."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:370
+msgid ""
+"This method has the advantage over <tt>dpkg --search</tt> in that it will "
+"find files in packages that are not currently installed on your system."
+msgstr ""
+"Tegenover <tt>dpkg --search</tt> heeft deze werkwijze het voordeel dat het "
+"bestanden kan vinden in pakketten die momenteel niet geÃ¯nstalleerd zijn op "
+"uw systeem."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:371
+msgid "<tt>apt-file search <var>foo</var></tt>"
+msgstr "<tt>apt-file search <var>foo</var></tt>"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:379
+msgid ""
+"If you install the <package>apt-file</package> package, similar to the "
+"above, it searches files which contain the substring or regular expression "
+"<tt>foo</tt> in their full path names. The advantage over the example above "
+"is that there is no need to retrieve the <tt>Contents-ARCH.gz</tt> files as "
+"it will do this automatically for all the sources defined in <file>/etc/apt/"
+"sources.list</file> when you run (as root) <tt>apt-file update</tt>."
+msgstr ""
+"Indien u het pakket <package>apt-file</package> geÃ¯nstalleerd heeft, zoekt "
+"dit commando net zoals in het voorgaande voorbeeld naar bestanden die de "
+"tekenreeks of de reguliere expressie <tt>foo</tt> hebben in de naam van hun "
+"volledig pad. Het voordeel tegenover het voorgaande voorbeeld is dat de "
+"<tt>Contents-ARCH.gz</tt>-bestanden niet moeten opgehaald worden, vermits "
+"het dit automatisch doet voor alle pakketbronnen die in <file>/etc/apt/"
+"sources.list</file> staan als u (als gebruiker root) de opdracht <tt>apt-"
+"file update</tt> geeft."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:49 pkgtools.sgml:385
+msgid ""
+"Why is `foo-data' not removed when I uninstall `foo'? How do I make sure old "
+"unused library-packages get purged?"
+msgstr ""
+"Waarom wordt 'foo-data' niet verwijderd als ik 'foo' de-installeer? Hoe zorg "
+"ik ervoor dat oude niet-gebruikte bibliotheekpakketten gewist worden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:392
+msgid ""
+"Some packages are split in program (`foo') and data (`foo-data') (or in "
+"`foo' and `foo-doc'). This is true for many games, multimedia applications "
+"and dictionaries in Debian and has been introduced since some users might "
+"want to access the raw data without installing the program or because the "
+"program can be run without the data itself, making `foo-data' optional."
+msgstr ""
+"Sommige pakketten werden opgesplitst in een programma-pakket ('foo') en een "
+"data-pakket (foo-data') (of in 'foo' en 'foo-doc'). Dit is het geval voor "
+"veel spellen, multimediatoepassingen en woordenboeken in Debian, omdat "
+"sommige gebruikers de ruwe data willen gebruiken zonder het programma te "
+"installeren, of omdat het programma gebruikt kan worden zonder de data zelf, "
+"hetgeen maakt dat 'foo-data' optioneel is."
+
+#. type: <p></p>
+#: debian-faq.sgml:49 pkgtools.sgml:399
+msgid ""
+"Similar situations occur when dealing with libraries: generally these get "
+"installed since packages containing applications depend on them. When the "
+"application-package is purged, the library-package might stay on the system. "
+"Or: when the application-package no longer depends upon e.g. libdb4.2, but "
+"upon libdb4.3, the libdb4.2 package might stay when the application-package "
+"is upgraded."
+msgstr ""
+"Gelijkaardige situaties doen zich met bibliotheken voor: over het algemeen "
+"worden ze geÃ¯nstalleerd omdat pakketten van toepassingen ze vereisen. Als "
+"het pakket met de toepassing gewist wordt, blijft het bibliotheek-pakket "
+"mogelijk op het systeem. Welnu, als het pakket met de toepassing niet langer "
+"bijvoorbeeld libdb4.2 vereist, maar libdb4.3, kan het pakket libdb4.2 "
+"achterblijven op het systeem als hete pakket met de toepassing opgewaardeerd "
+"wordt."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:3
+msgid ""
+"In these cases, `foo-data' doesn't depend on `foo', so when you remove the "
+"`foo' package it will not get automatically removed by most package "
+"management tools. The same holds true for the library packages. This is "
+"necessary to avoid circular dependencies. However, if you use <prgn>apt-get</"
+"prgn> (see <ref id=\"apt-get\">) or <prgn>aptitude</prgn> (see <ref id="
+"\"aptitude\">) as your package management tool, they will track "
+"automatically installed packages and give the possibility to remove them, "
+"when no packages making use of them remain in your system."
+msgstr ""
+"In deze gevallen is 'foo-data' niet afhankelijk van 'foo' en als u dus het "
+"pakket 'foo' verwijdert, zal het door de meeste pakketbeheergereedschappen "
+"niet automatisch verwijderd worden. Hetzelfde is het geval voor de "
+"bibliotheekpakketten. Dit is nodig om circulaire vereisten te vermijden. "
+"Indien u echter <prgn>apt-get</prgn> (zie <ref id=\"apt-get\">) of "
+"<prgn>aptitude</prgn> (zie <ref id=\"aptitude\">) gebruikt als "
+"pakketbeheergereedschap, zullen deze automatisch geÃ¯nstalleerde pakketten "
+"opvolgen en de mogelijkheid bieden om ze te verwijderen als er op uw systeem "
+"geen pakketten meer overblijven die er gebruik van maken."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:50 uptodate.sgml:5
+msgid "Keeping your Debian system up-to-date"
+msgstr "Uw Debian-systeem up-to-date houden"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:11
+msgid ""
+"One of Debian's goals is to provide a consistent upgrade path and a secure "
+"upgrade process. We always do our best to make upgrading to new releases a "
+"smooth procedure. In case there's some important note to add to the upgrade "
+"process, the packages will alert the user, and often provide a solution to a "
+"possible problem."
+msgstr ""
+"Een van de doelstellingen van Debian is om te voorzien in een consistent "
+"opwaarderingspad en een bedrijfszeker opwaarderingsproces. We doen altijd "
+"onze best om het opwaarderen naar een nieuwe release vlot te laten verlopen. "
+"Als er bij de opwaardering een belangrijke opmerking gemaakt moet worden, "
+"zal het pakket de gebruiker dit signaleren en dikwijls een oplossing "
+"aandragen voor een mogelijk probleem."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:18
+msgid ""
+"You should also read the Release Notes document that describes the details "
+"of specific upgrades. It is available on the Debian website at <url id="
+"\"http://www.debian.org/releases/stable/releasenotes\"> and is also shipped "
+"on the Debian CDs, DVDs and Blu-ray discs."
+msgstr ""
+"U moet ook het document 'Notities bij de release' (Release Notes) lezen "
+"waarin details in verband met specifieke upgradesituaties gegeven worden. "
+"Het is te vinden op de website van Debian op <url id=\"http://www.debian.org/"
+"releases/stable/releasenotes\"> en is ook te vinden op de cd's, dvd's en blu-"
+"raydiscs van Debian."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:50 uptodate.sgml:20
+msgid "How can I keep my Debian system current?"
+msgstr "Hoe kan ik mijn Debian-systeem actueel houden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:28
+msgid ""
+"One could simply execute an anonymous ftp call to a Debian archive, then "
+"peruse the directories until one finds the desired file, and then fetch it, "
+"and finally install it using <tt>dpkg</tt>. Note that <tt>dpkg</tt> will "
+"install upgrade files in place, even on a running system. Sometimes, a "
+"revised package will require the installation of a newly revised version of "
+"another package, in which case the installation will fail until/unless the "
+"other package is installed."
+msgstr ""
+"Men zou gewoon een anonieme ftp-verbinding kunnen maken met een Debian-"
+"archief, de mappen doorzoeken tot men het gewenste bestand vindt, het dan "
+"ophalen en het tenslotte installeren met <tt>dpkg</tt>. Merk op dat "
+"<tt>dpkg</tt> opwaarderingsbestanden op hun plaats zal installeren, ook op "
+"een werkend systeem. Soms zal een herwerkt pakket de installatie vereisen "
+"van een nieuwe revisieversie van een ander pakket en in een dergelijk geval "
+"zal de installatie mislukken totdat dit pakket geÃ¯nstalleerd is."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:34
+msgid ""
+"Many people find this approach much too time-consuming, since Debian evolves "
+"so quickly -- typically, a dozen or more new packages are uploaded every "
+"week. This number is larger just before a new major release. To deal with "
+"this avalanche, many people prefer to use a more automated method. Several "
+"different packages are available for this purpose:"
+msgstr ""
+"Velen vinden deze benadering veel te tijdrovend, vermits de evolutie van "
+"Debian zo snel gaat -- gewoonlijk worden wekelijks een dozijn of meer nieuwe "
+"pakketten geÃ¼pload. Net voor een nieuwe hoofdrelease is dit aantal groten. "
+"Om met deze stortvloed om te gaan, geven de meesten de voorkeur aan een meer "
+"geautomatiseerde werkwijze. Verschillende pakketten staan hiervoor ter "
+"beschikking:"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:39
+msgid ""
+"<prgn>aptitude</prgn> is the recommended package manager for &debian; "
+"systems, and is described in <ref id=\"aptitude\">."
+msgstr ""
+"<prgn>aptitude</prgn> is het aanbevolen programma voor pakketbeheer op "
+"&debian;-systemen. Het wordt beschreven in <ref id=\"aptitude\">."
+
+#. type: <p><example>
+#: debian-faq.sgml:50 uptodate.sgml:44
+msgid ""
+"Before you can use <prgn>aptitude</prgn> to make an upgrade, you'll have to "
+"edit the <tt>/etc/apt/sources.list</tt> file to set it up. If you wish to "
+"upgrade to the latest stable version of Debian, you'll probably want to use "
+"a source like this one:"
+msgstr ""
+"Voor u <prgn>aptitude</prgn> kunt gebruiken om een opwaardering uit te "
+"voeren, moet u het bestand <tt>/etc/apt/sources.list</tt> bewerken om het in "
+"te stellen. Indien u wenst op te waarderen naar de laatste stabiele versie "
+"van Debian, zult u wellicht een pakketbron gebruiken zoals deze:"
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:39
+#, no-wrap
+msgid "http://ftp.us.debian.org/debian stable main contrib"
+msgstr "http://ftp.us.debian.org/debian stable main contrib"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:50
+msgid ""
+"You can replace ftp.us.debian.org (the mirror in the United States) with the "
+"name of a faster Debian mirror near you. See the mirror list at <url id="
+"\"http://www.debian.org/mirror/list\"> for more information."
+msgstr ""
+"U kunt ftp.us.debian.org (de spiegelserver in de Verenigde Staten) vervangen "
+"door de naam van een snellere Debian-spiegelserver in uw buurt. Raadpleeg de "
+"lijst van spiegelservers op <url id=\"http://www.debian.org/mirror/list\"> "
+"voor meer informatie."
+
+#. type: <p><example>
+#: debian-faq.sgml:50 uptodate.sgml:56
+msgid ""
+"Or you can use the redirector service httpredir.debian.org which aims to "
+"solve the problem of choosing a Debian mirror. It uses the geographic "
+"location of the user and other information to choose the best mirror that "
+"can serve the files. To take advantage of it use a source like this one:"
+msgstr ""
+"Of u kunt de doorverwijzingsdienst httpredir.debian.org gebruiken, die erop "
+"gericht is het probleem van het kiezen van een Debian-spiegelserver op te "
+"lossen. Hij maakt gebruik van de geografische locatie van de gebruiker en "
+"van andere informatie om de beste spiegelserver voor het leveren van de "
+"bestanden te kiezen. Om hiervan gebruik te maken, moet u een pakketbron "
+"gebruiken zoals deze:"
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:50
+#, no-wrap
+msgid "http://httpredir.debian.org/debian stable main contrib"
+msgstr "http://httpredir.debian.org/debian stable main contrib"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:61
+msgid ""
+"More details on this can be found in the <manref name=\"sources.list\" "
+"section=\"5\"> manual page."
+msgstr ""
+"Meer informatie hierover is te vinden in de <manref name=\"sources.list\" "
+"section=\"5\"> manpagina."
+
+#. type: <p><example>
+#: debian-faq.sgml:50 uptodate.sgml:61
+msgid "To update your system from the command line, run"
+msgstr "Om uw systeem aan de commandoregel bij te werken, geeft u de opdracht"
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:61
+#, no-wrap
+msgid "aptitude update"
+msgstr "aptitude update"
+
+#. type: </example><example>
+#: debian-faq.sgml:50 uptodate.sgml:63 uptodate.sgml:93
+msgid "followed by"
+msgstr "gevolgd door"
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:61
+#, no-wrap
+msgid "aptitude full-upgrade"
+msgstr "aptitude full-upgrade"
+
+#. type: </example></p>
+#: debian-faq.sgml:50 uptodate.sgml:67
+msgid ""
+"Answer any questions that might come up, and your system will be upgraded."
+msgstr ""
+"Beantwoord eventuele vragen die zich aandienen en uw systeem zal "
+"opgewaardeerd worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:76
+msgid ""
+"Note that <prgn>aptitude</prgn> is not the recommended tool for doing "
+"upgrades from one &debian; release to another. Use <prgn>apt-get</prgn> "
+"instead. For upgrades between releases you should read the <url id=\"http://"
+"www.debian.org/releases/stable/releasenotes\" name=\"Release Notes\">. This "
+"document describes in detail the recommended steps for upgrades from "
+"previous releases as well as known issues you should consider before "
+"upgrading."
+msgstr ""
+"Merk op dat <prgn>aptitude</prgn> niet het aanbevolen gereedschap is om een "
+"opwaardering uit te voeren van de ene &debian;-release naar een andere. "
+"Gebruik in de plaats daarvan daarvoor <prgn>apt-get</prgn>. Voor "
+"opwaarderingen tussen releases moet u de <url id=\"http://www.debian.org/"
+"releases/stable/releasenotes\" name=\"Notities bij de Release\"> lezen. Dit "
+"document beschrijft in detail de aanbevolen stappen voor een opwaardering "
+"vanaf een eerdere release evenals bekende zaken waarmee u rekening moet "
+"houden voor u opwaardeert."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:79
+msgid ""
+"For details, see the manual page <manref name=\"aptitude\" section=\"8\">, "
+"and the file <file>/usr/share/aptitude/README</file>."
+msgstr ""
+"Zie voor gedetailleerde informatie de manpagina <manref name=\"aptitude\" "
+"section=\"8\"> en het bestand <file>/usr/share/aptitude/README</file>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:50 uptodate.sgml:81
+msgid "apt-get and apt-cdrom"
+msgstr "apt-get en apt-cdrom"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:84
+msgid ""
+"An alternative to <prgn>aptitude</prgn> is <prgn>apt-get</prgn> which is an "
+"APT-based command-line tool (described previously in <ref id=\"apt-get\">)."
+msgstr ""
+"Een alternatief voor <prgn>aptitude</prgn> is <prgn>apt-get</prgn> dat een "
+"op APT gebaseerd gereedschap voor de commandoregel is (eerder behandeld in "
+"<ref id=\"apt-get\">)."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:87
+msgid ""
+"<prgn>apt-get</prgn>, the APT-based command-line tool for handling packages, "
+"provides a simple, safe way to install and upgrade packages."
+msgstr ""
+"<prgn>apt-get</prgn>, het op APT gebaseerd commandoregelgereedschap voor het "
+"werken met pakketten, biedt een eenvoudige en veilige manier om pakketten te "
+"installeren en op te waarderen."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:91
+msgid ""
+"To use <prgn>apt-get</prgn>, edit the <tt>/etc/apt/sources.list</tt> file to "
+"set it up, just as for <ref id=\"aptitude-upgrade\">."
+msgstr ""
+"Om <prgn>apt-get</prgn> te gebruiken moet u het bestand <tt>/etc/apt/sources."
+"list</tt> bewerken om het in te stellen, net zoals voor <ref id=\"aptitude-"
+"upgrade\">."
+
+#. type: <p><example>
+#: debian-faq.sgml:50 uptodate.sgml:91
+msgid "Then run"
+msgstr "Geef dan de opdrachten"
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:91
+#, no-wrap
+msgid "apt-get update"
+msgstr "apt-get update"
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:91
+#, no-wrap
+msgid "apt-get dist-upgrade"
+msgstr "apt-get dist-upgrade"
+
+#. type: </example></p>
+#: debian-faq.sgml:50 uptodate.sgml:99
+msgid ""
+"Answer any questions that might come up, and your system will be upgraded. "
+"See also the <manref name=\"apt-get\" section=\"8\"> manual page, as well as "
+"<ref id=\"apt-get\">."
+msgstr ""
+"Beantwoord eventuele vragen die zich aandienen en uw systeem zal "
+"opgewaardeerd worden. Zie ook de man-pagina <manref name=\"apt-get\" section="
+"\"8\"> en <ref id=\"apt-get\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:103
+msgid ""
+"If you want to use CDs/DVDs/BDs to install packages, you can use <prgn>apt-"
+"cdrom</prgn>. For details, please see the Release Notes, section \"Adding "
+"APT sources from optical media\"."
+msgstr ""
+"Indien u CD's/DVD's/BD's wilt gebruiken om pakketten te installeren, kunt u "
+"<prgn>apt-cdrom</prgn> gebruiken. Raadpleeg voor bijkomende informatie het "
+"onderdeel \"APT-pakketbronnen van optische media toevoegen\" uit de "
+"'Notities bij de Release'."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:109
+msgid ""
+"Please note that when you get and install the packages, you'll still have "
+"them kept in your /var directory hierarchy. To keep your partition from "
+"overflowing, remember to delete extra files using <tt>apt-get clean</tt> and "
+"<tt>apt-get autoclean</tt>, or to move them someplace else (hint: use "
+"<package>apt-move</package>)."
+msgstr ""
+"Merk op dat wanneer u een pakket ophaalt en installeert, het ook behouden "
+"wordt in de mappenstructuur onder /var. Om te vermijden dat uw partitie "
+"volloopt, moet u eraan denken om extra bestanden te verwijderen met <tt>apt-"
+"get clean</tt> en <tt>apt-get autoclean</tt> of ze naar een andere plaats te "
+"verplaatsen (hint: gebruik <package>apt-move</package>)."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:50 uptodate.sgml:111
+msgid "mirror"
+msgstr "mirror"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:115
+msgid ""
+"This Perl script, and its (optional) manager program called <prgn>mirror-"
+"master</prgn>, can be used to fetch user-specified parts of a directory tree "
+"from a specified host <em>via</em> anonymous FTP."
+msgstr ""
+"Het Perl-script en zijn (optioneel) beheerprogramma met de naam <prgn>mirror-"
+"master</prgn> kan gebruikt worden om door de gebruiker gespecificeerde delen "
+"van een mappenboom <em>via</em> anonieme FTP op te halen van een opgegeven "
+"computer."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:122
+msgid ""
+"<prgn>mirror</prgn> is particularly useful for downloading large volumes of "
+"software. After the first time files have been downloaded from a site, a "
+"file called <tt>.mirrorinfo</tt> is stored on the local host. Changes to the "
+"remote file system are tracked automatically by <prgn>mirror</prgn>, which "
+"compares this file to a similar file on the remote system and downloads only "
+"changed files."
+msgstr ""
+"<prgn>mirror</prgn> is in het bijzonder nuttig voor het downloaden van grote "
+"volumes software. Nadat de eerste maal bestanden gedownload werden van een "
+"site, wordt op de lokale computer een bestand geplaatst met als naam <tt>."
+"mirrorinfo</tt>. Veranderingen aan het bestandssysteem van de externe "
+"computer worden automatisch opgevolgd door <prgn>mirror</prgn> via het "
+"vergelijken van dit bestand met een gelijkaardig bestand op het externe "
+"systeem, en enkel gewijzigde bestanden worden opgehaald."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:132
+msgid ""
+"The <prgn>mirror</prgn> program is generally useful for updating local "
+"copies of remote directory trees. The files fetched need not be Debian "
+"files. (Since <prgn>mirror</prgn> is a Perl script, it can also run on non-"
+"Unix systems.) Though the <prgn>mirror</prgn> program provides mechanisms "
+"for excluding files with names matching user-specified strings, this program "
+"is most useful when the objective is to download whole directory trees, "
+"rather than selected packages."
+msgstr ""
+"Het programma <prgn>mirror</prgn> is over het algemeen nuttig voor het "
+"bijwerken van een lokale kopie van een mappenboom van een externe computer. "
+"De opgehaalde bestanden moeten geen Debian-bestanden zijn. (Aangezien "
+"<prgn>mirror</prgn> een Perl-script is, kan het ook gebruikt worden op niet-"
+"Unixsystemen.) Hoewel het programma <prgn>mirror</prgn> voorziet in "
+"mechanismes voor het uitsluiten van bestanden waarvan de naam overeenkomt "
+"met door de gebruiker opgegeven tekenreeksen, is het toch vooral nuttig als "
+"het de bedoeling is volledige mappenbomen te downloaden, eerder dan "
+"uitgekozen pakketten."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:50 uptodate.sgml:135
+msgid "Must I go into single user mode in order to upgrade a package?"
+msgstr ""
+"Moet ik overschakelen naar de Ã©Ã©n-gebruikersmodus om een pakket op te "
+"waarderen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:139
+msgid ""
+"No. Packages can be upgraded in place, even in running systems. Debian has a "
+"<tt>start-stop-daemon</tt> program that is invoked to stop, then restart "
+"running process if necessary during a package upgrade."
+msgstr ""
+"Neen. Pakketten kunnen ter plaatse opgewaardeerd worden, zelfs op werkende "
+"systemen. Debian beschikt over een pargramma <tt>start-stop-daemon</tt> dat "
+"aangeroepen wordt om een actief proces te stoppen en dan opnieuw te starten "
+"als dat nodig is tijdens de opwaardering van een pakket."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:50 uptodate.sgml:142
+msgid "Do I have to keep all those .deb archive files on my disk?"
+msgstr "Moet ik al die .deb-archieven op mijn schijf behouden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:146
+msgid ""
+"No. If you have downloaded the files to your disk then after you have "
+"installed the packages, you can remove them from your system, e.g. by "
+"running <tt>aptitude clean</tt>."
+msgstr ""
+"Neen. Indien u de bestanden naar uw schijf gedownload heeft, kunt u ze van "
+"uw systeem verwijderen nadat u de pakketten geÃ¯nstalleerd heeft, "
+"bijvoorbeeld met de opdracht <tt>aptitude clean</tt>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:50 uptodate.sgml:150
+msgid ""
+"How can I keep a log of the packages I added to the system? I'd like to know "
+"when upgrades and removals have occurred and on which packages!"
+msgstr ""
+"Hoe kan ik een logboek bijhouden van de pakketten die ik toevoegde aan het "
+"systeem? Ik zou willen weten wanneer er opwaarderingen en verwijderingen "
+"plaats gevonden hebben en over welke pakketten het dan ging!"
+
+#. type: <p><example>
+#: debian-faq.sgml:50 uptodate.sgml:154
+msgid ""
+"Passing the <tt>--log</tt>-option to <prgn>dpkg</prgn> makes <prgn>dpkg</"
+"prgn> log status change updates and actions. It logs both the <prgn>dpkg</"
+"prgn>-invokation (e.g."
+msgstr ""
+"Als u bij <prgn>dpkg</prgn> de optie <tt>--log</tt> gebruikt, doet u "
+"<prgn>dpkg</prgn> toestandswijzigingen en acties loggen. Het logt zowel het "
+"aanroepen van <prgn>dpkg</prgn> (bijv."
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:156
+#, no-wrap
+msgid "2005-12-30 18:10:33 install hello 1.3.18 2.1.1-4"
+msgstr "2005-12-30 18:10:33 install hello 1.3.18 2.1.1-4"
+
+#. type: <p><example>
+#: debian-faq.sgml:50 uptodate.sgml:160
+msgid ") and the results (e.g."
+msgstr ") als het resultaat ervan (bijv."
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:162
+#, no-wrap
+msgid "2005-12-30 18:10:35 status installed hello 2.1.1-4"
+msgstr "2005-12-30 18:10:35 status installed hello 2.1.1-4"
+
+#. type: <p><example>
+#: debian-faq.sgml:50 uptodate.sgml:167
+msgid ""
+") If you'd like to log all your <prgn>dpkg</prgn> invocations (even those "
+"done using frontends like <prgn>aptitude</prgn>), you could add"
+msgstr ""
+") Indien u graag een log wilt bijhouden van elke aanroep van <prgn>dpkg</"
+"prgn> (ook die welke gebeurden via frontends zoals <prgn>aptitude</prgn>), "
+"zou u"
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:169
+#, no-wrap
+msgid "log /var/log/dpkg.log"
+msgstr "log /var/log/dpkg.log"
+
+#. type: <p><example>
+#: debian-faq.sgml:50 uptodate.sgml:175
+msgid ""
+"to your <file>/etc/dpkg/dpkg.cfg</file>. Be sure the created logfile gets "
+"rotated periodically. If you're using <prgn>logrotate</prgn>, this can be "
+"achieved by creating a file <file>/etc/logrotate.d/dpkg</file> with the "
+"following lines"
+msgstr ""
+"kunnen toevoegen aan uw bestand <file>/etc/dpkg/dpkg.cfg</file>. Zorg ervoor "
+"dat de gecreÃ«erde logbestanden periodiek geroteerd worden. Indien u gebruik "
+"maakt van <prgn>logrotate</prgn>, kunt u dit bekomen door een bestand <file>/"
+"etc/logrotate.d/dpkg</file> aan te maken met de volgende regels"
+
+#. type: <example></example>
+#: debian-faq.sgml:50 uptodate.sgml:180
+#, no-wrap
+msgid ""
+"/var/log/dpkg {\n"
+"  missingok\n"
+"  notifempty\n"
+"}"
+msgstr ""
+"/var/log/dpkg {\n"
+"  missingok\n"
+"  notifempty\n"
+"}"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:185
+msgid ""
+"More details on <prgn>dpkg</prgn> logging can be found in the <manref name="
+"\"dpkg\" section=\"1\"> manual page."
+msgstr ""
+"Meer informatie over loggen met <prgn>dpkg</prgn> is te vinden in de man-"
+"pagina van <manref name=\"dpkg\" section=\"1\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:189
+msgid ""
+"<prgn>aptitude</prgn> logs the package installations, removals, and upgrades "
+"that it intends to perform to <file>/var/log/aptitude</file>. Note that the "
+"<em>results</em> of those actions are not recorded in this file!"
+msgstr ""
+"<prgn>aptitude</prgn> logt de installaties, de verwijderingen en de "
+"opwaarderingen van pakketten die het van plan is uit te voeren in <file>/var/"
+"log/aptitude</file>. Merk op dat het resultaat van deze acties niet "
+"opgeschreven wordt in dit bestand!"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:192
+msgid ""
+"Another way to record your actions is to run your package management session "
+"within the <manref name=\"script\" section=\"1\"> program."
+msgstr ""
+"Een andere manier om uw acties te registreren is het uitvoeren van uw "
+"pakketbeheersessie binnenin het programma <manref name=\"script\" section="
+"\"1\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:50 uptodate.sgml:194
+msgid "Can I automatically update the system?"
+msgstr "Kan ik het systeem automatisch bijwerken?"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:198
+msgid ""
+"Yes. You can use <prgn>cron-apt</prgn>; this tool updates the system at "
+"regular intervals using a cron job. By default it just updates the package "
+"list and downloads new packages, but without installing them."
+msgstr ""
+"Ja. U kunt <prgn>cron-apt</prgn> gebruiken. Dit gereedschap werkt het "
+"systeem met regelmatige tussenpozen bij via een cron-taak. Standaard werkt "
+"het enkel de pakketlijst bij en downloadt het nieuwe pakketten, zonder ze "
+"evenwel te installeren."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:202
+msgid ""
+"Note: Automatic upgrade of packages is <strong>NOT</strong> recommended in "
+"<em>testing</em> or <em>unstable</em> systems as this might bring unexpected "
+"behaviour and remove packages without notice."
+msgstr ""
+"Opmerking: het automatisch opwaarderen van pakketten wordt op systemen die "
+"<em>testing</em> of <em>unstable</em> gebruiken, <strong>NIET</strong>, "
+"aangezien dit onverwachte effecten kan hebben en pakketten zonder "
+"kennisgeving kan verwijderen."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:50 uptodate.sgml:205
+msgid "I have several machines; how can I download the updates only one time?"
+msgstr ""
+"Ik heb verschillende computers. Hoe kan ik de bijwerkingen slechts eenmaal "
+"downloaden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:208
+msgid ""
+"If you have more than one Debian machine on your network, it is useful to "
+"use <prgn>apt-cacher</prgn> to keep all of your Debian systems up-to-date."
+msgstr ""
+"Indien u in uw netwerk meer dan een Debian-computer heeft, is ht nuttig om "
+"<prgn>apt-cacher</prgn> te gebruiken om al uw Debian-systemen up-to-date te "
+"houden."
+
+#. type: <p></p>
+#: debian-faq.sgml:50 uptodate.sgml:214
+msgid ""
+"<prgn>apt-cacher</prgn> reduces the bandwidth requirements of Debian mirrors "
+"by restricting the frequency of Packages, Releases and Sources file updates "
+"from the back end and only doing a single fetch for any file, independently "
+"of the actual request from the proxy. <prgn>apt-cacher</prgn> automatically "
+"builds a Debian HTTP mirror based on requests which pass through the proxy."
+msgstr ""
+"<prgn>apt-cacher</prgn> vermindert de vereisten inzake bandbreedte voor "
+"Debian-spiegelservers door de frequentie waarmee de backend de bestanden "
+"Packages, Releases en Sources bijwerkt, te beperken en door elk bestand "
+"slechts eenmaal op te halen, ongeacht het reÃ«le verzoek van de proxy. "
+"<prgn>apt-cacher</prgn> bouwt automatisch een Debian HTTP-spiegelserver op "
+"basis van de verzoeken die via de proxy passeren."
+
+#. type: <p></p>
+#: debian-faq.sgml:51 kernel.sgml:3
+msgid ""
+"Of course, you can get the same benefit if you are already using a standard "
+"caching proxy and all your systems are configured to use it."
+msgstr ""
+"U kunt natuurlijk ook hetzelfde resultaat bekomen als u reeds gebruik maakt "
+"van een standaard proxy met cache en al uw systemen geconfigureerd zijn om "
+"die te gebruiken."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:51 kernel.sgml:5
+msgid "Debian and the kernel"
+msgstr "Debian en de kernel"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:51 kernel.sgml:8
+msgid ""
+"Can I install and compile a kernel without some Debian-specific tweaking?"
+msgstr ""
+"Kan ik een kernel installeren en compileren zonder bepaalde Debian-"
+"specifieke afstellingen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:51 kernel.sgml:10
+msgid "Yes."
+msgstr "Ja."
+
+#. type: <p></p>
+#: debian-faq.sgml:51 kernel.sgml:19
+msgid ""
+"There's only one common catch: the Debian C libraries are built with the "
+"most recent <em>stable</em> releases of the <strong>kernel</strong> headers. "
+"If you happen to need to compile a program with kernel headers newer than "
+"the ones from the stable branch, then you should either upgrade the package "
+"containing the headers (<package>linux-libc-dev</package>), or use the new "
+"headers from an unpacked tree of the newer kernel. That is, if the kernel "
+"sources are in <file>/usr/src/linux</file>, then you should add <tt>-I/usr/"
+"src/linux/include/</tt> to your command line when compiling."
+msgstr ""
+"Er is enkel een gebruikelijke valkuil: De C-bibliotheken van Debian worden "
+"gebouwd met de recentste <em>stabiele</em> release van de <strong>kernel</"
+"strong>-headers. Mocht u echter een programma moeten compileren met "
+"recentere kernel-headers dan die van de stabiele tak, dan moet u ofwel het "
+"pakket dat de headers bevat (<package>linux-libc-dev</package>), "
+"opwaarderen, ofwel de nieuwe headers gebruiken uit de uitgepakte "
+"boomstructuur van de recentere kernel. Dit wil zeggen dat als de "
+"kernelbroncode zich in <file>/usr/src/linux</file> bevindt, u bij het "
+"compileren <tt>-I/usr/src/linux/include/</tt> moet toevoegen aan uw "
+"commandoregel."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:51 kernel.sgml:22
+msgid "What tools does Debian provide to build custom kernels?"
+msgstr ""
+"Welke gereedschappen stelt Debian ter beschikking om een aangepaste kernel "
+"te bouwen?"
+
+#. type: <p><example>
+#: debian-faq.sgml:51 kernel.sgml:24
+msgid ""
+"Users who wish to (or must) build a custom kernel are encouraged to use the "
+"Debian package target included with recent versions of the kernel build "
+"system. After configuring the kernel, simply run the following command:"
+msgstr ""
+"Gebruikers die een aangepaste kernel willen (of moeten) bouwen, worden "
+"aangemoedigd om er het daarvoor bedoelde Debian-pakket te gebruiken dat "
+"recente versies van het bouwsysteem voor de kernel bevat. Nadat u de kernel "
+"geconfigureerd heeft, moet u gewoon de volgende opdracht geven:"
+
+#. type: <example></example>
+#: debian-faq.sgml:51 kernel.sgml:22
+#, no-wrap
+msgid "make deb-pkg"
+msgstr "make deb-pkg"
+
+#. type: </example></p>
+#: debian-faq.sgml:51 kernel.sgml:29
+msgid ""
+"The new kernel package will be created in the directory one level above the "
+"kernel source tree, and it may be installed using <tt>dpkg -i</tt>."
+msgstr ""
+"Het nieuwe kernelpakket zal aangemaakt worden in de map net boven de "
+"mappenboom van de kernelbroncode en het kan geÃ¯nstalleerd worden met "
+"<tt>dpkg -i</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:51 kernel.sgml:35
+msgid ""
+"Users must separately download the source code for the most recent kernel "
+"(or the kernel of their choice) from their favorite Linux archive site, "
+"unless a <package>linux-source-<var>version</var></package> package is "
+"available (where <var>version</var> stands for the kernel version)."
+msgstr ""
+"Gebruikers moeten de broncode van de meest recente kernel (of de kernel van "
+"hun keuze) apart downloaden van hun favoriete Linux-archiefsite, tenzij er "
+"een pakket beschikbaar is met de naam <package>linux-source-<var>versie</"
+"var></package> (waarbij  <var>versie</var> staat voor de kernelversie)."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:51 kernel.sgml:38
+msgid "What special provisions does Debian provide to deal with modules?"
+msgstr ""
+"Welke bijzondere voorzieningen stelt Debian ter beschikking voor het omgaan "
+"met modules?"
+
+#. type: <p></p>
+#: debian-faq.sgml:51 kernel.sgml:41
+msgid ""
+"A configuration file containing modules to be manually loaded at boot time "
+"is kept at <file>/etc/modules</file>. However, editing this file is rarely "
+"needed."
+msgstr ""
+"Er wordt in het bestand <file>/etc/modules</file> een configuratie "
+"bijgehouden met de modules die bij het opstarten handmatig geladen moeten "
+"worden. Het bewerken van dit bestand is evenwel slechts zelden nodig."
+
+#. type: <p></p>
+#: debian-faq.sgml:51 kernel.sgml:45
+msgid ""
+"Other module configuration is kept in the <file>/etc/modprobe.d/</file> "
+"directory. More information about the format of those files can be found in "
+"the <manref name=\"modprobe.conf\" section=\"5\"> manual page."
+msgstr ""
+"Overige module-configuratie wordt bijgehouden in de map <file>/etc/modprobe."
+"d/</file>. Meer informatie over de indeling van deze bestanden is te vinden "
+"in de man-pagina <manref name=\"modprobe.conf\" section=\"5\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:51 kernel.sgml:48
+msgid "Can I safely de-install an old kernel package, and if so, how?"
+msgstr "Kan ik een oud kernel-pakket veilig de-installeren, en zo ja, hoe?"
+
+#. type: <p><example>
+#: debian-faq.sgml:51 kernel.sgml:53
+msgid ""
+"Yes. The <prgn>linux-image-<var>NNN</var>.prerm</prgn> script checks to see "
+"whether the kernel you are currently running is the same as the kernel you "
+"are trying to de-install. Therefore you can remove unwanted kernel image "
+"packages using this command:"
+msgstr ""
+"Ja. Het script <prgn>linux-image-<var>NNN</var>.prerm</prgn> controleert of "
+"de kernel die u momenteel gebruikt dezelfde is als die welke u tracht te de-"
+"installeren. Daardoor kunt u ongewenste pakketten met een kernel-image "
+"verwijderen met dit commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:51 kernel.sgml:48
+#, no-wrap
+msgid "dpkg --purge linux-image-<var>NNN</var>"
+msgstr "dpkg --purge linux-image-<var>NNN</var>"
+
+#. type: </example></p>
+#: debian-faq.sgml:51 kernel.sgml:57
+msgid ""
+"(replace <var>NNN</var> with your kernel version and revision number, of "
+"course)"
+msgstr ""
+"(vervang uiteraard <var>NNN</var> door het versie- en revisienummer van uw "
+"kernel)"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:51 kernel.sgml:59
+msgid "Where can I get more information about Linux packages for Debian?"
+msgstr "Waar vindt ik meer informatie over Linux-pakketten voor Debian?"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:3
+msgid ""
+"Further information is maintained in the <url id=\"http://kernel-handbook."
+"alioth.debian.org/\" name=\"Debian Linux Kernel Handbook\">."
+msgstr ""
+"Bijkomende informatie wordt bijgehouden in het <url id=\"http://kernel-"
+"handbook.alioth.debian.org/\" name=\"Debian Linux Kernel Handbook\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:5
+msgid "Customizing your &debian; system"
+msgstr "Uw &debian;-systeem aanpassen"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:8
+msgid "How can I ensure that all programs use the same paper size?"
+msgstr ""
+"Hoe zorg ik ervoor dat alle programma's dezelfde papiergrootte gebruiken?"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:12
+msgid ""
+"Install the <package>libpaper1</package> package, and it will ask you for a "
+"system-wide default paper size. This setting will be kept in the file <tt>/"
+"etc/papersize</tt>."
+msgstr ""
+"Installeer het pakket <package>libpaper1</package> en het zal u vragen naar "
+"een standaardpapiergrootte die voor het hele systeem geldt. Deze instelling "
+"wordt opgeslagen in het bestand <tt>/etc/papersize</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:16
+msgid ""
+"Users can override the paper size setting using the <tt>PAPERSIZE</tt> "
+"environment variable. For details, see the manual page <manref name="
+"\"papersize\" section=\"5\">."
+msgstr ""
+"Gebruikers kunnen de instelling van de papiergrootte omzeilen met de "
+"omgevingsvariabele <tt>PAPERSIZE</tt>. Raadpleeg voor bijkomende informatie "
+"de man-pagina <manref name=\"papersize\" section=\"5\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:19
+msgid ""
+"How can I provide access to hardware peripherals, without compromising "
+"security?"
+msgstr ""
+"Hoe kan ik toegang verlenen tot randapparatuur zonder de beveiliging in het "
+"gedrang te brengen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:23
+msgid ""
+"Many device files in the <tt>/dev</tt> directory belong to some predefined "
+"groups. For example, <tt>/dev/sr0</tt> belongs to the <tt>cdrom</tt> group."
+msgstr ""
+"Veel apparaatbestanden in de map <tt>/dev</tt> behoren toe aan vooraf "
+"gedefinieerde groepen. Bijvoorbeeld, <tt>/dev/sr0</tt> behoort toe aan de "
+"groep <tt>cdrom</tt>."
+
+#. type: <p><example>
+#: debian-faq.sgml:52 customizing.sgml:24
+msgid ""
+"If you want a certain user to have access to one of these devices, just add "
+"the user to the group the device belongs to, i.e. do:"
+msgstr ""
+"Indien u wilt dat een bepaalde gebruiker toegang heeft tot een van deze "
+"apparaten, moet u de gebruiker gewoon toevoegen aan de groep waartoe het "
+"apparaat behoort, d.w.z. doe:"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:23
+#, no-wrap
+msgid "adduser user group"
+msgstr "adduser gebruiker groep"
+
+#. type: </example></p>
+#: debian-faq.sgml:52 customizing.sgml:28
+msgid "This way you won't have to change the file permissions on the device."
+msgstr ""
+"Op die manier hoeft u de bestandspermissies van het apparaat niet te "
+"wijzigen."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:32
+msgid ""
+"If you do this from within a user's shell or a GUI environment you have to "
+"logout and login again to become an effective member of that group. To check "
+"which groups you belong to run <tt>groups</tt>."
+msgstr ""
+"Indien u dit doet vanuit een gebruikersshell of vanuit een grafische "
+"werkomgeving, dan moet u eerst uitloggen en weer inloggen om effectief een "
+"lid van die groep te worden. Om na te gaan tot welke groepen u behoort, "
+"gebruikt u het commando <tt>groups</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:37
+msgid ""
+"Notice that, since the introduction of <tt>udev</tt> if you change the "
+"permissions of a hardware peripheral, they might be adjusted for some "
+"devices when the system starts; if this happens to the hardware peripherals "
+"you are interested in, you will have to adjust the rules at <tt>/etc/udev</"
+"tt>."
+msgstr ""
+"Als u de toegangspermissies van een randapparaat wijzigt, moet u weten dat "
+"ten gevolge van de introductie van <tt>udev</tt>, de kans bestaat dat deze "
+"bij het opstarten van het systeem voor sommige apparaten aangepast worden. "
+"Indien dit het geval is voor de randapparaten waarin u geÃ¯nteresseerd bent, "
+"dan zult u de regels in <tt>/etc/udev</tt> moeten aanpassen."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:39
+msgid "How do I load a console font on startup the Debian way?"
+msgstr ""
+"Hoe laad ik bij het opstarten van de computer een tekenset voor de console "
+"op de manier van Debian?"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:42
+msgid ""
+"The <package>kbd</package> package supports this, edit the <tt>/etc/kbd/"
+"config</tt> file."
+msgstr ""
+"Het pakket <package>kbd</package> ondersteunt dit. Bewerk het bestand<tt>/"
+"etc/kbd/config</tt>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:45
+msgid "How can I configure an X11 program's application defaults?"
+msgstr ""
+"Hoe kan ik de standaardinstellingen configureren van een "
+"toepassingsprogramma onder X11?"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:51
+msgid ""
+"Debian's X programs will install their application resource data in the <tt>/"
+"etc/X11/app-defaults/</tt> directory. If you want to customize X "
+"applications globally, put your customizations in those files. They are "
+"marked as configuration files, so their contents will be preserved during "
+"upgrades."
+msgstr ""
+"In Debian plaatsen grafische programma's (X-programma's) de informatie over "
+"de hulpbronnen van hun toepassing in de map <tt>/etc/X11/app-defaults/</tt>. "
+"Indien u globale aanpassingen wilt maken aan grafische toepassingen, moet u "
+"die aanpassingen in deze bestanden plaatsen. Zij staan gemarkeerd als "
+"configuratiebestanden, waardoor hun inhoud bewaard blijft bij opwaarderingen."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:54
+msgid ""
+"Every distribution seems to have a different boot-up method. Tell me about "
+"Debian's."
+msgstr ""
+"Elke distributie blijkt een andere opstartmethode te hanteren. Vertel me "
+"eens wat over die van Debian."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:66
+msgid ""
+"Like all Unices, Debian boots up by executing the program <tt>init</tt> "
+"<footnote><p>As of this writing, the unstable release for Debian GNU/Linux "
+"is replacing sysvinit with <prgn>systemd</prgn>, a system and service "
+"manager for Linux. For more information see <url id=\"https://wiki.debian."
+"org/systemd\">.</p></footnote>. The configuration file for <tt>init</tt> "
+"(which is <tt>/etc/inittab</tt>) specifies that the first script to be "
+"executed should be <tt>/etc/init.d/rcS</tt>. This script runs all of the "
+"scripts in <tt>/etc/rcS.d/</tt> by forking subprocesses to perform "
+"initialization such as to check and to mount file systems, to load modules, "
+"to start the network services, to set the clock, and to perform other "
+"initialization."
+msgstr ""
+"Zoals alle vormen van Unix, start Debian op door het uitvoeren van het "
+"programma<tt>init</tt> <footnote><p>Momenteel wordt in de onstabiele release "
+"van Debian GNU/Linux sysvinit vervangen door<prgn>systemd</prgn>, een "
+"systeem- en dienstenbeheerder voor Linux. Raadpleeg voor meer informatie "
+"<url id=\"https://wiki.debian.org/systemd\">.</p></footnote>. Het "
+"configuratiebestand voor <tt>init</tt> (dat <tt>/etc/inittab</tt> is) "
+"bepaalt dat heteerste script dat uitgevoerd moet worden, <tt>/etc/init.d/"
+"rcS</tt> is. Dat script voert alle scripts uit <tt>/etc/rcS.d/</tt> uit door "
+"subprocessen af te splitsen om initialisatietaken uit te voeren, zoals het "
+"controleren en aankoppelen van bestandssystemen, het laden van modules, het "
+"starten van netwerkdiensten, het instellen van de klok en andere "
+"initialisatietaken."
+
+#. type: <p><list>
+#: debian-faq.sgml:52 customizing.sgml:70
+msgid ""
+"After completing the boot process, <tt>init</tt> executes all start scripts "
+"in a directory specified by the default runlevel (this runlevel is given by "
+"the entry for <tt>id</tt> in <tt>/etc/inittab</tt>). Like most System V "
+"compatible Unices, Linux has 7 runlevels:"
+msgstr ""
+"Nadat het opstartproces voltooid is, voert <tt>init</tt> alle start-scripts "
+"uit die zich in de map bevinden die gespecificeerd wordt door het standaard "
+"'runlevel' (dit 'runlevel' wordt opgegeven door het element <tt>id</tt> in "
+"<tt>/etc/inittab</tt>). Zoals de meeste vormen van Unix die compatibel zijn "
+"met System V, heeft Linux 7 'runlevels':"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:71
+msgid "0 (halt the system),"
+msgstr "0 (stop het systeem),"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:72
+msgid "1 (single-user mode),"
+msgstr "1 (Ã©Ã©n-gebruikersmodus),"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:73
+msgid "2 through 5 (various multi-user modes), and"
+msgstr "2 tot 5 (verschillende meerdere-gebruikersmodi), en"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:75
+msgid "6 (reboot the system)."
+msgstr "6 (herstart het systeem)."
+
+#. type: </list></p>
+#: debian-faq.sgml:52 customizing.sgml:80
+msgid ""
+"Debian systems come with id=2, which indicates that the default runlevel "
+"will be '2' when the multi-user state is entered, and the scripts in <tt>/"
+"etc/rc2.d/</tt> will be run."
+msgstr ""
+"Op Debian-systemen staat id=2 ingesteld, wat aangeeft dat het standaard-"
+"runlevel '2' is als naar de meerdere-gebruikers-toestand overgegaan wordt en "
+"dat de scripts uit <tt>/etc/rc2.d/</tt> uitgevoerd zullen worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:85
+msgid ""
+"Debian uses dependency-based boot ordering through <prgn>insserv</prgn>, "
+"using the LSB headers in each script under <tt>/etc/init.d/</tt>, as well as "
+"parallel concurrent booting through the use of <prgn>startpar</prgn> to "
+"speed up the boot process."
+msgstr ""
+"Debian past een onderling afhankelijke opstartvolgorde toe via "
+"<prgn>insserv</prgn> met behulp van de LSB-headers van elk script onder <tt>/"
+"etc/init.d/</tt>, evenals het gelijktijdig parallel opstarten via het "
+"gebruik van <prgn>startpar</prgn> om het opstartproces te versnellen."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:96
+msgid ""
+"The scripts in any of the directories, <tt>/etc/rcN.d/</tt> are just "
+"symbolic links back to scripts in <tt>/etc/init.d/</tt>. However, the "
+"<em>names</em> of the files in each of the <tt>/etc/rcN.d/</tt> directories "
+"are selected to indicate the <em>way</em> the scripts in <tt>/etc/init.d/</"
+"tt> will be run. Specifically, before entering any runlevel, all the scripts "
+"beginning with 'K' are run; these scripts kill services. Then all the "
+"scripts beginning with 'S' are run; these scripts start services. The two-"
+"digit number following the 'K' or 'S' indicates the order in which the "
+"script is run. Lower numbered scripts are executed first."
+msgstr ""
+"De scripts in elk van de <tt>/etc/rcN.d/</tt>-mappen zijn gewoon symbolische "
+"koppelingen naar scripts in <tt>/etc/init.d/</tt>. Het zijn echter de "
+"<em>namen</em> van de bestanden in elk van de <tt>/etc/rcN.d/</tt>-mappen "
+"die gebruikt worden om aan te geven op welke <em>wijze</em> de scripts in "
+"<tt>/etc/init.d/</tt> zullen uitgevoerd worden. Meer specifiek worden "
+"vooraleer een 'runlevel' binnengegaan wordt, alle scripts uitgevoerd die "
+"beginnen met 'K'. Dit zijn scripts die diensten doden. Daarna worden alle "
+"scripts die beginnen met 'S' uitgevoerd. Deze scripts starten diensten. Het "
+"uit twee cijfers bestaand getal dat na de 'K' of 'S' volgt, geeft de "
+"volgorde aan waarin het script uitgevoerd wordt. Scripts met het laagste "
+"getal worden eerst uitgevoerd."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:102
+msgid ""
+"This approach works because the scripts in <tt>/etc/init.d/</tt> all take an "
+"argument which can be either `start', `stop', `reload', `restart' or `force-"
+"reload' and will then do the task indicated by the argument. These scripts "
+"can be used even after a system has been booted, to control various "
+"processes."
+msgstr ""
+"Een dergelijke benadering werkt, omdat de scripts in <tt>/etc/init.d/</tt> "
+"allemaal een argument nodig hebben dat 'start', 'stop', 'reload', 'restart' "
+"of 'force-reload' kan zijn en dan de taak uitvoeren die door dat argument "
+"opgegeven wordt. Zelfs nadat een systeem opgestart werd kunnen deze scripts "
+"gebruikt worden om verschillende processen te controleren."
+
+#. type: <p><example>
+#: debian-faq.sgml:52 customizing.sgml:102
+msgid "For example, with the argument `reload' the command"
+msgstr "Bijvoorbeeld, met het argument 'reload' stuurt het commando"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:102
+#, no-wrap
+msgid "/etc/init.d/sendmail reload"
+msgstr "/etc/init.d/sendmail reload"
+
+#. type: </example></p>
+#: debian-faq.sgml:52 customizing.sgml:106
+msgid "sends the sendmail daemon a signal to reread its configuration file."
+msgstr ""
+"de sendmail-daemon het signaal om zijn configuratiebestand opnieuw in te "
+"lezen."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:109
+msgid ""
+"Note that <prgn>invoke-rc.d</prgn> should not be used to call the <tt>/etc/"
+"init.d/</tt> scripts, <prgn>service</prgn> should be used instead."
+msgstr ""
+"Merk op dat <prgn>invoke-rc.d</prgn> niet gebruikt zou moeten worden om de "
+"scripts uit <tt>/etc/init.d/</tt> aan te roepen. In plaats daarvan moet "
+"<prgn>service</prgn> gebruikt worden."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:113
+msgid ""
+"What other facilities are provided to customize the boot process besides "
+"<tt>rc.local</tt>?"
+msgstr ""
+"Welke andere voorzieningen worden er geboden om het opstartproces aan te "
+"passen, behalve <tt>rc.local</tt>?"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:118
+msgid ""
+"The <tt>rc.local</tt> script is executed at the end of each multiuser "
+"runlevel. In Debian it is configured to do nothing. This provides "
+"customisation of the boot process, but might not be sufficient for all "
+"situations."
+msgstr ""
+"Het script <tt>rc.local</tt> wordt uitgevoerd op het einde van elk runlevel "
+"in een meerdere-gebruikersmodus. In Debian staat het ingesteld om niets te "
+"doen. Dit geeft de mogelijkheid om het opstartproces aan te passen, maar het "
+"kan zijn dat dit niet voor alle situaties volstaat."
+
+#. type: <p><list>
+#: debian-faq.sgml:52 customizing.sgml:121
+msgid ""
+"Suppose a system needs to execute script <tt>foo</tt> on start-up, or on "
+"entry to a particular (System V) runlevel. Then the system administrator "
+"should:"
+msgstr ""
+"Veronderstel dat een systeem het script <tt>foo</tt> moet uitvoeren bij het "
+"opstarten of bij het binnengaan van een specifiek (System V) runlevel. Dan "
+"moet de systeembeheerder:"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:122
+msgid "Enter the script <tt>foo</tt> into the directory <tt>/etc/init.d/</tt>."
+msgstr "Het script <tt>foo</tt> toevoegen in de map <tt>/etc/init.d/</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:125
+msgid ""
+"Run the Debian command <tt>update-rc.d</tt> with appropriate arguments, to "
+"specify which runlevels should start the service, and which runlevels should "
+"stop the service."
+msgstr ""
+"Het Debian-commando <tt>update-rc.d</tt> met de passende argumenten "
+"uitvoeren om aan te geven bij welke runlevels de dienst gestart moet worden "
+"en bij welke runlevels de dienst gestopt moet worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:130
+msgid ""
+"Consider rebooting the system to check that the service starts correctly "
+"(assuming that you've asked for it to be started in the default runlevel). "
+"Otherwise, manually start it by running `<tt>/etc/init.d/foo start</tt>'."
+msgstr ""
+"Overweeg om het systeem opnieuw op te starten om na te gaan dat de dienst "
+"correct opstart (in de veronderstelling dat u gevraagd heeft dat het in het "
+"standaard-runlevel zou starten). Start het anders handmatig op met de "
+"opdracht '<tt>/etc/init.d/foo start</tt>'."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:145
+msgid ""
+"One might, for example, cause the script <tt>foo</tt> to execute at boot-up, "
+"by putting it in <tt>/etc/init.d/</tt> and running <tt>update-rc.d foo "
+"defaults 19</tt>. The argument `<tt>defaults</tt>' refers to the default "
+"runlevels, which means (at least in absence of any LSB comment block to the "
+"contrary) to start the service in runlevels 2 through 5, and to stop the "
+"service in runlevels 0, 1 and 6. (Any LSB Default-Start and Default-Stop "
+"directives in <tt>foo</tt> take precedence when using the sysv-rc version of "
+"update-rc.d, but are ignored by file-rc's variant (v0.8.10 and higher) of "
+"update-rc.d.) The argument `<tt>19</tt>' ensures that <tt>foo</tt> is called "
+"after all scripts whose number is less than 19 have completed, and before "
+"all scripts whose number is 20 or greater."
+msgstr ""
+"Men zou er bijvoorbeeld kunnen voor zorgen dat het script <tt>foo</tt> bij "
+"het opstarten van de computer gestart wordt door het in <tt>/etc/init.d/</"
+"tt> te plaatsen en de opdracht <tt>update-rc.d foo defaults 19</tt> te "
+"geven. Het argument '<tt>defaults</tt>' verwijst naar de standaard-"
+"runlevels, wat (ten minste bij afwezigheid van een anders luidend LSB-"
+"commentaarblok) het opstarten van de dienst in de runlevels 2 tot 5 "
+"impliceert en het stoppen van de dienst in de runlevels 0, 1 en 6. "
+"(Eventuele LSB Default-Start en Default-Stop directieven in <tt>foo</tt> "
+"hebben voorrang als de 'sysv-rc'-versie van update-rc.d gebruikt wordt, maar "
+"worden genegeerd door de 'file-rc'-variant (v0.8.10 en later) van update-rc."
+"d.) Het argument '<tt>19</tt>' zorgt ervoor dat <tt>foo</tt> aanroepen wordt "
+"nadat alle scripts waarvan het getal lager is dan 19, afgerond werden, en "
+"voor alle scripts met een getal groter of gelijk aan 20."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:148
+msgid ""
+"How does the package management system deal with packages that contain "
+"configuration files for other packages?"
+msgstr ""
+"Hoe gaat het systeem voor pakketbeheer om met pakketten die "
+"configuratiebestanden voor andere pakketten bevatten?"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:155
+msgid ""
+"Some users wish to create, for example, a new server by installing a group "
+"of Debian packages and a locally generated package consisting of "
+"configuration files. This is not generally a good idea, because <prgn>dpkg</"
+"prgn> will not know about those configuration files if they are in a "
+"different package, and may write conflicting configurations when one of the "
+"initial \"group\" of packages is upgraded."
+msgstr ""
+"Sommige gebruikers willen bijvoorbeeld een nieuwe server creÃ«ren door een "
+"groep Debian-pakketten te installeren evenals een lokaal gemaakt pakket dat "
+"uit configuratiebestanden bestaat. Dit is over het algemeen geen goed idee, "
+"omdat <prgn>dpkg</prgn> niet op de hoogte zal zijn van die "
+"configuratiebestanden die zich in een ander pakket bevinden, en dus mogelijk "
+"conflicterende configuraties kan neerschrijven wanneer een van de pakketten "
+"uit de initiÃ«le \"groep' opgewaardeerd wordt."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:162
+msgid ""
+"Instead, create a local package that modifies the configuration files of the "
+"\"group\" of Debian packages of interest. Then <prgn>dpkg</prgn> and the "
+"rest of the package management system will see that the files have been "
+"modified by the local \"sysadmin\" and will not try to overwrite them when "
+"those packages are upgraded."
+msgstr ""
+"Maak in de plaats daarvan een lokaal pakket dat de configuratiebestanden van "
+"de betreffende \"groep\" Debian-pakketten aanpast. Dan zal <prgn>dpkg</prgn> "
+"en de rest van het pakketbeheersysteem zien dat de bestanden gewijzigd "
+"werden door de lokale \"systeembeheerder\" en zullen ze geen poging doen om "
+"ze te overschrijven wanneer deze pakketten opgewaardeerd worden."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:165
+msgid ""
+"How do I override a file installed by a package, so that a different version "
+"can be used instead?"
+msgstr ""
+"Hoe omzeil ik een bestand dat door een pakket geÃ¯nstalleerd werd, zodat in "
+"de plaats van dat bestand een andere versie gebruikt kan worden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:169
+msgid ""
+"Suppose a sysadmin or local user wishes to use a program \"login-local\" "
+"rather than the program \"login\" provided by the Debian <package>login</"
+"package> package."
+msgstr ""
+"Verondersel dat een systeembeheerder of een lokale gebruiker liever een "
+"programma \"lokale-login\" wil gebruiken in plaats van het programma \"login"
+"\" warin door het Debian-pakket <package>login</package> voorzien wordt."
+
+#. type: <p><list>
+#: debian-faq.sgml:52 customizing.sgml:170
+msgid "Do <strong>not</strong>:"
+msgstr "Overschrijf"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:172
+msgid "Overwrite <tt>/bin/login</tt> with <tt>login-local</tt>."
+msgstr "<tt>/bin/login</tt> <strong>niet</strong> met <tt>lokale-login</tt>."
+
+#. type: </list></p>
+#: debian-faq.sgml:52 customizing.sgml:177
+msgid ""
+"The package management system will not know about this change, and will "
+"simply overwrite your custom <tt>/bin/login</tt> whenever <tt>login</tt> (or "
+"any package that provides <tt>/bin/login</tt>) is installed or updated."
+msgstr ""
+"Het systeem voor pakketbeheer zal geen kennis hebben van deze wijziging en "
+"zal uw aangepaste <tt>/bin/login</tt> gewoon overschrijven als het pakket "
+"<tt>login</tt> (of elk pakket dat voorziet in <tt>/bin/login</tt>) "
+"geÃ¯nstalleerd of opgewaardeerd wordt."
+
+#. type: <p><list>
+#: debian-faq.sgml:52 customizing.sgml:178
+msgid "Rather, do"
+msgstr "Doe liever het volgende:"
+
+#. type: <p><example>
+#: debian-faq.sgml:52 customizing.sgml:179
+msgid "Execute:"
+msgstr "Geef de opdracht:"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:179
+#, no-wrap
+msgid "dpkg-divert --divert /bin/login.debian /bin/login"
+msgstr "dpkg-divert --divert /bin/login.debian /bin/login"
+
+#. type: </example></p>
+#: debian-faq.sgml:52 customizing.sgml:183
+msgid ""
+"in order to cause all future installations of the Debian <package>login</"
+"package> package to write the file <tt>/bin/login</tt> to <tt>/bin/login."
+"debian</tt> instead."
+msgstr ""
+"om er voor te zorgen dat alle toekomstige installaties van het Debian-pakket "
+"<package>login</package> het bestand <tt>/bin/login</tt> naar <tt>/bin/login."
+"debian</tt> schrijven."
+
+#. type: <p><example>
+#: debian-faq.sgml:52 customizing.sgml:184
+msgid "Then execute:"
+msgstr "Voer dan de volgende opdracht uit:"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:179
+#, no-wrap
+msgid "cp login-local /bin/login"
+msgstr "cp login-local /bin/login"
+
+#. type: </example></p>
+#: debian-faq.sgml:52 customizing.sgml:187
+msgid "to move your own locally-built program into place."
+msgstr "om uw eigen lokaal gebouwd programma op zijn plaats te zetten."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:192
+msgid ""
+"Run <tt>dpkg-divert --list</tt> to see which diversions are currently active "
+"on your system."
+msgstr ""
+"Gebruik de opdracht <tt>dpkg-divert --list</tt> om te zien welke afgeleiden "
+"er momenteel actief zijn op uw systeem."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:194
+msgid ""
+"Details are given in the manual page <manref name=\"dpkg-divert\" section="
+"\"8\">."
+msgstr ""
+"Meer informatie wordt gegeven in de man-pagina <manref name=\"dpkg-divert\" "
+"section=\"8\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:198
+msgid ""
+"How can I have my locally-built package included in the list of available "
+"packages that the package management system knows about?"
+msgstr ""
+"Hoe kan ik mijn lokaal gebouwd pakket opgenomen krijgen in de lijst van "
+"beschikbare pakketten waar het pakketbeheersysteem weet heeft?"
+
+#. type: <p><example>
+#: debian-faq.sgml:52 customizing.sgml:200
+msgid "Execute the command:"
+msgstr "Geef de opdracht:"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:202
+#, no-wrap
+msgid "dpkg-scanpackages BIN_DIR OVERRIDE_FILE [PATHPREFIX] > my_Packages"
+msgstr "dpkg-scanpackages BIN_DIR OVERRIDE_FILE [PATHPREFIX] > mijn_Pakketten"
+
+#. type: <p><list>
+#: debian-faq.sgml:52 customizing.sgml:204
+msgid "where:"
+msgstr "waarbij"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:207
+msgid ""
+"BIN-DIR is a directory where Debian archive files (which usually have an "
+"extension of \".deb\") are stored."
+msgstr ""
+"BIN-DIR een map is waar Debian-archiefbestanden (die gewoonlijk de extensie "
+"\".deb\" hebben) opgeslagen worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:211
+msgid ""
+"OVERRIDE_FILE is a file that is edited by the distribution maintainers and "
+"is usually stored on a Debian FTP archive at <tt>indices/override.main.gz</"
+"tt> for the Debian packages in the \"main\" distribution. You can ignore "
+"this for local packages."
+msgstr ""
+"OVERRIDE_FILE een bestand is dat bewerkt door de onderhouders van de "
+"distributie en gewoonlijk opgeslagen wordt op een Debian FTP-archief in "
+"<tt>indices/override.main.gz</tt> voor de Debian-pakketten in de distributie "
+"\"main\". Voor lokale pakketten kunt u dit negeren."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:213
+msgid ""
+"PATHPREFIX is an <em>optional</em> string that can be prepended to the "
+"<tt>my_Packages</tt> file being produced."
+msgstr ""
+"PATHPREFIX een <em>optionele</em> tekenreeks is die vooraan toegevoegd kan "
+"worden voor <tt>mijn_Pakketten</tt>, het bestand dat aangemaakt wordt."
+
+#. type: <p><example>
+#: debian-faq.sgml:52 customizing.sgml:219
+msgid ""
+"Once you have built the file <tt>my_Packages</tt>, tell the package "
+"management system about it by using the command:"
+msgstr ""
+"Eens u het bestand <tt>mijn_Pakketten</tt> gebouwd heeft, moet u het "
+"pakketbeheersysteem erover informeren door het volgende commando te "
+"gebruiken:"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:221
+#, no-wrap
+msgid "dpkg --merge-avail my_Packages"
+msgstr "dpkg --merge-avail mijn_Pakketten"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:226
+msgid ""
+"If you are using APT, you can add the local repository to your <manref name="
+"\"sources.list\" section=\"5\"> file, too."
+msgstr ""
+"Indien u APT gebruikt, kunt u ook de lokale pakketbron toevoegen aan uw "
+"bestand <manref name=\"sources.list\" section=\"5\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:52 customizing.sgml:230
+msgid ""
+"Some users like mawk, others like gawk; some like vim, others like elvis; "
+"some like trn, others like tin; how does Debian support diversity?"
+msgstr ""
+"Dommige gebruikers houden van mawk, anderen houden van gawk; sommigen houden "
+"van vim, anderen houden van elvis; sommigen houden van trn, anderen houden "
+"van tin. Hoe ondersteunt Debian diversiteit?"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:236
+msgid ""
+"There are several cases where two packages provide two different versions of "
+"a program, both of which provide the same core functionality. Users might "
+"prefer one over another out of habit, or because the user interface of one "
+"package is somehow more pleasing than the interface of another. Other users "
+"on the same system might make a different choice."
+msgstr ""
+"Er zijn verschillende gevallen waarin twee pakketten voorzien in twee "
+"verschillenden versies van een programma, die beide dezelfde "
+"kernfunctionaliteit bieden. Gebruikers kunnen het ene verkiezen boven het "
+"andere uit gewoonte of omdat de gebruikersinterface van het ene pakket iets "
+"meer bevalt dan die van het andere. Andere gebruikers op hetzelfde systeem "
+"kunnen een andere keuze maken."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:241
+msgid ""
+"Debian uses a \"virtual\" package system to allow system administrators to "
+"choose (or let users choose) their favorite tools when there are two or more "
+"that provide the same basic functionality, yet satisfy package dependency "
+"requirements without specifying a particular package."
+msgstr ""
+"Debian gebruikt een \"virtueel\" pakketsysteem om systeembeheerders toe te "
+"laten hun voorkeursgereedschappen te kiezen (of de gebruikers deze te laten "
+"kiezen) als er twee of meer zijn die dezelfde basisfunctionaliteit bieden, "
+"en om zonder een specifiek pakket op te geven, toch te voldoen aan de "
+"vereisten inzake pakketafhankelijkheden."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:251
+msgid ""
+"For example, there might exist two different versions of newsreaders on a "
+"system. The news server package might 'recommend' that there exist <em>some</"
+"em> news reader on the system, but the choice of <tt>tin</tt> or <tt>trn</"
+"tt> is left up to the individual user. This is satisfied by having both the "
+"<package>tin</package> and <package>trn</package> packages provide the "
+"virtual package <package>news-reader</package>. <em>Which</em> program is "
+"invoked is determined by a link pointing from a file with the virtual "
+"package name <tt>/etc/alternatives/news-reader</tt> to the selected file, e."
+"g., <tt>/usr/bin/trn</tt>."
+msgstr ""
+"Er zouden op een systeem bijvoorbeeld twee verschillende versies van een "
+"nieuwslezerprogramma kunnen staan. Het nieuwsserverpakket kan de "
+"aanwezigheid op het systeem van <em>een</em> nieuwslezer 'aanbevelen', maar "
+"de keuze tussen <tt>tin</tt> en <tt>trn</tt> wordt overgelaten aan de "
+"individuele gebruiker. Aan de aanbeveling wordt voldaan door zowel het "
+"pakket <package>tin</package> als het pakket <package>trn</package> te laten "
+"voorzien in het virtuele pakket <package>news-reader</package>. <em>Welk</"
+"em> programma aanroepen wordt, wordt bepaald door een koppeling die van een "
+"bestand met de virtuele pakketnaam <tt>/etc/alternatives/news-reader</tt> "
+"verwijst naar het gekozen bestand, bijv. <tt>/usr/bin/trn</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:257
+msgid ""
+"A single link is insufficient to support full use of an alternate program; "
+"normally, manual pages, and possibly other supporting files must be selected "
+"as well. The Perl script <tt>update-alternatives</tt> provides a way of "
+"ensuring that all the files associated with a specified package are selected "
+"as a system default."
+msgstr ""
+"Een enkele koppeling volstaat niet om het gebruik van een alternatief "
+"programma ten volle te ondersteunen. Normaal moeten ook man-pagina's, en "
+"eventuele andere ondersteunende bestanden ook geselecteerd worden. Het Perl-"
+"script <tt>update-alternatives</tt> biedt een manier om ervoor te zorgen dat "
+"alle bestanden die met een opgegeven pakket verband houden, geselecteerd "
+"worden als de systeemstandaard."
+
+#. type: <p><example>
+#: debian-faq.sgml:52 customizing.sgml:257
+msgid "For example, to check what executables provide `x-window-manager', run:"
+msgstr ""
+"Om bijvoorbeeld na te gaan welke uitvoerbare bestanden voorzien in 'x-window-"
+"manager', geeft u de opdracht:"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:257
+#, no-wrap
+msgid "update-alternatives --display x-window-manager"
+msgstr "update-alternatives --display x-window-manager"
+
+#. type: </example><example>
+#: debian-faq.sgml:52 customizing.sgml:259
+msgid "If you want to change it, run:"
+msgstr "Indien u dit wenst te veranderen, geef dan het commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:257
+#, no-wrap
+msgid "update-alternatives --config x-window-manager"
+msgstr "update-alternatives --config x-window-manager"
+
+#. type: </example></p>
+#: debian-faq.sgml:52 customizing.sgml:264
+msgid ""
+"And follow the instructions on the screen (basically, press the number next "
+"to the entry you'd like better)."
+msgstr ""
+"en volg de instructies op het scherm (eigenlijk het cijfer invoeren dat "
+"naast het item staat dat u meer verkiest)."
+
+#. type: <p><example>
+#: debian-faq.sgml:52 customizing.sgml:267
+msgid ""
+"If a package doesn't register itself as a window manager for some reason "
+"(file a bug if it's in error), or if you use a window manager from /usr/"
+"local directory, the selections on screen won't contain your preferred "
+"entry. You can update the link through command line options, like this:"
+msgstr ""
+"Indien een pakket om een of andere reden zichzelf niet als 'window manager' "
+"bekendmaakt (stel een bugrapport op als dit een fout is), of indien u een "
+"windowmanager uit de map /usr/local gebruikt, zullen de keuzemogelijkheden "
+"op het scherm uw voorkeurprogramma niet vermelden. U kunt de koppeling "
+"bijwerken via commandoregelopties zoals deze:"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:264
+#, no-wrap
+msgid ""
+"update-alternatives --install /usr/bin/x-window-manager \\\n"
+"  x-window-manager /usr/local/bin/wmaker-cvs 50"
+msgstr ""
+"update-alternatives --install /usr/bin/x-window-manager \\\n"
+"  x-window-manager /usr/local/bin/wmaker-cvs 50"
+
+#. type: <p></p>
+#: debian-faq.sgml:52 customizing.sgml:277
+msgid ""
+"The first argument to `--install' option is the symlink that points to /etc/"
+"alternatives/NAME, where NAME is the second argument. The third argument is "
+"the program to which /etc/alternatives/NAME should point to, and the fourth "
+"argument is the priority (larger value means the alternative will more "
+"probably get picked automatically)."
+msgstr ""
+"Het eerste argument voor de optie '--install' is de symbolische koppeling "
+"die wijst naar /etc/alternatives/NAAM, waarbij NAAM het tweede argument is. "
+"Het derde argument is het programma waarnaar /etc/alternatives/NAAM moet "
+"verwijzen en het vierde argument is de prioriteit (hogere waarden betekenen "
+"een grotere kans dat het alternatief automatisch uitgekozen wordt)."
+
+#. type: <p><example>
+#: debian-faq.sgml:52 customizing.sgml:277
+msgid "To remove an alternative you added, simply run:"
+msgstr ""
+"Om een alternatief dat u toevoegde, te verwijderen, geeft u gewoon het "
+"commando:"
+
+#. type: <example></example>
+#: debian-faq.sgml:52 customizing.sgml:277
+#, no-wrap
+msgid "update-alternatives --remove x-window-manager /usr/local/bin/wmaker-cvs"
+msgstr "update-alternatives --remove x-window-manager /usr/local/bin/wmaker-cvs"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:5
+msgid "Getting support for &debian;"
+msgstr "Ondersteuning krijgen voor &debian;"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:8
+msgid "What other documentation exists on and for a Debian system?"
+msgstr "Welke andere documentatie bestaat er o en voor een Debian-systeem?"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:10
+msgid ""
+"Installation instructions for the current release: see <url id=\"http://www."
+"debian.org/releases/stable/installmanual\">."
+msgstr ""
+"Installatie-instructies voor de huidige release: zie <url id=\"http://www."
+"debian.org/releases/stable/installmanual\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:14
+msgid ""
+"The Debian GNU/Linux reference covers many aspects of system administration "
+"through shell-command examples. Basic tutorials, tips, and other information "
+"are provided for many different topics ranging from system administration to "
+"programming."
+msgstr ""
+"De Debian GNU/Linux referentiehandleiding behandelt veel aspecten van "
+"systeembeheer via voorbeelden met shell-opdrachten. Er worden elementaire "
+"inleidingen, tips, en andere informatie gegeven over veel verschillende "
+"onderwerpen, gaande van systeembeheer tot programmeren."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:16
+msgid ""
+"Get it from the <package>debian-reference</package> package, or at <url id="
+"\"http://www.debian.org/doc/user-manuals#quick-reference\">."
+msgstr ""
+"U vindt ze in het pakket <package>debian-reference</package> en op <url id="
+"\"http://www.debian.org/doc/user-manuals#quick-reference\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:22
+msgid ""
+"The Debian Policy manual documents the policy requirements for the "
+"distribution, i.e. the structure and contents of the Debian archive, several "
+"design issues of the operating system etc. It also includes the technical "
+"requirements that each package must satisfy to be included in the "
+"distribution, and documents the basic technical aspects of Debian binary and "
+"source packages."
+msgstr ""
+"Het Debian beleidshandboek beschrijft de beleidsmatige vereisten waaraan een "
+"distributie moet beantwoorden, met name de structuur en de inhoud van het "
+"Debian-archief, verschillende elementen in verband met het ontwerp van het "
+"besturingssysteem, enz. Het bevat ook de technische vereisten waaraan elk "
+"pakket moet beantwoorden om in de distributie opgenomen te worden en "
+"beschrijft de technische basisaspecten van binaire en bronpakketten in "
+"Debian."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:24
+msgid ""
+"Get it from the <package>debian-policy</package> package, or at <url id="
+"\"http://www.debian.org/doc/devel-manuals#policy\">."
+msgstr ""
+"U vindt het in het pakket <package>debian-policy</package> of op <url id="
+"\"http://www.debian.org/doc/devel-manuals#policy\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:28
+msgid ""
+"Documentation developed by the Debian Documentation Project. It is available "
+"at <url id=\"http://www.debian.org/doc/\"> and includes user guides, "
+"administration guides and security guides for the Debian GNU/Linux operating "
+"system."
+msgstr ""
+"Documentatie die ontwikkeld werd door het Debian Documentatieproject. Ze is "
+"te vinden op  <url id=\"http://www.debian.org/doc/\"> en bevat "
+"gebruikershandleidingen, systeembeheerhandleidingen en "
+"beveiligingshandleidingen voor het besturingssysteem Debian GNU/Linux."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:30
+msgid ""
+"Documentation on installed Debian packages: Most packages have files that "
+"are unpacked into <tt>/usr/share/doc/PACKAGE</tt>."
+msgstr ""
+"Documentatie over geÃ¯nstalleerde Debian-pakketten: de meeste pakketten "
+"bevatten bestanden die uitgepakt worden in <tt>/usr/share/doc/PAKKET</tt>."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:34
+msgid ""
+"Documentation on the Linux project: The Debian package <package>doc-linux</"
+"package> installs all of the most recent versions of the HOWTOs and mini-"
+"HOWTOs from the <url id=\"http://www.tldp.org/\" name=\"Linux Documentation "
+"Project\">."
+msgstr ""
+"Documentatie over het Linux-project: Het pakket <package>doc-linux</package> "
+"van Debian installeert alle meest recente versies van HOWTO's en mini-"
+"HOWTO's van het <url id=\"http://www.tldp.org/\" name=\"Linux Documentation "
+"Project\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:39
+msgid ""
+"Unix-style `man' pages: Most commands have manual pages written in the style "
+"of the original Unix 'man' files. For instance, to see the manual page for "
+"the command `ls', execute <tt>man ls</tt>. Execute <tt>man man</tt> for more "
+"information on finding and viewing manual pages."
+msgstr ""
+"'Man'-pagina's in de trant van Unix: voor de meeste commando's bestaan man-"
+"pagina's die geschreven werden naar het model van de originele 'man'-"
+"bestanden van Unix. Om bijvoorbeeld de man-pagina te zien van het commando "
+"'ls', geeft u de opdracht <tt>man ls</tt>. Geef de opdracht <tt>man man</tt> "
+"voor bijkomende informatie over het vinden en bekijken van man-pagina's."
+
+#. type: <p><list>
+#: debian-faq.sgml:53 support.sgml:41
+msgid ""
+"New Debian users should note that the 'man' pages of many general system "
+"commands are not available until they install these packages:"
+msgstr ""
+"Gebruikers voor wie Debian nieuw is, moeten weten dat de 'man'-pagina's van "
+"vele algemene systeemopdrachten pas beschikbaar zijn nadat deze pakketten "
+"geÃ¯nstalleerd zijn:"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:44
+msgid ""
+"<tt>man-db</tt>, which contains the <tt>man</tt> program itself, and other "
+"programs for manipulating the manual pages."
+msgstr ""
+"<tt>man-db</tt>, dat het <tt>man</tt>-programma zelf bevat en andere "
+"programma's voor het manipuleren van man-pagina's."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:46
+msgid ""
+"<tt>manpages</tt>, which contains the system manual pages. (see <ref id="
+"\"nonenglish\">)."
+msgstr ""
+"<tt>manpages</tt>, dat de systeem-man-pagina's bevat. (zie <ref id="
+"\"nonenglish\">)."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:51
+msgid ""
+"GNU-style `info' pages: User documentation for many commands, particularly "
+"GNU tools, is available not in `man' pages, but in `info' files which can be "
+"read by the GNU tool <tt>info</tt>, by running <tt>M-x info</tt> within GNU "
+"Emacs, or with some other Info page viewer."
+msgstr ""
+"'Info'-pagina's in de trant van GNU: gebruikersdocumentatie voor heel wat "
+"commando's, in het bijzonder de GNU-gereedschappen, is niet te vinden in "
+"'man'-pagina's, maar in 'info'-bestanden die gelezen kunnen worden met het "
+"GNU-gereedschap <tt>info</tt>, via het commando <tt>M-x info</tt> in GNU "
+"Emacs of met een ander programma voor het weergeven van Info-pagina's."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:56
+msgid ""
+"Its main advantage over the original `man' pages is that it is a hypertext "
+"system. It does <em>not</em> require the WWW, however; <tt>info</tt> can be "
+"run from a plain text console. It was designed by Richard Stallman and "
+"preceded the WWW."
+msgstr ""
+"Het belangrijkste voordeel tegenover de originele 'man'-pagina's is dat het "
+"een hypertekst-systeem betreft. Het heeft echter <em>geen</em> WWW nodig; "
+"<tt>info</tt> kan uitgevoerd worden in een gewone tekstconsole. Het werd "
+"ontworpen door Richard Stallman en is ouder dan WWW."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:62
+msgid ""
+"Note that you may access a lot of documentation on your system by using a "
+"WWW browser, through `dwww', `dhelp' or `doccentral' commands, found in "
+"respective packages, or by using `yelp'."
+msgstr ""
+"Merk op dat u heel wat documentatie op uw systeem kunt lezen met een WWW-"
+"browser via de commando's 'dwww', 'dhelp' en 'doccentral' die in hun "
+"respectieve pakketten te vinden zijn, of via het commando 'yelp'."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:65
+msgid "Are there any on-line resources for discussing Debian?"
+msgstr "Bestaan er online-hulpbronnen waar over Debian gepraat wordt?"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:70
+msgid ""
+"Yes. In fact, the main method of support Debian provides to our users is by "
+"the way of e-mail. We'll give some details on that, and mention some other "
+"useful resources. Even more resources are listed at the <url id=\"http://www."
+"debian.org/support\" name=\"Debian Support webpage\">."
+msgstr ""
+"Ja. In feite is de belangrijkste manier die Debian gebruikt om ondersteuning "
+"te bieden aan zijn gebruikers via e-mail. We zullen daarover wat informatie "
+"geven en enkele andere nuttige hulpbronnen vermelden. Er worden zelfs nog "
+"meer bronnen vermeld op de <url id=\"http://www.debian.org/support\" name="
+"\"webpagina over Ondersteuning voor Debian\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:72
+msgid "Mailing lists"
+msgstr "Mailinglijsten"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:75
+msgid ""
+"There are a lot of <url id=\"http://www.debian.org/MailingLists/\" name="
+"\"Debian-related mailing lists\">."
+msgstr ""
+"Er bestaan een heleboel <url id=\"http://www.debian.org/MailingLists/\" name="
+"\"mailinglijsten die verband houden met Debian\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:79
+msgid ""
+"On a system with the <package>doc-debian</package> package installed there "
+"is a complete list of mailing lists in <file>/usr/share/doc/debian/mailing-"
+"lists.txt</file>."
+msgstr ""
+"Op een systeem waarop het pakket <package>doc-debian</package> geÃ¯nstalleerd "
+"is, bevat het bestand <file>/usr/share/doc/debian/mailing-lists.txt</file> "
+"een volledige lijst met mailinglijsten.."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:90
+msgid ""
+"Debian mailing lists are named following the pattern debian-<var>list-"
+"subject</var>. Examples are debian-announce, debian-user, debian-news. To "
+"subscribe to any list debian-<var>list-subject</var>, send mail to debian-"
+"<var>list-subject</var>-request@lists.debian.org with the word \"subscribe\" "
+"in the Subject: header. Be sure to remember to add <em>-request</em> to the "
+"e-mail address when using this method to subscribe or unsubscribe. Otherwise "
+"your e-mail will go to the list itself, which could be embarrassing or "
+"annoying, depending on your point of view."
+msgstr ""
+"Mailinglijsten van Debian krijgen een naam volgens het patroon debian-"
+"<var>lijst-onderwerp</var>. Voorbeelden zijn debian-announce, debian-user, "
+"debian-news. Om in te schrijven op een van de debian-<var>lijst-onderwerp</"
+"var>-lijsten moet u een e-mail sturen naar debian-<var>lijst-onderwerp</var>-"
+"request@lists.debian.org met het woord \"subscribe\" in het kopveld "
+"Onderwerp:. Zorg ervoor om <em>-request</em> toe te voegen aan het e-"
+"mailadres als u deze methode gebruikt om in te tekenen of uit te schrijven. "
+"Anders gaat uw e-mailbericht naar de lijst zelf, wat, afhankelijk van uit "
+"welk perspectief u het bekijkt, pijnlijk of storend kan zijn."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:96
+msgid ""
+"You can subscribe to mailing lists using the <url id=\"http://www.debian.org/"
+"MailingLists/subscribe\" name=\"WWW form\">. You can also un-subscribe using "
+"a <url id=\"http://www.debian.org/MailingLists/unsubscribe\" name=\"WWW form"
+"\">."
+msgstr ""
+"U kunt ook intekenen op mailinglijsten met het <url id=\"http://www.debian."
+"org/MailingLists/subscribe\" name=\"Web-formulier\">. U kunt zich ook "
+"uitschrijven met een <url id=\"http://www.debian.org/MailingLists/unsubscribe"
+"\" name=\"Web-formulier\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:99
+msgid ""
+"The list manager's e-mail address is <email>listmaster@lists.debian.org</"
+"email>, in case you have any trouble."
+msgstr ""
+"Het e-mailadres van de lijstbeheerder is <email>listmaster@lists.debian.org</"
+"email>, mocht u problemen ondervinden."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:108
+msgid ""
+"The mailing lists are public forums. All e-mails sent to the lists are also "
+"copied to the public archive, for anybody (even non-subscribers) to browse "
+"or search. Please make sure you never send any confidential or unlicensed "
+"material to the lists. This includes things like e-mail addresses. Of "
+"particular note is the fact that spammers have been known to abuse e-mail "
+"addresses posted to our mailing lists. See the <url id=\"http://www.debian."
+"org/MailingLists/#disclaimer\" name=\"Mailing Lists Privacy policy\"> for "
+"more information."
+msgstr ""
+"De mailinglijsten zijn publieke fora. Alle e-mails die naar de lijsten "
+"verstuurd worden, worden ook naar de publieke archieven gekopieerd, waar "
+"iedereen (ook wie niet ingetekend heeft) ze kan doorbladeren en doorzoeken. "
+"Zorg er daarom voor om nooit confidentiÃ«le informatie of niet-toegelaten "
+"materiaal naar de lijsten te sturen. Daaronder vallen ook zaken zoals e-"
+"mailadressen. Van bijzonder belang is het feit dat bekend is dat spammers "
+"misbruik gemaakt hebben van e-mailadressen die op onze mailinglijsten gepost "
+"werden. Zie voor meer informatie het <url id=\"http://www.debian.org/"
+"MailingLists/#disclaimer\" name=\"Privacy-beleid voor de mailinglijsten\">"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:111
+msgid ""
+"Archives of the Debian mailing lists are available via WWW at <url id="
+"\"http://lists.debian.org/\">."
+msgstr ""
+"De archieven van de mailinglijsten van Debian zijn toegankelijk via WWW op "
+"<url id=\"http://lists.debian.org/\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:114
+msgid "What is the code of conduct for the mailing lists?"
+msgstr "Welke gedragscode geldt er voor de mailinglijsten?"
+
+#. type: <p><list>
+#: debian-faq.sgml:53 support.sgml:116
+msgid "When using the Debian mailing lists, please follow these rules:"
+msgstr ""
+"Als u de mailinglijsten van Debian gebruikt, wees dan zo vriendelijk om deze "
+"richtlijnen te volgen:"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:118
+msgid ""
+"Do not send spam. See the <url id=\"http://www.debian.org/MailingLists/#ads"
+"\" name=\"Debian mailing list advertising policy\">."
+msgstr ""
+"Zend geen spam. Zie het <url id=\"http://www.debian.org/MailingLists/#ads\" "
+"name=\"Reclamebeleid op de mailinglijsten van Debian\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:121
+msgid ""
+"Do not flame; it is not polite. The people developing Debian are all "
+"volunteers, donating their time, energy and money in an attempt to bring the "
+"Debian project together."
+msgstr ""
+"Wind u niet op, dat is niet beleefd. De mensen die Debian ontwikkelen zijn "
+"allen vrijwilligers die hun tijd, energie en geld investeren in een streven "
+"om het Debian-project te realiseren."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:123
+msgid ""
+"Do not use foul language; besides, some people receive the lists via packet "
+"radio, where swearing is illegal."
+msgstr ""
+"Gebruik geen schuttentaal. Trouwens, sommige mensen ontvangen de lijsten via "
+"GPRS (General Packet Radio Service), waarop men niet mag vloeken."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:126
+msgid ""
+"Make sure that you are using the proper list. <em>Never</em> post your "
+"(un)subscription requests to the mailing list itself.<footnote><p>Use the "
+"debian-<var>list-subject</var>-REQUEST@lists.debian.org address for that.</"
+"p></footnote>"
+msgstr ""
+"Zorg ervoor de passende lijst te gebruiken. Stuur uw vraag om in te tekenen/"
+"uit te schrijven <em>nooit</em> naar de mailinglijst zelf."
+"<footnote><p>Gebruik daarvoor het adres debian-<var>lijst-onderwerp</var>-"
+"REQUEST@lists.debian.org.</p></footnote>"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:128
+msgid "See section <ref id=\"bugreport\"> for notes on reporting bugs."
+msgstr ""
+"Zie het hoofdstuk <ref id=\"bugreport\"> voor notities over het rapporteren "
+"van bugs."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:132
+msgid "Web forums"
+msgstr "Webforums"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:137
+msgid ""
+"<url id=\"http://debianhelp.org/\" name=\"debianHELP\"> and <url id=\"http://"
+"forums.debian.net/\" name=\"Debian User Forums\"> are web forums on which "
+"you can submit questions about Debian and have them answered by other users. "
+"(These are not officially part of the Debian project.)"
+msgstr ""
+"<url id=\"http://debianhelp.org/\" name=\"debianHELP\"> and <url id=\"http://"
+"forums.debian.net/\" name=\"Debian Gebruikersforums\"> zijn webforums waarop "
+"u vragen over Debian kunt stellen en waarop andere gebruikers kunnen "
+"antwoorden. (Zijn maken formeel geen deel uit van het Debian-project.)"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:139
+msgid "Wiki"
+msgstr "Wiki"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:143
+msgid ""
+"Solutions to common problems, howtos, guides, tips and other documentation "
+"can be found at the constantly changing <url id=\"http://wiki.debian.org/\" "
+"name=\"Debian Wiki\">."
+msgstr ""
+"Oplossingen voor gebruikelijke peoblemen, howto's, handleidingen, tips en "
+"andere documentatie is te vinden op de permanent bijgewerkte pagina's van "
+"<url id=\"http://wiki.debian.org/\" name=\"Debian Wiki\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:145
+msgid "Maintainers"
+msgstr "Onderhouders"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:149
+msgid ""
+"Users can address questions to individual package maintainers using e-mail. "
+"To reach a maintainer of a package called xyz, send e-mail to "
+"<em>xyz@packages.debian.org</em>."
+msgstr ""
+"Gebruikers kunnen via e-mail een vraag stellen aan een individuele "
+"pakketonderhouder. Om de onderhouder van een pakket met de naam xyz te "
+"contacteren, moet u een e-mail sturen naar <em>xyz@packages.debian.org</em>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:151
+msgid "Usenet newsgroups"
+msgstr "Usenet-nieuwsgroepen"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:158
+msgid ""
+"Users should post non-Debian-specific questions to one of the Linux USENET "
+"groups, which are named comp.os.linux.* or linux.*. There are several lists "
+"of Linux Usenet newsgroups and other related resources on the WWW, e.g. on "
+"the <url id=\"http://www.linux.org/docs/usenet.html\" name=\"Linux Online\"> "
+"and <url id=\"http://www.linuxjournal.com/helpdesk.php\" name=\"LinuxJournal"
+"\"> sites."
+msgstr ""
+"Gebruikers moeten vragen die niet specifiek betrekking hebben op Debian "
+"stellen in een van de USENWT-groepen over Linux, die een naam hebben met "
+"comp.os.linux.* of linux.*. Op het WWW bestaan verschillende lijsten van "
+"Linux Usenet-nieuwsgroepen en andere verwante hulpbronnen, bijvoorbeeld op "
+"de sites <url id=\"http://www.linux.org/docs/usenet.html\" name=\"Linux "
+"Online\"> en <url id=\"http://www.linuxjournal.com/helpdesk.php\" name="
+"\"LinuxJournal\">"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:161
+msgid "Is there a quick way to search for information on &debian;?"
+msgstr ""
+"Bestaat eer een snelle manier om informatie over &debian; op te zoeken?"
+
+#. type: <p><list>
+#: debian-faq.sgml:53 support.sgml:164
+msgid ""
+"There is a variety of search engines that serve documentation related to "
+"Debian:"
+msgstr ""
+"Er bestaat een verscheidenheid aan zoekrobotten die documentatie in verband "
+"met Debian verschaffen:"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:166
+msgid "<url id=\"http://search.debian.org/\" name=\"Debian WWW search site\">."
+msgstr ""
+"<url id=\"http://search.debian.org/\" name=\"Zoekmachine voor de Website van "
+"Debian\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:169
+msgid ""
+"<url id=\"http://groups.google.com/\" name=\"Google Groups\">: a search "
+"engine for newsgroups."
+msgstr ""
+"<url id=\"http://groups.google.com/\" name=\"Google Groups\">: een "
+"zoekmachine voor nieuwsgroepen."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:176
+msgid ""
+"For example, to find out what experiences people have had with finding "
+"drivers for NVIDIA graphic cards under Debian, try searching the phrase "
+"<tt>NVIDIA Linux driver</tt>. This will show you all the posts that contain "
+"these strings, i.e. those where people discussed these topics. If you add "
+"<tt>Debian</tt> to those search strings, you'll also get the posts "
+"specifically related to Debian."
+msgstr ""
+"Om bijvoorbeeld te weten welke ervaringen mensen gehad hebben bij het zoeken "
+"naar stuurprogramma's in Debian voor de grafische kaarten van Debian, kunt u "
+"de vraag <tt>NVIDIA Linux driver</tt> invoeren in de zoekrobot. Dit zal alle "
+"berichten tonen waarin deze woorden terugkomen, d.w.z. die waarin mensen "
+"deze onderwerpen bespraken. Indien u aan deze zoekvraag ook <tt>Debian</tt> "
+"toevoegt, zult u ook die berichten krijgen die specifiek op Debian "
+"betrekking heeft."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:181
+msgid ""
+"Any of the common web spidering engines, such as <url id=\"https://"
+"duckduckgo.com/\" name=\"DuckDuckGo\"> or <url id=\"http://www.google.com/\" "
+"name=\"Google\">, as long as you use the right search terms."
+msgstr ""
+"Een van de gebruikelijke zoekrobotten op het internet, zoals <url id="
+"\"https://duckduckgo.com/\" name=\"DuckDuckGo\"> of <url id=\"http://www."
+"google.com/\" name=\"Google\">, zolang u maar de juiste zoektermen gebruikt."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:185
+msgid ""
+"For example, searching on the string \"evince\" gives a more detailed "
+"explanation of this package than the brief description field in its control "
+"file."
+msgstr ""
+"Als u bijvoorbeeld zoekt met het woord \"evince\", zult u een meer "
+"uitgebreide uitleg over dit pakket vinden dan de beperkte beschrijving uit "
+"een veld van zijn control-bestand."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:189
+msgid "Are there logs of known bugs?"
+msgstr "Worden er logboeken bijgehouden over bekende bugs?"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:193
+msgid ""
+"Reports on unsolved (and closed) issues are publicly available: Debian "
+"promissed to do so by stating \"We will not hide problems\" in the <url id="
+"\"http://www.debian.org/social_contract\" name=\"Debian Social Contract\">."
+msgstr ""
+"Er wordt op een publiekelijk toegankelijke wijze gerapporteerd over "
+"onopgeloste (en afgesloten) problemen: Debian maakte de belofte om zo te "
+"werk te gaan door in het <url id=\"http://www.debian.org/social_contract\" "
+"name=\"Sociale Contract van Debian\"> voorop te stellen: \"We zullen geen "
+"problemen verborgen houden\"."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:197
+msgid ""
+"The &debian; distribution has a bug tracking system (BTS) which files "
+"details of bugs reported by users and developers. Each bug is given a "
+"number, and is kept on file. Once it has been dealt with, it is marked as "
+"such."
+msgstr ""
+"De &debian;-distributie heeft een bugopvolgingssysteem (Bug Tracking System "
+"- BTS) waarin gedetailleerde informatie staat over bugs die door gebruikers "
+"en ontwikkelaars gerapporteerd werden. elke bug krijgt een nummer en wordt "
+"bijgehouden. Als het probleem opgelost is, wordt dit als zodanig "
+"geregistreerd."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:200
+msgid ""
+"Copies of this information are available at <url id=\"http://www.debian.org/"
+"Bugs/\">."
+msgstr ""
+"Een kopie van deze informatie is te vinden op <url id=\"http://www.debian."
+"org/Bugs/\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:204
+msgid ""
+"A mail server provides access to the bug tracking system database via e-"
+"mail. In order to get the instructions, send an e-mail to request@bugs."
+"debian.org with \"help\" in the body."
+msgstr ""
+"Een mailserver biedt toegang tot de database van het bugopvolgingssysteem "
+"via e-mail. Om de richtlijnen te bekomen, kunt u een e-mail sturen naar "
+"request@bugs.debian.org met \"help\" in de berichttekst."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:53 support.sgml:206
+msgid "How do I report a bug in Debian?"
+msgstr "Hoe rapporteer ik in Debian een bug?"
+
+#. type: <p><list>
+#: debian-faq.sgml:53 support.sgml:209
+msgid ""
+"If you have found a bug in Debian, please read the instructions for "
+"reporting a bug in Debian. These instructions can be obtained in one of "
+"several ways:"
+msgstr ""
+"Indien u in Debian een bug gevonden heeft, lees dan de instructies voor het "
+"indienen van een bugrapport in Debian. Deze instructies kunt u op "
+"verschillende plaatsen vinden:"
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:211
+msgid ""
+"From the WWW. A copy of the instructions is shown at <url id=\"http://www."
+"debian.org/Bugs/Reporting\">."
+msgstr ""
+"Op de website. Een exemplaar van de instructies is te vinden op <url id="
+"\"http://www.debian.org/Bugs/Reporting\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:214
+msgid ""
+"On any Debian system with the <package>doc-debian</package> package "
+"installed. The instructions are in the file <file>/usr/share/doc/debian/bug-"
+"reporting.txt</file>."
+msgstr ""
+"Op elk Debian-systeem waarop het pakket <package>doc-debian</package> "
+"geÃ¯nstalleerd is. De instructies bevinden zich in het bestand <file>/usr/"
+"share/doc/debian/bug-reporting.txt</file>."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:217
+msgid ""
+"By anonymous FTP. Debian mirror sites contain the instructions in the file "
+"<tt>doc/bug-reporting.txt</tt>."
+msgstr ""
+"Via anonieme FTP. Op de spiegelservers van Debian bevindt zich het bestand "
+"<tt>doc/bug-reporting.txt</tt> dat de instructies bevat."
+
+#. type: <p></p>
+#: debian-faq.sgml:53 support.sgml:227
+msgid ""
+"You can use the package <package>reportbug</package> that will guide you "
+"through the reporting process and mail the message to the proper address, "
+"with some extra details about your system added automatically. It will also "
+"show you a list of bugs already reported to the package you are reporting "
+"against in case your bug has been reported previously, so that you can add "
+"additional information to the existing bug report."
+msgstr ""
+"U kunt het pakket <package>reportbug</package> gebruiken om u te laten "
+"gidsen door het rapportageproces en het bericht naar het juiste adres te "
+"sturen, terwijl ook nog automatisch wat extra informatie over uw systeem "
+"toegevoegd wordt. Het toont u ook een lijst met bugs die reeds tegen het "
+"pakket waarover u een bug rapporteert, ingediend zijn. Mocht uw probleem "
+"reeds eerder gesignaleerd zijn, dan kunt u eventueel bijkomende informatie "
+"toevoegen aan het bestaande bugrapport."
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:3
+msgid ""
+"Expect to get an automatic acknowledgement of your bug report. It will also "
+"be automatically given a bug tracking number, entered into the bug log and "
+"forwarded to the debian-bugs-dist mailing list."
+msgstr ""
+"U kunt een automatisch ontvangstbericht over uw bugrapport verwachten. Het "
+"rapport zal ook automatisch een bugopvolgingsnummer toegekend krijgen, het "
+"zal toegevoegd worden aan de buglog en doorgestuurd worden naar de "
+"mailinglijst debian-bugs-dist."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:54 contrib.sgml:5
+msgid "Contributing to the Debian Project"
+msgstr "Bijdragen aan het project van Debian"
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:12
+msgid ""
+"<url id=\"&debian-donation;\" name=\"Donations\"> of time (to develop new "
+"packages, maintain existing packages, or provide user support), resources "
+"(to mirror the FTP and WWW archives), and money (to pay for new testbeds as "
+"well as hardware for the archives) can help the project. See also <url id="
+"\"&debian-help;\" name=\"How can you help Debian?\">."
+msgstr ""
+"<url id=\"&debian-donation;\" name=\"Donaties\"> van tijd (om nieuwe "
+"pakketten te ontwikkelen, bestaande pakketten te onderhouden of "
+"gebruikersondersteuning te bieden), hulpbronnen (voor het spiegelen van de "
+"FTP- en WWW-archieven) en geld (voor de aankoop van nieuwe testmachines en "
+"hardware voor de archieven) kunnen een hulp zijn voor het project. Zie ook "
+"<url id=\"&debian-help;\" name=\"Hoe kunt u Debian helpen?\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:54 contrib.sgml:14
+msgid "How can I become a Debian member/Debian developer?"
+msgstr "Hoe kan ik lid/een ontwikkelaar van Debian worden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:20
+msgid ""
+"The development of Debian is open to all, and new users with the right "
+"skills and/or the willingness to learn are needed to maintain existing "
+"packages which have been \"orphaned\" by their previous maintainers, to "
+"develop new packages, to write documentation, to do translation work, to "
+"help with the Debian website, to provide user support, etc."
+msgstr ""
+"Meewerken aan de ontwikkeling van Debian staat open voor iedereen. Nieuwe "
+"gebruikers met de juiste vaardigheden en/of de bereidheid om die te leren "
+"zijn nodig om bestaande pakketten te onderhouden die door hun vorige "
+"onderhouder \"verweesd\" werden, om nieuwe pakketten te ontwikkelen, om "
+"documentatie te schrijven, om vertaalwerk te doen, om te helpen met de "
+"website van Debian, om gebruikersondersteuning te bieden, enz."
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:24
+msgid ""
+"The description of becoming a Debian member can be found at the <url id="
+"\"http://www.debian.org/devel/join/newmaint\" name=\"New Member's Corner\"> "
+"at the Debian web site."
+msgstr ""
+"De beschrijving van hoe u een lid van Debian kunt worden, vindt u op de "
+"website van Debian op <url id=\"http://www.debian.org/devel/join/newmaint\" "
+"name=\"Het hoekje voor nieuwe leden\">"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:54 contrib.sgml:27
+msgid "How can I contribute resources to the Debian project?"
+msgstr "Hoe kan ik met hulpbronnen bijdragen aan het project van Debian?"
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:33
+msgid ""
+"Since the project aims to make a substantial body of software rapidly and "
+"easily accessible throughout the globe, mirrors are needed. It is desirable "
+"but not absolutely necessary to mirror all of the archive. Please visit the "
+"<url id=\"http://www.debian.org/mirror/size\" name=\"Debian mirror size\"> "
+"page for information on the disk space requirements."
+msgstr ""
+"Vermits het project ernaar streeft om een aanzienlijke hoeveelheid software "
+"overal ter wereld snel en gemakkelijk toegankelijk te maken, zijn "
+"spiegelservers nodig. Het verdient de voorkeur, al is het niet absoluut "
+"noodzakelijk om het volledige archief te spiegelen. Raadpleeg de pagina over "
+"<url id=\"http://www.debian.org/mirror/size\" name=\"De grootte van een "
+"Debian spiegelserver\"> voor informatie over vereisten op het gebied van "
+"opslagruimte."
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:37
+msgid ""
+"Most of the mirroring is accomplished entirely automatically by scripts, "
+"without any interaction. However, the occasional glitch or system change "
+"occurs which requires human intervention."
+msgstr ""
+"Het grootste deel van het spiegelen gebeurt zonder enige interactie en "
+"volledig automatisch met behulp van scripts. Toch kan het sporadisch "
+"gebeuren dat een storing of een systeemaanpassing een menselijke tussenkomst "
+"vereist."
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:42
+msgid ""
+"If you have a high-speed connection to the Internet, the resources to mirror "
+"all or part of the distribution, and are willing to take the time (or find "
+"someone) who can provide regular maintenance of the system, then please "
+"contact <email>debian-admin@lists.debian.org</email>."
+msgstr ""
+"Indien u over een snelle internetverbinding beschikt, over voldoende "
+"hulpbronnen om een deel of het geheel van de distributie te spiegelen en "
+"bereid bent de tijd te nemen (of daarvoor iemand te zoeken) om in te staan "
+"voor het regelmatig onderhoud van het systeem, neem dan contact met "
+"<email>debian-admin@lists.debian.org</email>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:54 contrib.sgml:45
+msgid "How can I contribute financially to the Debian project?"
+msgstr "Hoe kan ik op financieel vlak een bijdrage leveren aan Debian?"
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:51
+msgid ""
+"Donations from sponsors allow Debian to have machines, as well as other "
+"hardware, organise conferences and development sprints, amongst other "
+"things. For more information please visit <url id=\"http://www.debian.org/"
+"donations\" name=\"Debian Donations\">. The page also lists the different "
+"methods that can be used to donate."
+msgstr ""
+"Giften van sponsors maken het voor Debian mogelijk om over computers en "
+"andere hardware te beschikken, om conferenties en zogenaamde "
+"ontwikkelingssprints te organiseren, enzovoort. Raadpleeg voor bijkomende "
+"informatie <url id=\"http://www.debian.org/donations\" name=\"Giften aan "
+"Debian\">. Op de pagina staan ook de verschillende manieren vermeld waarop "
+"een donatie kan gebeuren."
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:55
+msgid ""
+"One can make individual donations to organizations that are critical to the "
+"development of the Debian project. The main organization is Software in the "
+"Public Interest, incorporated in the United States, but there are others."
+msgstr ""
+"Men kan individuele donaties geven aan organisaties die cruciaal zijn voor "
+"de ontwikkeling van het Debian-project. De belangrijkste organisatie is "
+"Software in the Public Interest, een vereniging in de Verenigde Staten, maar "
+"er zijn er ook nog andere."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:54 contrib.sgml:57
+msgid "Software in the Public Interest"
+msgstr "Software in the Public Interest"
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:61
+msgid ""
+"Software in the Public Interest (SPI) is an IRS 501(c)(3) non-profit "
+"organization based in the United States. The purpose of the organization is "
+"to develop and distribute free software."
+msgstr ""
+"Software in the Public Interest (SPI) is een onder IRS 501(c)(3) erkende non-"
+"profitorganisatie die gevestigd is in de Verenigde Staten. De vereniging "
+"heeft als doel vrije software te ontwikkelen en te verspreiden."
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:66
+msgid ""
+"It encourages programmers to use the GNU General Public License or other "
+"licenses that allow free redistribution and use of software, and hardware "
+"developers to distribute documentation that will allow device drivers to be "
+"written for their product."
+msgstr ""
+"Ze moedigt programmeurs aan om de 'GNU General Public License' te gebruiken "
+"of andere licenties die de vrije verspreiding en het vrije gebruik van "
+"software toelaten, en hardwareontwikkelaars om documentatie te verspreiden "
+"die het mogelijk maakt om voor hun product een apparaatstuurprogramma te "
+"schrijven."
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:69
+msgid ""
+"SPI acts as a fiscal sponsor to many free and open source projects. The "
+"Debian project has been an associate project since the organization's "
+"creation."
+msgstr ""
+"SPI ontvangt giften met fiscale vrijstelling voor veel projecten van vrije "
+"en open-bronsoftware. Sinds het ontstaan van de organisatie is Debian een "
+"van de geassocieerde projecten."
+
+#. type: <p></p>
+#: debian-faq.sgml:54 contrib.sgml:71
+msgid "SPI can be reached at: <url id=\"http://www.spi-inc.org/\">."
+msgstr "U kunt SPI bereiken op: <url id=\"http://www.spi-inc.org/\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:54 contrib.sgml:73
+msgid "Other organizations"
+msgstr "Andere organisaties"
+
+#. type: <p></p>
+#: debian-faq.sgml:55 redist.sgml:3
+msgid ""
+"There are a number of organizations created in different countries that hold "
+"assets in trust for Debian. The <url id=\"http://www.debian.org/donations\" "
+"name=\"donations page\"> lists the trusted organizations individuals can "
+"donate to. At the time of this writing there are three of them: <url id="
+"\"http://www.ffis.de/\" name=\"Verein zur FÃ¶rderung Freier Informationen & "
+"Software\"> (in Germany), the <url id=\"https://france.debian.net/\" name="
+"\"Debian France Association\"> (in France), and <url id=\"http://debian.ch/"
+"\" name=\"debian.ch\"> (Switzerland and the Principality of Liechtenstein). "
+"Additional affiliate organizations in other countries are listed in <url id="
+"\"https://wiki.debian.org/Teams/Auditor/Organizations\" name=\"Organizations"
+"\"> page in the Debian Wiki."
+msgstr ""
+"Er werden in verschillende landen een aantal organisaties opgericht die "
+"tegoeden voor Debian in beheer houden. De <url id=\"http://www.debian.org/"
+"donations\" name=\"pagina over giften\"> vermeldt de betrouwbare "
+"organisaties waaraan individuen schenkingen kunnen doen. Momenteel zijn dat "
+"er drie: <url id=\"http://www.ffis.de/\" name=\"Verein zur FÃ¶rderung Freier "
+"Informationen & Software\"> (in Duitsland), the <url id=\"https://france."
+"debian.net/\" name=\"Debian France Association\"> (in Frankrijk) en <url id="
+"\"http://debian.ch/\" name=\"debian.ch\"> (Zwitserland en het Vorstendom "
+"Liechtenstein). Bijkomende partnerorganisaties uit andere landen worden "
+"vermeld op de pagina<url id=\"https://wiki.debian.org/Teams/Auditor/"
+"Organizations\" name=\"Organizaties\"> van de Debian Wiki."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:55 redist.sgml:5
+msgid "Redistributing &debian; in a commercial product"
+msgstr "&debian; verspreiden in een commercieel product"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:55 redist.sgml:7
+msgid "Can I make and sell Debian CDs?"
+msgstr "Kan ik Debian CD's maken en verkopen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:55 redist.sgml:14
+msgid ""
+"Go ahead. You do not need permission to distribute anything we have "
+"<em>released</em>, so that you can master your CD as soon as the beta-test "
+"ends. You do not have to pay us anything. Of course, all CD manufacturers "
+"must honor the licenses of the programs in Debian. For example, many of the "
+"programs are licensed under the GPL, which requires you to distribute their "
+"source code."
+msgstr ""
+"Ga uw gang. Uw hoeft geen toestemming te vragen om iets wat we "
+"<em>uitgebracht</em> hebben, te verspreiden, zodat u uw CD kunt samenstellen "
+"van zodra de beta-testen achter de rug zijn. U hoeft ons niet te betalen. "
+"Uiteraard moeten alle fabrikanten van CD's de licenties van de programma's "
+"in Debian respecteren. Zo hebben veel van de programma's bijvoorbeeld een "
+"GPL-licentie, die vereist dat u de broncode ervan verspreidt."
+
+#. type: <p></p>
+#: debian-faq.sgml:55 redist.sgml:18
+msgid ""
+"Also, we will publish a list of CD manufacturers who donate money, software, "
+"and time to the Debian project, and we will encourage users to buy from "
+"manufacturers who donate, so it is good advertising to make donations."
+msgstr ""
+"Ook publiceren we een lijst van CD--fabrikanten die geld, software en tijd "
+"doneren aan het Debian-project en moedigen we gebruikers aan hun aankopen te "
+"doen bij fabrikanten die doneren. Doneren is dus een goede "
+"advertentiestrategie."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:55 redist.sgml:20
+msgid "Can Debian be packaged with non-free software?"
+msgstr "Kan Debian samen met niet-vrije software verpakt worden?"
+
+#. type: <p></p>
+#: debian-faq.sgml:55 redist.sgml:24
+msgid ""
+"Yes. While all the main components of Debian are free software, we provide a "
+"non-free directory for programs that are not freely redistributable."
+msgstr ""
+"Ja. Hoewel alle belangrijke componenten van Debian vrije software zijn, "
+"stellen we ook een map 'non-free' ter beschikking voor programma's die niet "
+"vrij mogen verspreid worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:55 redist.sgml:33
+msgid ""
+"CD manufacturers <em>may</em> be able to distribute the programs we have "
+"placed in that directory, depending on the license terms or their private "
+"arrangements with the authors of those software packages. CD manufacturers "
+"can also distribute the non-free software they get from other sources on the "
+"same CD. This is nothing new: free and commercial software are distributed "
+"on the same CD by many manufacturers now. Of course we still encourage "
+"software authors to release the programs they write as free software."
+msgstr ""
+"<em>Mogelijk</em> verkeren CD-fabrikanten in de mogelijkheid de programma's "
+"die we in die map geplaatst hebben, te verspreiden, afhankelijk van de "
+"bepalingen in de licentie of hun eigen overeenkomst met de auteurs van deze "
+"softwarepakketten. CD-fabrikanten kunnen ook de niet-vrije software die ze "
+"uit andere bronnen betrekken, op dezelfde CD verspreiden. Dat is niets "
+"nieuws: vrije en commerciÃ«le software wordt nu reeds door veel fabrikanten "
+"op dezelfde CD verspreid. Uiteraard blijven we auteurs van software "
+"aanmoedigen om de programma's die ze schrijven uit te brengen als vrije "
+"software."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:55 redist.sgml:37
+msgid ""
+"I am making a special Linux distribution for a \"vertical market\". Can I "
+"use &debian; for the guts of a Linux system and add my own applications on "
+"top of it?"
+msgstr ""
+"I maak een speciale Linux-distributie voor een \"verticale markt\". Kan ik "
+"&debian; gebruiken als Linux-basissysteem met daarbovenop mijn eigen "
+"toepassingen?"
+
+#. type: <p></p>
+#: debian-faq.sgml:55 redist.sgml:44
+msgid ""
+"Yes. Debian-derived distributions are being created both in close "
+"cooperation with the Debian project itself and by external parties. One can "
+"use the <url id=\"https://www.debian.org/blends/\" name=\"Debian Pure Blends"
+"\"> framework to work together with Debian; <url id=\"https://wiki.debian."
+"org/DebianEdu/\" name=\"DebianEdu/Skolelinux\"> is one such project."
+msgstr ""
+"Ja. Van Debian afgeleide distributies worden zowel in nauwe samenwerking met "
+"het Debian-project zelf gebouwd als door externe partijen. Men kan het "
+"raamwerk voor <url id=\"https://www.debian.org/blends/\" name="
+"\"Doelgroepspecifieke uitgaves van Debian (Debian Pure Blends)\"> gebruiken "
+"om met Debian samen te werken. Het project <url id=\"https://wiki.debian.org/"
+"DebianEdu/\" name=\"DebianEdu/Skolelinux\"> is een dergelijk project."
+
+#. type: <p></p>
+#: debian-faq.sgml:55 redist.sgml:50
+msgid ""
+"There are several other Debian-derived distributions already on the market, "
+"such as grml, LMDE (Linux Mint Debian Edition), Knoppix and Ubuntu, that are "
+"targeted at a different kind of audience than the original &debian; is, but "
+"use most of our components in their product."
+msgstr ""
+"Er zijn reeds verschillende van Debian afgeleide distributies op de markt, "
+"zoals grml, LMDE (Linux Mint Debian Edition), Knoppix en Ubuntu, die zich "
+"tot een ander type doelgroep richten dan het originele &debian;, maar de "
+"meeste van onze componenten gebruiken in hun product."
+
+#. type: <p></p>
+#: debian-faq.sgml:55 redist.sgml:55
+msgid ""
+"Debian also provides a mechanism to allow developers and system "
+"administrators to install local versions of selected files in such a way "
+"that they will not be overwritten when other packages are upgraded. This is "
+"discussed further in the question on <ref id=\"divert\">."
+msgstr ""
+"Debian beschikt ook over een mechanisme dat ontwikkelaars en "
+"systeembeheerders toelaat om van specifieke bestanden een lokale versie te "
+"installeren zodanig dat zie niet overschreven worden wanneer andere "
+"pakketten opgewaardeerd worden. Dit wordt verder besproken onder het thema "
+"<ref id=\"divert\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:55 redist.sgml:58
+msgid ""
+"Can I put my commercial program in a Debian \"package\" so that it installs "
+"effortlessly on any Debian system?"
+msgstr ""
+"Kan ik mijn commercieel programma in een Debian-\"pakket\" verpakken, zodat "
+"het probleemloos geÃ¯nstalleerd kan worden op een Debian-systeem?"
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:3
+msgid ""
+"Go right ahead. The package tool is free software; the packages may or may "
+"not be free software, it can install them all."
+msgstr ""
+"Ga uw gang. Het pakketgereedschap is vrije software. Pakketten kunnen al dan "
+"niet vrije software zijn, maar het pakketgereedschap zal beide installeren."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:56 nexttime.sgml:5
+msgid "Changes expected in the next major release of Debian"
+msgstr "Verwachte wijzigingen in de volgende hoofdrelease van Debian"
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:12
+msgid ""
+"With each new release, the Debian project tries to focus on a set of topics. "
+"These are known as \"Release Goals\" and they are all described in <url id="
+"\"https://wiki.debian.org/ReleaseGoals/\">. Please note that the following "
+"sections might not be fully up-to-date, please refer to the Wiki for more "
+"information and the up-to-date status of these goals."
+msgstr ""
+"Bij elke nieuwe release tracht het Debian-project te focussen op een aantal "
+"topics. Deze zijn gekend onder de noemer \"Release-doelstellingen\" (Release "
+"Goals) en ze worden allemaal beschreven in <url id=\"https://wiki.debian.org/"
+"ReleaseGoals/\">. Merk op dat de volgende onderdelen niet volledig up-to-"
+"date kunnen zijn. Wend u tot de Wiki voor bijkomende informatie en de "
+"actuele toestand betreffende deze doelstellingen."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:56 nexttime.sgml:14
+msgid "Hardening the system"
+msgstr "De beveiliging van het systeem versterken"
+
+#. type: <p><list>
+#: debian-faq.sgml:56 nexttime.sgml:17
+msgid ""
+"It is a goal for the Debian project to ensure that any system installed is "
+"hardened and secure against attacks. There are several ways to achieve this, "
+"which include:"
+msgstr ""
+"Het Debian-project stelt zich tot doel te verzekeren dat elk geÃ¯nstalleerd "
+"systeem tegen aanvallen gewapend en beschermd is. Op verschillende manieren "
+"kan dit gerealiseerd worden, waaronder:"
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:24
+msgid ""
+"Improve programs' security by compiling them with <url id=\"https://wiki."
+"debian.org/ReleaseGoals/SecurityHardeningBuildFlags\" name=\"Security "
+"Hardening Build Flags\"> in order to enable various protections against "
+"known security issues,"
+msgstr ""
+"De beveiliging van programma's verbeteren door ze te compileren met <url id="
+"\"https://wiki.debian.org/ReleaseGoals/SecurityHardeningBuildFlags\" name="
+"\"Security Hardening Build Flags\"> om ze te beschermen tegen verschillende "
+"bekende veiligheidsproblemen,"
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:27
+msgid ""
+"Improve the default system configuration to make it less vulnerable to "
+"attacks (both local or remote),"
+msgstr ""
+"De standaard systeemconfiguratie verbeteren om het systeem minder kwetsbaar "
+"te maken voor aanvallen (zowel van binnenuit als van buitenaf),"
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:29
+msgid "Enable security features delivered by new versions of the kernel."
+msgstr ""
+"Activeren van beveiligingsvoorzieningen die door nieuwe kernelversies "
+"geboden worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:41
+msgid ""
+"All of these are done in an ongoing basis. For the first item, a set of "
+"security hardening build flags that try to prevent known attacks such as "
+"stack smashing, predictable locations of values in memory, etc. is used. The "
+"target is to cover at least all packages that are part of the basic "
+"installation as well as packages that had to be updated through a Security "
+"Advisory since 2006. As of this writing, around 400 packages have been "
+"modified since this effort was first started. All the issues are <url id="
+"\"https://bugs.debian.org/cgi-bin/pkgreport.cgi?tag=goal-hardening;"
+"users=hardening-discuss@lists.alioth.debian.org\" name=\"tracked in the BTS"
+"\">."
+msgstr ""
+"Al deze maatregelen worden op permanente basis genomen. Wat het eerste "
+"aspect betreft, worden een aantal veiligheidsverhogende compilatievlaggen "
+"gebruikt, die een aantal gekende types aanvallen trachten te voorkomen, "
+"zoals overloop van de stack, voorspelbaarheid van de plaats in het geheugen "
+"van bepaalde waarden, enz. De doelstelling is om dit minstens te realiseren "
+"voor alle pakketten die deel uitmaken van een standaardinstallatie en voor "
+"de pakketten die sinds 2006 een opwaardering hebben gehad omwille van een "
+"beveiligingsprobleem. Momenteel werden ongeveer 400 pakketten aangepast "
+"sinds het begin van deze actie. Alle problemen worden <url id=\"https://bugs."
+"debian.org/cgi-bin/pkgreport.cgi?tag=goal-hardening;users=hardening-"
+"discuss@lists.alioth.debian.org\" name=\"in het BTS opgevolgd\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:56 nexttime.sgml:43
+msgid "Extended support for non-English users"
+msgstr "Verbeterde ondersteuning voor niet-Engelstalige gebruikers"
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:46
+msgid ""
+"Debian already has very good support for non-English users, see <ref id="
+"\"nonenglish\">."
+msgstr ""
+"Debian biedt reeds een zeer goede ondersteuning voor niet-Engelstalige "
+"gebruikers. Zie <ref id=\"nonenglish\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:52
+msgid ""
+"We hope to find people who will provide support for even more languages, and "
+"translate programs and documents. Many programs and Debian-specific "
+"documents already support internationalization, so we need message catalogs "
+"translators. However, still some programs remain to be properly "
+"internationalized."
+msgstr ""
+"We hopen mensen te kunnen vinden die ondersteuning kunnen bieden voor nog "
+"meer talen en programma's en documentatie kunnen vertalen. Veel programma's "
+"en Debian-specifieke documenten zijn reeds voorbereid op "
+"internationalisering, en dus hebben we nood aan vertalers van "
+"berichtencatalogussen. Sommige programma's moeten echter nog steeds goed "
+"klaargemaakt worden voor internationalisering."
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:60
+msgid ""
+"The GNU Translation Project <url id=\"ftp://ftp.gnu.org/pub/gnu/ABOUT-NLS\"> "
+"works on internationalizing the GNU programs and different projects, such as "
+"the Desktop environments GNOME or KDE have their own translation teams. The "
+"goal of Debian is not to replace or to repeat the work done by these "
+"projects, indeed, Debian benefits from the work done by translators in these "
+"projects. However, there are still many programs which are not in the scope "
+"of those projects and which are translated within Debian."
+msgstr ""
+"Het vertalingsproject van GNU (GNU Translation Project) <url id=\"ftp://ftp."
+"gnu.org/pub/gnu/ABOUT-NLS\"> werkt aan de internationalisering van de GNU-"
+"programma's en verschillende andere projecten, zoals de desktopomgevingen "
+"GNOME en KDE, beschikken over hun eigen vertalingsteams. Debian stelt zich "
+"niet tot doel om het werk dat door deze projecten geleverd wordt, te "
+"vervangen of over te doen. Debian geniet namelijk mee van het vertaalwerk "
+"dat in deze projecten door de vertalers geleverd wordt. Er zijn echter "
+"steeds nog veel programma's die buiten het bereik van deze projecten vallen "
+"en die binnen Debian vertaald worden."
+
+#. type: <p><list>
+#: debian-faq.sgml:56 nexttime.sgml:61
+msgid "Previous Debian releases have focused in topics such as:"
+msgstr "Eerdere releases van Debian hebben gefocust op zaken zoals:"
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:65
+msgid ""
+"I18n support in all debconf-using packages: Packages using the Debian "
+"configuration management must allow for translation of all messages "
+"displayed to the user during package configuration."
+msgstr ""
+"I18n-ondersteuning (meertalige ondersteuning) in alle pakketten die debconf "
+"gebruiken: pakketten die gebruik maken van het systeem voor "
+"configuratiebeheer van Debian, moeten voorzien in de mogelijkheid dat alle "
+"meldingen die de gebruiker te zien krijgt tijdens het configureren van het "
+"pakket, vertaald worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:67
+msgid ""
+"I18n support for package descriptions: Update package management frontends "
+"to use the translated descriptions of packages."
+msgstr ""
+"I18n-ondersteuning (meertalige ondersteuning) voor pakketbeschrijvingen: "
+"frontends voor pakketbeheer opwaarderen zodat ze de vertalingen van "
+"pakketbeschrijvingen gaan gebruiken."
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:69
+msgid ""
+"UTF-8 debian/changelog and debian/control. This way, e.g. names of people "
+"from asian countries can get typeset the right way in changelogs."
+msgstr ""
+"Naar UTF-8 omzetten van debian/changelog en debian/control. Op die manier "
+"kunnen de namen van mensen uit Aziatische landen bijvoorbeeld in changelogs "
+"op een correcte manier geschreven worden."
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:71
+msgid ""
+"I18n support in the Debian Installer including full support for some "
+"languages that require the use of the graphical interface."
+msgstr ""
+"I18n-ondersteuning (meertalige ondersteuning) voor het installatiesysteem "
+"van Debian, met inbegrip van ondersteuning voor bepaalde talen waarbij het "
+"gebruik van de grafische interface vereist is."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:56 nexttime.sgml:77
+msgid "Improvements in the Debian Installer"
+msgstr "Verbeteringen aan het installatiesysteem van Debian"
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:80
+msgid ""
+"Lots of work has been done on the Debian Installer, resulting in major "
+"improvements. We'll mention just two of them here."
+msgstr ""
+"Er werd veel werk verricht aan het installatiesysteem van Debian, wat geleid "
+"heeft tot belangrijke verbeteringen. We zullen er hier slechts twee "
+"vermelden."
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:85
+msgid ""
+"Starting the installer from Microsoft Windows: It is now possible to start "
+"the installer directly from Microsoft Windows without the need to change "
+"BIOS settings. Upon insertion of a CD-ROM, DVD-ROM or USB stick, an autorun "
+"program will be started, offering a step-by-step process to start the Debian "
+"Installer."
+msgstr ""
+"Het opstarten van het installatiesysteem vanuit Microsoft Windows: het is nu "
+"mogelijk om het installatiesysteem rechtstreeks op te starten vanuit  "
+"Microsoft Windows zonder dat wijzigingen aan de BIOS-instellingen nodig "
+"zijn. Bij het invoeren van een CD, DVD of USB-stick start automatisch een "
+"programma op dat een stapsgewijs proces biedt voor het opstarten van het "
+"installatiesysteem van Debian."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:56 nexttime.sgml:87
+msgid "More architectures"
+msgstr "Meer architecturen"
+
+#. type: <p></p>
+#: debian-faq.sgml:56 nexttime.sgml:91
+msgid ""
+"Complete Debian system on other architectures. Notice that even though some "
+"architectures are dropped for a given release, there still might be a way to "
+"install and upgrade using the latest <tt>sid</tt>."
+msgstr ""
+"Het volledige Debian-systeem op andere architecturen. Merk op dat, hoewel de "
+"ondersteuning voor sommige architecturen bij een bepaalde release soms "
+"wegvalt, er mogelijk nog steeds een manier kan zijn om een installatie uit "
+"te voeren en deze op te waarderen met de meest recente <tt>sid</tt>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:56 nexttime.sgml:93
+msgid "More kernels"
+msgstr "Mer kernels"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:3
+msgid ""
+"In addition to Debian GNU/Hurd, Debian is being ported also to BSD kernels, "
+"namely to <url id=\"http://www.debian.org/ports/kfreebsd-gnu/\" name="
+"\"FreeBSD\">. This port runs on both AMD64 (\"kfreebsd-amd64\") and "
+"traditional Intel (\"kfreebsd-i386\")."
+msgstr ""
+"Naast het geschikt maken van de distributie voor Debian GNU/Hurd, wordt "
+"Debian ook geschikt gemaakt voor BSD-kernels, namelijk voor <url id=\"http://"
+"www.debian.org/ports/kfreebsd-gnu/\" name=\"FreeBSD\">. Deze zogenaamde "
+"'port' functioneert zowel met AMD64- (\"kfreebsd-amd64\") als met de "
+"traditionele Intel-processors (\"kfreebsd-i386\")."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:57 faqinfo.sgml:5
+msgid "General information about the FAQ"
+msgstr "Algemene informatie over de FAQ"
+
+#. type: <heading></heading>
+#: debian-faq.sgml:57 faqinfo.sgml:7
+msgid "Authors"
+msgstr "Auteurs"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:13
+msgid ""
+"The first edition of this FAQ was made and maintained by J.H.M. Dassen (Ray) "
+"and Chuck Stickelman. Authors of the rewritten &debian; FAQ are Susan G. "
+"Kleinmann and Sven Rudolph. After them, the FAQ was maintained by Santiago "
+"Vila and, later, by Josip Rodin. The current maintainer is Javier Fernandez-"
+"Sanguino."
+msgstr ""
+"De eerste editie van deze FAQ werd gemaakt en onderhouden door J.H.M. Dassen "
+"(Ray) en Chuck Stickelman. De auteurs van de herwerkte &debian; FAQ zijn "
+"Susan G. Kleinmann en Sven Rudolph. Na hen werd de FAQ onderhouden door "
+"Santiago Vila en later door Josip Rodin. De huidige onderhouder is Javier "
+"Fernandez-Sanguino."
+
+#. type: <p><list>
+#: debian-faq.sgml:57 faqinfo.sgml:14
+msgid "Parts of the information came from:"
+msgstr "Delen van de informatie zijn afkomstig uit:"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:15
+msgid ""
+"The Debian-1.1 release announcement, by <url id=\"http://www.perens.com/\" "
+"name=\"Bruce Perens\">,"
+msgstr ""
+"De release-aankondiging van Debian-1.1 door <url id=\"http://www.perens.com/"
+"\" name=\"Bruce Perens\">,"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:16
+msgid ""
+"the Linux FAQ, by <url id=\"http://www.chiark.greenend.org.uk/~ijackson/\" "
+"name=\"Ian Jackson\">,"
+msgstr ""
+"de Linux-FAQ door <url id=\"http://www.chiark.greenend.org.uk/~ijackson/\" "
+"name=\"Ian Jackson\">,"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:17
+msgid ""
+"<url id=\"http://lists.debian.org/\" name=\"Debian Mailing Lists Archives\">,"
+msgstr ""
+"<url id=\"http://lists.debian.org/\" name=\"De archieven van de "
+"mailinglijsten van Debian\">,"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:19
+msgid ""
+"the dpkg programmers' manual and the Debian Policy manual (see <ref id="
+"\"debiandocs\">),"
+msgstr ""
+"de handleiding voor de programmeurs van dpkg en het Beleidshandboek van "
+"Debian (zie <ref id=\"debiandocs\">),"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:20
+msgid "many developers, volunteers, and beta testers,"
+msgstr "vele ontwikkelaars, vrijwilligers en testers van bÃ¨ta-releases,"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:21
+msgid "the flaky memories of its authors. :-)"
+msgstr "het onbetrouwbare geheugen van zijn auteurs. :-)"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:25
+msgid ""
+"and the <url id=\"http://KamarajuKusumanchi.github.io/"
+"choosing_debian_distribution/choosing_debian_distribution.html\" name="
+"\"Choosing a Debian distribution FAQ\">, which Kamaraju Kusumanchi "
+"graciously released under the GPL, so it could be included as a new chapter "
+"(see <ref id=\"choosing\">)."
+msgstr ""
+"en de <url id=\"http://KamarajuKusumanchi.github.io/"
+"choosing_debian_distribution/choosing_debian_distribution.html\" name=\"FAQ "
+"over het kiezen van een Debian-distributie\">, die Kamaraju Kusumanchi zo "
+"vriendelijk was uit te geven onder de GPL-licentie, zodat hij opgenomen kon "
+"worden als een nieuw hoofdstuk (zie <ref id=\"choosing\">)."
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:30
+msgid ""
+"The authors would like to thank all those who helped make this document "
+"possible."
+msgstr ""
+"De auteurs houden eraan al wie meehielp aan het realiseren van dit document, "
+"te bedanken. De Nederlandse vertaling van deze FAQ is van de hand van Frans "
+"Spiesschaert (2017). Mocht u in deze vertaling een fout aantreffen, "
+"signaleer ze dan alstublieft met een e-mailbericht aan <email>debian-l10n-"
+"dutch@lists.debian.org</email>."
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:33
+msgid ""
+"All warranties are disclaimed. All trademarks are property of their "
+"respective trademark owners."
+msgstr ""
+"Er wordt op geen enkel manier een garantie geboden. Alle handelsmerken zijn "
+"eigendom van hun respectieve eigenaars."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:57 faqinfo.sgml:35
+msgid "Feedback"
+msgstr "Feedback"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:41
+msgid ""
+"Comments and additions to this document are always welcome. Please send e-"
+"mail to <email>doc-debian@packages.debian.org</email>, or submit a wishlist "
+"bug report against the <package><url id=\"http://bugs.debian.org/debian-faq"
+"\" name=\"debian-faq\"></package> package."
+msgstr ""
+"Commentaar en toevoegingen bij dit document blijven welkom. Stuur een e-mail "
+"naar <email>doc-debian@packages.debian.org</email>, of dien een wens-"
+"probleemrapport (wishlist bug report) in tegen het pakket <package><url id="
+"\"http://bugs.debian.org/debian-faq\" name=\"debian-faq\"></package>."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:57 faqinfo.sgml:43
+msgid "Availability"
+msgstr "Beschikbaarheid"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:46
+msgid ""
+"The latest version of this document can be viewed on the Debian WWW pages at "
+"<url id=\"http://www.debian.org/doc/FAQ/\">."
+msgstr ""
+"De recentste versie van dit document kan geraadpleegd worden op de WWW-"
+"pagina's van Debian op <url id=\"http://www.debian.org/doc/FAQ/\">."
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:50
+msgid ""
+"It is also available for download in plain text, HTML, PostScript and PDF "
+"formats at <url id=\"http://www.debian.org/doc/user-manuals#faq\">. Also, "
+"there are several translations there."
+msgstr ""
+"Het kan ook gedownload worden in platte tekst, HTML, PostScript en PDF-"
+"formaat op <url id=\"http://www.debian.org/doc/user-manuals#faq\">. Daar "
+"zijn ook verschillende vertalingen ervan te vinden."
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:54
+msgid ""
+"This document is available in the <package>debian-faq</package> package. "
+"Translations are available in <package>debian-faq-de</package>, "
+"<package>debian-faq-fr</package> and other packages."
+msgstr ""
+"Dit document is te vinden in het pakket <package>debian-faq</package>. "
+"Vertalingen ervan zijn te vinden in <package>debian-faq-de</package>, "
+"<package>debian-faq-fr</package> en in andere pakketten."
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:59
+msgid ""
+"The original SGML files used to create this document are also available in "
+"<package>debian-faq</package>'s source package, or in SVN at: <tt>svn://svn."
+"debian.org/svn/ddp/manuals/trunk/debian-faq</tt> and <url id=\"http://svn."
+"debian.org/viewsvn/ddp/manuals/trunk/debian-faq/\">."
+msgstr ""
+"De originele SGML-bestanden die gebruikt werden om dit document te maken, "
+"zijn ook te vinden in het bronpakket van <package>debian-faq</package> of in "
+"SVN op: <tt>svn://svn.debian.org/svn/ddp/manuals/trunk/debian-faq</tt> en "
+"<url id=\"http://svn.debian.org/viewsvn/ddp/manuals/trunk/debian-faq/\">."
+
+#. type: <heading></heading>
+#: debian-faq.sgml:57 faqinfo.sgml:61
+msgid "Document format"
+msgstr "Bestandsformaat van het document"
+
+#. type: <p></p>
+#: debian-faq.sgml:57 faqinfo.sgml:66
+msgid ""
+"This document was written using the DebianDoc SGML DTD (rewritten from "
+"LinuxDoc SGML). DebianDoc SGML systems enables us to create files in a "
+"variety of formats from one source, e.g. this document can be viewed as "
+"HTML, plain text, TeX DVI, PostScript, PDF, or GNU info."
+msgstr ""
+"Dit document werd geschreven in het bestandsformaat DebianDoc SGML DTD (een "
+"herwerking van LinuxDoc SGML). De DebianDoc SGML-systemen laten ons toe om "
+"vanuit een bronformaat bestanden aan te maken in verschillende "
+"bestandsformaten: dit document bijvoorbeeld kan bekeken worden in de "
+"bestandsformaten HTML, platte tekst, TeX DVI, PostScript, PDF en GNU info."
+
+#. type: <p></p>
+#: debian-faq.sgml:58
+msgid ""
+"Conversion utilities for DebianDoc SGML are available in Debian package "
+"<package>debiandoc-sgml</package>."
+msgstr ""
+"Conversiehulpprogramma's voor DebianDoc SGML zijn te vinden in het pakket "
+"<package>debiandoc-sgml</package> van Debian."
+
+#~ msgid "28 August 2016"
+#~ msgstr "28 augustus 2016"
